/*   Copyright(c) Verifone, Inc 2005 -- All rights reserved */
/**********************************************************************
loadXsltTransformer(stylesheet)

sets up a transformer, ready to create a processor for XSLT.

@param stylesheet [string] the path to the stylesheet

@returns  IXSLTemplate

**********************************************************************/

function loadXsltTransformer(stylesheet) {

	var xslt = new ActiveXObject ("MSXML2.FreeThreadedDOMDocument.6.0");	
	xslt.async = false;
	xslt.load(stylesheet);
	var transformer = new ActiveXObject("MSXML2.XSLTemplate.6.0");
	transformer.stylesheet = xslt.documentElement;
	return transformer;
}


/**********************************************************************
loadXsltProcessor(stylesheet)
 
 Used to create a xslt processor.
 
 @param stylesheet [string] the path to the stylesheet
 
 @returns IXSLProcessor
 
**********************************************************************/

function loadXsltProcessor(stylesheet) {
	var transformer = loadXsltTransformer(stylesheet);
	return transformer.createProcessor();
}


/**********************************************************************
manageLogFiles(maxSize)

Used to "age" and rotate the 10 log files in C:\logs.
Can be called at the beginning or end of a session. 
If the "PDK-BO.log0" file exceeds the maxSize then all the 
files are shifted and the last file PDK-BO.log9 will fall off.
Will also create logDir if it doesn't already exist.
Will also create logFile if it doesn't already exist.

@param maxSize [int] specifies the maximum size the file 
	can reach before it is aged. If omitted the maxSize is
	defaulted to 10K
	
@return NONE

**********************************************************************/
function manageLogFiles(maxSize){

	mkdir(logDir);
		
	if (maxSize == null){
		maxSize = 10000;
	}
	if ( fso.FileExists(logDir + "\\" + logFile)){
		var f = fso.GetFile(logDir + "\\" + logFile);
		if (f.Size > maxSize){
		
			for (var i = 9; i >= 0; i--){
				if (fso.FileExists(logDir + "\\" + logFilePrefix + "." + logFileExt + i)){
					f = fso.GetFile(logDir + "\\" + logFilePrefix + "." + logFileExt + i);
					if ( f.attributes & 1){
						f.attributes = f.attributes - 1;
					}
					if (i != 9){
						f.Copy(logDir + "\\" + logFilePrefix + "." + logFileExt + (i + 1), true);
					}
					if (i == 0){
						var ts = fso.CreateTextFile(logDir + "\\" + logFile);
						ts.Close();	
					}
				}
			}
		}

	}else{
		var ts = fso.CreateTextFile(logDir + "\\" + logFile);
		ts.Close();	
	}
}

/**********************************************************************
getExecPath()

Get the path to the spot where the executable is running.  
This is useful for locating stylesheets and other runtime 
program resources that are positioned relative to where 
the script file is located as opposed to the current working 
directory.

@return the path where the executing script is located, 
includes a trailing \\.
**********************************************************************/
function getExecPath()
{
	var n = WScript.ScriptName;
	var fn = WScript.ScriptFullName;
	var strArray = fn.split(n);

	var execDir = strArray[0];
	return execDir;
}

/**********************************************************************
checkEXE()

Checks to see whether the script was launched using 
CScript.exe or WScript.exe. 
NOTE:
stdIn, stdOut and stdErr are only supported under 
CScript.exe

@return 
	false if WScript.exe was used to launch the script.
	true if CScript.exe was used to launch the script.
**********************************************************************/
function checkEXE(){

	if (WScript.FullName.toLowerCase().search(/wscript.exe$/) != -1) {
		return false;
	} else {
		return true;
	}
}

/**********************************************************************
writeOutput(output)

Checks the arguments to determine where to write the
output to. 
If (/out: exists && = = '' ) || ( /out: doesn't exist)  then writes 
	to stdOut
else assumes it is to be written to a file pointed to by the
	value of /out: The file will be created overwritting existing data.
	
@param output [string] to be written out.

@return NONE

**********************************************************************/
function writeOutput(output){
	if (	(WScript.Arguments.Named.Exists("out") && WScript.Arguments.Named("out") == '') || (!WScript.Arguments.Named.Exists("out"))){
		WScript.StdOut.Write(output);
	}else {
		var ts = fso.CreateTextFile(WScript.Arguments.Named("out"), true);
		ts.Write(output);
		ts.Close();
	}
}

/**********************************************************************
getInput()

Checks the arguments to determine where to read the
input from. 
If (/in: exists && = = '-' ) || ( /in: doesn't exist)  then reads 
	from stdIn
else assumes it is to be read from a file pointed to by the
	value of /in:

@param secs[integer]: OPTIONAL number of seconds to read from stdIn.
	This argument has no effect when reading from a file. 
	If the seconds expire an exception is thrown. By default the number
	of seconds getInput attempts to read from stdIn is 60.

@returns the input as a string

@throws exception 
	1) IF secs is NaN [err # 501]
	2) IF secs expire before the read is completed [err # 502]
	3) When objects cannot be created. [err # from OS]


**********************************************************************/
function getInput(secs){
	var input = "";
	var err = new Error();
	var eDate = null;
	var s = null;

	err.name = 'getInput()';
	err.number = 400;


	if (secs == null){
		s = new Number(60000);
	}else{
		s = new Number((secs * 1000));
	}

	if (isNaN(parseInt(s))){
		err.number += 1;
		err.description = 'secs is NaN';
		err.message = 'The value of secs is Not a Number (NaN)';
		throw(err);
	}


	if ((WScript.Arguments.Named.Exists("in") && WScript.Arguments.Named("in") == '-') || (!WScript.Arguments.Named.Exists("in"))){
		eDate = new Date(new Date().getTime() + s);
		while (!WScript.StdIn.AtEndOfStream){
			input += WScript.StdIn.Read(1024);
			if (new Date().getTime() >= eDate.getTime()){
				err.number += 2;
				err.description = 'Time Out';
				err.message = 'Timed out before completing the read from stdIn';
				throw(err);				
			}
		}
	}else {
		var f = fso.GetFile(WScript.Arguments.Named("in"));
		var ts = f.OpenAsTextStream(1, -2);	
		input += ts.ReadAll();
		ts.Close();
	}
	return input;
}

/**********************************************************************
createConnection(base, method, cgiApp, queryString)

Used to create and open a HTTP connection. A null must be 
passed for each optional argument. This function does not 
verify in anyway that base is correct, only that it is not null.
Nor does it validate the contents of queryString.

@param base[string]: is REQUIRED and points to a URL, 
	including the protocol prefix, of a sapphire e.g.: 
	http://sapphire 
		OR 
	http://192.168.31.11 
		OR 
	https://192.168.31.11, etc...
	NOTE: all requests for data in or out of a Sapphire are
	HTTP or HTTPS any other protocol will result in errors 
	and/or exceptions.
@param method [string]: is REQUIRED and can be only "POST" 
	or "GET"	

@param cgiApp [string]: is OPTIONAL and should indicate which 
	CGI application, available on Sapphire, will service the 
	request. i.e.: CGILink, CGIUplink, etc... 
	If the argument is not present/null CGILink is the default
	
@param queryString [string]: is OPTIONAL only  if cgiApp 
	is not equal to CGILink. If passed MUST contain all 
	required name/value pairs to GET/POST data 
	from/to Sapphire. e.g.:
	cmd=validate&user=foo&passwd=foo
		OR
	cmd=vdealcfg&cookie=abc123

@return IServerXMLHTTP object

@throws exception 
	1) IF base == null [err # 101]
	2) IF method is something other then POST or GET [err # 102]
	3) IF cgiApp is not valid [err # 103]
	4) IFcgiApp == 'CGILink' && 	queryString == null [err # 104]
	5) When object cannot be created. [err # from OS]
	6) When connection can't be opened. [err # from OS]
	
	
**********************************************************************/
function createConnection(base, method, cgiApp, queryString){
var err = new Error();
	err.name = 'createConnection()';
	err.number = 100;
	err.base = base;
	err.method = method;
	err.cgiApp = cgiApp;
	err.queryString = queryString;

var oHttp = new ActiveXObject("MSXML2.ServerXMLHTTP.6.0");
	oHttp.setOption( 3, '');
	oHttp.setTimeouts (60000, 60000, 300000, 300000);
var sURL = "";

	if (base == null){
		err.number += 1;
		err.description = 'base is null';
		err.message = 'base is required and is null';
		throw(err);
	}
	if (method != "GET" && method != "POST"){
		err.number += 2;
		err.description = 'incorrect method';
		err.message = 'method must be either POST or GET';
		throw(err);
	}
	if ((cgiApp !='CGIUplink' && cgiApp !='CGILink' && cgiApp !='CGIPLULink' && cgiApp !='NAXML') ||  (cgiApp == null)){
		err.number += 3;
		err.description = 'incorrect cgiApp';
		err.message = 'cgiApp must be one of the following CGILink, CGIUplink, CGIPLULink or NAXML';
		throw(err);
	}
	if (cgiApp =='CGILink' && queryString == null){
		err.number += 4;
		err.description = 'queryString missing';
		err.message = 'queryString is required if cgiApp is equal CGILink';
		throw(err);
	}
	
	if (cgiApp == 'CGILink'){
		sURL = base + '/' +'cgi-bin/' + cgiApp + '?' + queryString;
	}else{
		if (queryString == null || queryString == ''){
			sURL = base + '/' +'cgi-bin/' + cgiApp;
		}else{
			sURL = base + '/' +'cgi-bin/' + cgiApp + '?' + queryString;
		}
	}

	oHttp.open(method, sURL, false);

	return oHttp;
}

/**********************************************************************
validate()

Used to get a credential, even when the /cmd: argument
is not validate and there is no /cookie: argument.
Validate calls  createConnection

@return DOMDocument containing the credential

@throws exceptions
	1) IF a fault document is returned from Sapphire [err # 201]
	2) IF the credential is empty [err # 202]
	3) IF /user: == null [err # 203]
	4) IF /passwd: == null [err # 204]
	5) IF /base: == null  [err # 205]
	6) Any exceptions generated by createConnection()
**********************************************************************/
function validate(){
var base = null;
var user = null;
var passwd = null;
var oHttp = null;
var cgiApp = "CGILink";
var queryString = null;
var err = new Error();
	err.name = 'validate()';
	err.number = 200;
	if (!WScript.Arguments.Named.Exists("user") ){
		err.number += 3;
		err.description = 'user missing';
		err.message = 'user is required for validate command';
		throw(err);
	}else{
		user = WScript.Arguments.Named("user");
	}
	
	if (!WScript.Arguments.Named.Exists("passwd") ){
		err.number += 4;
		err.description = 'passwd missing';
		err.message = 'passwd is required for validate command';
		throw(err);
	}else{
		passwd = WScript.Arguments.Named("passwd");
	}
	if (!WScript.Arguments.Named.Exists("base") ){
		err.number += 5;
		err.description = 'base missing';
		err.message = 'base is required for all commands';
		throw(err);
	}else{
		base = WScript.Arguments.Named("base");
	}

	queryString = "cmd=validate&user=" + user + "&passwd=" + passwd;
	oHttp = createConnection(base, "GET", cgiApp, queryString);
	oHttp.send();
	var resp = new Response(oHttp.responseXML);
	if (resp.isError){
			err.message = resp.message;
			err.faultString = resp.faultString;
			err.faultCode = resp.faultCode;
		if (resp.faultString == "Empty"){
			err.number += 2;
			err.description = "Parse Error: " + oHttp.responseXML.parseError.reason + " "  + oHttp.responseXML.parseError;
		}else{
			err.number += 1;
			err.description = "Error getting credential";
		}
		throw(err);
	}
	
	return oHttp.responseXML;
}
/**********************************************************************
Response(dom)

Test the contents of the DOM for a fault document or 
for a 0 length "Empty DOM".  If the faultString property ==
"Empty" it is recommended to test the dom.parseError 
property to determine why the dom is empty. Use the new 
keyword to create a instance of Response as a object.

@param dom is a DOMDocument

@return none

@property isError  if not  null  then the dom
	contained a fault document or is empty.
@propety faultCode [string]  contains the contents of
	faultCode element from fault document or equal to
	"Empty". 
	Only present if isError != null.
@propety faultString [string]  contains the contents of
	faultString element from fault document or equal to
	"Empty". 
	Only present if isError != null.
@propety message [string]  contains the contents of
	e:message element from fault document or equal to
	"Empty Document". 
	Only present if isError != null.


**********************************************************************/
function Response(dom){

	dom.setProperty("SelectionNamespaces", "xmlns:VFI='urn:vfi-sapphire:np.domain.2001-07-01' xmlns:e='urn:vfi-sapphire:np.domain.2001-07-01'");
	dom.setProperty("SelectionLanguage", "XPath");

	this.isError = dom.selectSingleNode("//VFI:Fault") != null;
	if (this.isError) {
		var node = null;
		node = dom.selectSingleNode("//faultCode");
		if (node != null) {
			this.faultCode = node.text;
		}
		node = dom.selectSingleNode("//faultString");
		if (node != null) {
			this.faultString = node.text;
		}
		node = dom.selectSingleNode("//e:message");
		if (node != null) {
			this.message = node.text;
		}
	}
	if (dom.xml.length == 0){
		this.isError = true;
		this.message = "Empty Document";
		this.faultString = "Empty";
		this.faultCode = "Empty";
	}
}
/**********************************************************************
releaseCredential(cookie)

Used to release a credential once all the work is done
even when the command is not equal to releaseCredential.
releaseCredential calls createConnection

@param cookie [string] containing the value of 
	a cookie to release.

@return DOMDocument containing the response

@throws exceptions
	1) IF a fault document is returned from Sapphire [err # 401]
	2) IF the response is empty [err # 402]
	3) IF /base: == null  [err # 405]
	4) IF cookie is null or not present [err # 406]
	5) Any exceptions generated by createConnection()

**********************************************************************/
function releaseCredential(cookie){

var base = null;
var oHttp = null;
var cgiApp = "CGILink";
var queryString = null;
var err = new Error();
	err.name = 'releaseCredential()';
	err.number = 400;

	if (!WScript.Arguments.Named.Exists("base") ){
		err.number += 5;
		err.description = 'base missing';
		err.message = 'base is required for all commands';
		throw(err);
	}else{
		base = WScript.Arguments.Named("base");
	}
	if (cookie == null || cookie == ''){
		err.number += 6;
		err.description = 'cookie missing';
		err.message = 'cookie is required ';
		throw(err);
	}
	queryString = "cmd=releaseCredential&cookie=" + cookie;
	oHttp = createConnection(base, "GET", cgiApp, queryString);
	oHttp.send();
	var resp = new Response(oHttp.responseXML);
	if (resp.isError){
			err.message = resp.message;
			err.faultString = resp.faultString;
			err.faultCode = resp.faultCode;
		if (resp.faultString == "Empty"){
			err.number += 2;
			err.description = "Parse Error: " + oHttp.responseXML.parseError.reason + " "  + oHttp.responseXML.parseError;
		}else{
			err.number += 1;
			err.description = "Error releasing credential";
		}
		throw(err);
	}
	
	return oHttp.responseXML;
}

/**********************************************************************
getCookieFromCredential(dom)

Used to extract the value of cookie element from the 
credential. If returnCookie argument exists it will also 
write cookie to stdOut.

@param dom DOMDocument containing a credential

@return cookie [string]

@throws exception
	1) IF cookie can not be extracted [err # 301]
	2) IF dom argument is missing or null [err # 302]
**********************************************************************/
function getCookieFromCredential(dom){
var cookie = null;
var objNode = null;
var err = new Error();
	err.name = 'getCookieFromCredential()';
	err.number = 300;
	if (dom == null){
		err.number += 2;
		err.description = 'dom argument is missing or null';
		err.message = 'dom argument is not optional';
		throw(err);
	
	}
	dom.setProperty("SelectionNamespaces", "xmlns:domain='urn:vfi-sapphire:np.domain.2001-07-01' xmlns:vs='urn:vfi-sapphire:vs.2001-10-01'");
	dom.setProperty("SelectionLanguage", "XPath");
	objNode = dom.selectSingleNode("//cookie");
	if (objNode){
		cookie = objNode.text;
	}else{
		err.number += 1;
		err.description = 'no value for cookie';
		err.message = 'a value for cookie was not found';
		throw(err);
	}
	if (WScript.Arguments.Named.Exists("returnCookie")){
		WScript.StdOut.Write(cookie + "\n");
	}
	return cookie;
}


/**********************************************************************
writeToLog(msg)

Used to format and write information to the log. This function 
prepends the date time and appends a crlf.

@param msg [string] the message to be written to the log

@return NONE

**********************************************************************/

function writeToLog(msg){
	mkdir(logDir);
	var newStr;
	var tmp;
	var ts;
	var filename;
	if (! fso.FileExists(logDir + "\\" + logFile)){
		ts = fso.CreateTextFile(logDir + "\\" + logFile);
	}else{
		try{
			ts = fso.OpenTextFile(logDir + "\\" + logFile, 8);
		}catch(e){
			var failed = true;
			if (e.number = -2146828218){
				var retry = 0;
				while (retry != 3){
					try{
						failed = false;
						ts = fso.OpenTextFile(logDir + "\\" + logFile, 8);
						break;
					}catch (e){
						if (e.number = -2146828218){
							failed = true;
							WScript.sleep(200);
							retry++;
						}else{
							failed = true;
							newStr = "ERROR on " + (new Date).toString() + "\n";
							for (var prop in e){
								newStr += prop + ": " + e[prop] + ";  ";
							}
							filename = (new Date).toString();
							filename = filename.replace(/:/gi,"-");
							tmp = fso.CreateTextFile(logDir + "\\" + filename + ".txt");
							tmp.Write("[" + (new Date).toString() + "]--- Exception writting to log: " + newStr +"\r\n");
							tmp.Write("[" + (new Date).toString() + "]---" + msg + "\r\n");
							tmp.Close();
							break;
						}
					}
				}	
			}
 		}
	}
	if (failed != true){
		ts.Write("[" + (new Date).toString() + "]---" + msg +"\r\n");
		ts.Close();
	}else{
		var filename = (new Date).toString();
		filename = filename.replace(/:/gi,"-");
		ts = fso.CreateTextFile(logDir + "\\" + filename + ".txt");
		ts.Write("[" + (new Date).toString() + "]--- Failed to write to log:" + msg + "\r\n");
		ts.Close();
	}
}


/**********************************************************************
procException(e)

Used to convert a error object to a string and write that
string to the log file.

@param e the exception/error object to process

@return NONE
**********************************************************************/
function procException(e) {
	var str = "ERROR on " + (new Date).toString() + "\n";
	for (var prop in e){
		str += prop + ": " + e[prop] + ";  ";

	}
	writeToLog(str);
}
/**********************************************************************
generateFault(e)

Used to convert a error object to a string and write a fault document
to the output

@param e the exception/error object to process

@return NONE
**********************************************************************/
function generateFault(e) {
var fault = "";
var fc = "PDK-BO.UnexpectedError";
var fs = "PDK-BO Error";
var msg = "Generic Error";
var str = "";
var faultDom = new ActiveXObject("MSXML2.DOMDocument.6.0");	
	faultDom.async = false;
	faultDom.validateOnParse = false;
	faultDom.resolveExternals = false;
	faultDom.setProperty("SelectionNamespaces", "xmlns:VFI='urn:vfi-sapphire:np.domain.2001-07-01' xmlns:e='urn:vfi-sapphire:np.domain.2001-07-01'");
	faultDom.setProperty("SelectionLanguage", "XPath");

	fault = "<?xml version='1.0' ?> <VFI:Response xmlns:VFI='urn:vfi-sapphire:np.domain.2001-07-01'>"+
		"<VFI:Fault>" +
			"<faultCode>" + "</faultCode>" +
			"<faultString>" + "</faultString>" +
			"<detail>" +
				"<e:vfiFault xmlns:e='urn:vfi-sapphire:np.domain.2001-07-01'>" +
					"<e:message>" + "</e:message>" +
				"</e:vfiFault>" +
			"</detail>" +
		"</VFI:Fault>" +
	"</VFI:Response>";

	faultDom.loadXML(fault);
	
	str = "ERROR on " + (new Date).toString() + "\n";
	for (var prop in e){
		str += prop + ": " + e[prop] + ";\n";

	}

	msg += ":\n" + str;

	faultDom.selectSingleNode("//faultCode").text = fc;
	faultDom.selectSingleNode("//faultString").text = fs;
	faultDom.selectSingleNode("//e:message").text = msg;


	writeOutput(faultDom.xml);
}

/**********************************************************************
mkdir(dir)
Creates a directory (iteratively) given as a path.

@param dir the path to the directory

@return the path to the directory actually constructed.
**********************************************************************/

function mkdir(dir) {
	var fso = WScript.CreateObject("Scripting.FileSystemObject");
	var strAr = dir.split("\\");

	var subPath = "";
	for (var i = 0; i < strAr.length; i++) {	
		if (strAr[i] != "") {
			subPath += strAr[i];
			if (!fso.FolderExists(subPath)) fso.CreateFolder(subPath);
		}
		subPath += "\\";
	}
	return subPath;	
}

/*********************************************************************
extractValuePairs(filename)
Create a javascript object (used as an associative array)
from a name/value pair file in the form of a Java Properties file.

Example File:
#This is a test file comment
a=bbb xx yy
c=dddd

Returned Object:
obj["a"] == "bbb xx yy"
obj["c"] == "dddd" 

@param filename the name of the property file.

@return a javascript object constructed as an associative array. 
**********************************************************************/

function extractValuePairs(filename) {
	var fso = WScript.CreateObject("Scripting.FileSystemObject");
	if (!fso.FileExists(filename)) {
		throw new Error("extractValuePairs(): no file: " + filename);
	} 
	var obj = new Object();
	var fd = fso.OpenTextFile(filename);
	while (! fd.AtEndOfStream) {
		var line = fd.ReadLine();
		if (line.indexOf('#') == 0)
			continue;
		var equalAt = line.indexOf("=");
		if (equalAt == -1) 
			continue;
		var name = line.substr(0,equalAt);
		var value = line.substr(equalAt+1);
		
		obj[name] = value;
	}
	return obj;
}

/*******************************************************************
valueInXSDList(list,str)

XML Schema defines a simple type "list" whose values are whitespace
delimited (or in attributes no newlines).  This method tests such 
a list to see if a given value is in it.

@param list the whitespace delimited list

@return true if str exists in the list
********************************************************************/

function valueInXSDList(list,str) {
	var ar = list.split(" ");
	for (var i = 0; i < ar.length; i++) {
		if (ar[i] == str) return true;
	}
	return false;
}