<?xml version="1.0" encoding="UTF-8"?><xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" media-type="text/xml"/>

<xsl:param name="cashMOP">1</xsl:param>
<xsl:param name="checkMOP">2</xsl:param>
<xsl:param name="foodStampMOP">8</xsl:param>
<xsl:param name="lotteryMOP">9</xsl:param>
<xsl:param name="driveOffMOP">10</xsl:param>
<xsl:param name="lottoMOP">18</xsl:param>


<xsl:template match="transactionSet">

<cashActivity>

	<increases>
	
		<xsl:variable name="totCashSales" select="sum(trans[@type='sale' or @type='network sale']/trPaylines/trPayline[trpPaycode!='Change'][trpPaycode/@mop=$cashMOP]/trpAmt)"/>

		<xsl:variable name="totFoodStampSales" select="sum(trans[@type='sale' or @type='network sale']/trPaylines/trPayline[trpPaycode!='Change'][trpPaycode/@mop=$foodStampMOP]/trpAmt)"/>

		<xsl:variable name="totFoodStampChange" select="sum(trans[@type='sale']/trValue/trFstmp/trFstmpChg)"/>

		<xsl:variable name="totCheckSales" select="sum(trans[@type='sale' or @type='network sale']/trPaylines/trPayline[trpPaycode!='Change'][trpPaycode/@mop=$checkMOP]/trpAmt)"/>

		<xsl:variable name="totLottoWinAmt" select="sum(trans[@type='sale' or @type='network sale' or @type='refund sale']/trPaylines/trPayline[trpPaycode/@mop=$lottoMOP]/trpAmt)"/>

		<xsl:variable name="totLotteryWinAmt" select="sum(trans[@type='sale' or @type='network sale' or @type='refund sale']/trPaylines/trPayline[trpPaycode/@mop=$lotteryMOP]/trpAmt)"/>

		<xsl:variable name="totDriveOffs" select="sum(trans[@type='sale' or @type='network sale']/trPaylines/trPayline[trpPaycode!='Change'][trpPaycode/@mop=$driveOffMOP]/trpAmt)"/>

		<xsl:variable name="totSafeLoans" select="sum(trans[@type='safeloan']/trValue/trCurrTot)"/>

		<xsl:variable name="totIncreases" select="$totCashSales +               $totFoodStampSales +               $totFoodStampChange +               $totCheckSales +               $totLottoWinAmt +               $totLotteryWinAmt +               $totDriveOffs +               $totSafeLoans"/>

		<cash><xsl:value-of select="format-number($totCashSales,'###0.00')"/></cash>
		<foodStamps><xsl:value-of select="format-number($totFoodStampSales + $totFoodStampChange,'###0.00')"/></foodStamps>
		<checks><xsl:value-of select="format-number($totCheckSales,'###0.00')"/></checks>
		<lottoWinner><xsl:value-of select="format-number($totLottoWinAmt,'###0.00')"/></lottoWinner>
		<lotteryWinner><xsl:value-of select="format-number($totLotteryWinAmt,'###0.00')"/></lotteryWinner>
		<driveOffs><xsl:value-of select="format-number($totDriveOffs,'###0.00')"/></driveOffs>
		<safeLoans><xsl:value-of select="format-number($totSafeLoans,'###0.00')"/></safeLoans>
		<total><xsl:value-of select="format-number($totIncreases,'###0.00')"/></total>

	</increases>
	
	
	<decreases>

		<xsl:variable name="totCashChange" select="sum(trans[@type='sale' or @type='network sale']/trPaylines/trPayline[trpPaycode='Change'][trpPaycode/@mop=$cashMOP]/trpAmt) * -1"/>

		<xsl:variable name="totCheckChange" select="sum(trans[@type='sale' or @type='network sale']/trPaylines/trPayline[trpPaycode='Change'][trpPaycode/@mop=$foodStampMOP]/trpAmt)"/>

		<xsl:variable name="totCashRefunds" select="sum(trans[@type='refund sale']/trPaylines/trPayline[trpPaycode/@mop=$cashMOP]/trpAmt)"/>

		<xsl:variable name="totFoodStampRefunds" select="sum(trans[@type='refund sale']/trPaylines/trPayline[trpPaycode/@mop=$foodStampMOP]/trpAmt)"/>

		<xsl:variable name="totCheckRefunds" select="sum(trans[@type='refund sale']/trPaylines/trPayline[trpPaycode/@mop=$checkMOP]/trpAmt)"/>

		<xsl:variable name="totCashBack" select="sum(trans[@type='network sale']/trValue/trCshBk/trCshBkAmt)"/>

		<xsl:variable name="totSafeDropCash" select="sum(trans[@type='safedrop']/trPaylines/trPayline[trpPaycode/@mop=$cashMOP]/trpAmt)"/>

		<xsl:variable name="totSafeDropFoodStamp" select="sum(trans[@type='safedrop']/trPaylines/trPayline[trpPaycode/@mop=$foodStampMOP]/trpAmt)"/>

		<xsl:variable name="totSafeDropCheck" select="sum(trans[@type='safedrop']/trPaylines/trPayline[trpPaycode/@mop=$checkMOP]/trpAmt)"/>

		<xsl:variable name="totSafeDropLotto" select="sum(trans[@type='safedrop']/trPaylines/trPayline[trpPaycode/@mop=$lottoMOP]/trpAmt)"/>

		<xsl:variable name="totSafeDropLottery" select="sum(trans[@type='safedrop']/trPaylines/trPayline[trpPaycode/@mop=$lotteryMOP]/trpAmt)"/>

		<xsl:variable name="totDecreases" select="$totCashChange +               $totFoodStampChange +               $totCheckChange +               $totCashRefunds +               $totFoodStampRefunds +               $totCheckRefunds +               $totCashBack +               $totSafeDropCash +               $totSafeDropFoodStamp +               $totSafeDropCheck +               $totSafeDropLotto +               $totSafeDropLottery"/>


		<cashChange><xsl:value-of select="format-number($totCashChange,'###0.00')"/></cashChange>
		<foodStampChange><xsl:value-of select="format-number($totFoodStampChange,'###0.00')"/></foodStampChange>
		<checkChange><xsl:value-of select="format-number($totCheckChange,'###0.00')"/></checkChange>
		<cashRefunds><xsl:value-of select="format-number($totCashRefunds,'###0.00')"/></cashRefunds>
		<foodStampRefunds><xsl:value-of select="format-number($totFoodStampRefunds,'###0.00')"/></foodStampRefunds>
		<checkRefunds><xsl:value-of select="format-number($totCheckRefunds,'###0.00')"/></checkRefunds>
		<cashBack><xsl:value-of select="format-number($totCashBack,'###0.00')"/></cashBack>
		<safeDropCash><xsl:value-of select="format-number($totSafeDropCash,'###0.00')"/></safeDropCash>
		<safeDropFoodStamp><xsl:value-of select="format-number($totSafeDropFoodStamp,'###0.00')"/></safeDropFoodStamp>
		<safeDropCheck><xsl:value-of select="format-number($totSafeDropCheck,'###0.00')"/></safeDropCheck>
		<safeDropLotto><xsl:value-of select="format-number($totSafeDropLotto,'###0.00')"/></safeDropLotto>
		<safeDropLottery><xsl:value-of select="format-number($totSafeDropLottery,'###0.00')"/></safeDropLottery>
		<total><xsl:value-of select="format-number($totDecreases,'###0.00')"/></total>

	</decreases>
	
</cashActivity>

</xsl:template>
</xsl:transform>