<?xml version="1.0" encoding="UTF-8"?><xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:pd="urn:vfi-sapphire:pd.2002-05-21" version="1.0">
<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" media-type="text/xml"/>

<xsl:param name="numPLUsToList">25</xsl:param>

<xsl:variable name="numDays" select="count(pd:pluPd/vs:period)"/>

<xsl:template match="pd:pluPd">

<xsl:variable name="numPLUs" select="count(totals/pluInfo)"/>

<xsl:variable name="bottomStart">
	<xsl:choose>
		<xsl:when test="$numPLUs &lt; $numPLUsToList">
			0
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$numPLUs - $numPLUsToList + 1"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:variable>

<PLUTopSellers>
	<xsl:copy-of select="vs:site"/>
	<startDay><xsl:value-of select="substring(vs:period[position()=1]/@periodEndDate, 1, 10)"/></startDay>
	<endDay><xsl:value-of select="substring(vs:period[position()=last()]/@periodEndDate, 1, 10)"/></endDay>
	<daysReported><xsl:value-of select="$numDays"/></daysReported>
	<numPLUsToList><xsl:value-of select="$numPLUsToList"/></numPLUsToList>
	<category>
		<xsl:choose>
			<xsl:when test="vs:deptBase"><xsl:value-of select="vs:deptBase/name/@sysid"/> (<xsl:value-of select="vs:deptBase/name"/>)</xsl:when>
			<xsl:otherwise>ALL</xsl:otherwise>
	 	</xsl:choose>
	</category>
	<byQuantity>
		<top>
			<xsl:apply-templates select="totals/pluInfo">
				<xsl:with-param name="startRange">1</xsl:with-param>
				<xsl:with-param name="endRange"><xsl:value-of select="$numPLUsToList"/></xsl:with-param>
				<xsl:sort select="netSales/itemCount" data-type="number" order="descending"/>
				<xsl:sort select="vs:pluBase/upc" data-type="number"/>
			</xsl:apply-templates>
		</top>
		<bottom>
			<xsl:apply-templates select="totals/pluInfo">
				<xsl:with-param name="startRange"><xsl:value-of select="$bottomStart"/></xsl:with-param>
				<xsl:with-param name="endRange"><xsl:value-of select="$numPLUs"/></xsl:with-param>
				<xsl:sort select="netSales/itemCount" data-type="number" order="descending"/>
				<xsl:sort select="vs:pluBase/upc" data-type="number"/>
			</xsl:apply-templates>
		</bottom>
	</byQuantity>
	
	<byAmount>
		<top>
			<xsl:apply-templates select="totals/pluInfo">
				<xsl:with-param name="startRange">1</xsl:with-param>
				<xsl:with-param name="endRange"><xsl:value-of select="$numPLUsToList"/></xsl:with-param>
				<xsl:sort select="netSales/amount" data-type="number" order="descending"/>
				<xsl:sort select="vs:pluBase/upc" data-type="number"/>
			</xsl:apply-templates>
		</top>
		<bottom>
			<xsl:apply-templates select="totals/pluInfo">
				<xsl:with-param name="startRange"><xsl:value-of select="$bottomStart"/></xsl:with-param>
				<xsl:with-param name="endRange"><xsl:value-of select="$numPLUs"/></xsl:with-param>
				<xsl:sort select="netSales/amount" data-type="number" order="descending"/>
				<xsl:sort select="vs:pluBase/upc" data-type="number"/>
			</xsl:apply-templates>
		</bottom>
	</byAmount>

</PLUTopSellers>

</xsl:template>

<xsl:template match="pluInfo">
	<xsl:param name="startRange"/>
	<xsl:param name="endRange"/>

	<xsl:if test="position() &gt; ($startRange - 1) and position() &lt; ($endRange + 1)">
		<pluRecord>
			<upc><xsl:value-of select="vs:pluBase/upc"/></upc>
			<modifier><xsl:value-of select="vs:pluBase/modifier"/></modifier>
			<description><xsl:value-of select="vs:pluBase/name"/></description>
			<price><xsl:value-of select="salePrice"/></price>
			<quantity><xsl:value-of select="netSales/itemCount"/></quantity>
			<totalSales><xsl:value-of select="netSales/amount"/></totalSales>
			<averageQty><xsl:value-of select="netSales/itemCount div $numDays"/></averageQty>
			<averageSales><xsl:value-of select="netSales/amount div $numDays"/></averageSales>
		</pluRecord>
	</xsl:if>

</xsl:template>

</xsl:transform>