<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/NAXML-MCMDetail" xmlns:ns1="http://verifone.com/isd/vfit/tlog/lists" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" version="1.0" exclude-result-prefixes="xsl ext ns base vs t">

	<xsl:import href="lists-xalan.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:template name="ns:mcmDetailElem">
		<xsl:param name="saleSet"/>
		<xsl:param name="dept"/>
		<xsl:variable name="ns-dept" select="ext:nodeset($dept)"/>
		
		
		<xsl:variable name="deptSaleSet">
			<xsl:call-template name="ns1:getTLogEntriesForDept">
				<xsl:with-param name="tlogEntrySet" select="$saleSet"/>
				<xsl:with-param name="dept" select="$dept"/>
			</xsl:call-template>
		</xsl:variable>		
		<xsl:variable name="refundSaleSet">
			<xsl:call-template name="ns1:getRefundTLogEntrySet">
				<xsl:with-param name="tlogEntrySet" select="$deptSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="nonRefundSaleSet">
			<xsl:call-template name="ns1:getNonRefundTLogEntrySet">
				<xsl:with-param name="tlogEntrySet" select="$deptSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="deptSuperLineSet">
			<xsl:call-template name="ns1:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="$deptSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="deptSuperRefundLineSet">
			<xsl:call-template name="ns1:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="$refundSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="deptSuperNonRefundLineSet">
			<xsl:call-template name="ns1:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="$nonRefundSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="deptLineSet">
			<xsl:call-template name="ns1:getLinesForDept">
				<xsl:with-param name="lineSet" select="$deptSuperLineSet"/>
				<xsl:with-param name="dept" select="$dept"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="refundLineSet">
			<xsl:call-template name="ns1:getLinesForDept">
				<xsl:with-param name="lineSet" select="$deptSuperRefundLineSet"/>
				<xsl:with-param name="dept" select="$dept"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="nonRefundLineSet">
			<xsl:call-template name="ns1:getLinesForDept">
				<xsl:with-param name="lineSet" select="$deptSuperNonRefundLineSet"/>
				<xsl:with-param name="dept" select="$dept"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="deptDiscountSet">
			<xsl:call-template name="ns1:getDiscountSetFromLines">
				<xsl:with-param name="lineSet" select="$deptLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		

		<xsl:variable name="salesCount">
			<xsl:value-of select="count(ext:nodeset($deptSaleSet)/*)"/>
		</xsl:variable>
		<xsl:variable name="salesAmt">
			<xsl:value-of select="format-number( sum( ext:nodeset($deptLineSet)/*/stot) ,'#.00')"/>
		</xsl:variable>
		<xsl:variable name="quantity">
			<xsl:value-of select="format-number( sum( ext:nodeset($deptLineSet)/*/qty) ,'#.000')"/>
		</xsl:variable>
		<xsl:variable name="promoAmt">
			<xsl:value-of select="format-number( sum( ext:nodeset($deptDiscountSet)/t:promo/amt),'#.00')"/>
		</xsl:variable>
		<xsl:variable name="promoCount">
			<xsl:value-of select="count(ext:nodeset($deptDiscountSet)/t:promo)"/>
		</xsl:variable>
		<xsl:variable name="discTotAmt">
			<xsl:value-of select="format-number( sum( ext:nodeset($deptDiscountSet)/*/amt),'#.00')"/>
		</xsl:variable>
		<xsl:variable name="discTotCount">
			<xsl:value-of select="count(ext:nodeset($deptDiscountSet)/*)"/>
		</xsl:variable>
		<xsl:variable name="discAmt">
			<xsl:value-of select="format-number( $discTotAmt - $promoAmt,'#.00')"/>
		</xsl:variable>
		<xsl:variable name="discCount">
			<xsl:value-of select="$discTotCount - $promoCount"/>
		</xsl:variable>
		<xsl:variable name="refundSaleCount">
			<xsl:value-of select="count(ext:nodeset($refundSaleSet)/*)"/>
		</xsl:variable>
		<xsl:variable name="refundSaleAmt">
			<xsl:value-of select="format-number( - sum( ext:nodeset($refundLineSet)/*/stot) ,'#.00')"/>
		</xsl:variable>
		<xsl:variable name="openSaleLineSet">
			<xsl:copy-of select="ext:nodeset($deptLineSet)/*[ not(iid)]"/>
		</xsl:variable>
		
		<xsl:element name="MCMDetail">
			<xsl:element name="MerchandiseCode"><xsl:value-of select="$ns-dept/@sysid"/></xsl:element>
			<xsl:element name="MerchandiseCodeDescription"><xsl:value-of select="$ns-dept/name"/></xsl:element>
			<xsl:element name="MCMSalesTotals">
			
				<xsl:element name="DiscountAmount">
					<xsl:value-of select="$discAmt"/>				
				</xsl:element>
				<xsl:element name="DiscountCount">
					<xsl:value-of select="$discCount"/>
				</xsl:element>
				<xsl:element name="PromotionAmount">
					<xsl:value-of select="$promoAmt"/>
				</xsl:element>
				<xsl:element name="PromotionCount">
					<xsl:value-of select="$promoCount"/>
				</xsl:element>
				<xsl:element name="RefundAmount">
					<xsl:value-of select="$refundSaleAmt"/>				
				</xsl:element>
				<xsl:element name="RefundCount">
					<xsl:value-of select="$refundSaleCount"/>
				</xsl:element>
				<xsl:element name="SalesQuantity">
					<xsl:value-of select="$quantity"/>
				</xsl:element>
				<xsl:element name="SalesAmount">
					<xsl:value-of select="$salesAmt"/>
				</xsl:element>
				<xsl:element name="TransactionCount">
					<xsl:value-of select="$salesCount"/>
				</xsl:element>
				<xsl:element name="OpenDepartmentSalesAmount"> 
					<xsl:value-of select="format-number( sum( ext:nodeset($openSaleLineSet)/*/stot),'#.00')"/>
				</xsl:element>
				<xsl:element name="OpenDepartmentSalesCount"> 
					<xsl:value-of select="count(ext:nodeset($openSaleLineSet)/*)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template name="ns:mcmDetailForFeeDeptElem">
		<xsl:param name="saleSet"/>
		<xsl:param name="dept"/>
		<xsl:variable name="ns-dept" select="ext:nodeset($dept)"/>
		
		
		<xsl:variable name="feeDeptSaleSet">
			<xsl:call-template name="ns1:getTLogEntriesForFeeDept">
				<xsl:with-param name="tlogEntrySet" select="$saleSet"/>
				<xsl:with-param name="dept" select="$dept"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="refundFeeDeptSaleSet">
			<xsl:call-template name="ns1:getRefundTLogEntrySet">
				<xsl:with-param name="tlogEntrySet" select="$feeDeptSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="feeDeptSuperLineSet">
			<xsl:call-template name="ns1:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="$feeDeptSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="refundSuperLineSet">
			<xsl:call-template name="ns1:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="$refundFeeDeptSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="feeDeptLineSet">
			<xsl:call-template name="ns1:getLinesForFeeDept">
				<xsl:with-param name="lineSet" select="$feeDeptSuperLineSet"/>
				<xsl:with-param name="dept" select="$dept"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="refundLineSet">
			<xsl:call-template name="ns1:getLinesForFeeDept">
				<xsl:with-param name="lineSet" select="$refundSuperLineSet"/>
				<xsl:with-param name="dept" select="$dept"/>
			</xsl:call-template>
		</xsl:variable>
		
		
		<xsl:variable name="feeCount">
			<xsl:value-of select="count(ext:nodeset($feeDeptSaleSet)/*)"/>
		</xsl:variable>
		<xsl:variable name="feeAmt">
			<xsl:value-of select="format-number( sum( ext:nodeset($feeDeptLineSet)/*/t:fee/amt) ,'#.00')"/>
		</xsl:variable>
		<xsl:variable name="feeQty">
			<xsl:value-of select="format-number( sum( ext:nodeset($feeDeptLineSet)/*/qty) ,'#.000')"/>
		</xsl:variable>
		<xsl:variable name="feeRefundCount">
			<xsl:value-of select="count(ext:nodeset($refundFeeDeptSaleSet)/*)"/>
		</xsl:variable>
		<xsl:variable name="feeRefundAmt">
			<xsl:value-of select="format-number( - sum( ext:nodeset($refundLineSet)/*/t:fee/amt) ,'#.00')"/>
		</xsl:variable>
		
		<xsl:element name="MCMDetail">
			<xsl:element name="MerchandiseCode"><xsl:value-of select="$ns-dept/@sysid"/></xsl:element>
			<xsl:element name="MerchandiseCodeDescription"><xsl:value-of select="$ns-dept/name"/></xsl:element>
			<xsl:element name="MCMSalesTotals">
				
				<xsl:element name="DiscountAmount">
					<xsl:text>0.00</xsl:text>				
				</xsl:element>
				<xsl:element name="DiscountCount">
					<xsl:text>0</xsl:text>				
				</xsl:element>
				<xsl:element name="PromotionAmount">
					<xsl:text>0.00</xsl:text>				
				</xsl:element>
				<xsl:element name="PromotionCount">
					<xsl:text>0</xsl:text>				
				</xsl:element>
				<xsl:element name="RefundAmount">
					<xsl:value-of select="$feeRefundAmt"/>				
				</xsl:element>
				<xsl:element name="RefundCount">
					<xsl:value-of select="$feeRefundCount"/>
				</xsl:element>
				<xsl:element name="SalesQuantity">
					<xsl:value-of select="$feeQty"/>
				</xsl:element>
				<xsl:element name="SalesAmount">
					<xsl:value-of select="$feeAmt"/>
				</xsl:element>
				<xsl:element name="TransactionCount">
					<xsl:value-of select="$feeCount"/>
				</xsl:element>
				<xsl:element name="OpenDepartmentSalesAmount"> 
					<xsl:text>0.00</xsl:text>				
				</xsl:element>
				<xsl:element name="OpenDepartmentSalesCount"> 
					<xsl:text>0</xsl:text>				
				</xsl:element>
			</xsl:element>
		</xsl:element>
	
	</xsl:template>

</xsl:stylesheet>