<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/NAXML-MSMDetail" xmlns:ns1="http://verifone.com/isd/vfit/tlog/lists" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" version="1.0" exclude-result-prefixes="xsl ext ns base vs t">

	<xsl:import href="lists.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

	<xsl:param name="ns:driveoffMop"><t:mop cat="14"/></xsl:param>
	<xsl:param name="ns:lotteryScratchMop"><t:mop cat="17"/></xsl:param>	
	<xsl:param name="ns:lottoMop"><t:mop cat="5"/></xsl:param>	
	<xsl:param name="ns:carwashDept"><t:dept sysid="0055"/></xsl:param>
	<xsl:param name="ns:cardlockMop"/>
	
	<xsl:template name="ns:fmtMsmDetails">
		<xsl:param name="completeSet"/>
		<xsl:param name="saleSet"/>
		
		<xsl:variable name="ns-completeSet" select="ext:node-set($completeSet)"/>
		<xsl:variable name="ns-saleSet" select="ext:node-set($saleSet)"/>
		<xsl:variable name="refundSet">
			<xsl:call-template name="ns1:getRefundTLogEntrySet">
				<xsl:with-param name="tlogEntrySet" select="$saleSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="lineSet">
			<xsl:call-template name="ns1:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="$saleSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="pluLineSet">
			<xsl:call-template name="ns1:getLinesWithPlu">
				<xsl:with-param name="lineSet" select="$lineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="nonPluLineSet">
			<xsl:call-template name="ns1:getLinesWithoutPlu">
				<xsl:with-param name="lineSet" select="$lineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="paylineSet">
			<xsl:call-template name="ns1:getPaylineSet">
				<xsl:with-param name="tlogEntrySet" select="$saleSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="ns-refundSet" select="ext:node-set($refundSet)"/>
		<xsl:variable name="ns-lineSet" select="ext:node-set($lineSet)"/>
		<xsl:variable name="ns-pluLineSet" select="ext:node-set($pluLineSet)"/>
		<xsl:variable name="ns-nonPluLineSet" select="ext:node-set($nonPluLineSet)"/>
		<xsl:variable name="ns-paylineSet" select="ext:node-set($paylineSet)"/>

	
	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Safe Drops</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="1"/>
			<xsl:with-param name="summarySubCode" select="0"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-completeSet/t:tillSafeDrop/amount)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-completeSet/t:tillSafeDrop)"/>
			</xsl:with-param>
		</xsl:call-template>

	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Refunds</xsl:text></xsl:with-param>			
			<xsl:with-param name="summaryCode" select="3"/>
			<xsl:with-param name="summarySubCode" select="0"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="- sum($ns-refundSet/*/sum/total)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-refundSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>

	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Payouts</xsl:text></xsl:with-param>			
			<xsl:with-param name="summaryCode" select="4"/>
			<xsl:with-param name="summarySubCode" select="0"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-completeSet/t:tillPayout/amount)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-completeSet/t:tillPayout)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="paylineSetForLottery">
			<xsl:call-template name="ns1:getPaylinesForMop">
				<xsl:with-param name="paylineSet" select="$paylineSet"/>
				<xsl:with-param name="mop" select="$ns:lotteryScratchMop"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Lottery (scratch) Payouts</xsl:text></xsl:with-param>	
			<xsl:with-param name="summaryCode" select="4"/>
			<xsl:with-param name="summarySubCode" select="5"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum(ext:node-set($paylineSetForLottery)/t:payline/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count(ext:node-set($paylineSetForLottery)/t:payline)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="paylineSetForLotto">
			<xsl:call-template name="ns1:getPaylinesForMop">
				<xsl:with-param name="paylineSet" select="$paylineSet"/>
				<xsl:with-param name="mop" select="$ns:lottoMop"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Lotto (Online) Payouts</xsl:text></xsl:with-param>	
			<xsl:with-param name="summaryCode" select="4"/>
			<xsl:with-param name="summarySubCode" select="6"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum(ext:node-set($paylineSetForLotto)/t:payline/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count(ext:node-set($paylineSetForLotto)/t:payline)"/>
			</xsl:with-param>
		</xsl:call-template>

	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Payins</xsl:text></xsl:with-param>	
			<xsl:with-param name="summaryCode" select="5"/>
			<xsl:with-param name="summarySubCode" select="0"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-completeSet/t:tillPayin/amount)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-completeSet/t:tillPayin)"/>
			</xsl:with-param>
		</xsl:call-template>

	
		<xsl:variable name="carwashLineSet">
			<xsl:copy-of select="$ns-lineSet/*[ carwash ]"/>
		</xsl:variable>
		<xsl:variable name="ns-carwashLineSet" select="ext:node-set($carwashLineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Carwash Total Sales (not NAXML)</xsl:text></xsl:with-param>	
			<xsl:with-param name="summaryCode" select="6"/>
			<xsl:with-param name="summarySubCode" select="10"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-carwashLineSet/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-carwashLineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>

	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Items Sold (excludes open dept sales)</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="3"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-pluLineSet/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-pluLineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Scanned Items Sold</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="3"/>
			<xsl:with-param name="summarySubCodeModifier" select="1"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-pluLineSet/*[ flags/@scanned = 'true' ]/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-pluLineSet/*[ flags/@scanned = 'true' ])"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Open Department Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="3"/>
			<xsl:with-param name="summarySubCodeModifier" select="2"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-nonPluLineSet/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-nonPluLineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>No Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="4"/>
			<xsl:with-param name="amt" select="0"/>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-completeSet/t:tillNoSale)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="voidTransSet">
			<xsl:copy-of select="$ns-completeSet/t:void"/>
		</xsl:variable>
		<xsl:variable name="voidTransLineSet">
			<xsl:call-template name="ns1:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="$voidTransSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Void Transactions</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="9"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum(ext:node-set($voidTransLineSet)/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-completeSet/t:void)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="paylineSetForDriveoffs">
			<xsl:call-template name="ns1:getPaylinesForMop">
				<xsl:with-param name="paylineSet" select="$paylineSet"/>
				<xsl:with-param name="mop" select="$ns:driveoffMop"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Drive Offs</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="12"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum(ext:node-set($paylineSetForDriveoffs)/t:payline/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count(ext:node-set($paylineSetForDriveoffs)/t:payline)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Refunds</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="15"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="- sum($ns-refundSet/*/sum/total)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-refundSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Drawer Alarms Count</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="16"/>
			<xsl:with-param name="summarySubCodeModifier" select="1"/>
			<xsl:with-param name="amt" select="0"/>
			<xsl:with-param name="cnt" select="count($ns-completeSet/t:event[ @type = 'drawerAlarm'])"/>
		</xsl:call-template>
	
		<xsl:variable name="saleCount" select="count($ns-saleSet/*)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Average Sale</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="16"/>
			<xsl:with-param name="summarySubCodeModifier" select="2"/>
			<xsl:with-param name="amt">
				<xsl:choose>
					<xsl:when test="$saleCount &gt; 0">
						<xsl:value-of select="sum($ns-lineSet/*/stot) div $saleCount"/>
					</xsl:when>
					<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="$saleCount"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="fuelPrepaidCancelEventSet">
			<xsl:copy-of select="$ns-completeSet/t:event[ @type = 'fuelPrepaidCancel']"/>
		</xsl:variable>
		<xsl:variable name="ns-fuelPrepaidCancelEventSet" select="ext:node-set($fuelPrepaidCancelEventSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Cancelled Prepay Transactions</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="16"/>
			<xsl:with-param name="summarySubCodeModifier" select="3"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-fuelPrepaidCancelEventSet/t:event/t:fuelPrepay/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-fuelPrepaidCancelEventSet/t:event)"/>
			</xsl:with-param>
		</xsl:call-template>
	
	
		<xsl:variable name="cardlockPaylineSet">
			<xsl:call-template name="ns1:getPaylinesForMop">
				<xsl:with-param name="paylineSet" select="$paylineSet"/>
				<xsl:with-param name="mop" select="$ns:cardlockMop"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="ns-cardlockPaylineSet" select="ext:node-set($cardlockPaylineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Cardlock Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="16"/>
			<xsl:with-param name="summarySubCodeModifier" select="4"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-cardlockPaylineSet/*/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-cardlockPaylineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="priceOverrideAmt">
			<xsl:variable name="priceOverrideSet">
				<xsl:for-each select="$ns-lineSet/*">
					<xsl:if test="priceOverride">
						<xsl:element name="lval"><xsl:value-of select="qty * (priceOverride/oldprc - itmprc)"/></xsl:element>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<xsl:value-of select="sum(ext:node-set($priceOverrideSet)/*)"/>
		</xsl:variable>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Price Overrides</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="7"/>
			<xsl:with-param name="summarySubCode" select="16"/>
			<xsl:with-param name="summarySubCodeModifier" select="5"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="$priceOverrideAmt"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-lineSet/*[priceOverride])"/>
			</xsl:with-param>
		</xsl:call-template>

	
		
	
		

	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="9"/>
			<xsl:with-param name="summarySubCode" select="1"/>
			<xsl:with-param name="summarySubCodeModifier" select="1"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-lineSet/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-saleSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="insideLineSet">
			<xsl:call-template name="ns1:getLinesForInsideSales">
				<xsl:with-param name="lineSet" select="$lineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="ns-insideLineSet" select="ext:node-set($insideLineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Inside Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="9"/>
			<xsl:with-param name="summarySubCode" select="1"/>
			<xsl:with-param name="summarySubCodeModifier" select="2"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-insideLineSet/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-insideLineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="fuelLineSet">
			<xsl:call-template name="ns1:getLinesForFuelSales">
				<xsl:with-param name="lineSet" select="$lineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="ns-fuelLineSet" select="ext:node-set($fuelLineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Fuel Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="9"/>
			<xsl:with-param name="summarySubCode" select="1"/>
			<xsl:with-param name="summarySubCodeModifier" select="9"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-fuelLineSet/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-fuelLineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="moneyOrderLineSet">
			<xsl:copy-of select="$ns-lineSet/*[ flags/@moneyOrder = 'true' ]"/>
		</xsl:variable>
		<xsl:variable name="ns-moneyOrderLineSet" select="ext:node-set($moneyOrderLineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Money Orders</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="9"/>
			<xsl:with-param name="summarySubCode" select="1"/>
			<xsl:with-param name="summarySubCodeModifier" select="18"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-moneyOrderLineSet/*/stot)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-moneyOrderLineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Money Orders</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="9"/>
			<xsl:with-param name="summarySubCode" select="1"/>
			<xsl:with-param name="summarySubCodeModifier" select="21"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum($ns-moneyOrderLineSet/*/t:fee/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count($ns-moneyOrderLineSet/*/t:fee)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="countCashier">
			<xsl:copy-of select="ext:node-set($completeSet)/t:countCashier"/>
		</xsl:variable>
		<xsl:if test="count(ext:node-set($countCashier)/*) &gt; 0">
			<xsl:variable name="tillAmountForCash">
				<xsl:copy-of select="ext:node-set($countCashier)/t:countCashier/tillAmount[ t:mop/@cat = '0']"/>
			</xsl:variable>
			<xsl:variable name="ns-tillAmountForCash" select="ext:node-set($tillAmountForCash)"/>
			<xsl:call-template name="ns:msmDetailElem">
				<xsl:with-param name="comment"><xsl:text>Cash Over/Short</xsl:text></xsl:with-param>
				<xsl:with-param name="summaryCode" select="9"/>
				<xsl:with-param name="summarySubCode" select="3"/>
				<xsl:with-param name="amt">
					<xsl:choose>
						<xsl:when test="$ns-tillAmountForCash/tillAmount/actualAmount">
							<xsl:value-of select="$ns-tillAmountForCash/tillAmount/actualAmount - $ns-tillAmountForCash/tillAmount/ecrAmount"/>
						</xsl:when>
						<xsl:otherwise><xsl:value-of select="0"/></xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
				<xsl:with-param name="cnt" select="1"/>
			</xsl:call-template>
		</xsl:if>

	
		<xsl:variable name="mopList">
			<xsl:call-template name="ns1:getMopList">
				<xsl:with-param name="tlogEntrySet" select="$saleSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:for-each select="ext:node-set($mopList)/*">
			<xsl:variable name="mop" select="."/>
			<xsl:variable name="mopPaylineSet">
				<xsl:call-template name="ns1:getPaylinesForMop">
					<xsl:with-param name="paylineSet" select="$paylineSet"/>
					<xsl:with-param name="mop" select="$mop"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="ns-mopPaylineSet" select="ext:node-set($mopPaylineSet)"/>
			<xsl:call-template name="ns:msmDetailElem">
				<xsl:with-param name="comment"><xsl:text>Sales by MOP: </xsl:text><xsl:value-of select="ext:node-set($mop)/name"/></xsl:with-param>
				<xsl:with-param name="summaryCode" select="19"/>
				<xsl:with-param name="summarySubCode" select="1"/>
				<xsl:with-param name="summarySubCodeModifier" select="ext:node-set($mop)/@sysid"/>
				<xsl:with-param name="amt">
					<xsl:value-of select="sum($ns-mopPaylineSet/*/amt)"/>
				</xsl:with-param>
				<xsl:with-param name="cnt">
					<xsl:value-of select="count($ns-mopPaylineSet/*)"/>
				</xsl:with-param>
			</xsl:call-template>
			
		</xsl:for-each>
	
		<xsl:variable name="mopSafeList">
			<xsl:call-template name="ns1:getMopSafeList">
				<xsl:with-param name="tlogEntrySet" select="$completeSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:for-each select="ext:node-set($mopSafeList)/*">
			<xsl:variable name="mop" select="."/>
			<xsl:variable name="mopSafeSet">
				<xsl:call-template name="ns1:getTillItemsForMop">
					<xsl:with-param name="tlogEntrySet"><xsl:copy-of select="ext:node-set($completeSet)/t:tillSafeDrop"/></xsl:with-param>
					<xsl:with-param name="mop" select="$mop"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="ns-mopSafeSet" select="ext:node-set($mopSafeSet)"/>
			<xsl:call-template name="ns:msmDetailElem">
				<xsl:with-param name="comment"><xsl:text>Safe Drops by MOP: </xsl:text><xsl:value-of select="ext:node-set($mop)/name"/></xsl:with-param>
				<xsl:with-param name="summaryCode" select="19"/>
				<xsl:with-param name="summarySubCode" select="4"/>
				<xsl:with-param name="summarySubCodeModifier" select="ext:node-set($mop)/@sysid"/>
				<xsl:with-param name="amt">
					<xsl:value-of select="sum( $ns-mopSafeSet/*/amount)"/>
				</xsl:with-param>
				<xsl:with-param name="cnt">
					<xsl:value-of select="count( $ns-mopSafeSet/*)"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:for-each>

	
		<xsl:variable name="creditPaylineSet">
			<xsl:copy-of select="$ns-paylineSet/t:payline[ t:cardInfo ]"/>
		</xsl:variable>
		<xsl:variable name="ns-creditPaylineSet" select="ext:node-set($creditPaylineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Credit Card Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="19"/>
			<xsl:with-param name="summarySubCode" select="10"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum( $ns-creditPaylineSet/*/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count( $ns-creditPaylineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="networkAuthorizedCreditPaylineSet">
			<xsl:copy-of select="$ns-paylineSet/t:payline[            t:cardInfo/authSrc = 'host' or            t:cardInfo/authSrc = 'interchange' ]"/>
		</xsl:variable>
		<xsl:variable name="ns-networkAuthorizedCreditPaylineSet" select="ext:node-set($networkAuthorizedCreditPaylineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Network Authorized Credit Card Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="19"/>
			<xsl:with-param name="summarySubCode" select="10"/>
			<xsl:with-param name="summarySubCodeModifier" select="1"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum( $ns-networkAuthorizedCreditPaylineSet/*/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count( $ns-networkAuthorizedCreditPaylineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="manualCreditPaylineSet">
			<xsl:copy-of select="$ns-paylineSet/t:payline[ t:cardInfo/entryMeth/@type = 'manual' ]"/>
		</xsl:variable>
		<xsl:variable name="ns-manualCreditPaylineSet" select="ext:node-set($manualCreditPaylineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Manually Keyed Credit Card Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="19"/>
			<xsl:with-param name="summarySubCode" select="10"/>
			<xsl:with-param name="summarySubCodeModifier" select="2"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum( $ns-manualCreditPaylineSet/*/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count( $ns-manualCreditPaylineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	
		<xsl:variable name="imprintPaylineSet">
			<xsl:copy-of select="$ns-paylineSet/t:payline[ t:cardInfo/entryMeth/@type = 'imprint' ]"/>
		</xsl:variable>
		<xsl:variable name="ns-imprintPaylineSet" select="ext:node-set($imprintPaylineSet)"/>
		<xsl:call-template name="ns:msmDetailElem">
			<xsl:with-param name="comment"><xsl:text>Total Imprinter Credit Card Sales</xsl:text></xsl:with-param>
			<xsl:with-param name="summaryCode" select="19"/>
			<xsl:with-param name="summarySubCode" select="10"/>
			<xsl:with-param name="summarySubCodeModifier" select="3"/>
			<xsl:with-param name="amt">
				<xsl:value-of select="sum( $ns-imprintPaylineSet/*/amt)"/>
			</xsl:with-param>
			<xsl:with-param name="cnt">
				<xsl:value-of select="count( $ns-imprintPaylineSet/*)"/>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:msmDetailElem">
		<xsl:param name="comment"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:param name="summarySubCodeModifier"/>
		<xsl:param name="tenderCode"/>
		<xsl:param name="tenderSubCode"/>
		<xsl:param name="amt"/>
		<xsl:param name="cnt"/>
		<xsl:element name="MSMDetail">
			<xsl:element name="MiscellaneousSummaryCodes">
				<xsl:comment><xsl:value-of select="$comment"/></xsl:comment>
				<xsl:element name="MiscellaneousSummaryCode">
					<xsl:value-of select="$summaryCode"/>
				</xsl:element>
				<xsl:element name="MiscellaneousSummarySubCode">
					<xsl:value-of select="$summarySubCode"/>
				</xsl:element>
				<xsl:element name="MiscellaneousSummarySubCodeModifier">
					<xsl:value-of select="$summarySubCodeModifier"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="MSMSalesTotals">
				<xsl:element name="Tender">
					<xsl:element name="TenderCode">
						<xsl:value-of select="$tenderCode"/>
					</xsl:element>
					<xsl:element name="TenderSubCode">
						<xsl:value-of select="$tenderSubCode"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="MiscellaneousSummaryAmount">
					<xsl:value-of select="format-number($amt,'#.00')"/>
				</xsl:element>
				<xsl:element name="MiscellaneousSummaryCount">
					<xsl:value-of select="number($cnt)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
</xsl:stylesheet>