<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildBiometric" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2 jsc base">
	<xsl:import href="lists-xalan.xslt"/>
	<xsl:import href="../transactionSet/scripts-xalan.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:dcrRegister" select="'9'"/>
	<xsl:param name="ns:credit">1</xsl:param>
	<xsl:param name="ns:debit">2</xsl:param>
	<xsl:param name="ns:ebtFS">20</xsl:param>
	<xsl:param name="ns:ebtCshBen">21</xsl:param>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		
		<xsl:variable name="biometricSales">
			<xsl:call-template name="ns:getBiometricSales">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="biometricRefunds">
			<xsl:call-template name="ns:getBiometricRefunds">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="final">
			<xsl:element name="t:biometricReport">
				<xsl:copy-of select="$header"/>
				<xsl:element name="sales">
					<xsl:call-template name="ns:buildCreditTransactions">
						<xsl:with-param name="lineSet" select="$biometricSales"/>
					</xsl:call-template>
					<xsl:element name="totals">
						<xsl:element name="amount">
							<xsl:value-of select="format-number(sum(ext:nodeset($biometricSales)/*/sum/total),'0.00;0.00')"/>
						</xsl:element>
						<xsl:element name="count">
							<xsl:value-of select="count(ext:nodeset($biometricSales)/*)"/>
						</xsl:element>
					</xsl:element>
				</xsl:element>
				<xsl:element name="refunds">
					<xsl:call-template name="ns:buildCreditTransactions">
						<xsl:with-param name="lineSet" select="$biometricRefunds"/>
					</xsl:call-template>
					<xsl:element name="totals">
						<xsl:element name="amount">
							<xsl:value-of select="format-number(sum(ext:nodeset($biometricRefunds)/*/sum/total),'0.00;0.00')"/>
						</xsl:element>
						<xsl:element name="count">
							<xsl:value-of select="count(ext:nodeset($biometricRefunds)/*)"/>
						</xsl:element>
					</xsl:element>
				</xsl:element>

			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$final"/>
	</xsl:template>
	<xsl:template name="ns:getBiometricSales">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/t:sale[not(@isRefund) and paylines/*/t:cardInfo[entryMeth/@type='biometric']]"/>
	</xsl:template>
	<xsl:template name="ns:getBiometricRefunds">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/t:sale[@isRefund and paylines/*/t:cardInfo[entryMeth/@type='biometric']]"/>
	</xsl:template>
	<xsl:template name="ns:buildCreditTransactions">
		<xsl:param name="lineSet"/>
		<xsl:variable name="ns-lineSet" select="ext:nodeset($lineSet)"/>
		<xsl:for-each select="$ns-lineSet/*">
			<xsl:element name="cardEntry">
				<xsl:attribute name="DCR"><xsl:choose><xsl:when test="./hdr/t:register[@sysid = $ns:dcrRegister]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
				<xsl:attribute name="EBT"><xsl:choose><xsl:when test="./paylines/*[t:mop/@cat = $ns:ebtFS or t:mop/@cat = $ns:ebtCshBen]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
				
				<xsl:copy-of select="./paylines/*[t:mop/@cat = $ns:credit or t:mop/@cat = $ns:debit or t:mop/@cat = $ns:ebtFS or t:mop/@cat = $ns:ebtCshBen]/t:cardInfo"/>
				
				<xsl:copy-of select="./hdr/dateTime"/>
				
				<xsl:copy-of select="./vs:transactionSeq"/>
				
				<xsl:copy-of select="./hdr/t:register"/>
				
				<xsl:copy-of select="./t:cashier"/>
				
				<xsl:copy-of select="./paylines/*[t:mop/@cat = $ns:credit or t:mop/@cat = $ns:debit or t:mop/@cat = $ns:ebtFS or t:mop/@cat = $ns:ebtCshBen]/amt"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>