<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildCCExceptions" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns t js vs ns2 base">
	<xsl:import href="../transactionSet/scripts.xslt"/>
	<xsl:import href="lists.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:param name="ns:credit">1</xsl:param>
	<xsl:param name="ns:reportPrefs">reptPrefs.xml</xsl:param>
	<xsl:param name="ns:imprinterName">imprinterSales</xsl:param>

	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>

		<xsl:variable name="rptPrefDoc" select="document(string($ns:reportPrefs))//reptDefinitionMap"/>


			<xsl:variable name="allImprinterSales">
			<xsl:call-template name="ns:getImprinterTransactions">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
			</xsl:call-template>
		</xsl:variable>
		

		<xsl:variable name="imprinterSet">
			<xsl:call-template name="ns:buildImprinterTransactions">
				<xsl:with-param name="lineSet" select="$allImprinterSales"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
			</xsl:call-template>
		</xsl:variable>
			

		<xsl:variable name="allCreditSales">
			<xsl:call-template name="ns:getCreditTransactions">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>


		<xsl:variable name="cardEntrySet">
			<xsl:call-template name="ns:buildCreditTransactions">
				<xsl:with-param name="lineSet" select="$allCreditSales"/>
			</xsl:call-template>
		</xsl:variable>


		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:node-set($cardEntrySet)/*">
				<xsl:sort data-type="number" order="ascending" select="./t:cardInfo/acct"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
	

		<xsl:variable name="manualEntered">
			<xsl:copy-of select="ext:node-set($sortedList)/*/*[entryMeth/@type='manual']/.."/>
		</xsl:variable>


		<xsl:variable name="duplicateList">
			<xsl:call-template name="ns:getListOfDuplicateCards">
				<xsl:with-param name="lineSet" select="$sortedList"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="duplicateEntries">
			<xsl:for-each select="ext:node-set($duplicateList)/*/acct">
				<xsl:variable name="currAcct" select="."/>
				<xsl:copy-of select="ext:node-set($sortedList)/*/*[acct = $currAcct]/.."/>
			</xsl:for-each>
		</xsl:variable>
		

	<xsl:variable name="final">
		<xsl:element name="t:creditCardExceptions">
			<xsl:copy-of select="$header"/>
			<xsl:element name="manualEntered">
					<xsl:copy-of select="ext:node-set($manualEntered)/*"/>
			</xsl:element>
			<xsl:element name="duplicateEntries">
				<xsl:copy-of select="ext:node-set($duplicateEntries)/*"/>
			</xsl:element>
			<xsl:element name="imprinterEntries">
				<xsl:copy-of select="$imprinterSet"/>
			</xsl:element>
		</xsl:element>
	</xsl:variable>
	<xsl:copy-of select="$final"/>
	</xsl:template>
	
	<xsl:template name="ns:getCreditTransactions">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/*[name() != 't:prefuel' and name() != 't:rollback']/paylines/*[t:mop/@cat = $ns:credit]/../.."/>
	</xsl:template>
	
	<xsl:template name="ns:getImprinterTransactions">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="manCreditPrefs" select="$ns-rptPrefs//*[*=$ns:imprinterName]"/>
		
		<xsl:copy-of select="$ns-set/*/paylines/*[t:mop/@sysid = $manCreditPrefs//@sysid]/../.."/>
	</xsl:template>
	
	<xsl:template name="ns:buildCreditTransactions">
		<xsl:param name="lineSet"/>
		<xsl:variable name="ns-lineSet" select="ext:node-set($lineSet)"/>
			<xsl:for-each select="$ns-lineSet/*">
				<xsl:element name="cardEntry">

					<xsl:copy-of select="./paylines/*[t:mop/@cat = $ns:credit]/t:cardInfo"/>

					<xsl:copy-of select="./hdr/dateTime"/>

					<xsl:copy-of select="./vs:transactionSeq"/>

					<xsl:copy-of select="./hdr/t:register"/>

					<xsl:copy-of select="./t:cashier"/>

					<xsl:copy-of select="./paylines/*[t:mop/@cat = $ns:credit]/amt"/>
				</xsl:element>
			</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="ns:buildImprinterTransactions">
		<xsl:param name="lineSet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="ns-lineSet" select="ext:node-set($lineSet)"/>
		
		<xsl:variable name="manCreditPrefs" select="$ns-rptPrefs//*[*=$ns:imprinterName]"/>

			<xsl:for-each select="$ns-lineSet/*">
				<xsl:element name="imprinterEntry">

					<xsl:copy-of select="./hdr/dateTime"/>

					<xsl:copy-of select="./vs:transactionSeq"/>

					<xsl:copy-of select="./hdr/t:register"/>

					<xsl:copy-of select="./t:cashier"/>

					<xsl:copy-of select="./paylines/*[t:mop/@sysid = $manCreditPrefs//@sysid]/amt"/>
				</xsl:element>
			</xsl:for-each>
	</xsl:template>

	<xsl:template name="ns:getListOfDuplicateCards">
		<xsl:param name="lineSet"/>
		<xsl:variable name="ns-lineSet" select="ext:node-set($lineSet)"/>
		<xsl:copy-of select="$ns-lineSet/cardEntry[          (t:cardInfo/acct = preceding-sibling::cardEntry[1]/t:cardInfo/acct) and          (t:cardInfo/acct != following-sibling::cardEntry[1]/t:cardInfo/acct)         ]/t:cardInfo"/>
	</xsl:template>
</xsl:stylesheet>