<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildCardtypeProd" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns js vs ns2 base">
	
	<xsl:import href="../transactionSet/scripts-xalan.xslt"/>
	<xsl:import href="lists-xalan.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:reportPrefs">reptPrefs.xml</xsl:param>
	<xsl:param name="ns:reptGroupName">cardTypeProductReport</xsl:param>

	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		
		<xsl:variable name="rptPrefDoc" select="document(string($ns:reportPrefs))"/>

		<xsl:variable name="rawRptPrefs" select="$rptPrefDoc//*[* = $ns:reptGroupName]"/>
		

		<xsl:variable name="cardTypeList">
			<xsl:call-template name="ns:getCardTypeList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="allCreditSales">
			<xsl:call-template name="ns:getCreditSalesTransactions">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="allCreditRefunds">
			<xsl:call-template name="ns:getCreditRefundTransactions">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="cardEntries">
			<xsl:call-template name="ns:createCardTypeTotals">
				<xsl:with-param name="cardList" select="$cardTypeList"/>
				<xsl:with-param name="sales" select="$allCreditSales"/>
				<xsl:with-param name="refunds" select="$allCreditRefunds"/>
				<xsl:with-param name="reptPref" select="$rawRptPrefs"/>
			</xsl:call-template>
		</xsl:variable>

		<t:cardtypeProductReport>
			<xsl:copy-of select="$header"/>
			<xsl:copy-of select="$cardEntries"/>
		</t:cardtypeProductReport>
	</xsl:template>



	<xsl:template name="ns:getCardTypeList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rawList">
			<xsl:call-template name="ns:getRawCardTypeList">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:nodeset($rawList)/*">
				<xsl:sort data-type="text" order="ascending" select="."/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="ext:nodeset($sortedList)/ccName[ not(. = preceding-sibling::ccName[1] )] "/>
	</xsl:template>

	<xsl:template name="ns:getRawCardTypeList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/*/paylines/*/t:cardInfo/ccName"/>
	</xsl:template>
	
	<xsl:template name="ns:getCreditSalesTransactions">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/t:sale[not (@isRefund='true')]/paylines/t:payline[t:cardInfo]/../.."/>
	</xsl:template>
	
	<xsl:template name="ns:getCreditRefundTransactions">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/*[@isRefund='true']/paylines/t:payline[t:cardInfo]/../.."/>
	</xsl:template>
	
	<xsl:template name="ns:createCardTypeTotals">
		<xsl:param name="cardList"/>
		<xsl:param name="sales"/>
		<xsl:param name="refunds"/>
		<xsl:param name="reptPref"/>
		<xsl:variable name="ns-cl" select="ext:nodeset($cardList)"/>
		<xsl:variable name="ns-ss" select="ext:nodeset($sales)"/>
		<xsl:variable name="ns-rs" select="ext:nodeset($refunds)"/>
		<xsl:variable name="ns-rp" select="ext:nodeset($reptPref)"/>
		
		<xsl:variable name="cardEntries">
			<xsl:for-each select="ext:nodeset($ns-cl)/*">
					<xsl:variable name="currCC" select="."/>
					<xsl:element name="cardTypeEntry">
						<xsl:copy-of select="."/>
						
						<xsl:variable name="creditSales">
							<xsl:copy-of select="ext:nodeset($ns-ss)/*/paylines[               (t:payline/t:cardInfo/ccName = $currCC)]/.."/>
						</xsl:variable>
						<xsl:variable name="creditRefunds">
							<xsl:copy-of select="ext:nodeset($ns-rs)/*/paylines[               (t:payline/t:cardInfo/ccName = $currCC)]/.."/>
						</xsl:variable>

						<xsl:variable name="totalCreditSales" select="sum(ext:nodeset($creditSales)/*/                     paylines/t:payline[t:cardInfo]/amt)"/>
						<xsl:variable name="countCreditSales" select="count(ext:nodeset($creditSales)/*/                     paylines/t:payline[t:cardInfo])"/>

						<xsl:variable name="totalFuelSales" select="sum(ext:nodeset($creditSales)                     /*/lines/t:line[t:fuel]/tot)"/>

						<xsl:variable name="totalFuelDepartmentSales" select="sum(ext:nodeset($creditSales)                       /*/lines/t:line[not(t:fuel)                       and (fid/t:dept/@sysid =                        $ns-rp//@sysid)]/tot)"/>

						<xsl:variable name="sRemainder" select="($totalCreditSales -                        ($totalFuelSales + $totalFuelDepartmentSales))"/>

						<xsl:element name="sales">
						<xsl:choose>

							<xsl:when test="($sRemainder &gt; 0)">
								<xsl:element name="cardCount">
									<xsl:value-of select="$countCreditSales"/>
								</xsl:element>
								<xsl:element name="fuel">
									<xsl:value-of select="format-number($totalFuelSales + $totalFuelDepartmentSales, '0.00')"/>
								</xsl:element>
								<xsl:element name="merchandise">
									<xsl:value-of select="format-number($sRemainder, '0.00')"/>
								</xsl:element>
							</xsl:when>

							<xsl:when test="(($sRemainder &lt; 0) or ($sRemainder = 0))">
								<xsl:element name="cardCount">
									<xsl:value-of select="$countCreditSales"/>
								</xsl:element>
								<xsl:element name="fuel">
									<xsl:value-of select="format-number($totalCreditSales, '0.00')"/>
								</xsl:element>
								<xsl:element name="merchandise">
									<xsl:value-of select="format-number(0.00, '0.00')"/>
								</xsl:element>
							</xsl:when>
						</xsl:choose>
						</xsl:element>
	
						<xsl:variable name="totalCreditRefunds" select="sum(ext:nodeset($creditRefunds)/*/                     paylines/t:payline[t:cardInfo]/amt)"/>
						<xsl:variable name="countCreditRefunds" select="count(ext:nodeset($creditRefunds)/*/                     paylines/t:payline[t:cardInfo])"/>


						<xsl:variable name="totalFuelRefunds" select="sum(ext:nodeset($creditRefunds)                     /*/lines/t:line[t:fuel]/tot)"/>

						<xsl:variable name="totalFuelDepartmentRefunds" select="sum(ext:nodeset($creditRefunds)                       /*/lines/t:line[not(t:fuel)                       and (fid/t:dept/@sysid                       = $ns-rp//@sysid)]/tot)"/>

						<xsl:variable name="rRemainder" select="($totalCreditRefunds -                        ($totalFuelRefunds + $totalFuelDepartmentRefunds))"/>

						<xsl:element name="refunds">
						<xsl:choose>

							<xsl:when test="($rRemainder &lt; 0)">
								<xsl:element name="cardCount">
									<xsl:value-of select="$countCreditRefunds"/>
								</xsl:element>
								<xsl:element name="fuel">
									<xsl:value-of select="format-number($totalFuelRefunds                      + $totalFuelDepartmentRefunds, '0.00')"/>
								</xsl:element>
								<xsl:element name="merchandise">
									<xsl:value-of select="format-number($rRemainder, '0.00')"/>
								</xsl:element>
							</xsl:when>

							<xsl:when test="(($rRemainder &gt; 0) or ($rRemainder = 0))">
								<xsl:element name="cardCount">
									<xsl:value-of select="$countCreditRefunds"/>
								</xsl:element>
								<xsl:element name="fuel">
									<xsl:value-of select="format-number($totalCreditRefunds, '0.00')"/>
								</xsl:element>
								<xsl:element name="merchandise">
									<xsl:value-of select="format-number(0.00, '0.00')"/>
								</xsl:element>
							</xsl:when>
						</xsl:choose>
						</xsl:element>					
					</xsl:element>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="$cardEntries"/>
	</xsl:template>
</xsl:stylesheet>