<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildCashReconcile" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns ns1 t js vs">
	<xsl:import href="../transactionSet/scripts-xalan.xslt"/>
	<xsl:import href="lists-xalan.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

	<xsl:param name="ns:dcrRegister" select="'9'"/>
	<xsl:param name="ns:sappRegister" select="'1'"/>
	
	<xsl:param name="ns:reportPrefs">reptPrefs.xml</xsl:param>
	<xsl:param name="ns:reptGroupName">cashReconciliation-1</xsl:param>

	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>


		<xsl:variable name="rawRegisterList">
			<xsl:call-template name="ns2:getRegisterList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="rptPrefDoc" select="document(string($ns:reportPrefs))"/>

		<xsl:variable name="rawRptPrefs" select="$rptPrefDoc//*[* = $ns:reptGroupName]"/>


		<xsl:variable name="allRegisters">
			<xsl:for-each select="ext:nodeset($rawRegisterList)/*[@sysid != $ns:dcrRegister                  and @sysid != $ns:sappRegister]">
				<xsl:variable name="currRegister" select="."/>

				<xsl:element name="registerInfo">
					<xsl:copy-of select="$currRegister"/>

					<xsl:variable name="cashierPrints">
						<xsl:copy-of select="$baseRawSet/t:countCashier/hdr/t:register[@sysid = $currRegister/@sysid and @till = $currRegister/@till]/../.."/>
					</xsl:variable>

					<xsl:variable name="cashierOpens">
							<xsl:copy-of select="$baseRawSet/t:openCashier/hdr/t:register[@sysid = $currRegister/@sysid and @till = $currRegister/@till]/../.."/>
					</xsl:variable>
					

					<xsl:variable name="newCashierPrints">
						<xsl:for-each select="ext:nodeset($cashierPrints)/*">
							<xsl:variable name="currPrint" select="."/>

							<xsl:element name="cashierDrawerInfo">

							<xsl:copy-of select="./t:cashier"/>

							<xsl:copy-of select="ext:nodeset($cashierOpens)/*/t:cashier[               (../hdr/t:register/@till =$currPrint/hdr/t:register/@till)                 and (@sysid = $currPrint/t:cashier/@sysid)               and (period =$currPrint/t:cashier/period)               ]/../open"/>

							<xsl:copy-of select="./close"/>

							<xsl:copy-of select="ext:nodeset($cashierOpens)/*/t:cashier[               (../hdr/t:register/@till = $currPrint/hdr/t:register/@till)                 and (@sysid = $currPrint/t:cashier/@sysid)               and (period =$currPrint/t:cashier/period)               ]/../beginCash"/>
							<xsl:copy-of select="ext:nodeset($cashierOpens)/*/t:cashier[               (../hdr/t:register/@till =$currPrint/hdr/t:register/@till)                 and (@sysid = $currPrint/t:cashier/@sysid)               and (period =$currPrint/t:cashier/period)               ]/../beginFoodStmp"/>

							<xsl:for-each select="ext:nodeset($rawRptPrefs)/t:mop">
								<xsl:variable name="currMOP" select="."/>
									<xsl:copy-of select="$currPrint/tillAmount/t:mop[@sysid=$currMOP/@sysid]/.."/>
							</xsl:for-each>
	
							</xsl:element>

						</xsl:for-each>
						
					</xsl:variable>

					<xsl:variable name="sortedList">
						<xsl:for-each select="ext:nodeset($newCashierPrints)/*">
							<xsl:sort order="ascending" data-type="number" select="t:cashier/@sysid"/>
							<xsl:copy-of select="."/>
						</xsl:for-each>
					</xsl:variable>
						<xsl:copy-of select="$sortedList"/>
						
						
					</xsl:element>
			
			</xsl:for-each>

		</xsl:variable>

<xsl:element name="t:cashReconciliation">
<xsl:copy-of select="$header"/>
<xsl:apply-templates mode="ns:apply" select="ext:nodeset($allRegisters)/*"/>
</xsl:element>

	</xsl:template>
	
<xsl:template mode="ns:apply" match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*" mode="ns:attrs"/>
			<xsl:apply-templates mode="ns:apply"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="@*" mode="ns:attrs">
		<xsl:copy-of select="."/>
	</xsl:template>

	<xsl:template match="tillAmount" mode="ns:apply">
		<xsl:element name="tillInfo">
			<xsl:choose>
				<xsl:when test="./t:mop[@cat='0']">
					<xsl:element name="beginDraw">
						<xsl:value-of select="../beginCash"/>
					</xsl:element>
				</xsl:when>
				<xsl:when test="./t:mop[@cat='13']">
					<xsl:element name="beginDraw">
						<xsl:value-of select="../beginFoodStmp"/>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="beginDraw">
						<xsl:value-of select="format-number(0.00, '0.00')"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
				<xsl:copy-of select="t:mop"/>
				<xsl:element name="endingDraw">
					<xsl:value-of select="ecrAmount"/>
				</xsl:element>
				<xsl:element name="actualDraw">
					<xsl:value-of select="actualAmount"/>
				</xsl:element>
				<xsl:element name="overShort">
					<xsl:value-of select="format-number((actualAmount - ecrAmount), '#.00')"/>
				</xsl:element>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>