<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildCashierTracking" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:nsc="http://verifone.com/isd/vfit/transactionSet/scripts" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns ns2 nsc jsc">
	<xsl:import href="lists-xalan.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:param name="ns:reportPrefs">reptPrefs.xml</xsl:param>
	<xsl:param name="ns:pluGroupName">pluTracking</xsl:param>
	<xsl:param name="ns:deptGroupName">deptTracking</xsl:param>
	<xsl:param name="ns:catGroupName">catTracking</xsl:param>
	<xsl:param name="ns:pluReptGrp">pluGrp</xsl:param>
	<xsl:param name="ns:deptReptGrp">deptGrp</xsl:param>
	<xsl:param name="ns:categoryReptGrp">categoryGrp</xsl:param>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		
		<xsl:variable name="rptPrefDoc" select="document(string($ns:reportPrefs))"/>
		
		<xsl:variable name="pluList" select="$rptPrefDoc//*[* = $ns:pluGroupName]"/>
		<xsl:variable name="deptList" select="$rptPrefDoc//*[* = $ns:deptGroupName]"/>
		<xsl:variable name="catList" select="$rptPrefDoc//*[* = $ns:catGroupName]"/>
		
		<xsl:variable name="cshTrkEntry" select="'cashierTrackingEntry'"/>
		<xsl:variable name="grossSales" select="'grossSales'"/>
		<xsl:variable name="refunds" select="'refunds'"/>
		<xsl:variable name="discounts" select="'discounts'"/>
		<xsl:variable name="cshTrkPLU" select="'t:pluTracking'"/>
		<xsl:variable name="cshTrkDept" select="'t:deptTracking'"/>
		<xsl:variable name="cshTrkCat" select="'t:catTracking'"/>
		
		<xsl:variable name="cashierList">
			<xsl:call-template name="ns:getCashierList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="allCashiers">
			
			<xsl:for-each select="ext:nodeset($cashierList)/cashierRegisterPair[t:cashier/@sysid !='0' ]">
				<xsl:variable name="curCshr" select="."/>
				<xsl:element name="{$cshTrkEntry}">
					<xsl:copy-of select="$curCshr/t:cashier"/>
					<xsl:copy-of select="$curCshr/t:register"/>
					
					<xsl:variable name="cshrTLogEntries">
						<xsl:call-template name="ns:getTLogEntriesForCashier">
							<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
							<xsl:with-param name="cashierPair" select="$curCshr"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:for-each select="$pluList/vs:pluBase">
						<xsl:variable name="curPLU" select="."/>
						<xsl:variable name="pluTLogEntries">
							<xsl:call-template name="ns2:getTLogEntriesForPlu">
								<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
								<xsl:with-param name="plu" select="$curPLU"/>
							</xsl:call-template>
						</xsl:variable>
						
						<xsl:variable name="gross-ns">
							<xsl:copy-of select="ext:nodeset($pluTLogEntries)/t:sale[not                            (@isRefund)]/lines/*                         | t:adjustment/lines/*"/>
						</xsl:variable>
						
						<xsl:variable name="gross-ls">
							<xsl:call-template name="ns2:getLinesForPlu">
								<xsl:with-param name="lineSet" select="$gross-ns"/>
								<xsl:with-param name="plu" select="$curPLU"/>
							</xsl:call-template>
						</xsl:variable>
						
						<xsl:variable name="refund-ns">
							<xsl:copy-of select="ext:nodeset($pluTLogEntries)/t:sale[@isRefund]/lines/*"/>
						</xsl:variable>
						<xsl:variable name="refund-ls">
							<xsl:call-template name="ns2:getLinesForPlu">
								<xsl:with-param name="lineSet" select="$refund-ns"/>
								<xsl:with-param name="plu" select="$curPLU"/>
							</xsl:call-template>
						</xsl:variable>
						
						
						<xsl:variable name="discounts-ls">
							<xsl:call-template name="ns2:getDiscountSetFromLines">
								<xsl:with-param name="lineSet" select="$gross-ls"/>
							</xsl:call-template>
						</xsl:variable>
						
						
						<xsl:if test="ext:nodeset($gross-ls)//*[1]/iid/t:plu or           ext:nodeset($refund-ls)//*[1]/iid/t:plu">
							
							<xsl:element name="{$cshTrkPLU}">
								

								<xsl:variable name="sellunit" select="ext:nodeset($gross-ls)//*[1]/iid/t:plu/sellunit | ext:nodeset($refund-ls)//*[1]/iid/t:plu/sellunit"/>
								<xsl:choose>
									<xsl:when test="ext:nodeset($gross-ls)//*[1]/iid/t:plu">
										<xsl:copy-of select="ext:nodeset($gross-ls)//*[1]/iid/t:plu"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:copy-of select="ext:nodeset($refund-ls)//*[1]/iid/t:plu"/>
									</xsl:otherwise>
								</xsl:choose>
								
								<xsl:element name="{$grossSales}">
									<xsl:element name="amount">

										<xsl:value-of select="format-number(sum(ext:nodeset($gross-ls)/*/stot)  +                        sum(ext:nodeset($discounts-ls)//amt),'0.00')"/>
										
									</xsl:element>
									<xsl:element name="qty">
										<xsl:value-of select="sum(ext:nodeset($gross-ls)/*/qty)"/>
									</xsl:element>
									<xsl:element name="extendedQty">
										<xsl:value-of select="sum(ext:nodeset($gross-ls)/*/qty) * $sellunit"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="{$refunds}">
									<xsl:element name="amount">
										<xsl:value-of select="format-number(sum(ext:nodeset($refund-ls)//stot),'0.00')"/>
									</xsl:element>
									<xsl:element name="qty">
										<xsl:value-of select="sum(ext:nodeset($refund-ls)/*/qty)"/>
									</xsl:element>
									<xsl:element name="extendedQty">
										<xsl:value-of select="sum(ext:nodeset($refund-ls)/*/qty) * $sellunit"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="{$discounts}">
									<xsl:element name="amount">
										<xsl:value-of select="format-number(sum(ext:nodeset($discounts-ls)//amt),'0.00')"/>
									</xsl:element>
									<xsl:element name="count">
										<xsl:value-of select="count(ext:nodeset($discounts-ls)/*)"/>
									</xsl:element>
								</xsl:element>
							</xsl:element>
						</xsl:if>
					</xsl:for-each>
					
					<xsl:for-each select="$deptList/vs:deptBase">
						<xsl:variable name="curDept" select="."/>
						<xsl:variable name="deptTLogEntries">
							<xsl:call-template name="ns2:getTLogEntriesForDept">
								<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
								<xsl:with-param name="dept" select="$curDept"/>
							</xsl:call-template>
						</xsl:variable>
						
						<xsl:variable name="gross-ns">
							<xsl:copy-of select="ext:nodeset($deptTLogEntries)/t:sale[not                            (@isRefund)]/lines/*                         | t:adjustment/lines/*"/>
						</xsl:variable>
						
						<xsl:variable name="gross-ls">
							<xsl:call-template name="ns2:getLinesForDept">
								<xsl:with-param name="lineSet" select="$gross-ns"/>
								<xsl:with-param name="dept" select="$curDept"/>
							</xsl:call-template>
						</xsl:variable>
												
						<xsl:variable name="grossFees-ns">
							<xsl:variable name="tmp-ns">
								<xsl:call-template name="ns2:getTLogEntriesForFeeDept">
									<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
									<xsl:with-param name="dept" select="$curDept"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:copy-of select="ext:nodeset($tmp-ns)/t:sale[not(@isRefund)]/lines/*                               | t:adjustment/lines/*"/>
						</xsl:variable>
						<xsl:variable name="grossFees-ls">
							<xsl:call-template name="ns:getFeesForDept">
								<xsl:with-param name="lineSet" select="$grossFees-ns"/>
								<xsl:with-param name="dept" select="$curDept"/>
							</xsl:call-template>
						</xsl:variable>
						
						<xsl:variable name="refund-ns">
							<xsl:copy-of select="ext:nodeset($deptTLogEntries)/t:sale[@isRefund]/lines/*"/>
						</xsl:variable>
						<xsl:variable name="refund-ls">
							<xsl:call-template name="ns2:getLinesForDept">
								<xsl:with-param name="lineSet" select="$refund-ns"/>
								<xsl:with-param name="dept" select="$curDept"/>
							</xsl:call-template>
						</xsl:variable>
												
						<xsl:variable name="refundFees-ns">
							<xsl:variable name="tmp-ns">
								<xsl:call-template name="ns2:getTLogEntriesForFeeDept">
									<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
									<xsl:with-param name="dept" select="$curDept"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:copy-of select="ext:nodeset($tmp-ns)/t:sale[@isRefund]/lines/*"/>
						</xsl:variable>
						<xsl:variable name="refundFees-ls">
							<xsl:call-template name="ns:getFeesForDept">
								<xsl:with-param name="lineSet" select="$refundFees-ns"/>
								<xsl:with-param name="dept" select="$curDept"/>
							</xsl:call-template>
						</xsl:variable>
						
						
						<xsl:variable name="discounts-ls">
							<xsl:call-template name="ns2:getDiscountSetFromLines">
								<xsl:with-param name="lineSet" select="$gross-ls"/>
							</xsl:call-template>
						</xsl:variable>
						

						
						<xsl:if test="ext:nodeset($gross-ls)//*[1]/fid/t:dept or             ext:nodeset($refund-ls)//*[1]/fid/t:dept or             ext:nodeset($grossFees-ls)//*[1]/t:dept or             ext:nodeset($refundFees-ls)//*[1]/t:dept">
							
							<xsl:element name="{$cshTrkDept}">
								
								<xsl:choose>
									<xsl:when test="ext:nodeset($gross-ls)//*[1]/fid/t:dept">
										<xsl:copy-of select="ext:nodeset($gross-ls)//*[1]/fid/t:dept"/>
									</xsl:when>
		 							<xsl:when test="ext:nodeset($refund-ls)//*[1]/fid/t:dept">
										<xsl:copy-of select="ext:nodeset($refund-ls)//*[1]/fid/t:dept"/>
									</xsl:when>
									<xsl:when test="ext:nodeset($grossFees-ls)//*[1]/t:dept ">
										<xsl:copy-of select="ext:nodeset($grossFees-ls)//*[1]/t:dept "/>
									</xsl:when>
		 							<xsl:when test="ext:nodeset($refundFees-ls)//*[1]/t:dept">
										<xsl:copy-of select="ext:nodeset($refundFees-ls)//*[1]/t:dept"/>
									</xsl:when>
								</xsl:choose> 

								<xsl:element name="{$grossSales}">
									<xsl:element name="amount">
	
										<xsl:value-of select="format-number(sum(ext:nodeset($gross-ls)/*/stot) +                        sum(ext:nodeset($discounts-ls)//amt) +                       sum(ext:nodeset($grossFees-ls)//amt),'0.00')"/>
										
									</xsl:element>
									<xsl:element name="qty">
										<xsl:value-of select="sum(ext:nodeset($gross-ls)/*/qty) +                     format-number(count(ext:nodeset($grossFees-ls)/*),'0')"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="{$refunds}">
									<xsl:element name="amount">
										<xsl:value-of select="format-number(sum(ext:nodeset($refund-ls)//stot),'0.00') +                      format-number(sum(ext:nodeset($refundFees-ls)//amt),'0.00')"/>
									</xsl:element>
									<xsl:element name="qty">
										<xsl:value-of select="sum(ext:nodeset($refund-ls)/*/qty)  +                     format-number(count(ext:nodeset($refundFees-ls)/*),'-0')"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="{$discounts}">
									<xsl:element name="amount">
										<xsl:value-of select="format-number(sum(ext:nodeset($discounts-ls)//amt),'0.00')"/>
									</xsl:element>
									<xsl:element name="count">
										<xsl:value-of select="count(ext:nodeset($discounts-ls)/*)"/>
									</xsl:element>
								</xsl:element>
							</xsl:element>
						</xsl:if>
					</xsl:for-each>
					
					<xsl:for-each select="$catList/vs:categoryBase">
						<xsl:variable name="curCat" select="."/>
						<xsl:variable name="catTLogEntries">
							<xsl:call-template name="ns2:getTLogEntriesForCategory">
								<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
								<xsl:with-param name="cat" select="$curCat"/>
							</xsl:call-template>
						</xsl:variable>
						
						<xsl:variable name="gross-ns">
							<xsl:copy-of select="ext:nodeset($catTLogEntries)/t:sale[not                            (@isRefund)]/lines/*                         | t:adjustment/lines/*"/>
						</xsl:variable>
						
						<xsl:variable name="gross-ls">
							<xsl:call-template name="ns2:getLinesForCategory">
								<xsl:with-param name="lineSet" select="$gross-ns"/>
								<xsl:with-param name="cat" select="$curCat"/>
							</xsl:call-template>
						</xsl:variable>
												
						<xsl:variable name="grossFees-ns">
							<xsl:variable name="tmp-ns">
								<xsl:call-template name="ns:getTLogEntriesForFeeCat">
									<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
									<xsl:with-param name="cat" select="$curCat"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:copy-of select="ext:nodeset($tmp-ns)/t:sale[not(@isRefund)]/lines/*                               | t:adjustment/lines/*"/>
						</xsl:variable>
						<xsl:variable name="grossFees-ls">
							<xsl:call-template name="ns:getFeesForCat">
								<xsl:with-param name="lineSet" select="$grossFees-ns"/>
								<xsl:with-param name="cat" select="$curCat"/>
							</xsl:call-template>
						</xsl:variable>
						
						<xsl:variable name="refund-ns">
							<xsl:copy-of select="ext:nodeset($catTLogEntries)/t:sale[@isRefund]/lines/*"/>
						</xsl:variable>
						<xsl:variable name="refund-ls">
							<xsl:call-template name="ns2:getLinesForCategory">
								<xsl:with-param name="lineSet" select="$refund-ns"/>
								<xsl:with-param name="cat" select="$curCat"/>
							</xsl:call-template>
						</xsl:variable>
												
						<xsl:variable name="refundFees-ns">
							<xsl:variable name="tmp-ns">
								<xsl:call-template name="ns:getTLogEntriesForFeeCat">
									<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
									<xsl:with-param name="cat" select="$curCat"/>
								</xsl:call-template>
							</xsl:variable>
							<xsl:copy-of select="ext:nodeset($tmp-ns)/t:sale[@isRefund]/lines/*"/>
						</xsl:variable>
						<xsl:variable name="refundFees-ls">
							<xsl:call-template name="ns:getFeesForCat">
								<xsl:with-param name="lineSet" select="$refundFees-ns"/>
								<xsl:with-param name="cat" select="$curCat"/>
							</xsl:call-template>
						</xsl:variable>
						
						
						<xsl:variable name="discounts-ls">
							<xsl:call-template name="ns2:getDiscountSetFromLines">
								<xsl:with-param name="lineSet" select="$gross-ls"/>
							</xsl:call-template>
						</xsl:variable>
						
						
						
						<xsl:if test="ext:nodeset($gross-ls)//*[1]/fid/t:cat or             ext:nodeset($refund-ls)//*[1]/fid/t:cat or             ext:nodeset($grossFees-ls)//*[1]/t:cat or             ext:nodeset($refundFees-ls)//*[1]/t:cat">
							
							<xsl:element name="{$cshTrkCat}">
								
								<xsl:choose>
									<xsl:when test="ext:nodeset($gross-ls)//*[1]/fid/t:cat">
										<xsl:copy-of select="ext:nodeset($gross-ls)//*[1]/fid/t:cat"/>
									</xsl:when>
		 							<xsl:when test="ext:nodeset($refund-ls)//*[1]/fid/t:dept">
										<xsl:copy-of select="ext:nodeset($refund-ls)//*[1]/fid/t:cat"/>
									</xsl:when>
									<xsl:when test="ext:nodeset($grossFees-ls)//*[1]/t:dept ">
										<xsl:copy-of select="ext:nodeset($grossFees-ls)//*[1]/t:cat "/>
									</xsl:when>
		 							<xsl:when test="ext:nodeset($refundFees-ls)//*[1]/t:dept">
										<xsl:copy-of select="ext:nodeset($refundFees-ls)//*[1]/t:cat"/>
									</xsl:when>
								</xsl:choose> 
								<xsl:element name="{$grossSales}">
									<xsl:element name="amount">
	
											<xsl:value-of select="format-number(sum(ext:nodeset($gross-ls)/*/stot) +                        sum(ext:nodeset($discounts-ls)//amt) +                       sum(ext:nodeset($grossFees-ls)//amt),'0.00')"/>
	
									</xsl:element>									
									<xsl:element name="qty">
										<xsl:value-of select="sum(ext:nodeset($gross-ls)/*/qty) +                     format-number(count(ext:nodeset($grossFees-ls)/*),'0')"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="{$refunds}">
									<xsl:element name="amount">
										<xsl:value-of select="format-number(sum(ext:nodeset($refund-ls)//stot),'0.00') +                      format-number(sum(ext:nodeset($refundFees-ls)//amt),'0.00')"/>
									</xsl:element>
									<xsl:element name="qty">
										<xsl:value-of select="sum(ext:nodeset($refund-ls)/*/qty)  +                     format-number(count(ext:nodeset($refundFees-ls)/*),'-0')"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="{$discounts}">
									<xsl:element name="amount">
										<xsl:value-of select="format-number(sum(ext:nodeset($discounts-ls)//amt),'0.00')"/>
									</xsl:element>
									<xsl:element name="count">
										<xsl:value-of select="count(ext:nodeset($discounts-ls)/*)"/>
									</xsl:element>
								</xsl:element>
							</xsl:element>
						</xsl:if>
					</xsl:for-each>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		
		<t:cashierTracking>
			
			<xsl:copy-of select="$header"/>
			
			<xsl:copy-of select="$allCashiers"/>
		</t:cashierTracking>
	</xsl:template>
	
	<xsl:template name="ns:getCashierList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="uniqueCashierList">
			<xsl:call-template name="ns2:getCashierList">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($tlogEntrySet)"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="uniqueRegisterList">
			<xsl:call-template name="ns2:getRegisterList">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($tlogEntrySet)"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:for-each select="ext:nodeset($uniqueCashierList)/t:cashier [(@sysid !='0') ]">
			<xsl:variable name="curCsh" select="."/>
			<xsl:for-each select="ext:nodeset($uniqueRegisterList)/t:register">
				<xsl:variable name="curReg" select="."/>
				<xsl:if test="count(ext:nodeset($tlogEntrySet)/*[               hdr/t:register/@sysid = $curReg/@sysid               and hdr/t:register/@till = $curReg/@till               and t:cashier/@sysid = $curCsh/@sysid               and t:cashier/period = $curCsh/period]) &gt; 0">
					<xsl:element name="cashierRegisterPair">
						<xsl:copy-of select="$curCsh"/>
						<xsl:copy-of select="$curReg"/>
					</xsl:element>
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="ns:getTLogEntriesForCashier">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="cashierPair"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="ns-cashier" select="ext:nodeset($cashierPair)"/>
		<xsl:copy-of select="$ns-set/*[             (t:cashier/@sysid = $ns-cashier//t:cashier/@sysid            and hdr/t:register/@sysid = $ns-cashier//t:register/@sysid             and hdr/t:register/@till = $ns-cashier//t:register/@till)            and             (not($ns-cashier//period) or (t:cashier/period = $ns-cashier//period) )]"/>
	</xsl:template>
	
	<xsl:template name="ns:getFeesForDept">
		<xsl:param name="lineSet"/>
		<xsl:param name="dept"/>
		<xsl:variable name="ns-set" select="ext:nodeset($lineSet)"/>
		<xsl:variable name="ns-dept" select="ext:nodeset($dept)"/>
		<xsl:copy-of select="$ns-set/t:line[ t:fee/t:dept/@sysid = $ns-dept//@sysid ]/t:fee        | $ns-set/t:cline/t:sline[ t:fee/t:dept/@sysid = $ns-dept//@sysid ]/t:fee        | $ns-set/t:sline[ t:fee/t:dept/@sysid = $ns-dept//@sysid ]/t:fee"/>		
	</xsl:template>
	
	<xsl:template name="ns:getFeesForCat">
		<xsl:param name="lineSet"/>
		<xsl:param name="cat"/>
		<xsl:variable name="ns-set" select="ext:nodeset($lineSet)"/>
		<xsl:variable name="ns-cat" select="ext:nodeset($cat)"/>
		<xsl:copy-of select="$ns-set/t:line[ t:fee/t:cat/@sysid = $ns-cat//@sysid ]/t:fee        | $ns-set/t:cline/t:sline[ t:fee/t:cat/@sysid = $ns-cat//@sysid ]/t:fee        | $ns-set/t:sline[ t:fee/t:cat/@sysid = $ns-cat//@sysid ]/t:fee"/>		
	</xsl:template>
	
	<xsl:template name="ns:getTLogEntriesForFeeCat">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="cat"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="ns-cat" select="ext:nodeset($cat)"/>
		<xsl:copy-of select="$ns-set/*[ lines/t:line/t:fee/t:cat/@sysid = $ns-cat//@sysid ]         | $ns-set/*[ lines/t:cline/t:fee/t:cat/@sysid = $ns-cat//@sysid ]"/>
	</xsl:template>
</xsl:stylesheet>