<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildClerkAnalysis" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:fuel="urn:vfi-sapphire:fuel.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" xmlns:vt="urn:vfi-valero:tlog.2004-05-26" version="1.0" exclude-result-prefixes="xsl ext ns vs js fuel base vt ns2">
	
	<xsl:import href="lists.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:deptMap">deptMap</xsl:param>
	<xsl:param name="ns:categoryMap">categoryMap</xsl:param>
	<xsl:param name="ns:reportPrefs">reptPrefs.xml</xsl:param>
	<xsl:param name="ns:reptMerchName">merchandiseSales</xsl:param>
	<xsl:param name="ns:driveOffName">driveOffs</xsl:param>
	<xsl:param name="ns:reptCWName">carWashSales</xsl:param>
	<xsl:param name="ns:overShortName">overShort</xsl:param>
	<xsl:param name="ns:creditName">creditSales</xsl:param>	
	<xsl:param name="ns:rollUpCashier">false</xsl:param>
	<xsl:param name="ns:uomType">USG</xsl:param>
	<xsl:param name="ns:currencyType">USD</xsl:param>
	<xsl:param name="ns:compCWAmt">0.01</xsl:param>
	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		
		<xsl:variable name="rptPrefDoc" select="document(string($ns:reportPrefs))//reptDefinitionMap"/>

		
	<xsl:variable name="oc">
		<xsl:copy-of select="ext:node-set($baseRawSet)/t:openCashier"/>
	</xsl:variable>
	<xsl:variable name="rawcc">
	 	<xsl:copy-of select="ext:node-set($baseRawSet)/t:closeCashier"/>
	 </xsl:variable>

	<xsl:variable name="cc">
	 	<xsl:for-each select="ext:node-set($rawcc)/t:closeCashier">
	 	
				<xsl:sort data-type="number" order="ascending" select="concat(substring(open,3,2), substring(open,6,2),substring(open,9,2), substring(open,12,2), substring(open,15,2))"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
	 </xsl:variable>
	<xsl:variable name="pc">
		<xsl:copy-of select="ext:node-set($baseRawSet)/t:countCashier"/>
	</xsl:variable>

	<xsl:variable name="cashiers">
	
		<xsl:for-each select="ext:node-set($cc)/t:closeCashier">
			<xsl:variable name="currCsh" select="ext:node-set(./t:cashier)"/>
			<xsl:variable name="currReg" select="ext:node-set(./hdr/t:register)"/>

			<xsl:element name="cashier">

				<xsl:variable name="test" select="ext:node-set($pc)/t:countCashier[t:cashier/@sysid = $currCsh//@sysid and                 t:cashier/period = $currCsh//period                 and hdr/t:register/@sysid = $currReg//@sysid]"/>

				<xsl:attribute name="sysid"><xsl:value-of select="t:cashier/@sysid"/></xsl:attribute>
				<xsl:attribute name="empnum"><xsl:value-of select="t:cashier/@number"/></xsl:attribute>
				<xsl:attribute name="register"><xsl:value-of select="hdr/t:register/@sysid"/></xsl:attribute>
				<xsl:attribute name="drw"><xsl:value-of select="hdr/t:register/@till"/></xsl:attribute>
				<xsl:choose>
					<xsl:when test="$test">
						<xsl:attribute name="enteredData">true</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="enteredData">false</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:element name="name"><xsl:value-of select="t:cashier/name"/></xsl:element>
				<xsl:element name="seq"><xsl:value-of select="t:cashier/period"/></xsl:element>
				<xsl:element name="startDateTime"><xsl:value-of select="open"/></xsl:element>
				<xsl:element name="endDateTime"><xsl:value-of select="close"/></xsl:element>

				<xsl:variable name="rawLineSet">
					<xsl:copy-of select="$baseRawSet/*[t:cashier/@sysid = $currCsh//@sysid                    and t:cashier/period = $currCsh//period                   and hdr/t:register/@sysid = $currReg//@sysid]"/> 
				</xsl:variable>

				<xsl:variable name="mdse">
					<xsl:call-template name="ns:createMerchandiseTotals">
						<xsl:with-param name="tlogEntrySet" select="$rawLineSet"/>
						<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:element name="vt:insideSales">
					<xsl:element name="count">
						<xsl:value-of select="sum(ext:node-set($mdse)//salesLineCount)"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="format-number((sum(ext:node-set($mdse)//salesAmount) + sum(ext:node-set($mdse)//refundAmount)),'0.00')"/>
					</xsl:element>
				</xsl:element>
				
				<xsl:element name="vt:avgMdseSale">
					<xsl:element name="count">
						<xsl:value-of select="ext:node-set($mdse)//salesCustCount"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:choose>
							<xsl:when test="ext:node-set($mdse)//salesCustCount != 0">
								<xsl:value-of select="format-number((sum(ext:node-set($mdse)//salesAmount) + sum(ext:node-set($mdse)//refundAmount))div ext:node-set($mdse)//salesCustCount , '0.00')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number((0.00) , '0.00')"/>
							</xsl:otherwise> 
						</xsl:choose>
					</xsl:element>
				</xsl:element>
				
				<xsl:element name="vt:cashOverShort">
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:choose>
							<xsl:when test="$test">
								<xsl:variable name="overShort">
									<xsl:call-template name="ns:createOverShort">
										<xsl:with-param name="tlogEntrySet" select="$rawLineSet"/>
										<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
									</xsl:call-template>
								</xsl:variable>
									<xsl:value-of select="format-number(sum(ext:node-set($overShort)/*/TotalOverShortAmt), '0.00')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number((0.00) , '0.00')"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
				</xsl:element>
				<xsl:element name="vt:noSales">
					<xsl:element name="count">
						<xsl:value-of select="count(ext:node-set($rawLineSet)/t:tillNosale)"/>
					</xsl:element>
				</xsl:element>

				<xsl:element name="vt:totalVoids">
					<xsl:element name="count">
						<xsl:value-of select="count(ext:node-set($rawLineSet)/t:void)"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="format-number(sum(ext:node-set($rawLineSet)/t:void/sum/beforeTax), '0.00')"/>
					</xsl:element>
				</xsl:element>
				
				<xsl:element name="vt:mdseVoids">
					<xsl:element name="count">
						<xsl:value-of select="sum(ext:node-set($mdse)//voidsCount)"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="format-number(sum(ext:node-set($mdse)//voidsAmount),'0.00')"/>					
					</xsl:element>
				</xsl:element>

				<xsl:element name="vt:refunds">
					<xsl:element name="count">
						<xsl:value-of select="count(ext:node-set($rawLineSet)/t:sale[@isRefund='true'])"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="format-number( sum(ext:node-set($rawLineSet)/t:sale[@isRefund='true']/sum/total), '0.00')"/>
					</xsl:element>
				</xsl:element>

				<xsl:variable name="prcOvrs">
					<xsl:copy-of select="ext:node-set($rawLineSet)/*/lines/t:line[priceOverride]"/>
				</xsl:variable>
				<xsl:element name="vt:prcOvrs">
					<xsl:element name="count">
						<xsl:value-of select="count(ext:node-set($prcOvrs)/t:line)"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="format-number((               (sum(ext:node-set($prcOvrs)/t:line/itmprc)) - (sum(ext:node-set($prcOvrs)/t:line/priceOverride/oldprc)))               , '0.00')"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="vt:drvOffs">
					<xsl:call-template name="ns:createDriveOffTotals">
						<xsl:with-param name="tlogEntrySet" select="$rawLineSet"/>
						<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
					</xsl:call-template>
				</xsl:element>
				<xsl:element name="vt:cancelPrePay">
					<xsl:element name="count">
						<xsl:value-of select="count(ext:node-set($rawLineSet)/t:event[@type='fuelPrepaidCancel'])"/>
					</xsl:element>
				</xsl:element>

				<xsl:element name="vt:drwAlarms">
					<xsl:element name="count">
						<xsl:value-of select="count(ext:node-set($rawLineSet)/t:event[@type='drawerAlarm'])"/>
					</xsl:element>
				</xsl:element>
				
				<xsl:variable name="manDeptSales">
					<xsl:call-template name="ns:createItemTotals">
						<xsl:with-param name="tlogEntrySet" select="$rawLineSet"/>
						<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:element name="vt:manualDeptSales">
					<xsl:element name="count">
						<xsl:value-of select="(ext:node-set($manDeptSales)/openDeptRings/count              + ext:node-set($manDeptSales)/pluNotFoundItems/count)"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="(ext:node-set($manDeptSales)/openDeptRings/amount              + ext:node-set($manDeptSales)/pluNotFoundItems/amount)"/>
					</xsl:element>
				</xsl:element>
				
				<xsl:variable name="crdTots">
					<xsl:call-template name="ns:createCreditTotals">
						<xsl:with-param name="tlogEntrySet" select="$rawLineSet"/>
						<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:element name="vt:nonSwipeCC">
					<xsl:element name="count">
						<xsl:value-of select="ext:node-set($crdTots)/manuallyEntered/count"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="ext:node-set($crdTots)/manuallyEntered/amount"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="vt:imprintCC">
					<xsl:element name="count">
						<xsl:value-of select="ext:node-set($crdTots)/imprinted/count"/>					
					</xsl:element>
					<xsl:element name="amount">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="ext:node-set($crdTots)/imprinted/amount"/>					
					</xsl:element>
				</xsl:element>

				<xsl:variable name="cwTots">
				<xsl:call-template name="ns:createCarwashTotals">
					<xsl:with-param name="tlogEntrySet" select="$rawLineSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>				
				</xsl:variable>
				<xsl:element name="vt:compCarWash">
					<xsl:element name="count">
						<xsl:value-of select="ext:node-set($cwTots)/carWashComp/count"/>
					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:variable>
	

		
		<xsl:element name="vt:clerkAnalysis">
			
			<xsl:call-template name="ns:createHeader">
				<xsl:with-param name="header" select="$baseRawSet/t:hdr"/>
			</xsl:call-template>
			<xsl:copy-of select="$cashiers"/>
		</xsl:element>
	</xsl:template>



	<xsl:template name="ns:createHeader">
		<xsl:param name="header"/>
		<xsl:variable name="hdr" select="ext:node-set($header)"/>
		<xsl:element name="vt:hdr">
			<xsl:element name="site">
				<xsl:value-of select="$hdr/vs:site"/>
			</xsl:element>
			<xsl:element name="period">
				<xsl:value-of select="$hdr/vs:period/@periodType"/>
			</xsl:element>
			<xsl:element name="seq">
				<xsl:value-of select="$hdr/seq"/>
			</xsl:element>
			<xsl:element name="startDateTime">
				<xsl:value-of select="$hdr/startDateTime"/>
			</xsl:element>
			<xsl:element name="endDateTime">
				<xsl:value-of select="$hdr/endDateTime"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template name="ns:createMerchandiseTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="rptPrefDoc" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="string($ns:reptMerchName)"/>
			</xsl:call-template>
		</xsl:variable>



		<xsl:variable name="categoryList">
			<xsl:call-template name="ns2:getCategoryListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="depList" select="ext:node-set($departmentList)"/>
		<xsl:variable name="catList" select="ext:node-set($categoryList)"/>


		<xsl:variable name="merch">
			<xsl:for-each select="ext:node-set($categoryList)/t:cat">
				<xsl:variable name="currCategory" select="."/>
				<xsl:element name="categoryInfo">
					<xsl:copy-of select="$currCategory"/>





					<xsl:element name="salesAmount">
						<xsl:value-of select="format-number(sum(             $ns-set/t:sale[not (@isRefund='true')]/lines/t:line              [(fid/t:cat/@sysid = $currCategory/@sysid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |              $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline               [(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot             ), '0.00')"/>
					</xsl:element>
					<xsl:element name="salesLineCount">
						<xsl:value-of select="count(              $ns-set/t:sale[not (@isRefund='true')]/lines/t:line               [(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot |               $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline                [(fid/t:cat/@sysid = $currCategory/@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]/stot              )"/>
					</xsl:element>

					<xsl:element name="refundAmount">
						<xsl:value-of select="format-number(sum(            $ns-set/t:sale[@isRefund='true']/lines/t:line             [fid/t:cat/@sysid = $currCategory/@sysid             and (fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline              [fid/t:cat/@sysid = $currCategory/@sysid               and (fid/t:dept/@sysid = $depList//@sysid)]/stot            ), '0.00')"/>
					</xsl:element>
					<xsl:element name="refundCount">
						<xsl:value-of select="count(             $ns-set/t:sale[@isRefund='true']/lines/t:line              [(fid/t:cat/@sysid = $currCategory/@sysid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline              [(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot             )"/>
					</xsl:element>

					<xsl:element name="voidsAmount">
						<xsl:value-of select="format-number(sum(            $ns-set/t:void/lines/t:line[(fid/t:cat/@sysid = $currCategory/@sysid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:void/lines/t:cline/t:sline[(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot            ), '0.00')"/>
					</xsl:element>
					<xsl:element name="voidsCount">
						<xsl:value-of select="count(              $ns-set/t:void/lines/t:line[(fid/t:cat/@sysid = $currCategory/@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]/stot |               $ns-set/t:void/lines/t:cline/t:sline[(fid/t:cat/@sysid = $currCategory/@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]/stot                   )"/>
					</xsl:element>

			</xsl:element>

			</xsl:for-each>

			<xsl:element name="salesCustCount">
				<xsl:value-of select="count(          $ns-set/t:sale[not (@isRefund='true') and            lines/t:line[(fid/t:cat/@sysid = $catList//@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]] |           $ns-set/t:sale[not (@isRefund='true') and             lines/t:cline/t:sline[(fid/t:cat/@sysid = $catList//@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]]          )"/>
					</xsl:element>		
			</xsl:variable>
		<xsl:copy-of select="$merch"/>
	</xsl:template>


	<xsl:template name="ns:createSetOfLines">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:param name="rptName"/>
		<xsl:variable name="rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="rawSet" select="ext:node-set($tlogEntrySet)"/>


		<xsl:variable name="rawRptPrefs" select="$rptPrefs//*[*=$rptName]"/>
		<xsl:variable name="setOfLines">
			<xsl:choose>

				<xsl:when test="local-name($rawRptPrefs) = $ns:deptMap">
					<xsl:variable name="deptList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:dept">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:node-set($deptList)/*">
							<xsl:variable name="currDept" select="."/>
							<xsl:call-template name="ns2:getLinesForDept">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="dept" select="$currDept"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>

				<xsl:when test="local-name($rawRptPrefs) = $ns:categoryMap">
					<xsl:variable name="catList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:cat">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:node-set($catList)/*">
							<xsl:variable name="currCat" select="."/>
							<xsl:call-template name="ns2:getLinesForCategory">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="cat" select="$currCat"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$setOfLines"/>
	</xsl:template>
		
	<xsl:template name="ns:createOverShort">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="overShortPrefs" select="$rptPrefs//*[*=$ns:overShortName]"/>
		
		<xsl:variable name="mopLineSet">
			<xsl:for-each select="ext:node-set($overShortPrefs)/t:mop">
				<xsl:variable name="currMOP" select="."/>
				<xsl:element name="overShortMOP">
					<xsl:copy-of select="$currMOP"/>
					<xsl:variable name="ecrAmt">
						<xsl:value-of select="format-number(sum(             $ns-set/t:countCashier/tillAmount              [t:mop/@sysid = $currMOP/@sysid]/ecrAmount             ), '0.00')"/>
					</xsl:variable>
					<xsl:variable name="actualAmt">
						<xsl:value-of select="format-number(sum(             $ns-set/t:countCashier/tillAmount              [t:mop/@sysid = $currMOP/@sysid]/actualAmount             ), '0.00')"/>
					</xsl:variable>
					<xsl:element name="TotalEcrAmt">
						<xsl:value-of select="$ecrAmt"/>
					</xsl:element>
					<xsl:element name="TotalActualAmt">
						<xsl:value-of select="$actualAmt"/>
					</xsl:element>
					<xsl:element name="TotalOverShortAmt">
						<xsl:value-of select="format-number(($actualAmt - $ecrAmt) ,'0.00')"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="$mopLineSet"/>
	</xsl:template>
	
	<xsl:template name="ns:createCreditTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>

			<xsl:variable name="creditLineSet">
				<xsl:call-template name="ns:getCreditLineSet">
					<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
					<xsl:with-param name="reportPrefs" select="$ns-rptPrefs"/>
				</xsl:call-template>
			</xsl:variable>
	<xsl:variable name="creditPrefs" select="$ns-rptPrefs//*[*=$ns:creditName]"/>


			<xsl:variable name="totCnt" select="count(ext:node-set($creditLineSet)/*)"/>
			<xsl:variable name="totAmt" select="sum(ext:node-set($creditLineSet)/*            /paylines/t:payline[t:mop/@sysid = $creditPrefs//@sysid]/amt)"/> 


			<xsl:variable name="swipeCnt" select="count(ext:node-set($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'swipe'])"/>
			<xsl:variable name="swipeAmt" select="sum(ext:node-set($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'swipe']/../../amt)"/>


			<xsl:variable name="manEntryCnt" select="count(ext:node-set($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'manual'])"/>
			<xsl:variable name="manEntryAmt" select="sum(ext:node-set($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'manual']/../../amt)"/>


			<xsl:variable name="imprintCnt" select="count(ext:node-set($creditLineSet)/*            /paylines/t:payline[not(t:cardInfo)            and (t:mop/@sysid = $creditPrefs//@sysid)])"/>
			<xsl:variable name="imprintAmt" select="sum(ext:node-set($creditLineSet)/*            /paylines/t:payline[not(t:cardInfo)            and (t:mop/@sysid = $creditPrefs//@sysid)]/amt)"/>
											

			<xsl:variable name="creditTot">
				<xsl:element name="totalCreditCount">
					<xsl:element name="count">
						<xsl:value-of select="$totCnt"/>
					</xsl:element>
					<xsl:element name="percent">
						<xsl:choose>
							<xsl:when test="$totCnt= 0">
								<xsl:value-of select="format-number(0.00, '0.00')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(($totCnt div $totCnt * 100), '0.00')"/>												</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:value-of select="format-number($totAmt, '0.00')"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="swiped">
					<xsl:element name="count">
						<xsl:value-of select="$swipeCnt"/>
					</xsl:element>
					<xsl:element name="percent">
						<xsl:choose>
							<xsl:when test="$swipeCnt= 0">
								<xsl:value-of select="format-number(0.00, '0.00')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(($swipeCnt div $totCnt * 100), '0.00')"/>												</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:value-of select="format-number($swipeAmt, '0.00')"/>
					</xsl:element>
				</xsl:element>

				<xsl:element name="manuallyEntered">
					<xsl:element name="count">
						<xsl:value-of select="$manEntryCnt"/>
					</xsl:element>
					<xsl:element name="percent">
						<xsl:choose>
							<xsl:when test="$manEntryCnt= 0">
								<xsl:value-of select="format-number(0.00, '0.00')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(($manEntryCnt div $totCnt * 100), '0.00')"/>												</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:value-of select="format-number($manEntryAmt, '0.00')"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="imprinted">
					<xsl:element name="count">
						<xsl:value-of select="$imprintCnt"/>
					</xsl:element>
					<xsl:element name="percent">
						<xsl:choose>
							<xsl:when test="$imprintCnt= 0">
								<xsl:value-of select="format-number(0.00, '0.00')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(($imprintCnt div $totCnt * 100), '0.00')"/>												</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:value-of select="format-number($imprintAmt, '0.00')"/>
					</xsl:element>
				</xsl:element>
			</xsl:variable>	
			<xsl:copy-of select="$creditTot"/>
	</xsl:template>
		
	<xsl:template name="ns:getCreditLineSet">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="creditPrefs" select="$rptPrefs//*[*=$ns:creditName]"/>
		<xsl:variable name="creditLineSet">
			<xsl:for-each select="ext:node-set($creditPrefs)/t:mop">
				<xsl:variable name="currMOP" select="."/>
				<xsl:copy-of select="$ns-set/*/paylines/t:payline[t:mop/@sysid = $currMOP/@sysid]/../.."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="$creditLineSet"/>
	</xsl:template>
	

	<xsl:template name="ns:createItemTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		
		<xsl:variable name="rptPrefDoc" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>

		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="string($ns:reptMerchName)"/>
			</xsl:call-template>
		</xsl:variable>
		

		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="depList" select="ext:node-set($departmentList)"/>


		<xsl:variable name="ns-sales" select="$ns-set/t:sale | $ns-set/t:adjustment"/>
		<xsl:variable name="itemTotals">
			<xsl:element name="totalPLUs">
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)]                  )"/>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot            ), '#.00')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="scannedItems">
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                    and (flags/@scanned='true')] |              $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                    and (flags/@scanned='true')] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (flags/@scanned='true')] |              $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (flags/@scanned='true')]                  )"/>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot |            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot  |                $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot             ), '#.00')"/>			
				</xsl:element>
			</xsl:element>
			<xsl:element name="keyedItems">
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                    and (not (flags/@scanned='true'))] |              $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)                      and (fid/t:dept/@sysid = $depList//@sysid)                    and (not (flags/@scanned='true'))] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (not (flags/@scanned='true'))] |              $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (not (flags/@scanned='true'))]                 )"/>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot |            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot |            $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot                 ), '#.00')"/>				</xsl:element>
			</xsl:element>
			<xsl:element name="openDeptRings">
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[not (iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:adjustment/lines/t:line[not (iid)                       and (fid/t:dept/@sysid = $depList//@sysid)              ])"/>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[not (iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:adjustment/lines/t:line[not (iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot                 ), '#.00')"/>			
				</xsl:element>
			</xsl:element>
			<xsl:element name="pluNotFoundItems">
				<xsl:variable name="pamt" select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@pluNotFound='true')]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@pluNotFound='true')]/stot                 ), '#.00')"/>
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                     and (flags/@pluNotFound='true')] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                   and (flags/@pluNotFound='true')              ])"/>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@pluNotFound='true')]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@pluNotFound='true')]/stot                 ), '#.00')"/>
				</xsl:element>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$itemTotals"/>
	</xsl:template>

	<xsl:template name="ns:createDriveOffTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="driveOffPrefs" select="$rptPrefs//*[*=$ns:driveOffName]"/>
		<xsl:variable name="doTots">
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $driveOffPrefs//@sysid])"/>
			</xsl:element>
			<xsl:element name="amount">
				<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
				<xsl:value-of select="format-number(sum(           $ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $driveOffPrefs//@sysid]/amt           ),'0.00')"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$doTots"/>
	</xsl:template>
	
	<xsl:template name="ns:createCarwashTotals">
			<xsl:param name="tlogEntrySet"/>
			<xsl:param name="reportPrefs"/>
			<xsl:variable name="ns-rptPrefs" select="ext:node-set($reportPrefs)"/>
			<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>

			<xsl:variable name="carwashLineSet">
				<xsl:call-template name="ns:getCarwashSales">
					<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
					<xsl:with-param name="reportPrefs" select="$ns-rptPrefs"/>
				</xsl:call-template>
			</xsl:variable>

		<xsl:variable name="rawIdList">
			<xsl:call-template name="ns2:getPluListFromLines">
				<xsl:with-param name="lineSet" select="$carwashLineSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="cwList">
		<xsl:for-each select="ext:node-set($rawIdList)/t:plu">
			<xsl:variable name="currPLU" select="."/>
			<xsl:variable name="PLULines">
				<xsl:call-template name="ns2:getLinesForPlu">
					<xsl:with-param name="lineSet" select="$carwashLineSet"/>
					<xsl:with-param name="plu" select="$currPLU"/>
				</xsl:call-template>
			</xsl:variable>

			
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:node-set($PLULines)/t:line">
					<xsl:sort data-type="number" order="ascending" select="./tot"/>
					<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>

			<xsl:variable name="prices" select="ext:node-set($sortedList)/t:line[                 not( tot = preceding-sibling::t:line[1]/tot)]/tot"/>

		
				<xsl:variable name="carWashSales">
				<xsl:for-each select="ext:node-set($prices)">
					<xsl:variable name="currPrice" select="."/>
					<xsl:element name="carWashSaleItem">
						<xsl:copy-of select="$currPLU"/>
						<xsl:element name="soldAtPrice">
							<xsl:value-of select="$currPrice"/>
						</xsl:element>
						<xsl:element name="count">
							<xsl:value-of select="count(ext:node-set($PLULines)/*[tot = $currPrice])"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
				</xsl:variable>
				<xsl:copy-of select="$carWashSales"/>
		</xsl:for-each>
		</xsl:variable>


		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:node-set($cwList)/carWashSaleItem">
				<xsl:sort order="ascending" data-type="number" select="soldAtPrice"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>

			<xsl:element name="carWashComp">
				<xsl:element name="count">
					<xsl:value-of select="sum(ext:node-set($cwList)/carWashSaleItem[soldAtPrice= $ns:compCWAmt]/count)"/>
				</xsl:element>
			</xsl:element>
		</xsl:variable>
 	  <xsl:copy-of select="$sortedList"/>
	</xsl:template>


	<xsl:template name="ns:getCarwashSales">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="rptPrefs" select="ext:node-set($reportPrefs)"/>
		<xsl:variable name="rawSet" select="ext:node-set($tlogEntrySet)"/>


		<xsl:variable name="rawRptPrefs" select="$rptPrefs//*[*=$ns:reptCWName]"/>
		<xsl:variable name="setOfLines">
			<xsl:choose>

				<xsl:when test="local-name($rawRptPrefs) = $ns:deptMap">
					<xsl:variable name="deptList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:dept">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:node-set($deptList)/*">
							<xsl:variable name="currDept" select="."/>
							<xsl:call-template name="ns2:getLinesForDept">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="dept" select="$currDept"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>

				<xsl:when test="local-name($rawRptPrefs) = $ns:categoryMap">
					<xsl:variable name="catList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:cat">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:node-set($catList)/*">
							<xsl:variable name="currCat" select="."/>
							<xsl:call-template name="ns2:getLinesForCategory">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="cat" select="$currCat"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$setOfLines"/>
	</xsl:template>

</xsl:stylesheet>