<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildCustomerCount" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2 js vs">
	<xsl:import href="lists.xslt"/>
	<xsl:import href="../transactionSet/scripts.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:periodType" select="0"/>

	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>

	<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>			

		
	<xsl:variable name="completeSaleSet">
		<xsl:call-template name="ns2:getSaleSet">
			<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
		</xsl:call-template>
	</xsl:variable>
		

	<xsl:variable name="rawCashierList">
		<xsl:call-template name="ns2:getCashierList">
			<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
		</xsl:call-template>
	</xsl:variable>
	

	<xsl:variable name="cashierList">
		<xsl:copy-of select="ext:node-set($rawCashierList)/t:cashier[not( @sysid = preceding-sibling::t:cashier          [1]/@sysid)]"/>
	</xsl:variable>
		

	<xsl:variable name="prdType"><vs:period sysid="{$ns:periodType}"/></xsl:variable> 
		<xsl:variable name="periodList">
			<xsl:call-template name="ns2:getPeriodList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				<xsl:with-param name="period" select="$prdType"/>
			</xsl:call-template>
		</xsl:variable>
		

	<xsl:variable name="salesByHour">
		<xsl:for-each select="ext:node-set($periodList)/*">
			<xsl:variable name="period" select="."/>
				<xsl:element name="hour">
					<xsl:attribute name="sysid"><xsl:value-of select="./@periodSeqNum"/></xsl:attribute>
						<xsl:call-template name="ns2:getTLogEntriesForPeriod">
							<xsl:with-param name="tlogEntrySet" select="$completeSaleSet"/>
							<xsl:with-param name="period" select="$period"/>
						</xsl:call-template>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		

	<xsl:variable name="salesByHalfHour">
		<xsl:for-each select="ext:node-set($salesByHour)/hour">
			<xsl:variable name="hour" select="@sysid"/>
			<xsl:variable name="hourSale" select="./t:sale"/>
			<xsl:element name="hour">
			<xsl:value-of select="$hour"/>
				<xsl:for-each select="$hourSale">
					<xsl:choose>
					
						<xsl:when test="js:computeHalfHour(string(./hdr/dateTime)) = 0 ">
							<xsl:element name="info">
							<xsl:attribute name="sysid">00</xsl:attribute>
							<xsl:copy-of select="./hdr/dateTime"/>
							<xsl:copy-of select="./hdr/t:register"/>
							<xsl:copy-of select="./t:cashier"/>
							<xsl:copy-of select="./sum/beforeTax"/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="info">
							<xsl:attribute name="sysid">30</xsl:attribute>
							<xsl:copy-of select="./hdr/dateTime"/>
							<xsl:copy-of select="./hdr/t:register"/>
							<xsl:copy-of select="./t:cashier"/>
							<xsl:copy-of select="./sum/beforeTax"/>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:element>
		</xsl:for-each>
	</xsl:variable>




	<xsl:variable name="byCashiers">
		<xsl:for-each select="ext:node-set($cashierList)/t:cashier">
			<xsl:variable name="currCashier" select="."/>
			<xsl:element name="cashierHours">
				<xsl:element name="t:cashier">
					<xsl:attribute name="sysid">
						<xsl:value-of select="$currCashier/@sysid"/>
					</xsl:attribute>
					<xsl:attribute name="number">
						<xsl:value-of select="$currCashier/@number"/>
					</xsl:attribute>
					<xsl:element name="name">
						<xsl:value-of select="$currCashier/name"/>
					</xsl:element>
				</xsl:element>
				
				<xsl:choose>
					<xsl:when test="$currCashier/@sysid = '0'">
						<xsl:element name="location">outside</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="location">inside</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:for-each select="ext:node-set($salesByHalfHour)/hour">
					<xsl:variable name="nhour" select="node()"/>
						<xsl:element name="hourDesignation">
							<xsl:attribute name="sysid"><xsl:value-of select="$nhour"/></xsl:attribute>
								<xsl:element name="minutesDesignation">
									<xsl:attribute name="sysid">00</xsl:attribute>
									<xsl:element name="custCount">
										<xsl:value-of select="count(./info[@sysid='00']/t:cashier                        [@sysid=$currCashier/@sysid])"/>																	</xsl:element>
									<xsl:element name="salesAmount">
										<xsl:value-of select="format-number(sum(./info[(@sysid='00')                   and (t:cashier/@sysid=$currCashier/@sysid)]/beforeTax), '0.00')"/>								
									</xsl:element>
								</xsl:element>
								<xsl:element name="minutesDesignation">
									<xsl:attribute name="sysid">30</xsl:attribute>
									<xsl:element name="custCount">
										<xsl:value-of select="count(./info[@sysid='30']/t:cashier                        [@sysid=$currCashier/@sysid])"/>		
									</xsl:element>
									<xsl:element name="salesAmount">
										<xsl:value-of select="format-number(sum(./info[(@sysid='30')                   and (t:cashier/@sysid=$currCashier/@sysid)]/beforeTax), '0.00')"/>								
									</xsl:element>

								</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>


		<xsl:element name="t:hourlyCustomerCount">
			<xsl:copy-of select="$baseRawSet/t:hdr"/>
			
			<xsl:element name="byCashiers">
				<xsl:copy-of select="$byCashiers"/>
			</xsl:element>
		</xsl:element>				
	</xsl:template>

</xsl:stylesheet>