<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildFuelTransactionIndicators" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2  vs jsc xsi base">


	<xsl:import href="lists.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:driveoff" select="14"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>

		<xsl:variable name="cashierList">
			<xsl:call-template name="ns2:getCashierList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>

		<xsl:variable name="allCashiers">
			<xsl:for-each select="ext:node-set($cashierList)/t:cashier [(not( @sysid = preceding-sibling::t:cashier             [1]/@sysid)) and (@sysid !='0') ]">
			<xsl:variable name="currCashier" select="."/>
			<xsl:element name="cashierInfo">
				<xsl:element name="t:cashier">
					<xsl:attribute name="sysid">
						<xsl:value-of select="$currCashier/@sysid"/>
					</xsl:attribute>
					<xsl:attribute name="number">
						<xsl:value-of select="$currCashier/@number"/>
					</xsl:attribute>
					<xsl:element name="name">
						<xsl:value-of select="$currCashier/name"/>
					</xsl:element>
				</xsl:element>
				<xsl:variable name="completeCashierTlogEntries">
					<xsl:call-template name="ns:getTLogEntriesForCashier">
						<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
						<xsl:with-param name="cashier" select="$currCashier"/>
					</xsl:call-template>
				</xsl:variable>


				<xsl:variable name="allPumpTest">
					<xsl:copy-of select="ext:node-set($completeCashierTlogEntries)/t:pumpTest"/>
				</xsl:variable>
				<pumptests><xsl:copy-of select="$allPumpTest"/></pumptests>

				<xsl:variable name="allDriveOffs">
					<xsl:copy-of select="ext:node-set($completeCashierTlogEntries)/t:sale/paylines/t:payline/t:mop[@cat=             $ns:driveoff]/../../.."/>
				</xsl:variable>
				<driveoffs><xsl:copy-of select="$allDriveOffs"/></driveoffs>

				<xsl:variable name="allPrepayCancel">
					<xsl:copy-of select="ext:node-set($completeCashierTlogEntries)/t:event[@type='fuelPrepaidCancel']"/>
				</xsl:variable>
				<prepayCancels><xsl:copy-of select="$allPrepayCancel"/></prepayCancels>

			</xsl:element>

		</xsl:for-each>
		
	</xsl:variable>
	<t:fuelTransactionIndicators>
		<xsl:copy-of select="$header"/>
		<xsl:apply-templates mode="ns:apply" select="ext:node-set($allCashiers)/*"/>
	</t:fuelTransactionIndicators>
	</xsl:template>
	
	<xsl:template name="ns:getTLogEntriesForCashier">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="cashier"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="ns-cashier" select="ext:node-set($cashier)"/>
		<xsl:copy-of select="$ns-set/*[ t:cashier/@sysid = $ns-cashier//@sysid]"/>
	</xsl:template>

	<xsl:template mode="ns:apply" match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*" mode="ns:attrs"/>
			<xsl:apply-templates mode="ns:apply"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="@*" mode="ns:attrs">
		<xsl:copy-of select="."/>
	</xsl:template>
		
	<xsl:template match="pumptests" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:for-each select="./*">
				<xsl:element name="pumptest">
	
					<xsl:copy-of select="./hdr/dateTime"/>

					<xsl:copy-of select="./hdr/t:register"/>

					<xsl:copy-of select="./t:cashier"/>

					<xsl:copy-of select="./vs:transactionSeq"/>

					<xsl:copy-of select="./lines/*/t:fuel"/>
				</xsl:element>
			</xsl:for-each>

			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(./t:pumpTest/paylines/t:payline/amt), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(./*)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
		
	<xsl:template match="driveoffs" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:for-each select="./*">
				<xsl:element name="driveoff">
	
					<xsl:copy-of select="./hdr/dateTime"/>

					<xsl:copy-of select="./hdr/t:register"/>

					<xsl:copy-of select="./t:cashier"/>

					<xsl:copy-of select="./vs:transactionSeq"/>

					<xsl:copy-of select="./lines/*/t:fuel"/>
				</xsl:element>
			</xsl:for-each>

			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(./t:sale/paylines/t:payline/amt), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(./*)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
		
	<xsl:template match="prepayCancels" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:for-each select="./*">
				<xsl:element name="prepaycancel">
	
					<xsl:copy-of select="./hdr/dateTime"/>

					<xsl:copy-of select="./hdr/t:register"/>

					<xsl:copy-of select="./t:cashier"/>

					<xsl:copy-of select="./vs:transactionSeq"/>

					<xsl:copy-of select="./t:fuelPrepay"/>
				</xsl:element>
			</xsl:for-each>

			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(./t:event/t:fuelPrepay/amt), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(./*)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
		
		
</xsl:stylesheet>