<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildHourly" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" xmlns:pd="urn:vfi-sapphire:pd.2002-05-21" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2 js t">
	<xsl:import href="lists.xslt"/>
	<xsl:import href="../transactionSet/scripts.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:periodType" select="0"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:variable name="hdr">
			<vs:period>
				<xsl:attribute name="sysid"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/vs:period/@sysid"/></xsl:attribute>
				<xsl:attribute name="periodType"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/vs:period/@periodType"/></xsl:attribute>
				<xsl:attribute name="name"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/vs:period/@periodType"/></xsl:attribute>
				<xsl:attribute name="periodSeqNum"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/vs:period/@periodSeqNum"/></xsl:attribute>
				<xsl:attribute name="periodBeginDate"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/startDateTime"/></xsl:attribute>
				<xsl:attribute name="periodEndDate"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/endDateTime"/></xsl:attribute>
			</vs:period>
			<vs:site>
				<xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/vs:site"/>
			</vs:site>
			
			<pd:constituentPeriods>
				<vs:period>
					<xsl:attribute name="sysid"><xsl:value-of select="'1'"/></xsl:attribute>
					<xsl:attribute name="periodType"><xsl:value-of select="'SHIFT'"/></xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="'SHIFT'"/></xsl:attribute>
					<xsl:attribute name="periodSeqNum"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/vs:period/@periodSeqNum"/></xsl:attribute>
					<xsl:attribute name="periodBeginDate"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/startDateTime"/></xsl:attribute>
					<xsl:attribute name="periodEndDate"><xsl:value-of select="ext:node-set($baseRawSet)//t:hdr[1]/endDateTime"/></xsl:attribute>
					<xsl:attribute name="isFirst"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:attribute name="isLast"><xsl:value-of select="'true'"/></xsl:attribute>
				</vs:period>
			</pd:constituentPeriods>
		</xsl:variable>
		
		<xsl:variable name="completeSaleSet">
			<xsl:call-template name="ns2:getSaleSet">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
			<xsl:copy-of select="ext:node-set($baseRawSet)//t:fuelReprintEvent"/>
		</xsl:variable>
		
		<xsl:variable name="registerList">
			<xsl:call-template name="ns2:getRegisterList">
				<xsl:with-param name="tlogEntrySet" select="$completeSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="prdType">
			<vs:period sysid="{$ns:periodType}"/>
		</xsl:variable>
		<xsl:variable name="periodList">
			<xsl:call-template name="ns2:getPeriodList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				<xsl:with-param name="period" select="$prdType"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="salesByHour">
			<xsl:for-each select="ext:node-set($periodList)/*">
				<xsl:variable name="period" select="."/>
				<xsl:element name="hour">
					<xsl:attribute name="sysid"><xsl:value-of select="./@periodSeqNum"/></xsl:attribute>
					<xsl:call-template name="ns2:getTLogEntriesForPeriod">
						<xsl:with-param name="tlogEntrySet" select="$completeSaleSet"/>
						<xsl:with-param name="period" select="$period"/>
					</xsl:call-template>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="hourlyTotals">
			
			<totals>
				<xsl:for-each select="ext:node-set($salesByHour)/hour">
					<xsl:variable name="thisHour">
						<xsl:copy-of select="."/>
					</xsl:variable>
					<hourlyInfo>
						<hour>
							<xsl:value-of select="@sysid"/>
						</hour>
						<itemCount>
							<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale/lines/t:line[not(t:fuel or t:fuelPrepay)]/qty) + count(ext:node-set($thisHour)//t:sale/lines/t:line[t:fuel or t:fuelPrepay]),'0.00')"/>
						</itemCount>
						<merchOnly>
							<count>
								<xsl:value-of select="format-number(count(ext:node-set($thisHour)//t:sale[not(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay)]),'0')"/>
							</count>
							<amount>
								<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale/lines[not(t:line/t:fuel or t:line/t:fuelPrepay)]/t:line/tot),'0.00')"/>
							</amount>
						</merchOnly>
						<merchFuel>
							<count>
								<xsl:value-of select="format-number(count(ext:node-set($thisHour)//t:sale[(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']] ),'0')"/>
							</count>
							<amount>
								<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']]/t:line/tot ),'0.00')"/>
							</amount>
						</merchFuel>
						<fuelOnly>
							<count>
								<xsl:value-of select="format-number(count(ext:node-set($thisHour)//t:sale[(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and not(lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]),'0') + format-number(count(ext:node-set($thisHour)//t:fuelReprintEvent),'0')"/>
							</count>
							<amount>
								<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and not(t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]/t:line/tot),'0.00')"/>
							</amount>
						</fuelOnly>
					</hourlyInfo>
					
				</xsl:for-each>
				<total>
					<merchOnly>
						<count>
							<xsl:value-of select="format-number(count(ext:node-set($completeSaleSet)//t:sale[not(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay)]),'0')"/>
						</count>
						<amount>
							<xsl:value-of select="format-number(sum(ext:node-set($completeSaleSet)//t:sale/lines[not(t:line/t:fuel or t:line/t:fuelPrepay)]/t:line/tot),'0.00')"/>
						</amount>
						
					</merchOnly>
					<merchFuel>
						<count>
							<xsl:value-of select="format-number(count(ext:node-set($completeSaleSet)//t:sale[(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']] ),'0')"/>
						</count>
						<amount>
							<xsl:value-of select="format-number(sum(ext:node-set($completeSaleSet)//t:sale/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']]/t:line/tot ),'0.00')"/>
						</amount>
						
					</merchFuel>
					<fuelOnly>
						<count>
							<xsl:value-of select="format-number(count(ext:node-set($completeSaleSet)//t:sale[(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and not(lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]),'0') + format-number(count(ext:node-set($completeSaleSet)//t:fuelReprintEvent),'0')"/>
						</count>
						<amount>
							<xsl:value-of select="format-number(sum(ext:node-set($completeSaleSet)//t:sale/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and not(t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]/t:line/tot),'0.00')"/>
						</amount>
						
					</fuelOnly>
				</total>
			</totals>
		</xsl:variable>
		<xsl:variable name="hourlyByRegister">
			
			<xsl:for-each select="ext:node-set($registerList)/*">
				<xsl:variable name="regNum">
					<xsl:value-of select="@sysid"/>
				</xsl:variable>
				<byRegister>
					<vs:register>
						<xsl:choose>
							
							<xsl:when test="@sysid='9'">
								<xsl:attribute name="sysid"><xsl:value-of select="'6'"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="sysid"><xsl:value-of select="$regNum"/></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					</vs:register>
					<xsl:variable name="tickNums">
						<xsl:copy-of select="ext:node-set($baseRawSet)/*[hdr/t:register/@sysid = $regNum]/vs:transactionSeq"/>
					</xsl:variable>
					<ticketRange>
						<begin>
							<xsl:value-of select="ext:node-set($tickNums)/*[1]"/>
						</begin>
						<end>
							<xsl:value-of select="ext:node-set($tickNums)/*[last()]"/>
						</end>
					</ticketRange>
					<xsl:for-each select="ext:node-set($salesByHour)/hour">
						<xsl:variable name="thisHour">
							<xsl:copy-of select="."/>
						</xsl:variable>
						<hourlyInfo>
							<hour>
								<xsl:value-of select="@sysid"/>
							</hour>
							<itemCount>
								<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum]/lines/t:line[not(t:fuel or t:fuelPrepay)]/qty) + count(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum]/lines/t:line[t:fuel or t:fuelPrepay]),'0.00')"/>
							</itemCount>
							<merchOnly>
								<count>
									<xsl:value-of select="format-number(count(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum and not(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay)]),'0')"/>
								</count>
								<amount>
									<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum]/lines[not(t:line/t:fuel or t:line/t:fuelPrepay)]/t:line/tot),'0.00')"/>
								</amount>
							</merchOnly>
							<merchFuel>
								<count>
									<xsl:value-of select="format-number(count(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum and (lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']] ),'0')"/>
								</count>
								<amount>
									<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum]/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']]/t:line/tot ),'0.00')"/>
								</amount>
							</merchFuel>
							<fuelOnly>
								<count>
									<xsl:value-of select="format-number(count(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum and (lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and not(lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]),'0') + format-number(count(ext:node-set($thisHour)//t:fuelReprintEvent[hdr/t:register/@sysid = $regNum]),'0')"/>
								</count>
								<amount>
									<xsl:value-of select="format-number(sum(ext:node-set($thisHour)//t:sale[hdr/t:register/@sysid = $regNum]/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and not(t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]/t:line/tot),'0.00')"/>
								</amount>
							</fuelOnly>
						</hourlyInfo>
						
					</xsl:for-each>
					<total>
						<merchOnly>
							<count>
								<xsl:value-of select="format-number(count(ext:node-set($completeSaleSet)//t:sale[hdr/t:register[@sysid = $regNum] and not(lines/t:line/t:fuel or lines/t:line/t:fuelPrepay)]),'0')"/>
							</count>
							<amount>
								<xsl:value-of select="format-number(sum(ext:node-set($completeSaleSet)//t:sale[hdr/t:register[@sysid = $regNum]]/lines[not(t:line/t:fuel or t:line/t:fuelPrepay)]/t:line/tot),'0.00')"/>
							</amount>
							
						</merchOnly>
						<merchFuel>
							<count>
								<xsl:value-of select="format-number(count(ext:node-set($completeSaleSet)//t:sale[hdr/t:register[@sysid = $regNum] and (lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']] ),'0')"/>
							</count>
							<amount>
								<xsl:value-of select="format-number(sum(ext:node-set($completeSaleSet)//t:sale[hdr/t:register[@sysid = $regNum]]/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder']]/t:line/tot ),'0.00')"/>
							</amount>
							
						</merchFuel>
						<fuelOnly>
							<count>
								<xsl:value-of select="format-number(count(ext:node-set($completeSaleSet)//t:sale[hdr/t:register[@sysid = $regNum] and (lines/t:line/t:fuel or lines/t:line/t:fuelPrepay) and not(lines/t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]),'0') + format-number(count(ext:node-set($completeSaleSet)//t:fuelReprintEvent[hdr/t:register[@sysid = $regNum]]),'0')"/>
							</count>
							<amount>
								<xsl:value-of select="format-number(sum(ext:node-set($completeSaleSet)//t:sale[hdr/t:register[@sysid = $regNum]]/lines[(t:line/t:fuel or t:line/t:fuelPrepay) and not(t:line/fid/t:dept[not(@deptType) or @deptType = 'norm' or @deptType = 'moneyOrder'])]/t:line/tot),'0.00')"/>
							</amount>
							
						</fuelOnly>
					</total>
				</byRegister>
			</xsl:for-each>
			
		</xsl:variable>
		
		<xsl:element name="pd:hourlyPd">
			<xsl:copy-of select="$hdr"/>
			<xsl:copy-of select="$hourlyTotals"/>
			<xsl:copy-of select="$hourlyByRegister"/>

		</xsl:element>
	</xsl:template>
</xsl:stylesheet>