<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildHourlyFuelSales" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:fuel="urn:vfi-sapphire:fuel.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns vs js fuel base">
	

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

	<xsl:param name="ns:uomType">USG</xsl:param>
	<xsl:param name="ns:currencyType">USD</xsl:param>
	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>


			<xsl:variable name="productList">
				<xsl:call-template name="ns:getProductList">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:variable>


		<xsl:variable name="dateTimeList">
			<xsl:call-template name="ns:getDateHour">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="fuelHourData">
	
			<xsl:for-each select="ext:nodeset($dateTimeList)/hdr">
				<xsl:variable name="curDateTime" select="./dateTime"/>
				
				<xsl:variable name="fuelLines" select="$baseRawSet/*/hdr[contains( ./dateTime, substring($curDateTime, 1,               13))]/../lines/t:line/t:fuel"/>
	
				<xsl:call-template name="ns:buildHourlyTotals">
					<xsl:with-param name="fuelLines" select="$fuelLines"/>
					<xsl:with-param name="dateTime" select="$curDateTime"/>
					<xsl:with-param name="prodList" select="$productList"/>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:variable>	

		
		<xsl:element name="t:hourlyFuelSales">
			<xsl:copy-of select="$baseRawSet/t:hdr"/>
			<xsl:copy-of select="$fuelHourData"/>
		</xsl:element>
	</xsl:template>

	

	<xsl:template name="ns:buildHourlyTotals">
		<xsl:param name="fuelLines"/>
		<xsl:param name="dateTime"/>
		<xsl:param name="prodList"/>
		<xsl:variable name="ns-pl" select="ext:nodeset($prodList)"/>
		<xsl:variable name="ns-fl" select="ext:nodeset($fuelLines)"/>
		<xsl:variable name="ns-dt" select="ext:nodeset($dateTime)"/>

		<xsl:element name="timeSlot">
			<xsl:attribute name="sysid"><xsl:value-of select="substring($ns-dt, 12, 2)"/></xsl:attribute>
			<xsl:attribute name="saleDate"><xsl:value-of select="substring($ns-dt, 1, 10)"/></xsl:attribute>
			<xsl:for-each select="$ns-pl/grade">
				<xsl:variable name="curGrade" select="."/>
				<xsl:element name="productEntry">
					<xsl:element name="fuel:fuelProdBase">
						<xsl:attribute name="sysid"><xsl:value-of select="$curGrade/@sysid"/></xsl:attribute>
						<xsl:element name="name"><xsl:value-of select="$curGrade/name"/></xsl:element>
					</xsl:element>
					<xsl:element name="volume">
						<xsl:attribute name="uom"><xsl:value-of select="$ns:uomType"/></xsl:attribute>
						<xsl:value-of select="format-number(sum($ns-fl[grade/@sysid = $curGrade/@sysid]/vol), '#0.000')"/>
					</xsl:element>
					<xsl:element name="dollarSales">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="format-number(sum($ns-fl[grade/@sysid = $curGrade/@sysid]/amt), '#0.00')"/>
					</xsl:element> 
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>

	
	
	<xsl:template name="ns:getProductList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)//t:fuel"/>

		<xsl:variable name="rawList">
			<xsl:call-template name="ns:getRawProductList">
				<xsl:with-param name="fuelLineSet" select="$ns-set"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:nodeset($rawList)/*">
				<xsl:sort data-type="text" order="ascending" select="./@sysid"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
	
		<xsl:copy-of select="ext:nodeset($sortedList)/grade[ not(./@sysid = preceding-sibling::grade[1]/@sysid)] "/>

	</xsl:template>
	
	
	<xsl:template name="ns:getRawProductList">
		<xsl:param name="fuelLineSet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($fuelLineSet)"/>
		<xsl:copy-of select="$ns-set/grade"/>

	</xsl:template>

	<xsl:template name="ns:getFuelEntriesForPeriod">
		<xsl:param name="tlogEntrySet"/>
	</xsl:template>		

<xsl:template name="ns:getDateHour">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>

		<xsl:variable name="rawList">
			<xsl:copy-of select="$ns-set/t:sale/hdr | $ns-set/t:adjustment/hdr"/>
		</xsl:variable> 

		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:nodeset($rawList)/hdr">
				<xsl:sort data-type="text" order="ascending" select="dateTime"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>

		<xsl:copy-of select="ext:nodeset($sortedList)/hdr[ not(        contains(substring(preceding-sibling::hdr[1]/dateTime, 1, 13),substring( ./dateTime ,1,13)))]"/>
</xsl:template>
	

</xsl:stylesheet>