<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildHouseAccount" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns vs xsi base">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>

		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		

		<xsl:variable name="houseAcctRawList">
			<xsl:copy-of select="$baseRawSet/t:sale/paylines/t:payline/t:houseAcct"/>	
		</xsl:variable>
		<xsl:variable name="houseAcctList">
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:node-set($houseAcctRawList)/t:houseAcct">
					<xsl:sort order="ascending" select="acct"/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="ext:node-set($sortedList)/t:houseAcct[ not(acct = preceding-sibling::t:houseAcct[1]/acct)]"/>
		</xsl:variable>
		

		<xsl:variable name="houseAcctSales">
			<xsl:copy-of select="$baseRawSet/t:sale[not(@isRefund)]/paylines/t:payline[t:houseAcct]"/>	
		</xsl:variable>


		<xsl:variable name="houseAcctRefunds">
			<xsl:copy-of select="$baseRawSet/t:sale[@isRefund]/paylines/t:payline[t:houseAcct]"/>	
		</xsl:variable>
		

		<xsl:variable name="houseAcctPayins">
			<xsl:copy-of select="$baseRawSet/t:tillPayin[@isHouseAcct = 'true']"/>	
		</xsl:variable>
		

		<xsl:variable name="houseAcctPayouts">
			<xsl:copy-of select="$baseRawSet/t:tillPayout[@isHouseAcct = 'true']"/>	
		</xsl:variable>
		

		<xsl:variable name="houseAcctPIRawList">
			<xsl:copy-of select="ext:node-set($houseAcctPayins)//reference"/>	
		</xsl:variable>
		<xsl:variable name="houseAcctPIList">
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:node-set($houseAcctPIRawList)/reference">
					<xsl:sort order="ascending" select="."/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="ext:node-set($sortedList)/reference[ not(. = preceding-sibling::reference[1])]"/>
		</xsl:variable>


		<xsl:variable name="houseAcctPORawList">
			<xsl:copy-of select="ext:node-set($houseAcctPayouts)//reference"/>	
		</xsl:variable>
		<xsl:variable name="houseAcctPOList">
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:node-set($houseAcctPORawList)/reference">
					<xsl:sort order="ascending" select="."/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="ext:node-set($sortedList)/reference[ not(. = preceding-sibling::reference[1])]"/>
		</xsl:variable>


<xsl:variable name="salesRefunds">
	<xsl:for-each select="ext:node-set($houseAcctList)/*">
		<xsl:call-template name="ns:SalesRefunds">
			<xsl:with-param name="acct" select="."/>
			<xsl:with-param name="sales" select="$houseAcctSales"/>
			<xsl:with-param name="refunds" select="$houseAcctRefunds"/>
		</xsl:call-template>
	</xsl:for-each>
</xsl:variable>


<xsl:variable name="paidOnAcct">
	<xsl:for-each select="ext:node-set($houseAcctPIList)/*">
		<xsl:call-template name="ns:PaidOnEntries">
			<xsl:with-param name="acct" select="."/>
			<xsl:with-param name="payIns" select="$houseAcctPayins"/>
		</xsl:call-template>
	</xsl:for-each>
</xsl:variable>		


<xsl:variable name="paidOutAcct">
	<xsl:for-each select="ext:node-set($houseAcctPOList)/*">
		<xsl:call-template name="ns:PaidOutEntries">
			<xsl:with-param name="acct" select="."/>
			<xsl:with-param name="payOuts" select="$houseAcctPayouts"/>
		</xsl:call-template>
	</xsl:for-each>
</xsl:variable>	


		<t:houseAccountReport>
			<xsl:copy-of select="$header"/>
			<xsl:copy-of select="$salesRefunds"/>
			<xsl:copy-of select="$paidOnAcct"/>
			<xsl:copy-of select="$paidOutAcct"/>
		</t:houseAccountReport>
	</xsl:template>


	<xsl:template name="ns:SalesRefunds">
		<xsl:param name="acct"/>
		<xsl:param name="sales"/>
		<xsl:param name="refunds"/>

		<xsl:element name="houseAccountEntry">
			<xsl:copy-of select="$acct"/>
			<xsl:element name="sales">
				<xsl:element name="amount">
					<xsl:copy-of select="sum(ext:node-set($sales)/t:payline[t:houseAcct/acct =$acct/acct]/amt)"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(ext:node-set($sales)/t:payline[t:houseAcct/acct =$acct/acct]/amt)"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="refunds">
				<xsl:element name="amount">
					<xsl:copy-of select="sum(ext:node-set($refunds)/t:payline[t:houseAcct/acct =$acct/acct]/amt)"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(ext:node-set($refunds)/t:payline[t:houseAcct/acct =$acct/acct]/amt)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>


	<xsl:template name="ns:PaidOnEntries">
		<xsl:param name="acct"/>
		<xsl:param name="payIns"/>
		<xsl:element name="paidOnAcctEntry">
			<xsl:call-template name="ns:create-houseAcct-elem">
				<xsl:with-param name="ref" select="$acct"/>
			</xsl:call-template>
			<xsl:element name="amount">
				<xsl:value-of select="sum(ext:node-set($payIns)/t:tillPayin[reference = $acct]/amount)"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>


	<xsl:template name="ns:PaidOutEntries">
		<xsl:param name="acct"/>
		<xsl:param name="payOuts"/>
		<xsl:element name="paidOutAcctEntry">
			<xsl:call-template name="ns:create-houseAcct-elem">
				<xsl:with-param name="ref" select="$acct"/>
			</xsl:call-template>
			<xsl:element name="amount">
				<xsl:value-of select="sum(ext:node-set($payOuts)/t:tillPayout[reference = $acct]/amount)"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	

	<xsl:template name="ns:create-houseAcct-elem">
		<xsl:param name="ref"/>
		<t:houseAcct>
			<xsl:element name="acct">
				<xsl:value-of select="$ref"/>
			</xsl:element>
			<xsl:if test="@name">
				<xsl:element name="name">
					<xsl:value-of select="$ref/@name"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="@subAccount">
				<xsl:element name="subAccount">
					<xsl:value-of select="$ref/@subAccount"/>
				</xsl:element>
			</xsl:if>
		</t:houseAcct>
	</xsl:template>
</xsl:stylesheet>