<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildKiosk" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns">
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>

	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>

		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>

	<xsl:variable name="allordersPlaced">
		<xsl:copy-of select="$baseRawSet//t:sale[(hdr/t:register/@sysid='133')] | $baseRawSet//t:order[hdr/t:register/@device='kiosk']"/>
	</xsl:variable>
	<xsl:variable name="ordersPlaced">
		<xsl:copy-of select="$baseRawSet//t:order[not(hdr/t:register/@sysid='155') and (hdr/t:register/@device='kiosk')]"/>
	</xsl:variable>

	<xsl:variable name="ordersTendered">
		<xsl:copy-of select="$baseRawSet//t:sale[recalledTickets/recallTicket/t:register/@device='kiosk']"/>
	</xsl:variable>

	<xsl:variable name="ordersVoided">
		<xsl:copy-of select="$baseRawSet//t:void[not(hdr/t:register/@sysid='155') and (hdr/t:register/@device='kiosk')]"/>
	</xsl:variable>
	<xsl:variable name="ordersPlacedMobile">
		<xsl:copy-of select="$baseRawSet//t:sale[hdr/t:register/@sysid='133']"/>
	</xsl:variable>
	<xsl:variable name="ordersPlacedMobileUnPaid">
		<xsl:copy-of select="$baseRawSet//t:order[hdr/t:register/@sysid='155']"/>
	</xsl:variable>
	<xsl:variable name="ordersVoidedMobile">
		<xsl:copy-of select="$baseRawSet//t:void[(hdr/t:register/@sysid='155') and (hdr/t:register/@device='kiosk')]"/>
		<xsl:copy-of select="$baseRawSet//t:void[hdr/t:register/@sysid='133']"/>
	</xsl:variable>

		<t:kioskReport>
			<xsl:copy-of select="$header"/>
			<allordersPlaced>
				<xsl:copy-of select="$allordersPlaced"/>
				<count>
					<xsl:value-of select="count(ext:node-set($allordersPlaced)/*)"/>
				</count>
			</allordersPlaced>
			<ordersPlaced>
				<xsl:copy-of select="$ordersPlaced"/>
				<count>
					<xsl:value-of select="count(ext:node-set($ordersPlaced)/*)"/>
				</count>
			</ordersPlaced>
			<ordersTendered>
				<xsl:copy-of select="$ordersTendered"/>
				<count>
					<xsl:value-of select="count(ext:node-set($ordersTendered)/*)"/>
				</count>
			</ordersTendered>
			<ordersVoided>
				<xsl:copy-of select="$ordersVoided"/>
				<count>
					<xsl:value-of select="count(ext:node-set($ordersVoided)/*)"/>
				</count>
			</ordersVoided>
			<ordersPlacedMobile>
				<xsl:copy-of select="$ordersPlacedMobile"/>
				<count>
					<xsl:value-of select="count(ext:node-set($ordersPlacedMobile)/*)"/>
				</count>
			</ordersPlacedMobile>
			<ordersPlacedMobileUnPaid>
				<xsl:copy-of select="$ordersPlacedMobileUnPaid"/>
				<count>
					<xsl:value-of select="count(ext:node-set($ordersPlacedMobileUnPaid)/*)"/>
				</count>
			</ordersPlacedMobileUnPaid>
			<ordersVoidedMobile>
				<xsl:copy-of select="$ordersVoidedMobile"/>
				<count>
					<xsl:value-of select="count(ext:node-set($ordersVoidedMobile)/*)"/>
				</count>
			</ordersVoidedMobile>
			<xsl:call-template name="ns:hourlyCount">
				<xsl:with-param name="orders" select="ext:node-set($ordersPlaced)"/>
			</xsl:call-template>
			<xsl:call-template name="ns:hourlyCount">
				<xsl:with-param name="orders" select="ext:node-set($ordersPlacedMobile)"/>
			</xsl:call-template>
			<xsl:call-template name="ns:hourlyCount">
				<xsl:with-param name="orders" select="ext:node-set($ordersPlacedMobileUnPaid)"/>
			</xsl:call-template>
			<xsl:call-template name="ns:hourlyCount">
				<xsl:with-param name="orders" select="ext:node-set($allordersPlaced)"/>
			</xsl:call-template>
		</t:kioskReport>
	</xsl:template>
	
	<xsl:template name="ns:hourlyCount">
		<xsl:param name="orders"/>
		
		
		<xsl:variable name="rawHours">
			<xsl:apply-templates select="ext:node-set($orders)//hdr/dateTime" mode="ns:processHours"/>
		</xsl:variable>
		<xsl:variable name="hours">
			<xsl:copy-of select="ext:node-set($rawHours)/hour[not(@sysid = preceding-sibling::hour[1]/@sysid)]"/>
		</xsl:variable>
		<xsl:variable name="rawKiosks">
			<xsl:apply-templates select="ext:node-set($orders)//hdr/t:register" mode="ns:processKiosks">
				<xsl:sort order="ascending" select="@sysid"/>
			</xsl:apply-templates>
		</xsl:variable>
		<xsl:variable name="kiosks">
			<xsl:copy-of select="ext:node-set($rawKiosks)/t:register[not(@sysid = preceding-sibling::t:register[1]/@sysid)]"/>
		</xsl:variable>
		<xsl:element name="kioskCustomerCount">
			<xsl:apply-templates select="ext:node-set($kiosks)/*" mode="ns:process">
				<xsl:with-param name="orders" select="ext:node-set($orders)"/>
				<xsl:with-param name="hours" select="ext:node-set($hours)"/>
			</xsl:apply-templates>
		</xsl:element>
		
	</xsl:template>
	
	<xsl:template match="dateTime" mode="ns:processHours">
		<xsl:element name="hour">
			<xsl:attribute name="sysid">
				<xsl:value-of select="substring-before(.,':')"/>
			</xsl:attribute>
		</xsl:element>
	</xsl:template>
	<xsl:template match="* | @* | text()" mode="ns:processHours"/>
	
	<xsl:template match="t:register" mode="ns:processKiosks">
		<xsl:copy-of select="."/>
	</xsl:template>
	<xsl:template match="* | @* | text()" mode="ns:processKiosks"/>
	
	<xsl:template match="t:register" mode="ns:process">
		<xsl:param name="hours"/>
		<xsl:param name="orders"/>
		<xsl:variable name="register" select="@sysid"/>
		
		<xsl:variable name="o">
				<xsl:if test="$orders//t:order[hdr/t:register/@device='kiosk']">
					<xsl:copy-of select="$orders//t:order[hdr/t:register/@sysid = $ register]"/>
				</xsl:if>
		</xsl:variable>
		<xsl:variable name="os">
				<xsl:if test="$orders//t:sale[hdr/t:register/@sysid='133']">
					<xsl:copy-of select="$orders//t:sale[hdr/t:register/@sysid = $ register]"/>
				</xsl:if>	
		</xsl:variable>
		<xsl:element name="kioskEntry">
			<xsl:copy-of select="."/>
			<xsl:if test="$orders//t:sale[hdr/t:register/@sysid='133']">
				<xsl:apply-templates select="ext:node-set($hours)/*" mode="ns:process">
					<xsl:with-param name="orders" select="ext:node-set($os)"/>
				</xsl:apply-templates>
			</xsl:if>
			<xsl:if test="$orders//t:order[hdr/t:register/@device='kiosk']">
				<xsl:apply-templates select="ext:node-set($hours)/*" mode="ns:process">
					<xsl:with-param name="orders" select="ext:node-set($o)"/>
				</xsl:apply-templates>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template match="hour" mode="ns:process">
		<xsl:param name="orders"/>		
		<xsl:variable name="hour" select="@sysid"/>
		<xsl:element name="{name()}">
			<xsl:copy-of select="@*"/>
			<xsl:element name="count">
				<xsl:choose>
					<xsl:when test="$orders//t:order[hdr/t:register/@device='kiosk']">
						<xsl:copy-of select="count($orders//t:order[substring-before(hdr/dateTime,':') = $hour])"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="count($orders//t:sale[substring-before(hdr/dateTime,':') = $hour])"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="* | @* | text()" mode="ns:process"/>

</xsl:stylesheet>