<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildLoyalty" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:key name="names" match="//t:sumLoyalty/name" use="."/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:call-template name="buildLoyaltyReport">
			<xsl:with-param name="tLogData" select="$baseRawSet"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="detailTemplateGener">
		<xsl:param name="currSale"/>
		<xsl:param name="tLog"/>
		<xsl:param name="programName"/>
		<xsl:element name="Detail">
			
			<xsl:copy-of select="$currSale/t:cashier"/>
			<xsl:copy-of select="$currSale/vs:transactionSeq"/>
			<xsl:copy-of select="$currSale/hdr/t:register"/>
			<xsl:copy-of select="$currSale/hdr/dateTime"/>
			<xsl:element name="TicketTotal">
				<xsl:copy-of select="format-number($currSale/sum/total,'0.00')"/>
				<xsl:attribute name="currency"/>
			</xsl:element>
			
			<xsl:for-each select="$tLog//t:adjustment">
				
				<xsl:variable name="tempAdj" select="."/>
				<xsl:if test="$tempAdj/vs:transactionSeq=$currSale/vs:transactionSeq">
					
					<xsl:for-each select="$tempAdj//t:line">
						<xsl:variable name="tempLine" select="."/>
						<xsl:if test="$tempLine/t:fuel/loyaltyDisc">
							<xsl:copy-of select="$tempLine"/>
						</xsl:if>
					</xsl:for-each>
				</xsl:if>
			</xsl:for-each>
			
			<xsl:for-each select="$currSale/lines//t:line">
				<xsl:variable name="tempLine" select="."/>
				<xsl:if test="$tempLine/t:fuel/loyaltyDisc or $tempLine/t:loyalty">
					<xsl:copy-of select="$tempLine"/>
				</xsl:if>
			</xsl:for-each>
			<xsl:copy-of select="$currSale/sum/t:sumLoyalty"/>
			
		</xsl:element>
	</xsl:template>
	<xsl:template name="detailPgm">
		<xsl:param name="programName"/>
		<xsl:param name="tLog"/>
		<xsl:variable name="tLogSale" select="$tLog//t:sale"/>
		<xsl:element name="loyaltyDetailByProgram">
			<xsl:attribute name="programID"><xsl:value-of select="$programName"/></xsl:attribute>
			<xsl:for-each select="$tLogSale">
				<xsl:variable name="currSale" select="."/>
				<xsl:choose>
					<xsl:when test="$currSale/sum/t:sumLoyalty[name=$programName and loyaltyDiscounts] or $currSale/lines//t:line/t:fuel//loyaltyDisc[name=$programName] or $currSale/lines//t:line//t:loyalty[name=$programName]">
						<xsl:call-template name="detailTemplateGener">
							<xsl:with-param name="currSale" select="$currSale"/>
							<xsl:with-param name="tLog" select="$tLog"/>
							<xsl:with-param name="programName" select="$programName"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="$tLog//t:adjustment">
							<xsl:variable name="tempAdj" select="."/>
							<xsl:if test="$tempAdj/vs:transactionSeq=$currSale/vs:transactionSeq">
								<xsl:if test="$tempAdj/sum/t:sumLoyalty[name=$programName and loyaltyDiscounts] or $tempAdj/lines//t:line/t:fuel//loyaltyDisc[name=$programName] or $tempAdj/lines//t:line//t:loyalty[name=$programName]">
								<xsl:call-template name="detailTemplateGener">
									<xsl:with-param name="currSale" select="$currSale"/>
									<xsl:with-param name="tLog" select="$tLog"/>
									<xsl:with-param name="programName" select="$programName"/>
								</xsl:call-template>
								</xsl:if>
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<xsl:template name="countLoyaltyProgram">
		<xsl:param name="tLogSale"/>
		<xsl:param name="programName"/>
		<xsl:param name="tLog"/>
		<xsl:variable name="loyaltyTicketCount">
			<xsl:value-of select="count($tLogSale/sum//t:sumLoyalty[name = $programName and loyaltyDiscounts])"/>
		</xsl:variable>
		<xsl:variable name="loyaltyLineCount">
			<xsl:value-of select="count($tLogSale/lines//t:line//t:loyalty[name=$programName])"/>
		</xsl:variable>
		<xsl:variable name="loyaltyFuelCount">
			<xsl:value-of select="count($tLog/*//t:line/t:fuel//loyaltyDisc[name=$programName])"/>
		</xsl:variable>
		<xsl:copy-of select="$loyaltyTicketCount + $loyaltyLineCount + $loyaltyFuelCount"/>
	</xsl:template>
	<xsl:template name="loyaltySummaryByPgm">
		<xsl:param name="programName"/>
		<xsl:param name="tLog"/>
		<xsl:variable name="tLogSale" select="$tLog//t:sale"/>
		<xsl:element name="Summary">
			<xsl:attribute name="programID"><xsl:value-of select="$programName"/></xsl:attribute>
			<xsl:element name="count">
				<xsl:call-template name="countLoyaltyProgram">
					<xsl:with-param name="tLogSale" select="$tLogSale"/>
					<xsl:with-param name="programName" select="$programName"/>
					<xsl:with-param name="tLog" select="$tLog"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:if test="$tLogSale/sum/t:sumLoyalty/loyaltyDiscounts">
				<xsl:element name="TicketDiscTotal">
					<xsl:copy-of select="format-number(sum($tLogSale/sum/t:sumLoyalty[name = $programName]//loyaltyDiscounts/autoApplied),'0.00')"/>
					<xsl:attribute name="currency"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="$tLogSale/sum/t:sumLoyalty/loyaltyDiscounts/custApproved">
				<xsl:element name="CustAuthDiscTotal">
					<xsl:copy-of select="format-number(sum($tLogSale/sum//t:sumLoyalty[name = $programName]//loyaltyDiscounts/custApproved),'0.00')"/>
					<xsl:attribute name="currency"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="$tLogSale/sum//t:sumLoyalty[name = $programName] or $tLogSale/lines//t:line/fuel//loyaltyDisc[name=$programName] or $tLogSale/lines//t:line//t:loyalty[name=$programName]">
				<xsl:element name="TicketTotal">
					<xsl:copy-of select="format-number(sum($tLogSale/sum/total[..//t:sumLoyalty[name = $programName] or ../../lines//t:line/fuel//loyaltyDisc[name=$programName] or ../../lines//t:line//t:loyalty[name=$programName]]),'0.00')"/>
					<xsl:attribute name="currency"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="$tLog/*//t:line/t:fuel/loyaltyDisc">
				<xsl:element name="PPGDiscTotal">
					<xsl:value-of select="format-number(sum($tLog/*//t:line/t:fuel//loyaltyDisc[name=$programName]/amt),'0.00')"/>
					<xsl:attribute name="currency"/>
				</xsl:element>
			</xsl:if>
			
			<xsl:if test="$tLogSale/lines/t:line/t:loyalty">
				<xsl:element name="LineDiscTotal">
					<xsl:value-of select="format-number(sum($tLogSale/lines//t:line//t:loyalty[name=$programName]/amt),'0.00')"/>
					<xsl:attribute name="currency"/>
				</xsl:element>
			</xsl:if>
			<xsl:variable name="TotalTicketDiscAmount">
				<xsl:value-of select="format-number(sum($tLogSale/*//t:sumLoyalty[name = $programName]//loyaltyDiscounts/total),'0.00')"/>
			</xsl:variable>
			<xsl:variable name="TotalLineDiscountAmount">
				<xsl:value-of select="sum($tLogSale/lines//t:line//t:loyalty[name=$programName]/amt)"/>
			</xsl:variable>
			<xsl:variable name="TotalPPUAmount">
				<xsl:value-of select="sum($tLog/*//t:line/t:fuel//loyaltyDisc[name=$programName]/amt)"/>
			</xsl:variable>
			<xsl:element name="TotalDisc">
				<xsl:value-of select="format-number($TotalTicketDiscAmount + $TotalLineDiscountAmount + $TotalPPUAmount ,'0.00')"/>
				<xsl:attribute name="currency"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="summaryTemplate">
		<xsl:param name="tLogData"/>
		<xsl:for-each select="$tLogData//t:sumLoyalty/name[generate-id() = generate-id(key('names',.))]">
			<xsl:variable name="program" select="."/>
			<xsl:call-template name="loyaltySummaryByPgm">
				<xsl:with-param name="programName" select="$program"/>
				<xsl:with-param name="tLog" select="$tLogData"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="detailTemplate">
		<xsl:param name="tLogData"/>
		<xsl:for-each select="$tLogData//t:sumLoyalty/name[generate-id() = generate-id(key('names',.))]">
			<xsl:variable name="program" select="."/>
			<xsl:call-template name="detailPgm">
				<xsl:with-param name="programName" select="$program"/>
				<xsl:with-param name="tLog" select="$tLogData"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="buildLoyaltyReport">
		<xsl:param name="tLogData"/>
		<xsl:element name="loyaltyDetailReport">
			<xsl:copy-of select="$tLogData/t:hdr"/>
			<xsl:if test="$tLogData//t:sale/sum//t:sumLoyalty">
				<xsl:element name="loyaltySummaryByProgram">
					<xsl:call-template name="summaryTemplate">
						<xsl:with-param name="tLogData" select="$tLogData"/>
					</xsl:call-template>
				</xsl:element>
				<xsl:element name="detailByProgram">
					<xsl:call-template name="detailTemplate">
						<xsl:with-param name="tLogData" select="$tLogData"/>
					</xsl:call-template>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>