<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildMerchandiseSales" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:nsc="http://verifone.com/isd/vfit/transactionSet/scripts" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" version="1.0" exclude-result-prefixes="xsl ext ns ns2 nsc jsc">
	<xsl:import href="lists-xalan.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:param name="ns:reportPrefs">reptPrefs.xml</xsl:param>
	<xsl:param name="ns:reptGroupName">merchandiseSales-1</xsl:param>
	<xsl:param name="ns:deptReptGrp">deptGrp</xsl:param>
	<xsl:param name="ns:categoryReptGrp">categoryGrp</xsl:param>

	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>

		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		


		<xsl:variable name="completeSetOfLines">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="baseRawLines" select="ext:nodeset($completeSetOfLines)"/>



		<xsl:variable name="categoryList">
			<xsl:call-template name="ns2:getCategoryListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLines"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="allTransactions">
		<xsl:for-each select="ext:nodeset($categoryList)/t:cat">
			<xsl:variable name="currCategory" select="."/>
			<xsl:element name="categoryInfo">
				<xsl:copy-of select="$currCategory"/>
			

				<xsl:variable name="completeCategoryLines">
					<xsl:call-template name="ns2:getLinesForCategory">
						<xsl:with-param name="lineSet" select="$baseRawLines"/>
						<xsl:with-param name="cat" select="$currCategory"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="departmentList">
					<xsl:call-template name="ns2:getDeptListFromLines">
						<xsl:with-param name="lineSet" select="$completeCategoryLines"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="completeLineSetByDep">
					<xsl:for-each select="ext:nodeset($departmentList)/t:dept">
						<xsl:variable name="currDepartment" select="."/>
							<xsl:element name="departmentInfo">
								<xsl:copy-of select="$currDepartment"/>
							
							<xsl:call-template name="ns2:getLinesForDept">
								<xsl:with-param name="lineSet" select="$completeCategoryLines"/>
								<xsl:with-param name="dept" select="$currDepartment"/>
							</xsl:call-template>

							</xsl:element>

					</xsl:for-each>
				</xsl:variable>
			<xsl:copy-of select="$completeLineSetByDep"/>
		
		</xsl:element>

		</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="consolidated">
		<xsl:for-each select="ext:nodeset($allTransactions)/*">
			<xsl:variable name="currCat" select="."/>
			<xsl:element name="categoryInfo">
				<xsl:copy-of select="$currCat/t:cat"/>
			
			<xsl:for-each select="ext:nodeset($currCat)/departmentInfo">
				<xsl:variable name="currDepartment" select="."/>
				<xsl:element name="departmentInfo">
					<xsl:copy-of select="$currDepartment/t:dept"/>

				<xsl:variable name="pluLineSet">
					<xsl:call-template name="ns2:getLinesWithPlu">
						<xsl:with-param name="lineSet" select="$currDepartment"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="pluList">
					<xsl:call-template name="ns2:getPluListFromLines">
						<xsl:with-param name="lineSet" select="$pluLineSet"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="pluSale">
				<xsl:for-each select="ext:nodeset($pluList)/*">
					<xsl:variable name="currPLU" select="."/>
					<xsl:element name="pluSale">
						<xsl:variable name="tmpPlu">
							<xsl:call-template name="ns2:getLinesForPlu">
								<xsl:with-param name="lineSet" select="$pluLineSet"/>
								<xsl:with-param name="plu" select="$currPLU"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:variable name="tmpQty" select="sum(ext:nodeset($tmpPlu)/*/qty)"/>
						<xsl:element name="qty">
							<xsl:value-of select="$tmpQty"/>
						</xsl:element>
						<xsl:element name="sellUnit">

							<xsl:value-of select="$currPLU/sellunit"/>
						</xsl:element>
						<xsl:element name="extendedQty">
							<xsl:value-of select="$tmpQty * ext:nodeset($currPLU)/sellunit"/>
						</xsl:element>
						<xsl:element name="salesAmount">
							<xsl:value-of select="format-number(sum(ext:nodeset($tmpPlu)/*/tot), '#.00')"/>								</xsl:element>
					</xsl:element>

				</xsl:for-each>
				</xsl:variable>


				<xsl:variable name="sellUnits">
					<xsl:call-template name="ns:getSellUnitsFromLines">
						<xsl:with-param name="lines" select="$pluSale"/>
					</xsl:call-template>
				</xsl:variable>

				<xsl:variable name="pluSales">
					<xsl:for-each select="ext:nodeset($sellUnits)/*">
						<xsl:variable name="currSU" select="."/>
						<xsl:element name="pluSales">
							<xsl:element name="qty">
								<xsl:value-of select="sum(ext:nodeset($pluSale)/pluSale[sellUnit = $currSU]/qty)"/>
							</xsl:element>
							<xsl:element name="sellUnit">
								<xsl:value-of select="$currSU"/>
							</xsl:element>
							<xsl:element name="extendedQty">
								<xsl:value-of select="sum(ext:nodeset($pluSale)/pluSale[sellUnit =                  $currSU]/extendedQty)"/>
							</xsl:element>
							<xsl:element name="salesAmount">
								<xsl:value-of select="format-number(sum(ext:nodeset($pluSale)/pluSale[sellUnit =                  $currSU]/salesAmount), '#.00')"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:variable>

				<xsl:variable name="openDeptSales">
					<xsl:variable name="tmpOpenDept">
						<xsl:call-template name="ns2:getLinesWithoutPlu">
							<xsl:with-param name="lineSet" select="$currDepartment"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="sum(ext:nodeset($tmpOpenDept)/*/qty)!=0">
						<xsl:element name="openDeptSales">
							<xsl:element name="qty">
								<xsl:value-of select="sum(ext:nodeset($tmpOpenDept)/*/qty)"/>
							</xsl:element>
							<xsl:element name="sellUnit">
								<xsl:value-of select="1.000"/>
							</xsl:element>
							<xsl:element name="extendedQty">
								<xsl:value-of select="sum(ext:nodeset($tmpOpenDept)/*/qty)"/>
							</xsl:element>
							<xsl:element name="salesAmount">
								<xsl:value-of select="format-number(sum(ext:nodeset($tmpOpenDept)/*/tot), '#.00')"/>											</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:variable>
				<xsl:copy-of select="$openDeptSales"/>
				<xsl:copy-of select="$pluSales"/>			
				
				</xsl:element>

			</xsl:for-each>
		
			</xsl:element>
	
		</xsl:for-each>
		</xsl:variable>		
		
		<xsl:element name="t:merchandiseSales">
			<xsl:copy-of select="$header"/>
			<xsl:copy-of select="$consolidated"/>
			
		</xsl:element>
		
	</xsl:template>

	<xsl:template name="ns:createSetOfLines">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="rawSet">
			<xsl:call-template name="ns2:getSaleSet">
				<xsl:with-param name="tlogEntrySet" select="$tlogEntrySet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="ns-set" select="ext:nodeset($rawSet)"/>

		
		<xsl:variable name="rptPrefDoc" select="document(string($ns:reportPrefs))"/>

		<xsl:variable name="rawRptPrefs" select="$rptPrefDoc//*[* = $ns:reptGroupName]"/>
		<xsl:variable name="setOfLines">
		<xsl:choose>
			
			<xsl:when test="local-name($rawRptPrefs) = $ns:deptReptGrp">
				<xsl:variable name="deptList">
					<xsl:for-each select="$rawRptPrefs/*">
						<xsl:element name="t:dept">
							<xsl:attribute name="sysid">
								<xsl:value-of select="./@sysid"/>
							</xsl:attribute>
							<xsl:element name="name"><xsl:value-of select="./name"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="tmpTranLineSet">
					<xsl:for-each select="ext:nodeset($deptList)/*">
						<xsl:variable name="currDept" select="."/>
						<xsl:call-template name="ns2:getLinesForDept">
							<xsl:with-param name="lineSet" select="$ns-set/*/lines"/>
							<xsl:with-param name="dept" select="$currDept"/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:variable>
				<xsl:copy-of select="$tmpTranLineSet"/>
			</xsl:when>
		
			<xsl:when test="local-name($rawRptPrefs) = $ns:categoryReptGrp">
				<xsl:variable name="catList">
					<xsl:for-each select="$rawRptPrefs/*">
						<xsl:element name="t:cat">
							<xsl:attribute name="sysid">
								<xsl:value-of select="./@sysid"/>
							</xsl:attribute>
							<xsl:element name="name"><xsl:value-of select="./name"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="tmpTranLineSet">
					<xsl:for-each select="ext:nodeset($catList)/*">
						<xsl:variable name="currCat" select="."/>
						<xsl:call-template name="ns2:getLinesForCategory">
							<xsl:with-param name="lineSet" select="$ns-set/*/lines"/>
							<xsl:with-param name="cat" select="$currCat"/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:variable>
				<xsl:copy-of select="$tmpTranLineSet"/>
			</xsl:when>
		</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$setOfLines"/>
	</xsl:template>
	

	<xsl:template name="ns:getSellUnitsFromLines">
		<xsl:param name="lines"/>
		<xsl:variable name="ns-lines" select="ext:nodeset($lines)"/>
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:nodeset($ns-lines)/*">
				<xsl:sort data-type="number" order="ascending" select="sellUnit"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="ext:nodeset($sortedList)/pluSale[ not (sellUnit = preceding-sibling::pluSale/sellUnit         [1])]/sellUnit"/>

	</xsl:template>
</xsl:stylesheet>