<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildSafedropPd" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" xmlns:pd="urn:vfi-sapphire:pd.2002-05-21" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:list="http://verifone.com/isd/vfit/tlog/lists" version="1.0" exclude-result-prefixes="xsl ext ns js base t list">
	<xsl:import href="lists-xalan.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		
		<pd:safedropPd>
			
			<xsl:apply-templates select="$baseRawSet/t:hdr"/>
			
			<xsl:copy-of select="$baseRawSet/*/vs:site"/>
			
			<xsl:element name="totals">
				
				<xsl:call-template name="ns:safeDropEvents">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
				
				
				<xsl:call-template name="ns:safeDropInfo">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
				
				
				<dropCancelCount>
					<xsl:value-of select="count($baseRawSet//t:event[@type='safeDropCancel'])"/>
				</dropCancelCount>
				
				
			</xsl:element>
			
		</pd:safedropPd>
	</xsl:template>
	<xsl:template name="ns:safeDropInfo">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="mopList">
			<xsl:call-template name="list:getMopSafeList">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($tlogEntrySet)"/>
			</xsl:call-template>
		</xsl:variable>
		<safeDropInfo>
			<total>
				<count>
					<xsl:value-of select="count(ext:nodeset($tlogEntrySet)//t:tillSafeDrop[not(@correction='true')])"/>
				</count>

				<amount>
					<xsl:value-of select="sum(ext:nodeset($tlogEntrySet)//t:tillSafeDrop/amount) - sum(ext:nodeset($tlogEntrySet)//t:tillSafeDrop[@correction='true']/origSafedropInfo/amount)"/>
				</amount>
			</total>
			<xsl:for-each select="ext:nodeset($mopList)/*">
				<xsl:variable name="curMop" select="."/>
					<xsl:variable name="entries">
						<xsl:call-template name="list:getTillItemsForMop">
							<xsl:with-param name="tlogEntrySet" select="ext:nodeset($tlogEntrySet)"/>
							<xsl:with-param name="mop" select="$curMop"/>
						</xsl:call-template>
					</xsl:variable>
				<mopInfo>
					<xsl:attribute name="sysid">	<xsl:value-of select="$curMop/@sysid"/></xsl:attribute>
					<name>
						<xsl:value-of select="$curMop/name"/>
					</name>
					<xsl:variable name="ns">
						<xsl:copy-of select="ext:nodeset($tlogEntrySet)//t:tillSafeDrop[t:mop/@sysid = $curMop//@sysid and t:mop/@cat = $curMop//@cat]"/>
					</xsl:variable>
					<count>
						<xsl:value-of select="count(ext:nodeset($ns)//t:tillSafeDrop[not(@correction='true')])"/>
					</count>

				<amount>
					<xsl:value-of select="sum(ext:nodeset($ns)//t:tillSafeDrop/amount) - sum(ext:nodeset($ns)//t:tillSafeDrop[@correction='true']/origSafedropInfo/amount)"/>
				</amount>
				</mopInfo>
			</xsl:for-each>
		</safeDropInfo>
	</xsl:template>
	<xsl:template match="t:hdr">
		<vs:period>
			<xsl:attribute name="sysid"><xsl:value-of select="vs:period/@sysid"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="vs:period/@periodType"/></xsl:attribute>
			<xsl:attribute name="periodType"><xsl:value-of select="vs:period/@periodType"/></xsl:attribute>
			<xsl:attribute name="periodBeginDate"><xsl:value-of select="startDateTime"/></xsl:attribute>
			<xsl:if test="endDateTime">
				<xsl:attribute name="periodEndDate"><xsl:value-of select="endDateTime"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="boolean(vs:period/@periodSeqNum)">
				<xsl:attribute name="periodSeqNum"><xsl:value-of select="seq"/></xsl:attribute>
			</xsl:if>
		</vs:period>
	</xsl:template>
	<xsl:template name="ns:safeDropEvents">
		<xsl:param name="tlogEntrySet"/>
		
		<xsl:variable name="safeDrops">
			<xsl:apply-templates select="ext:nodeset($tlogEntrySet)//t:tillSafeDrop" mode="ns:createSafeDrop"/>
		</xsl:variable>
		
		<xsl:for-each select="ext:nodeset($safeDrops)/*">
			<xsl:sort data-type="number" order="ascending" select="@ticketNumber"/>
			<xsl:copy-of select="."/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="t:tillSafeDrop" mode="ns:createSafeDrop">
		
		<safedropEvent>
			
			
			<xsl:attribute name="ticketNumber"><xsl:choose><xsl:when test="@correction='false'"><xsl:value-of select="vs:transactionSeq"/></xsl:when><xsl:when test="@correction='true'"><xsl:value-of select="origSafedropInfo/vs:transactionSeq"/></xsl:when><xsl:otherwise><xsl:value-of select="vs:transactionSeq"/></xsl:otherwise></xsl:choose></xsl:attribute>
			
			<xsl:if test="@correction">
				<xsl:attribute name="correction"><xsl:value-of select="@correction"/></xsl:attribute>
			</xsl:if>
			
			
			<dropTime>
				
				<xsl:value-of select="hdr/dateTime"/>
			</dropTime>
			
			<refNum>
				<xsl:value-of select="reference"/>
			</refNum>
			
			<vs:cashier>
				<xsl:attribute name="sysid"><xsl:value-of select="t:cashier/@sysid"/></xsl:attribute>
				<xsl:if test="t:cashier/@number">
					<xsl:attribute name="number"><xsl:value-of select="t:cashier/@number"/></xsl:attribute>
				</xsl:if>
				<name>
					<xsl:value-of select="t:cashier/name"/>
				</name>
			</vs:cashier>
			
			<vs:register>
				<xsl:attribute name="sysid"><xsl:value-of select="hdr/t:register/@sysid"/></xsl:attribute>
			</vs:register>
			
			<amount>
				<xsl:if test="amount/@currency">
					<xsl:attribute name="currency"><xsl:value-of select="amount/@currency"/></xsl:attribute>
				</xsl:if>
				<xsl:value-of select="amount"/>
			</amount>
			
			<vs:mop>
				<xsl:attribute name="sysid"><xsl:value-of select="t:mop/@sysid"/></xsl:attribute>
				<xsl:if test="t:mop/@isCardBased">
					<xsl:attribute name="isCardBased"><xsl:value-of select="t:mop/@isCardBased"/></xsl:attribute>
				</xsl:if>
				<name>
					<xsl:value-of select="t:mop/name"/>
				</name>
			</vs:mop>
			
			<xsl:if test="boolean(@eSafeId)">
				<safeId>
					<xsl:attribute name="sysid"><xsl:value-of select="@eSafeId"/></xsl:attribute>
					<xsl:if test="@eSafeName">
						<xsl:attribute name="name"><xsl:value-of select="@eSafeName"/></xsl:attribute>
					</xsl:if>
				</safeId>
			</xsl:if>
		</safedropEvent>
	</xsl:template>
</xsl:stylesheet>