<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildSummary" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:nsc="http://verifone.com/isd/vfit/transactionSet/scripts" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2 nsc jsc">
	<xsl:import href="lists-xalan.xslt"/>
	<xsl:import href="../transactionSet/scripts-xalan.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:param name="ns:deptMap">deptMap</xsl:param>
	<xsl:param name="ns:categoryMap">categoryMap</xsl:param>
	<xsl:param name="ns:reportPrefs">reptPrefs.xml</xsl:param>
	<xsl:param name="ns:reptMerchName">merchandiseSales</xsl:param>
	<xsl:param name="ns:reptCWName">carWashSales</xsl:param>
	<xsl:param name="ns:driveOffName">driveOffs</xsl:param>
	<xsl:param name="ns:imprinterName">imprinterSales</xsl:param>
	<xsl:param name="ns:creditName">creditSales</xsl:param>
	<xsl:param name="ns:debitName">debitSales</xsl:param>
	<xsl:param name="ns:couponName">coupons</xsl:param>
	<xsl:param name="ns:overShortName">overShort</xsl:param>
	<xsl:param name="ns:electronicCheckName">electronicCheck</xsl:param>
	<xsl:param name="ns:manualCheckName">manualCheck</xsl:param>
	<xsl:param name="ns:ebtName">ebt</xsl:param>
	<xsl:param name="ns:foodStampName">foodStamp</xsl:param>
	<xsl:param name="ns:reptOthServicesName">otherServices</xsl:param>
	<xsl:param name="ns:reptLottoSalesName">lottoSales</xsl:param>
	<xsl:param name="ns:reptLotterySalesName">lotterySales</xsl:param>
	<xsl:param name="ns:reptLottoWinnersName">lottoWinners</xsl:param>
	<xsl:param name="ns:reptLotteryWinnersName">lotteryWinners</xsl:param>
	<xsl:param name="ns:reptMoneyOrderName">moneyOrderSales</xsl:param>
	<xsl:param name="ns:reptPrepaidName">prepaidSales</xsl:param>
	<xsl:param name="ns:rollUpCashier">true</xsl:param>
	<xsl:param name="ns:dcrRegister" select="'9'"/>
	<xsl:param name="ns:currencyType">USD</xsl:param>
	<xsl:param name="ns:compCWAmt">0.01</xsl:param>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		
		<xsl:variable name="rptPrefDoc" select="document(string($ns:reportPrefs))//reptDefinitionMap"/>
		
		
		
		<xsl:variable name="allDCR">
			<xsl:variable name="dcrSales">
				<xsl:copy-of select="ext:nodeset($baseRawSet)/t:sale[hdr/t:register/@sysid=$ns:dcrRegister]"/>
			</xsl:variable>
			
			<xsl:element name="fuelTotals">
				<xsl:call-template name="ns:createFuelTotals">
					<xsl:with-param name="tlogEntrySet" select="$dcrSales"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="carwashTotals">
				<xsl:call-template name="ns:createCarwashTotals">
					<xsl:with-param name="tlogEntrySet" select="$dcrSales"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
		</xsl:variable>
		
		<xsl:variable name="byCashier">
			
			<xsl:variable name="rawCashierList">
				<xsl:call-template name="ns2:getCashierList">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="cashierList">
				<xsl:call-template name="ns:getCashierList">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:for-each select="ext:nodeset($cashierList)/t:cashier [(@sysid !='0') ]">
				<xsl:variable name="currCashier" select="."/>
				
				<xsl:variable name="cashierSet">
					<xsl:call-template name="ns:getTLogEntriesForCashier">
						<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
						<xsl:with-param name="cashier" select="$currCashier"/>
						<xsl:with-param name="rawList" select="$rawCashierList"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:element name="cashierInfo">
					
					<xsl:copy-of select="$currCashier"/>
					
					<xsl:element name="cashierAmounts">
						<xsl:variable name="cshMerchSales">
							<xsl:call-template name="ns:createMerchandiseTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:element name="merchandiseSales">
							<xsl:copy-of select="$cshMerchSales"/>
						</xsl:element>
						
						<xsl:element name="fuelTotals">
							<xsl:call-template name="ns:createCashierFuelTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="fuelVoids">
							<xsl:element name="amount">
								<xsl:value-of select="format-number(sum(ext:nodeset($cashierSet)/t:event                 [@type='fuelPrepaidCancel']/t:fuelPrepay/amt                 ), '0.00')"/>
							</xsl:element>
							<xsl:element name="count">
								<xsl:value-of select="count(ext:nodeset($cashierSet)/t:event                 [@type='fuelPrepaidCancel'])"/>
							</xsl:element>
						</xsl:element>
						
						<xsl:element name="driveOffTotals">
							<xsl:call-template name="ns:createDriveOffTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="pumpTestTotals">
							<xsl:call-template name="ns:createPumpTestTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="carwashTotals">
							<xsl:call-template name="ns:createCarwashTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="totalLottoSales">
							<xsl:call-template name="ns:createLottoSalesTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="totalLotterySales">
							<xsl:call-template name="ns:createLotterySalesTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="totalLottoWinners">
							<xsl:call-template name="ns:createLottoWinnersTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="totalLotteryWinners">
							<xsl:call-template name="ns:createLotteryWinnersTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="moneyOrderTotals">
							<xsl:call-template name="ns:createMoneyOrderTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="totalOtherServices">
							<xsl:call-template name="ns:createOtherServTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="prePaidCardTotals">
							<xsl:call-template name="ns:createPrepaidCards">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						
						
						<xsl:element name="totalTendered">
							<xsl:element name="amount">
								<xsl:value-of select="format-number(sum(              ext:nodeset($cashierSet)/t:sale[not(@isRefund = 'true')]/paylines/*/amt |               ext:nodeset($cashierSet)/t:pumpTest/paylines/*/amt),               '0.00')"/>
							</xsl:element>
							<xsl:element name="count">
								<xsl:value-of select="count(              ext:nodeset($cashierSet)/t:sale[not(@isRefund = 'true')]/paylines/t:payline               [t:mop/name != 'Change'] |              ext:nodeset($cashierSet)/t:pumpTest/paylines/t:payline               [t:mop/name != 'Change']              )"/>
							</xsl:element>
						</xsl:element>
						
						<xsl:element name="totalOverShort">
							<xsl:call-template name="ns:createOverShort">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="totalTaxes">
							<xsl:call-template name="ns:createTaxTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:if test="ns-set/t:sale/sum/t:sumTaxExempt">
							<xsl:element name="totalExemptTaxes">
								<xsl:call-template name="ns:createTaxExemptTotals">
									<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								</xsl:call-template>
							</xsl:element>
						</xsl:if>
						
						<xsl:element name="totalRefunds">
							<xsl:element name="amount">
								<xsl:value-of select="format-number(sum(              ext:nodeset($cashierSet)/t:sale[@isRefund='true']/sum/total),               '0.00')"/>
							</xsl:element>
							<xsl:element name="count">
								<xsl:value-of select="count(ext:nodeset($cashierSet)/t:sale[@isRefund='true'])"/>
							</xsl:element>
						</xsl:element>
						
						<xsl:element name="couponTotals">
							<xsl:call-template name="ns:createCouponTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="totalVoids">
							<xsl:element name="amount">
								<xsl:value-of select="format-number(sum(               ext:nodeset($cashierSet)/t:void/sum/beforeTax), '0.00')"/>
							</xsl:element>
							<xsl:element name="count">
								<xsl:value-of select="count(ext:nodeset($cashierSet)/t:void)"/>
							</xsl:element>
						</xsl:element>
						
						<xsl:element name="drawerAlarmTotals">
							<xsl:call-template name="ns:createDrawerAlarmTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="errorCorrectTotals">
							<xsl:call-template name="ns:createErrorCorrectTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
							</xsl:call-template>
						</xsl:element>
						
						
						<xsl:variable name="ns-ms" select="ext:nodeset($cshMerchSales)"/>
						<xsl:variable name="cshDepCatTotals">
							<xsl:element name="amount">
								<xsl:value-of select="format-number(sum($ns-ms/categoryInfo/salesAmount), '0.00')"/>
							</xsl:element>
							<xsl:element name="count">
								<xsl:value-of select="sum($ns-ms/categoryInfo/salesLineCount)"/>
							</xsl:element>
						</xsl:variable>
						<xsl:element name="depCatTotals">
							<xsl:copy-of select="$cshDepCatTotals"/>
						</xsl:element>
						
						<xsl:element name="totalNoSales">
							<xsl:element name="count">
								<xsl:value-of select="count(ext:nodeset($cashierSet)/t:tillNosale)"/>
							</xsl:element>
						</xsl:element>
						
						<xsl:element name="safeDropTotals">
							<xsl:call-template name="ns:createSafeDropTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="creditMOPTotals">
							<xsl:call-template name="ns:createCreditTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="debitMOPTotals">
							<xsl:call-template name="ns:createDebitTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="electronicCheckTotals">
							<xsl:call-template name="ns:createECheckTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="manualCheckTotals">
							<xsl:call-template name="ns:createCheckTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="EBTTotals">
							<xsl:call-template name="ns:createEBTTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:element name="foodStampTotals">
							<xsl:call-template name="ns:createFoodStampTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
							</xsl:call-template>
						</xsl:element>
						
						<xsl:variable name="ns-dc" select="ext:nodeset($cshDepCatTotals)"/>
						
						
						<xsl:element name="itemTotals">
							<xsl:call-template name="ns:createItemTotals">
								<xsl:with-param name="tlogEntrySet" select="$cashierSet"/>
								<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
								<xsl:with-param name="depCatTotals" select="$ns-dc"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:variable name="allCashiers">
			
			<xsl:variable name="merchandiseSales">
				<xsl:call-template name="ns:createMerchandiseTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:element name="merchandiseSales">
				<xsl:copy-of select="$merchandiseSales"/>
			</xsl:element>
			
			<xsl:element name="fuelTotals">
				<xsl:call-template name="ns:createFuelTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="fuelVoids">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum($baseRawSet/t:event               [@type='fuelPrepaidCancel']/t:fuelPrepay/amt               ), '0.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count($baseRawSet/t:event[@type='fuelPrepaidCancel'])"/>
				</xsl:element>
			</xsl:element>
			
			<xsl:element name="driveOffTotals">
				<xsl:call-template name="ns:createDriveOffTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="pumpTestTotals">
				<xsl:call-template name="ns:createPumpTestTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="carwashTotals">
				<xsl:call-template name="ns:createCarwashTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="totalLottoSales">
				<xsl:call-template name="ns:createLottoSalesTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:element name="totalLotterySales">
				<xsl:call-template name="ns:createLotterySalesTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="totalLottoWinners">
				<xsl:call-template name="ns:createLottoWinnersTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:element name="totalLotteryWinners">
				<xsl:call-template name="ns:createLotteryWinnersTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="moneyOrderTotals">
				<xsl:call-template name="ns:createMoneyOrderTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="totalOtherServices">
				<xsl:call-template name="ns:createOtherServTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:element name="prePaidCardTotals">
				<xsl:call-template name="ns:createPrepaidCards">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			
			
			<xsl:element name="totalTendered">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(           $baseRawSet/t:sale[not(@isRefund = 'true')]/paylines/*/amt |            $baseRawSet/t:pumpTest/paylines/*/amt),            '0.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(           $baseRawSet/t:sale[not(@isRefund = 'true')]/paylines/t:payline            [t:mop/name != 'Change'] |           $baseRawSet/t:pumpTest/paylines/t:payline            [t:mop/name != 'Change']           )"/>
				</xsl:element>
			</xsl:element>
			
			<xsl:element name="totalOverShort">
				<xsl:call-template name="ns:createOverShort">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="totalTaxes">
				<xsl:call-template name="ns:createTaxTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:if test="ns-set/t:sale/sum/t:sumTaxExempt">
				<xsl:element name="totalExemptTaxes">
					<xsl:call-template name="ns:createTaxExemptTotals">
						<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					</xsl:call-template>
				</xsl:element>
			</xsl:if>
			
			<xsl:element name="totalRefunds">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(           $baseRawSet/t:sale[@isRefund='true']/sum/total), '0.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count($baseRawSet/t:sale[@isRefund='true'])"/>
				</xsl:element>
			</xsl:element>
			
			<xsl:element name="couponTotals">
				<xsl:call-template name="ns:createCouponTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="totalVoids">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(            $baseRawSet/t:void/sum/beforeTax), '0.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count($baseRawSet/t:void)"/>
				</xsl:element>
			</xsl:element>
			
			<xsl:element name="drawerAlarmTotals">
				<xsl:call-template name="ns:createDrawerAlarmTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="errorCorrectTotals">
				<xsl:call-template name="ns:createErrorCorrectTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:element>
			
			
			<xsl:variable name="ns-ms" select="ext:nodeset($merchandiseSales)"/>
			<xsl:variable name="depCatTotals">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum($ns-ms/categoryInfo/salesAmount), '0.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="sum($ns-ms/categoryInfo/salesLineCount)"/>
				</xsl:element>
			</xsl:variable>
			<xsl:element name="depCatTotals">
				<xsl:copy-of select="$depCatTotals"/>
			</xsl:element>
			
			<xsl:element name="totalNoSales">
				<xsl:element name="count">
					<xsl:value-of select="count($baseRawSet/t:tillNosale)"/>
				</xsl:element>
			</xsl:element>
			
			<xsl:element name="safeDropTotals">
				<xsl:call-template name="ns:createSafeDropTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="creditMOPTotals">
				<xsl:call-template name="ns:createCreditTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="debitMOPTotals">
				<xsl:call-template name="ns:createDebitTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="electronicCheckTotals">
				<xsl:call-template name="ns:createECheckTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="manualCheckTotals">
				<xsl:call-template name="ns:createCheckTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="EBTTotals">
				<xsl:call-template name="ns:createEBTTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:element name="foodStampTotals">
				<xsl:call-template name="ns:createFoodStampTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				</xsl:call-template>
			</xsl:element>
			
			<xsl:variable name="ns-dc" select="ext:nodeset($depCatTotals)"/>
			
			
			<xsl:element name="itemTotals">
				<xsl:call-template name="ns:createItemTotals">
					<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
					<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
					<xsl:with-param name="depCatTotals" select="$ns-dc"/>
				</xsl:call-template>
			</xsl:element>
		</xsl:variable>
		
		<t:summaryReport>
			<xsl:copy-of select="$header"/>
			<xsl:element name="summaryAmounts">
				<xsl:copy-of select="$allCashiers"/>
			</xsl:element>
			<xsl:element name="allDCR">
				<xsl:copy-of select="$allDCR"/>
			</xsl:element>
			<xsl:element name="byCashier">
				<xsl:copy-of select="$byCashier"/>
			</xsl:element>
		</t:summaryReport>
	</xsl:template>
	
	
	<xsl:template name="ns:getCashierList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="list">
			<xsl:choose>
				
				<xsl:when test="$ns:rollUpCashier != 'true'">
					<xsl:call-template name="ns2:getCashierList">
						<xsl:with-param name="tlogEntrySet" select="$tlogEntrySet"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					
					<xsl:variable name="tmpList">
						<xsl:call-template name="ns2:getCashierList">
							<xsl:with-param name="tlogEntrySet" select="$tlogEntrySet"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:for-each select="ext:nodeset($tmpList)/t:cashier [(not( @sysid = preceding-sibling::t:cashier[1]/              @sysid))]">
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$list"/>
	</xsl:template>
	
	<xsl:template name="ns:getTLogEntriesForCashier">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="cashier"/>
		<xsl:param name="rawList"/>
		<xsl:variable name="ns-csh" select="ext:nodeset($cashier)"/>
		<xsl:variable name="ns-raw" select="ext:nodeset($rawList)"/>
		<xsl:variable name="tranSet">
			<xsl:choose>
				
				<xsl:when test="$ns:rollUpCashier != 'true'">
					<xsl:call-template name="ns2:getTLogEntriesForCashier">
						<xsl:with-param name="tlogEntrySet" select="$tlogEntrySet"/>
						<xsl:with-param name="cashier" select="$ns-csh"/>
					</xsl:call-template>
				</xsl:when>
				
				<xsl:otherwise>
					<xsl:for-each select="$ns-raw/t:cashier[@sysid = $ns-csh/@sysid]">
						<xsl:variable name="currCsh" select="."/>
						<xsl:call-template name="ns2:getTLogEntriesForCashier">
							<xsl:with-param name="tlogEntrySet" select="$tlogEntrySet"/>
							<xsl:with-param name="cashier" select="$currCsh"/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$tranSet"/>
	</xsl:template>
	
	<xsl:template name="ns:createSetOfLines">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:param name="rptName"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="rawSet" select="ext:nodeset($tlogEntrySet)"/>
		
		
		<xsl:variable name="rawRptPrefs" select="$rptPrefs//*[*=$rptName]"/>
		<xsl:variable name="setOfLines">
			<xsl:choose>
				
				<xsl:when test="local-name($rawRptPrefs) = $ns:deptMap">
					<xsl:variable name="deptList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:dept">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:nodeset($deptList)/*">
							<xsl:variable name="currDept" select="."/>
							<xsl:call-template name="ns2:getLinesForDept">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="dept" select="$currDept"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>
				
				<xsl:when test="local-name($rawRptPrefs) = $ns:categoryMap">
					<xsl:variable name="catList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:cat">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:nodeset($catList)/*">
							<xsl:variable name="currCat" select="."/>
							<xsl:call-template name="ns2:getLinesForCategory">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="cat" select="$currCat"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$setOfLines"/>
	</xsl:template>
	
	<xsl:template name="ns:createItemTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:param name="depCatTotals"/>
		<xsl:variable name="rptPrefDoc" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="ns-dc" select="ext:nodeset($depCatTotals)"/>
		
		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="string($ns:reptMerchName)"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="depList" select="ext:nodeset($departmentList)"/>
		
		<xsl:variable name="ns-sales" select="$ns-set/t:sale | $ns-set/t:adjustment"/>
		<xsl:variable name="itemTotals">
			<xsl:element name="totalPLUs">
				<xsl:variable name="tamt" select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot            ), '#.00')"/>
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)]                  )"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$tamt != 0">
							<xsl:value-of select="format-number(($tamt div $ns-dc/amount * 100), '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number((0.00), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="$tamt"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="scannedItems">
				<xsl:variable name="samt" select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot |            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot  |                $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@scanned='true')]/stot             ), '#.00')"/>
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                    and (flags/@scanned='true')] |              $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                    and (flags/@scanned='true')] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (flags/@scanned='true')] |              $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (flags/@scanned='true')]                  )"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$samt != 0">
							<xsl:value-of select="format-number(($samt div $ns-dc/amount * 100), '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number((0.00), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="$samt"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="keyedItems">
				<xsl:variable name="kamt" select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot |            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot |            $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (not (flags/@scanned='true'))]/stot                 ), '#.00')"/>
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                    and (not (flags/@scanned='true'))] |              $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:cline/t:sline[(iid)                      and (fid/t:dept/@sysid = $depList//@sysid)                    and (not (flags/@scanned='true'))] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (not (flags/@scanned='true'))] |              $ns-set/t:adjustment/lines/t:cline/t:sline[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                  and (not (flags/@scanned='true'))]                 )"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$kamt != 0">
							<xsl:value-of select="format-number(($kamt div $ns-dc/amount * 100), '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number((0.00), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="$kamt"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="openDeptRings">
				<xsl:variable name="oamt" select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[not (iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |            $ns-set/t:adjustment/lines/t:line[not (iid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot                 ), '#.00')"/>
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[not (iid)                       and (fid/t:dept/@sysid = $depList//@sysid)] |              $ns-set/t:adjustment/lines/t:line[not (iid)                       and (fid/t:dept/@sysid = $depList//@sysid)              ])"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$oamt != 0">
							<xsl:value-of select="format-number(($oamt div $ns-dc/amount * 100), '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number((0.00), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="$oamt"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="pluNotFoundItems">
				<xsl:variable name="pamt" select="format-number(sum(            $ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@pluNotFound='true')]/stot |            $ns-set/t:adjustment/lines/t:line[(iid)              and (fid/t:dept/@sysid = $depList//@sysid)             and (flags/@pluNotFound='true')]/stot                 ), '#.00')"/>
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:sale[not (@isRefund = 'true')]/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                     and (flags/@pluNotFound='true')] |              $ns-set/t:adjustment/lines/t:line[(iid)                       and (fid/t:dept/@sysid = $depList//@sysid)                   and (flags/@pluNotFound='true')              ])"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$pamt != 0">
							<xsl:value-of select="format-number(($pamt div $ns-dc/amount * 100), '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number((0.00), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="$pamt"/>
				</xsl:element>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$itemTotals"/>
	</xsl:template>
	
	<xsl:template name="ns:createMerchandiseTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="rptPrefDoc" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="string($ns:reptMerchName)"/>
			</xsl:call-template>
		</xsl:variable>
		
		
		<xsl:variable name="categoryList">
			<xsl:call-template name="ns2:getCategoryListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="depList" select="ext:nodeset($departmentList)"/>
		
		<xsl:variable name="merch">
			<xsl:for-each select="ext:nodeset($categoryList)/t:cat">
				<xsl:variable name="currCategory" select="."/>
				<xsl:element name="categoryInfo">
					<xsl:copy-of select="$currCategory"/>
					
					
					
					
					
					<xsl:element name="salesAmount">
						<xsl:value-of select="format-number(sum(             $ns-set/t:sale[not (@isRefund='true')]/lines/t:line              [(fid/t:cat/@sysid = $currCategory/@sysid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |              $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline               [(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot             ), '0.00')"/>
					</xsl:element>
					<xsl:element name="salesLineCount">
						<xsl:value-of select="count(              $ns-set/t:sale[not (@isRefund='true')]/lines/t:line               [(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot |               $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline                [(fid/t:cat/@sysid = $currCategory/@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]/stot              )"/>
					</xsl:element>
					
					<xsl:element name="refundAmount">
						<xsl:value-of select="format-number(sum(            $ns-set/t:sale[@isRefund='true']/lines/t:line             [fid/t:cat/@sysid = $currCategory/@sysid             and (fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline              [fid/t:cat/@sysid = $currCategory/@sysid               and (fid/t:dept/@sysid = $depList//@sysid)]/stot            ), '0.00')"/>
					</xsl:element>
					<xsl:element name="refundCount">
						<xsl:value-of select="count(             $ns-set/t:sale[@isRefund='true']/lines/t:line              [(fid/t:cat/@sysid = $currCategory/@sysid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline              [(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot             )"/>
					</xsl:element>
					
					<xsl:element name="voidsAmount">
						<xsl:value-of select="format-number(sum(            $ns-set/t:void/lines/t:line[(fid/t:cat/@sysid = $currCategory/@sysid)              and (fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:void/lines/t:cline/t:sline[(fid/t:cat/@sysid = $currCategory/@sysid)               and (fid/t:dept/@sysid = $depList//@sysid)]/stot            ), '0.00')"/>
					</xsl:element>
					<xsl:element name="voidsCount">
						<xsl:value-of select="count(              $ns-set/t:void/lines/t:line[(fid/t:cat/@sysid = $currCategory/@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]/stot |               $ns-set/t:void/lines/t:cline/t:sline[(fid/t:cat/@sysid = $currCategory/@sysid)                and (fid/t:dept/@sysid = $depList//@sysid)]/stot                   )"/>
					</xsl:element>
					
				</xsl:element>
				
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="$merch"/>
	</xsl:template>
	
	<xsl:template name="ns:createDriveOffTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="driveOffPrefs" select="$rptPrefs//*[*=$ns:driveOffName]"/>
		<xsl:variable name="doTots">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(           $ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $driveOffPrefs//@sysid]/amt           ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $driveOffPrefs//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$doTots"/>
	</xsl:template>
	
	<xsl:template name="ns:createTaxTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="taxList">
			<xsl:call-template name="ns2:getTaxList">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="totTaxes">
			<xsl:variable name="count" select="count($ns-set/t:sale/sum/t:sumTaxExempt)"/>
			<xsl:for-each select="ext:nodeset($taxList)/vs:taxrateBase">
				<xsl:variable name="currTax" select="."/>
				<xsl:element name="t:sumTax">
					<xsl:copy-of select="$currTax"/>
					<xsl:element name="amt">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax                     [(vs:taxrateBase/name = $currTax/name)                    and (vs:taxrateBase/taxRate = $currTax/taxRate)]/amt |                   $ns-set/t:adjustment/sum/t:sumTax                    [(vs:taxrateBase/name = $currTax/name)                    and (vs:taxrateBase/taxRate = $currTax/taxRate)]/amt                  ), '0.00')"/>
					</xsl:element>
					<xsl:element name="taxable">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/                    t:sumTax[(vs:taxrateBase/name = $currTax/name)                    and (vs:taxrateBase/taxRate = $currTax/taxRate)]/taxable |                   $ns-set/t:adjustment/sum/                    t:sumTax[(vs:taxrateBase/name = $currTax/name)                    and (vs:taxrateBase/taxRate = $currTax/taxRate)]/taxable                  ), '0.00')"/>
					</xsl:element>
					
					<xsl:if test="$count=0">
						<xsl:element name="forgivenTax">
							<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax                      [(vs:taxrateBase/name = $currTax/name)                     and (vs:taxrateBase/taxRate = $currTax/taxRate)]/forgivenTax), '0.00')"/>
						</xsl:element>
						<xsl:element name="forgivenAgainst">
							<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax                     [(vs:taxrateBase/name = $currTax/name)                     and (vs:taxrateBase/taxRate = $currTax/taxRate)]/forgivenAgainst), '0.00')"/>
						</xsl:element>	
						<xsl:element name="exemptTax">
							<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax                     [(vs:taxrateBase/name = $currTax/name)                    and (vs:taxrateBase/taxRate = $currTax/taxRate)]/exemptTax), '0.00')"/>
						</xsl:element>
						<xsl:element name="exemptAgainst">
							<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax                     [(vs:taxrateBase/name = $currTax/name)                     and (vs:taxrateBase/taxRate = $currTax/taxRate)]/exemptAgainst), '0.00')"/>
						</xsl:element>
					</xsl:if>
				</xsl:element>
			</xsl:for-each>
			
			<xsl:element name="total">
				<xsl:element name="amt">
					<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/*/amt |                  $ns-set/t:adjustment/sum/*/amt                ), '0.00')"/>
				</xsl:element>
				<xsl:element name="taxable">
					<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/*/taxable |                  $ns-set/t:adjustment/sum/*/taxable                 ), '0.00')"/>
				</xsl:element>
			</xsl:element>
			<xsl:if test="$count=0">
				<xsl:element name="totalExemptTaxes">
					<xsl:element name="amt">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax/exemptTax |                  $ns-set/t:adjustment/sum/t:sumTaxExempt/forgivenTax                ), '0.00')"/>
						</xsl:element>
					<xsl:element name="exemptAgainst">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax/exemptAgainst |                  $ns-set/t:adjustment/sum/t:sumTaxExempt/forgivenAgainst                  ), '0.00')"/>
					</xsl:element>
				</xsl:element>
				<xsl:element name="totalForgivenTaxes">
					<xsl:element name="amt">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax/forgivenTax |                  $ns-set/t:adjustment/sum/t:sumTaxExempt/forgivenTax                ), '0.00')"/>
						</xsl:element>
					<xsl:element name="forgivenAgainst">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTax/forgivenAgainst |                  $ns-set/t:adjustment/sum/t:sumTaxExempt/forgivenAgainst                  ), '0.00')"/>
					</xsl:element>
				</xsl:element>
			</xsl:if>
		</xsl:variable>
		<xsl:copy-of select="$totTaxes"/>
	</xsl:template>
	
	<xsl:template name="ns:createCouponTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="couponPrefs" select="$rptPrefs//*[*=$ns:couponName]"/>
		<xsl:variable name="couponTots">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(           $ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $couponPrefs//@sysid]/amt           ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $couponPrefs//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$couponTots"/>
	</xsl:template>
	
	<xsl:template name="ns:getCreditLineSet">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="creditPrefs" select="$rptPrefs//*[*=$ns:creditName]"/>
		<xsl:variable name="creditLineSet">
			<xsl:for-each select="ext:nodeset($creditPrefs)/t:mop">
				<xsl:variable name="currMOP" select="."/>
				<xsl:copy-of select="$ns-set/*/paylines/t:payline[t:mop/@sysid = $currMOP/@sysid]/../.."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="$creditLineSet"/>
	</xsl:template>
	
	<xsl:template name="ns:createFuelTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		
		<xsl:variable name="salesLines">
			<xsl:call-template name="ns2:getSaleSet">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="salesLineSet">
			<xsl:call-template name="ns2:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($salesLines)"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="fuelSaleLines">
			<xsl:call-template name="ns2:getLinesForFuelSales">
				<xsl:with-param name="lineSet" select="ext:nodeset($salesLineSet)"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="ns-fuelSales" select="ext:nodeset($fuelSaleLines)"/>
		<xsl:variable name="fuelTot">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum($ns-fuelSales/t:line/t:fuel/amt), '0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-fuelSales/t:line/t:fuel)"/>
			</xsl:element>
			<xsl:element name="volume">
				<xsl:value-of select="format-number(sum($ns-fuelSales/t:line/t:fuel/vol), '0.000')"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$fuelTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createCashierFuelTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		
		<xsl:variable name="salesLines">
			<xsl:call-template name="ns2:getSaleSet">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="salesLineSet">
			<xsl:call-template name="ns2:getLineSet">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($salesLines)"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="fuelSaleLines">
			<xsl:call-template name="ns2:getLinesForFuelSales">
				<xsl:with-param name="lineSet" select="ext:nodeset($salesLineSet)"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="ns-fuelSales" select="ext:nodeset($fuelSaleLines)"/>
		<xsl:variable name="fuelTot">
			<xsl:element name="amount">
				<xsl:value-of select="format-number((sum($ns-fuelSales/t:line/t:fuel/amt) + sum($ns-fuelSales/t:line/t:fuelPrepay/amt)), '0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-fuelSales/t:line/t:fuel) + count($ns-fuelSales/t:line/t:fuelPrepay)"/>
			</xsl:element>
			<xsl:element name="volume">
				<xsl:value-of select="format-number((sum($ns-fuelSales/t:line/t:fuel/vol) +  sum($ns-fuelSales/t:line/t:fuelPrepay/vol)), '0.000')"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$fuelTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createPumpTestTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="pumpTestTot">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum($ns-set/t:pumpTest/lines/t:line/t:fuel/amt), '0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:pumpTest/lines/t:line/t:fuel)"/>
			</xsl:element>
			<xsl:element name="volume">
				<xsl:value-of select="format-number(sum($ns-set/t:pumpTest/lines/t:line/t:fuel/vol), '0.000')"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$pumpTestTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createCreditTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		
		<xsl:variable name="creditLineSet">
			<xsl:call-template name="ns:getCreditLineSet">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$ns-rptPrefs"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="creditPrefs" select="$ns-rptPrefs//*[*=$ns:creditName]"/>
		
		<xsl:variable name="totCnt" select="count(ext:nodeset($creditLineSet)/*)"/>
		<xsl:variable name="totAmt" select="sum(ext:nodeset($creditLineSet)/*            /paylines/t:payline[t:mop/@sysid = $creditPrefs//@sysid]/amt)"/>
		
		<xsl:variable name="swipeCnt" select="count(ext:nodeset($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'swipe'])"/>
		<xsl:variable name="swipeAmt" select="sum(ext:nodeset($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'swipe']/../../amt)"/>
		
		<xsl:variable name="manEntryCnt" select="count(ext:nodeset($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'manual'])"/>
		<xsl:variable name="manEntryAmt" select="sum(ext:nodeset($creditLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'manual']/../../amt)"/>
		
		<xsl:variable name="imprintCnt" select="count(ext:nodeset($creditLineSet)/*            /paylines/t:payline[not(t:cardInfo)            and (t:mop/@sysid = $creditPrefs//@sysid)])"/>
		<xsl:variable name="imprintAmt" select="sum(ext:nodeset($creditLineSet)/*            /paylines/t:payline[not(t:cardInfo)            and (t:mop/@sysid = $creditPrefs//@sysid)]/amt)"/>
		
		<xsl:variable name="creditTot">
			<xsl:element name="totalCreditCount">
				<xsl:element name="count">
					<xsl:value-of select="$totCnt"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$totCnt= 0">
							<xsl:value-of select="format-number(0.00, '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(($totCnt div $totCnt * 100), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number($totAmt, '0.00')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="swiped">
				<xsl:element name="count">
					<xsl:value-of select="$swipeCnt"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$swipeCnt= 0">
							<xsl:value-of select="format-number(0.00, '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(($swipeCnt div $totCnt * 100), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number($swipeAmt, '0.00')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="manuallyEntered">
				<xsl:element name="count">
					<xsl:value-of select="$manEntryCnt"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$manEntryCnt= 0">
							<xsl:value-of select="format-number(0.00, '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(($manEntryCnt div $totCnt * 100), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number($manEntryAmt, '0.00')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="imprinted">
				<xsl:element name="count">
					<xsl:value-of select="$imprintCnt"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$imprintCnt= 0">
							<xsl:value-of select="format-number(0.00, '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(($imprintCnt div $totCnt * 100), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number($imprintAmt, '0.00')"/>
				</xsl:element>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$creditTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createCarwashTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="ns-set">
			<xsl:copy-of select="ext:nodeset($tlogEntrySet)/t:sale"/>
		</xsl:variable>
		
		<xsl:variable name="carwashLineSet">
			<xsl:call-template name="ns:getCarwashSales">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$ns-rptPrefs"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="rawIdList">
			<xsl:call-template name="ns2:getPluListFromLines">
				<xsl:with-param name="lineSet" select="$carwashLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="cwList">
			<xsl:for-each select="ext:nodeset($rawIdList)/t:plu">
				<xsl:variable name="currPLU" select="."/>
				<xsl:variable name="PLULines">
					<xsl:call-template name="ns2:getLinesForPlu">
						<xsl:with-param name="lineSet" select="$carwashLineSet"/>
						<xsl:with-param name="plu" select="$currPLU"/>
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:variable name="sortedList">
					<xsl:for-each select="ext:nodeset($PLULines)/t:line">
						<xsl:sort data-type="number" order="ascending" select="./tot"/>
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</xsl:variable>
				
				<xsl:variable name="prices" select="ext:nodeset($sortedList)/t:line[                 not( tot = preceding-sibling::t:line[1]/tot)]/tot"/>
				
				<xsl:variable name="carWashSales">
					<xsl:for-each select="ext:nodeset($prices)">
						<xsl:variable name="currPrice" select="."/>
						<xsl:element name="carWashSaleItem">
							<xsl:copy-of select="$currPLU"/>
							<xsl:element name="soldAtPrice">
								<xsl:value-of select="$currPrice"/>
							</xsl:element>
							<xsl:element name="count">
								<xsl:value-of select="count(ext:nodeset($PLULines)/*[tot = $currPrice])"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:variable>
				<xsl:copy-of select="$carWashSales"/>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:nodeset($cwList)/carWashSaleItem">
				<xsl:sort order="ascending" data-type="number" select="soldAtPrice"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
			
			<xsl:element name="carWashComp">
				<xsl:element name="count">
					<xsl:value-of select="sum(ext:nodeset($cwList)/carWashSaleItem[soldAtPrice= $ns:compCWAmt]/count)"/>
				</xsl:element>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$sortedList"/>
	</xsl:template>
	
	<xsl:template name="ns:getCarwashSales">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="rawSet" select="ext:nodeset($tlogEntrySet)"/>
		
		
		<xsl:variable name="rawRptPrefs" select="$rptPrefs//*[*=$ns:reptCWName]"/>
		<xsl:variable name="setOfLines">
			<xsl:choose>
				
				<xsl:when test="local-name($rawRptPrefs) = $ns:deptMap">
					<xsl:variable name="deptList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:dept">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:nodeset($deptList)/*">
							<xsl:variable name="currDept" select="."/>
							<xsl:call-template name="ns2:getLinesForDept">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="dept" select="$currDept"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>
				
				<xsl:when test="local-name($rawRptPrefs) = $ns:categoryMap">
					<xsl:variable name="catList">
						<xsl:for-each select="$rawRptPrefs/*">
							<xsl:element name="t:cat">
								<xsl:attribute name="sysid"><xsl:value-of select="./@sysid"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="./name"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="tmpTranLineSet">
						<xsl:for-each select="ext:nodeset($catList)/*">
							<xsl:variable name="currCat" select="."/>
							<xsl:call-template name="ns2:getLinesForCategory">
								<xsl:with-param name="lineSet" select="$rawSet/*/lines"/>
								<xsl:with-param name="cat" select="$currCat"/>
							</xsl:call-template>
						</xsl:for-each>
					</xsl:variable>
					<xsl:copy-of select="$tmpTranLineSet"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:copy-of select="$setOfLines"/>
	</xsl:template>
	
	<xsl:template name="ns:createOverShort">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="overShortPrefs" select="$rptPrefs//*[*=$ns:overShortName]"/>
		<xsl:variable name="mopLineSet">
			<xsl:for-each select="ext:nodeset($overShortPrefs)/t:mop">
				<xsl:variable name="currMOP" select="."/>
				<xsl:element name="overShortMOP">
					<xsl:copy-of select="$currMOP"/>
					<xsl:variable name="ecrAmt">
						<xsl:value-of select="format-number(sum(             $ns-set/t:countCashier/tillAmount              [t:mop/@sysid = $currMOP/@sysid]/ecrAmount             ), '0.00')"/>
					</xsl:variable>
					<xsl:variable name="actualAmt">
						<xsl:value-of select="format-number(sum(             $ns-set/t:countCashier/tillAmount              [t:mop/@sysid = $currMOP/@sysid]/actualAmount             ), '0.00')"/>
					</xsl:variable>
					<xsl:element name="TotalEcrAmt">
						<xsl:value-of select="$ecrAmt"/>
					</xsl:element>
					<xsl:element name="TotalActualAmt">
						<xsl:value-of select="$actualAmt"/>
					</xsl:element>
					<xsl:element name="TotalOverShortAmt">
						<xsl:value-of select="format-number(($actualAmt - $ecrAmt) ,'0.00')"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="$mopLineSet"/>
	</xsl:template>
	
	<xsl:template name="ns:createOtherServTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefDoc" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="$ns:reptOthServicesName"/>
			</xsl:call-template>
		</xsl:variable>
		
		
		<xsl:variable name="categoryList">
			<xsl:call-template name="ns2:getCategoryListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="depList" select="ext:nodeset($departmentList)"/>
		<xsl:variable name="catList" select="ext:nodeset($categoryList)"/>
		<xsl:variable name="totOthrServ">
			<xsl:element name="salesAmount">
				<xsl:value-of select="format-number(sum(             $ns-set/t:sale[not (@isRefund='true')]/lines/t:line              [(fid/t:dept/@sysid = $depList//@sysid) and               (fid/t:cat/@sysid = $catList//@sysid)]/stot |              $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline               [(fid/t:dept/@sysid = $depList//@sysid) and               (fid/t:cat/@sysid = $catList//@sysid)]/stot             ), '0.00')"/>
			</xsl:element>
			<xsl:element name="salesLineCount">
				<xsl:value-of select="count(              $ns-set/t:sale[not (@isRefund='true')]/lines/t:line               [(fid/t:dept/@sysid = $depList//@sysid) and               (fid/t:cat/@sysid = $catList//@sysid)]/stot |               $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline                [(fid/t:dept/@sysid = $depList//@sysid)and                 (fid/t:cat/@sysid = $catList//@sysid)]/stot              )"/>
			</xsl:element>
			<xsl:element name="refundAmount">
				<xsl:value-of select="format-number(sum(            $ns-set/t:sale[@isRefund='true']/lines/t:line             [(fid/t:dept/@sysid = $depList//@sysid) and             (fid/t:cat/@sysid = $catList//@sysid)]/stot |             $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline              [(fid/t:dept/@sysid = $depList//@sysid)and               (fid/t:cat/@sysid = $catList//@sysid)]/stot            ), '0.00')"/>
			</xsl:element>
			<xsl:element name="refundCount">
				<xsl:value-of select="count(             $ns-set/t:sale[@isRefund='true']/lines/t:line              [(fid/t:dept/@sysid = $depList//@sysid) and              (fid/t:cat/@sysid = $catList//@sysid)]/stot |             $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline              [(fid/t:dept/@sysid = $depList//@sysid) and               (fid/t:cat/@sysid = $catList//@sysid)]/stot             )"/>
			</xsl:element>
			<xsl:element name="voidsAmount">
				<xsl:value-of select="format-number(sum(            $ns-set/t:void/lines/t:line[(fid/t:dept/@sysid = $depList//@sysid) and                  (fid/t:cat/@sysid = $catList//@sysid)]/stot |             $ns-set/t:void/lines/t:cline/t:sline[(fid/t:dept/@sysid = $depList//@sysid) and                   (fid/t:cat/@sysid = $catList//@sysid)]/stot            ), '0.00')"/>
			</xsl:element>
			<xsl:element name="voidsCount">
				<xsl:value-of select="count(              $ns-set/t:void/lines/t:line[(fid/t:dept/@sysid = $depList//@sysid) and                     (fid/t:cat/@sysid = $catList//@sysid)]/stot |               $ns-set/t:void/lines/t:cline/t:sline[(fid/t:dept/@sysid = $depList//@sysid) and                     (fid/t:cat/@sysid = $catList//@sysid)]/stot               )"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$totOthrServ"/>
	</xsl:template>
	
	<xsl:template name="ns:createLottoSalesTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefDoc" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="$ns:reptLottoSalesName"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="depList" select="ext:nodeset($departmentList)"/>
		<xsl:variable name="lottoTot">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(             $ns-set/t:sale/lines/t:line              [(fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:sale/lines/t:cline/t:sline              [(fid/t:dept/@sysid = $depList//@sysid)]/stot)             , '0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale[not (@isRefund='true')]/lines/t:line              [(fid/t:dept/@sysid = $depList//@sysid)] |             $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline              [(fid/t:dept/@sysid = $depList//@sysid)])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$lottoTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createLotterySalesTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefDoc" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="$ns:reptLotterySalesName"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="depList" select="ext:nodeset($departmentList)"/>
		<xsl:variable name="lotteryTot">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(             $ns-set/t:sale/lines/t:line              [(fid/t:dept/@sysid = $depList//@sysid)]/stot |             $ns-set/t:sale/lines/t:cline/t:sline              [(fid/t:dept/@sysid = $depList//@sysid)]/stot)             , '0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale[not (@isRefund='true')]/lines/t:line              [(fid/t:dept/@sysid = $depList//@sysid)] |             $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline              [(fid/t:dept/@sysid = $depList//@sysid)])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$lotteryTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createLottoWinnersTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="lottoPrefs" select="$rptPrefs//*[*=$ns:reptLottoWinnersName]"/>
		<xsl:variable name="ns-mop" select="ext:nodeset($lottoPrefs)"/>
		<xsl:variable name="lottoTot">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(              $ns-set/t:sale[not (@isRefund)]               /paylines/t:payline[t:mop/@sysid = $ns-mop//@sysid]/amt              ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale[not (@isRefund='true')]             /paylines/t:payline[t:mop/@sysid = $ns-mop//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$lottoTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createLotteryWinnersTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="lotteryPrefs" select="$rptPrefs//*[*=$ns:reptLotteryWinnersName]"/>
		<xsl:variable name="ns-mop" select="ext:nodeset($lotteryPrefs)"/>
		<xsl:variable name="lotteryTot">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(              $ns-set/t:sale[not (@isRefund)]               /paylines/t:payline[t:mop/@sysid = $ns-mop//@sysid]/amt              ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale[not (@isRefund='true')]             /paylines/t:payline[t:mop/@sysid = $ns-mop//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$lotteryTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createDrawerAlarmTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="drwAlarmCnt" select="count($ns-set/t:event[@type='drawerAlarm'])"/>
		
		<xsl:variable name="salesCnt" select="count($ns-set/t:sale |                $ns-set/t:adjustment |                $ns-set/t:tillPayin |                $ns-set/t:tillPayout |                $ns-set/t:tillSafeDrop |                $ns-set/t:tillSafeLoan |                $ns-set/t:tillNoSale)"/>
		<xsl:variable name="drwAlrmTot">
			<xsl:element name="count">
				<xsl:value-of select="$drwAlarmCnt"/>
			</xsl:element>
			<xsl:element name="totalDrawerOpens">
				<xsl:value-of select="$salesCnt"/>
			</xsl:element>
			<xsl:element name="averageTimes">
				<xsl:choose>
					<xsl:when test="$salesCnt != 0">
						<xsl:value-of select="format-number(($drwAlarmCnt div $salesCnt ) , '0.00')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="format-number((0.00) , '0.00')"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$drwAlrmTot"/>
	</xsl:template>
	
	<xsl:template name="ns:createMoneyOrderTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="MOPrefs" select="$rptPrefs//*[*=$ns:reptMoneyOrderName]"/>
		<xsl:variable name="ns-mo" select="ext:nodeset($MOPrefs)"/>
		<xsl:variable name="moTots">
			<xsl:element name="salesAmount">
				<xsl:value-of select="format-number(sum($ns-set/t:sale/lines/t:line                  [fid/t:dept/@sysid = $ns-mo//@sysid]/stot           ), '0.00')"/>
			</xsl:element>
			<xsl:element name="salesLineCount">
				<xsl:value-of select="count($ns-set/t:sale/lines/t:line                  [fid/t:dept/@sysid = $ns-mo//@sysid])"/>
			</xsl:element>
			<xsl:element name="feesAmount">
				<xsl:value-of select="format-number(sum($ns-set/t:sale/lines/t:line                  [fid/t:dept/@sysid = $ns-mo//@sysid]/t:fee/amt           ), '0.00')"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$moTots"/>
	</xsl:template>
	
	<xsl:template name="ns:createDebitTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		
		<xsl:variable name="debitLineSet">
			<xsl:call-template name="ns:getDebitLineSet">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$ns-rptPrefs"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="debitPrefs" select="$ns-rptPrefs//*[*=$ns:debitName]"/>
		
		<xsl:variable name="totCnt" select="count(ext:nodeset($debitLineSet)/*)"/>
		<xsl:variable name="totAmt" select="sum(ext:nodeset($debitLineSet)/*            /paylines/t:payline[t:mop/@sysid = $debitPrefs//@sysid]/amt)"/>
		
		<xsl:variable name="swipeCnt" select="count(ext:nodeset($debitLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'swipe'])"/>
		<xsl:variable name="swipeAmt" select="sum(ext:nodeset($debitLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'swipe']/../../amt)"/>
		
		<xsl:variable name="manEntryCnt" select="count(ext:nodeset($debitLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'manual'])"/>
		<xsl:variable name="manEntryAmt" select="sum(ext:nodeset($debitLineSet)/*            /paylines/t:payline/t:cardInfo/entryMeth[@type = 'manual']/../../amt)"/>
		
		
		
		<xsl:variable name="debitTot">
			<xsl:element name="totalDebitCount">
				<xsl:element name="count">
					<xsl:value-of select="$totCnt"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$totCnt= 0">
							<xsl:value-of select="format-number(0.00, '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(($totCnt div $totCnt * 100), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number($totAmt, '0.00')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="swiped">
				<xsl:element name="count">
					<xsl:value-of select="$swipeCnt"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$swipeCnt= 0">
							<xsl:value-of select="format-number(0.00, '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(($swipeCnt div $totCnt * 100), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number($swipeAmt, '0.00')"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="manuallyEntered">
				<xsl:element name="count">
					<xsl:value-of select="$manEntryCnt"/>
				</xsl:element>
				<xsl:element name="percent">
					<xsl:choose>
						<xsl:when test="$manEntryCnt= 0">
							<xsl:value-of select="format-number(0.00, '0.00')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="format-number(($manEntryCnt div $totCnt * 100), '0.00')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="amount">
					<xsl:value-of select="format-number($manEntryAmt, '0.00')"/>
				</xsl:element>
			</xsl:element>
			
		</xsl:variable>
		<xsl:copy-of select="$debitTot"/>
	</xsl:template>
	
	<xsl:template name="ns:getDebitLineSet">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="debitPrefs" select="$rptPrefs//*[*=$ns:debitName]"/>
		<xsl:variable name="debitLineSet">
			<xsl:for-each select="ext:nodeset($debitPrefs)/t:mop">
				<xsl:variable name="currMOP" select="."/>
				<xsl:copy-of select="$ns-set/*/paylines/t:payline[t:mop/@sysid = $currMOP/@sysid]/../.."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="$debitLineSet"/>
	</xsl:template>
	<xsl:template name="ns:createErrorCorrectTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set">
			<xsl:copy-of select="ext:nodeset($tlogEntrySet)/t:event[@type='errorCorrect']"/>
		</xsl:variable>
		<xsl:variable name="ecd">
			<xsl:for-each select="ext:nodeset($ns-set)/*">
				
				<xsl:element name="t:errorCorrectDetail">
					<xsl:choose>
						<xsl:when test="./trLine">
							<xsl:element name="tot">
								<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
								<xsl:value-of select="./trLine/trlLineTot"/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="tot">
								<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
								<xsl:value-of select="format-number(jsc:getErrorCorrectPrice(string(./text)), '0.00')"/>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:variable name="totals">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(ext:nodeset($ecd)//tot), '#.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count(ext:nodeset($ecd)//t:errorCorrectDetail)"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$totals"/>
	</xsl:template>
	
	<xsl:template name="ns:createPrepaidCards">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefDoc" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="baseRawLineSet">
			<xsl:call-template name="ns:createSetOfLines">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				<xsl:with-param name="reportPrefs" select="$rptPrefDoc"/>
				<xsl:with-param name="rptName" select="$ns:reptPrepaidName"/>
			</xsl:call-template>
		</xsl:variable>
		
		
		<xsl:variable name="categoryList">
			<xsl:call-template name="ns2:getCategoryListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="departmentList">
			<xsl:call-template name="ns2:getDeptListFromLines">
				<xsl:with-param name="lineSet" select="$baseRawLineSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="catList" select="ext:nodeset($categoryList)"/>
		<xsl:variable name="prePaidCardTotals">
			<xsl:for-each select="ext:nodeset($departmentList)/*">
				<xsl:variable name="depList" select="."/>
				<xsl:element name="prePaidCardInfo">
					<xsl:copy-of select="$depList"/>
					<xsl:element name="salesAmount">
						<xsl:value-of select="format-number(sum(              $ns-set/t:sale[not (@isRefund='true')]/lines/t:line               [(fid/t:dept/@sysid = $depList/@sysid) and                (fid/t:cat/@sysid = $catList//@sysid)]/stot |               $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline                [(fid/t:dept/@sysid = $depList/@sysid) and                (fid/t:cat/@sysid = $catList//@sysid)]/stot              ), '0.00')"/>
					</xsl:element>
					<xsl:element name="salesLineCount">
						<xsl:value-of select="count(               $ns-set/t:sale[not (@isRefund='true')]/lines/t:line                [(fid/t:dept/@sysid = $depList/@sysid) and                (fid/t:cat/@sysid = $catList//@sysid)]/stot |                $ns-set/t:sale[not (@isRefund='true')]/lines/t:cline/t:sline                 [(fid/t:dept/@sysid = $depList/@sysid)and                  (fid/t:cat/@sysid = $catList//@sysid)]/stot               )"/>
					</xsl:element>
					<xsl:element name="refundAmount">
						<xsl:value-of select="format-number(sum(             $ns-set/t:sale[@isRefund='true']/lines/t:line              [(fid/t:dept/@sysid = $depList/@sysid) and              (fid/t:cat/@sysid = $catList//@sysid)]/stot |              $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline               [(fid/t:dept/@sysid = $depList/@sysid)and                (fid/t:cat/@sysid = $catList//@sysid)]/stot             ), '0.00')"/>
					</xsl:element>
					<xsl:element name="refundCount">
						<xsl:value-of select="count(              $ns-set/t:sale[@isRefund='true']/lines/t:line               [(fid/t:dept/@sysid = $depList/@sysid) and               (fid/t:cat/@sysid = $catList//@sysid)]/stot |              $ns-set/t:sale[@isRefund='true']/lines/t:cline/t:sline               [(fid/t:dept/@sysid = $depList/@sysid) and                (fid/t:cat/@sysid = $catList//@sysid)]/stot              )"/>
					</xsl:element>
					<xsl:element name="voidsAmount">
						<xsl:value-of select="format-number(sum(             $ns-set/t:void/lines/t:line[(fid/t:dept/@sysid = $depList/@sysid) and                   (fid/t:cat/@sysid = $catList//@sysid)]/stot |              $ns-set/t:void/lines/t:cline/t:sline[(fid/t:dept/@sysid = $depList/@sysid) and                    (fid/t:cat/@sysid = $catList//@sysid)]/stot             ), '0.00')"/>
					</xsl:element>
					<xsl:element name="voidsCount">
						<xsl:value-of select="count(               $ns-set/t:void/lines/t:line[(fid/t:dept/@sysid = $depList/@sysid) and                      (fid/t:cat/@sysid = $catList//@sysid)]/stot |                $ns-set/t:void/lines/t:cline/t:sline[(fid/t:dept/@sysid = $depList/@sysid) and                      (fid/t:cat/@sysid = $catList//@sysid)]/stot                )"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="$prePaidCardTotals"/>
	</xsl:template>
	
	<xsl:template name="ns:createECheckTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="eCheckPrefs" select="$rptPrefs//*[*=$ns:electronicCheckName]"/>
		<xsl:variable name="eCheckTots">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(           $ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $eCheckPrefs//@sysid]/amt           ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $eCheckPrefs//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$eCheckTots"/>
	</xsl:template>
	
	<xsl:template name="ns:createCheckTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="checkPrefs" select="$rptPrefs//*[*=$ns:manualCheckName]"/>
		<xsl:variable name="checkTots">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(           $ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $checkPrefs//@sysid]/amt           ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $checkPrefs//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$checkTots"/>
	</xsl:template>
	
	<xsl:template name="ns:createEBTTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="ebtPrefs" select="$rptPrefs//*[*=$ns:ebtName]"/>
		<xsl:variable name="ebtTots">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(           $ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $ebtPrefs//@sysid]/amt           ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $ebtPrefs//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$ebtTots"/>
	</xsl:template>
		
	<xsl:template name="ns:createFoodStampTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="reportPrefs"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="rptPrefs" select="ext:nodeset($reportPrefs)"/>
		<xsl:variable name="fsPrefs" select="$rptPrefs//*[*=$ns:foodStampName]"/>
		<xsl:variable name="fsTots">
			<xsl:element name="amount">
				<xsl:value-of select="format-number(sum(           $ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $fsPrefs//@sysid]/amt           ),'0.00')"/>
			</xsl:element>
			<xsl:element name="count">
				<xsl:value-of select="count($ns-set/t:sale/paylines/t:payline[t:mop/@sysid = $fsPrefs//@sysid])"/>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$fsTots"/>
	</xsl:template>
	
	<xsl:template name="ns:createTaxExemptTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:if test="ns-set/t:sale/sum/t:sumTaxExempt">
			<xsl:variable name="taxList">
				<xsl:call-template name="ns2:getTaxList">
					<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="totExemptTaxes">
				<xsl:for-each select="ext:nodeset($taxList)/vs:taxrateBase">
					<xsl:variable name="currTax" select="."/>
					<xsl:element name="t:sumTaxExempt">
						<xsl:copy-of select="$currTax"/>
						<xsl:element name="forgivenTax"> 
							<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTaxExempt                      [(vs:taxrateBase/name = $currTax/name)                     and (vs:taxrateBase/taxRate = $currTax/taxRate)]/forgivenTax |                    $ns-set/t:adjustment/sum/t:sumTaxExempt                     [(vs:taxrateBase/name = $currTax/name)                     and (vs:taxrateBase/taxRate = $currTax/taxRate)]/forgivenTax                   ), '0.00')"/>
						</xsl:element>
						<xsl:element name="forgivenAgainst">
							<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTaxExempt                     [(vs:taxrateBase/name = $currTax/name)                     and (vs:taxrateBase/taxRate = $currTax/taxRate)]/forgivenAgainst |                    $ns-set/t:adjustment/sum/                     t:sumTaxExempt[(vs:taxrateBase/name = $currTax/name)                     and (vs:taxrateBase/taxRate = $currTax/taxRate)]/forgivenAgainst                   ), '0.00')"/>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
				<xsl:element name="total">
					<xsl:element name="forgivenTax">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTaxExempt/forgivenTax |                   $ns-set/t:adjustment/sum/t:sumTaxExempt/forgivenTax                 ), '0.00')"/>
					</xsl:element>
					<xsl:element name="forgivenAgainst">
						<xsl:value-of select="format-number(sum($ns-set/t:sale/sum/t:sumTaxExempt/forgivenAgainst |                   $ns-set/t:adjustment/sum/t:sumTaxExempt/forgivenAgainst                   ), '0.00')"/>
					</xsl:element>
				</xsl:element>
			</xsl:variable>
			<xsl:copy-of select="$totExemptTaxes"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="ns:createSafeDropTotals">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		
		<xsl:variable name="amount">
			<xsl:value-of select="format-number(sum($ns-set/t:tillSafeDrop/amount) - sum($ns-set/t:tillSafeDrop[@correction='true']/origSafedropInfo/amount),'0.00')"/>
		</xsl:variable>
		
		<xsl:variable name="count" select="count($ns-set/t:tillSafeDrop[not(@correction='true')])"/>
		<xsl:element name="amount">
			<xsl:value-of select="$amount"/>
		</xsl:element>
		<xsl:element name="count">
			<xsl:value-of select="$count"/>
		</xsl:element>
		
		<xsl:element name="averageAmount">
			<xsl:choose>
				<xsl:when test="$count = 0">
					<xsl:value-of select="format-number(0.00, '0.00')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="format-number($amount div $count, '0.00')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
		
		
		<xsl:if test="count($ns-set/t:tillSafeDrop[@correction='true']) &gt; 0">
			<xsl:element name="safeDropCorrections">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum($ns-set/t:tillSafeDrop[@correction='true']/amount),'#,##0.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count($ns-set/t:tillSafeDrop[@correction='true'])"/>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		
		<xsl:if test="count($ns-set/t:tillSafeDrop[@eSafeId]) &gt; 0">
			<xsl:variable name="rawList">
				<xsl:copy-of select="$ns-set/t:tillSafeDrop[@eSafeId]"/>
			</xsl:variable>
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:nodeset($rawList)/t:tillSafeDrop">
					<xsl:sort data-type="number" order="ascending" select="@eSafeId"/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:variable name="list">
				<xsl:copy-of select="ext:nodeset($sortedList)/t:tillSafeDrop[ not( @eSafeId = preceding-sibling::t:tillSafeDrop[1]/@eSafeId) ]"/>
			</xsl:variable>
			<xsl:for-each select="ext:nodeset($list)/t:tillSafeDrop">
				<xsl:variable name="id" select="@eSafeId"/>
				<xsl:element name="totalsByEsafe">
					<xsl:attribute name="sysid"><xsl:value-of select="$id"/></xsl:attribute> 
					<xsl:if test="@eSafeName">
						<xsl:attribute name="name"><xsl:value-of select="@eSafeName"/></xsl:attribute> 
					</xsl:if>
						<xsl:element name="amount">
							<xsl:value-of select="format-number(sum($ns-set/t:tillSafeDrop[@eSafeId=$id]/amount) - sum($ns-set/t:tillSafeDrop[@correction='true' and @eSafeId=$id]/origSafedropInfo/amount),'0.00')"/>
						</xsl:element>
						<xsl:element name="count">
							<xsl:value-of select="count($ns-set/t:tillSafeDrop[not(@correction='true') and @eSafeId=$id])"/>
						</xsl:element>
				</xsl:element>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>