<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildTaxableRebates" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns js vs ns2 base">
	<xsl:import href="../transactionSet/scripts.xslt"/>
	<xsl:import href="lists.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		
		<xsl:variable name="rebatePLUList">
			<xsl:call-template name="ns:getPLURebateList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		
		<xsl:variable name="rebatePromoList">
			<xsl:call-template name="ns:getPromoRebateList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="taxList">
			<xsl:call-template name="ns:getTaxList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="report">
			<xsl:call-template name="ns:createReport">
				<xsl:with-param name="taxList" select="$taxList"/>
				<xsl:with-param name="pluList" select="$rebatePLUList"/>
				<xsl:with-param name="promoList" select="$rebatePromoList"/>
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<t:taxableRebateReport>
			<xsl:copy-of select="$header"/>
			<xsl:copy-of select="$report"/>
		</t:taxableRebateReport>
	</xsl:template>
	
	
	<xsl:template name="ns:getTaxList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="rawList">
			<xsl:call-template name="ns2:getRawTaxList">
				<xsl:with-param name="tlogEntrySet" select="$ns-set"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:node-set($rawList)/*">
				<xsl:sort data-type="number" order="ascending" select="./@sysid"/>
				<xsl:sort data-type="text" order="ascending" select="./name"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="ext:node-set($sortedList)/vs:taxrateBase[           not( name = preceding-sibling::vs:taxrateBase[1]/name )          or not(taxRate = preceding-sibling::vs:taxrateBase[1]/taxRate           )]"/>
	</xsl:template>
	
	<xsl:template name="ns:getPLURebateList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="rawList">
			<xsl:copy-of select="$ns-set/t:sale/lines/t:line[flags/taxableRebateFlag[not(@promoID)]]/iid/t:plu"/>
		</xsl:variable>
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:node-set($rawList)/*">
				<xsl:sort data-type="number" order="ascending" select="./upc"/>
				<xsl:sort data-type="number" order="ascending" select="./modifier"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="ext:node-set($sortedList)/t:plu[           not( upc = preceding-sibling::t:plu[1]/upc )          or not(modifier = preceding-sibling::t:plu[1]/modifier           )]"/>
	</xsl:template>
	
	<xsl:template name="ns:getPromoRebateList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="rawList">
			<xsl:copy-of select="$ns-set/t:sale/lines/t:line[flags/taxableRebateFlag[@promoID]]/t:match"/>
		</xsl:variable>
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:node-set($rawList)/*">
				<xsl:sort data-type="number" order="ascending" select="./promoID"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="ext:node-set($sortedList)/t:match[           not( promoID = preceding-sibling::t:match[1]/promoID )          ]"/>
	</xsl:template>
	
	<xsl:template name="ns:createReport">
		<xsl:param name="pluList"/>
		<xsl:param name="promoList"/>
		<xsl:param name="taxList"/>
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="ns-plus" select="ext:node-set($pluList)"/>
		<xsl:variable name="ns-promos" select="ext:node-set($promoList)"/>
		<xsl:variable name="ns-taxes" select="ext:node-set($taxList)"/>
		
		<xsl:variable name="report">
			<rebateEntries>
				
				<xsl:for-each select="ext:node-set($ns-taxes)/*">
					<rebateEntry>
						<xsl:variable name="taxrate">
							<xsl:copy-of select="."/>
						</xsl:variable>
						<xsl:copy-of select="$taxrate"/>
						
						<xsl:if test="count($ns-set/t:sale[lines/t:line/flags[taxableRebateFlag/@sysid =        ext:node-set($taxrate)//@sysid]/taxableRebateFlag[not(@promoID)]]) &gt; 0">
							<items>
								<xsl:for-each select="ext:node-set($ns-plus)/t:plu">
									<xsl:variable name="plu">
										<xsl:copy-of select="."/>
									</xsl:variable>
									
									<xsl:variable name="items">
										<xsl:copy-of select="$ns-set/t:sale/lines/t:line              [(iid/t:plu/upc =ext:node-set($plu)//upc) and               iid/t:plu/modifier = ext:node-set($plu)//modifier and              flags/taxableRebateFlag[@sysid = ext:node-set($taxrate)//@sysid] and              flags/taxableRebateFlag[not(@promoID)]]"/>
									</xsl:variable>
									
									<xsl:if test="count(ext:node-set($items)/*) &gt; 0">
										<item>
											<xsl:copy-of select="$plu"/>
											<totals>
												<xsl:variable name="rebateAmount">
													<xsl:value-of select="ext:node-set($items)/t:line[1]/flags/taxableRebateFlag[@sysid= ext:node-set($taxrate)//@sysid and not(@promoID)] "/>
												</xsl:variable>
												<rebateAmt>
													<xsl:value-of select="format-number($rebateAmount,'0.00')"/>
												</rebateAmt>
												<totalSold>
													<count>
														<xsl:value-of select="format-number(sum(ext:node-set($items)/t:line/qty)                     ,'0.000')"/>
													</count>
													<amount>
														<xsl:value-of select="format-number(                    sum(ext:node-set($items)/t:line/qty) * $rebateAmount                    ,'0.00')"/>
													</amount>
												</totalSold>
											</totals>
											
										</item>
									</xsl:if>
								</xsl:for-each>
							</items>
						</xsl:if>
						
						<xsl:if test="count($ns-set/t:sale[lines/t:line/flags/taxableRebateFlag[@sysid = ext:node-set($taxrate)//@sysid and @promoID]]) &gt; 0">
							<xsl:variable name="sales">
								<xsl:copy-of select="$ns-set/t:sale[lines/t:line/flags/taxableRebateFlag[@sysid =             ext:node-set($taxrate)//@sysid and @promoID]]"/>
							</xsl:variable>
							<promos>
								
								
								<xsl:for-each select="ext:node-set($ns-promos)/t:match">
									
									<xsl:variable name="promoID" select="./promoID"/>
									
									<xsl:variable name="promos">
										<xsl:copy-of select="ext:node-set($sales)/t:sale/sum/t:sumTax[vs:taxrateBase/@sysid =             ext:node-set($taxrate)//@sysid]/taxableRebate[@promoID = $promoID]"/>
									</xsl:variable>
									
									<xsl:if test="count(ext:node-set($promos)/*) &gt; 0">
										<promo>
											<xsl:variable name="promo">
												<xsl:copy-of select="."/>
											</xsl:variable>
											<xsl:variable name="rebateAmount" select="ext:node-set($promos)/*[1]"/>
											<xsl:copy-of select="$promo"/>
											<totals>
												<rebateAmt>
													<xsl:value-of select="$rebateAmount"/>
												</rebateAmt>
												<totalSold>
													<count>
														<xsl:value-of select="format-number(count(ext:node-set($promos)/*), '0.000')"/>
													</count>
													<amount>
														<xsl:value-of select="format-number(                   count(ext:node-set($promos)/*) * $rebateAmount,                    '0.000')"/>
													</amount>
												</totalSold>
											</totals>
										</promo>
									</xsl:if>
								</xsl:for-each>
							</promos>
						</xsl:if>
					</rebateEntry>
				</xsl:for-each>
			</rebateEntries>
		</xsl:variable>
		<xsl:copy-of select="$report"/>
	</xsl:template>
</xsl:stylesheet>