<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildTopazCashierTracking" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:nsc="http://verifone.com/isd/vfit/transactionSet/scripts" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:VFI="urn:vfi-sapphire:np.domain.2001-07-01" xmlns:e="urn:vfi-sapphire:np.domain.2001-07-01" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns ns2 nsc jsc base vs t xsi VFI e">
	<xsl:import href="lists.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:param name="ns:cshTrackConfig"/>
	<xsl:param name="ns:cshNum"/>
	<xsl:param name="ns:regNum"/>
	<xsl:param name="ns:period"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="fault">
			<xsl:if test="$ns:cshTrackConfig = false() or $ns:cshNum = false() or $ns:regNum = false() or $ns:period = false()">
				<xsl:value-of select="-1"/>
			</xsl:if>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$fault = -1">
				<xsl:call-template name="ns:fault"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="ns:process">
					<xsl:with-param name="inputDoc" select="ext:node-set($inputDoc)"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:fault">
		<VFI:Response>
			<VFI:Fault>
				<faultCode>Report.process.error</faultCode>
				<faultString>Missing Params</faultString>
				<detail>
					<e:vfiFault>
						<e:message>
							<xsl:if test="$ns:cshTrackConfig = false()">
								<xsl:value-of select="' cashier tracking config missing ;'"/>
							</xsl:if>
							<xsl:if test="$ns:period = false()">
								<xsl:value-of select="' period missing ;'"/>
							</xsl:if>
							<xsl:if test="$ns:cshNum = false()">
								<xsl:value-of select="' cashier number missing ;'"/>
							</xsl:if>
							<xsl:if test="$ns:regNum = false()">
								<xsl:value-of select="' register number missing ;'"/>
							</xsl:if>
						</e:message>
					</e:vfiFault>
				</detail>
			</VFI:Fault>
		</VFI:Response>
	</xsl:template>
	
	<xsl:template name="ns:process">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		
		<xsl:variable name="pluList" select="$ns:cshTrackConfig/*/pluTracking/plu"/>
		<xsl:variable name="deptList" select="$ns:cshTrackConfig/*/deptTracking/dept"/>
		<xsl:variable name="catList" select="$ns:cshTrackConfig/*/catTracking/cat"/>
		
		<xsl:variable name="cshTrkEntry" select="'cashierTrackingEntry'"/>
		<xsl:variable name="grossSales" select="'grossSales'"/>
		<xsl:variable name="refunds" select="'refunds'"/>
		<xsl:variable name="discounts" select="'discounts'"/>
		<xsl:variable name="cshTrkPLU" select="'t:pluTracking'"/>
		<xsl:variable name="cshTrkDept" select="'t:deptTracking'"/>
		<xsl:variable name="cshTrkCat" select="'t:catTracking'"/>
		
		<xsl:variable name="cashier">
			<xsl:element name="{$cshTrkEntry}">
				
				<xsl:variable name="cshrTLogEntries">
					<xsl:call-template name="ns:getTLogEntriesForCashier">
						<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
						<xsl:with-param name="cashier" select="$ns:cshNum"/>
						<xsl:with-param name="register" select="$ns:regNum"/>
						<xsl:with-param name="period" select="$ns:period"/>
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:copy-of select="ext:node-set($cshrTLogEntries)/*[1]/t:cashier"/>
				<xsl:copy-of select="ext:node-set($cshrTLogEntries)/*[1]/hdr/t:register"/>
				
				<xsl:for-each select="ext:node-set($pluList)">
					<xsl:variable name="curPLU" select="."/>
					<xsl:variable name="pluTLogEntries">
						<xsl:call-template name="ns2:getTLogEntriesForPlu">
							<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
							<xsl:with-param name="plu" select="$curPLU"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="gross-ns">
						<xsl:copy-of select="ext:node-set($pluTLogEntries)/t:sale[not(@isRefund)]/lines/* | t:adjustment/lines/*"/>
					</xsl:variable>
					
					<xsl:variable name="gross-ls">
						<xsl:call-template name="ns2:getLinesForPlu">
							<xsl:with-param name="lineSet" select="$gross-ns"/>
							<xsl:with-param name="plu" select="$curPLU"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="refund-ns">
						<xsl:copy-of select="ext:node-set($pluTLogEntries)/t:sale[@isRefund]/lines/*"/>
					</xsl:variable>
					<xsl:variable name="refund-ls">
						<xsl:call-template name="ns2:getLinesForPlu">
							<xsl:with-param name="lineSet" select="$refund-ns"/>
							<xsl:with-param name="plu" select="$curPLU"/>
						</xsl:call-template>
					</xsl:variable>
					
					
					<xsl:variable name="discounts-ls">
						<xsl:call-template name="ns2:getDiscountSetFromLines">
							<xsl:with-param name="lineSet" select="$gross-ls"/>
						</xsl:call-template>
					</xsl:variable>
					
					
					<xsl:if test="ext:node-set($gross-ls)//*[1]/iid/t:plu or           ext:node-set($refund-ls)//*[1]/iid/t:plu">
						
						<xsl:element name="{$cshTrkPLU}">
							
							
							<xsl:variable name="sellunit" select="ext:node-set($gross-ls)//*[1]/iid/t:plu/sellunit | ext:node-set($refund-ls)//*[1]/iid/t:plu/sellunit"/>
							<xsl:choose>
								<xsl:when test="ext:node-set($gross-ls)//*[1]/iid/t:plu">
									<xsl:copy-of select="ext:node-set($gross-ls)//*[1]/iid/t:plu"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="ext:node-set($refund-ls)//*[1]/iid/t:plu"/>
								</xsl:otherwise>
							</xsl:choose>
							
							<xsl:element name="{$grossSales}">
								<xsl:element name="amount">
									
									<xsl:value-of select="format-number(sum(ext:node-set($gross-ls)/*/stot)  +                        sum(ext:node-set($discounts-ls)//amt),'0.000')"/>
									
								</xsl:element>
								<xsl:element name="qty">
									<xsl:value-of select="format-number(sum(ext:node-set($gross-ls)/*/qty),'0.000')"/>
								</xsl:element>
								<xsl:element name="extendedQty">
									<xsl:value-of select="format-number((sum(ext:node-set($gross-ls)/*/qty) * $sellunit),'0.000')"/>
								</xsl:element>
							</xsl:element>
							<xsl:element name="{$refunds}">
								<xsl:element name="amount">
									<xsl:value-of select="format-number(sum(ext:node-set($refund-ls)//stot),'0.000')"/>
								</xsl:element>
								<xsl:element name="qty">
									<xsl:value-of select="format-number(sum(ext:node-set($refund-ls)/*/qty),'0.000')"/>
								</xsl:element>
								<xsl:element name="extendedQty">
									<xsl:value-of select="format-number((sum(ext:node-set($refund-ls)/*/qty) * $sellunit),'0.000')"/>
								</xsl:element>
							</xsl:element>
							<xsl:element name="{$discounts}">
								<xsl:element name="amount">
									<xsl:value-of select="format-number(sum(ext:node-set($discounts-ls)//amt),'0.000')"/>
								</xsl:element>
								<xsl:element name="count">
									<xsl:value-of select="count(ext:node-set($discounts-ls)/*)"/>
								</xsl:element>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
				
				<xsl:for-each select="ext:node-set($deptList)">
					<xsl:variable name="curDept" select="."/>
					<xsl:variable name="deptTLogEntries">
						<xsl:call-template name="ns2:getTLogEntriesForDept">
							<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
							<xsl:with-param name="dept" select="$curDept"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="gross-ns">
						<xsl:copy-of select="ext:node-set($deptTLogEntries)/t:sale[not                            (@isRefund)]/lines/*                         | t:adjustment/lines/*"/>
					</xsl:variable>
					
					<xsl:variable name="gross-ls">
						<xsl:call-template name="ns2:getLinesForDept">
							<xsl:with-param name="lineSet" select="$gross-ns"/>
							<xsl:with-param name="dept" select="$curDept"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="grossFees-ns">
						<xsl:variable name="tmp-ns">
							<xsl:call-template name="ns2:getTLogEntriesForFeeDept">
								<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
								<xsl:with-param name="dept" select="$curDept"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:copy-of select="ext:node-set($tmp-ns)/t:sale[not(@isRefund)]/lines/*                               | t:adjustment/lines/*"/>
					</xsl:variable>
					<xsl:variable name="grossFees-ls">
						<xsl:call-template name="ns:getFeesForDept">
							<xsl:with-param name="lineSet" select="$grossFees-ns"/>
							<xsl:with-param name="dept" select="$curDept"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="refund-ns">
						<xsl:copy-of select="ext:node-set($deptTLogEntries)/t:sale[@isRefund]/lines/*"/>
					</xsl:variable>
					<xsl:variable name="refund-ls">
						<xsl:call-template name="ns2:getLinesForDept">
							<xsl:with-param name="lineSet" select="$refund-ns"/>
							<xsl:with-param name="dept" select="$curDept"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="refundFees-ns">
						<xsl:variable name="tmp-ns">
							<xsl:call-template name="ns2:getTLogEntriesForFeeDept">
								<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
								<xsl:with-param name="dept" select="$curDept"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:copy-of select="ext:node-set($tmp-ns)/t:sale[@isRefund]/lines/*"/>
					</xsl:variable>
					<xsl:variable name="refundFees-ls">
						<xsl:call-template name="ns:getFeesForDept">
							<xsl:with-param name="lineSet" select="$refundFees-ns"/>
							<xsl:with-param name="dept" select="$curDept"/>
						</xsl:call-template>
					</xsl:variable>
					
					
					<xsl:variable name="discounts-ls">
						<xsl:call-template name="ns2:getDiscountSetFromLines">
							<xsl:with-param name="lineSet" select="$gross-ls"/>
						</xsl:call-template>
					</xsl:variable>
					
					
					<xsl:if test="ext:node-set($gross-ls)//*[1]/fid/t:dept or             ext:node-set($refund-ls)//*[1]/fid/t:dept or             ext:node-set($grossFees-ls)//*[1]/t:dept or             ext:node-set($refundFees-ls)//*[1]/t:dept">
						
						<xsl:element name="{$cshTrkDept}">
							
							<xsl:choose>
								<xsl:when test="ext:node-set($gross-ls)//*[1]/fid/t:dept">
									<xsl:copy-of select="ext:node-set($gross-ls)//*[1]/fid/t:dept"/>
								</xsl:when>
								<xsl:when test="ext:node-set($refund-ls)//*[1]/fid/t:dept">
									<xsl:copy-of select="ext:node-set($refund-ls)//*[1]/fid/t:dept"/>
								</xsl:when>
								<xsl:when test="ext:node-set($grossFees-ls)//*[1]/t:dept ">
									<xsl:copy-of select="ext:node-set($grossFees-ls)//*[1]/t:dept "/>
								</xsl:when>
								<xsl:when test="ext:node-set($refundFees-ls)//*[1]/t:dept">
									<xsl:copy-of select="ext:node-set($refundFees-ls)//*[1]/t:dept"/>
								</xsl:when>
							</xsl:choose>
							<xsl:element name="{$grossSales}">
								<xsl:element name="amount">
									
									<xsl:value-of select="format-number(sum(ext:node-set($gross-ls)/*/stot) +                        sum(ext:node-set($discounts-ls)//amt) +                       sum(ext:node-set($grossFees-ls)//amt),'0.000')"/>
									
								</xsl:element>
								<xsl:element name="qty">
									<xsl:value-of select="format-number((sum(ext:node-set($gross-ls)/*/qty) +                     format-number(count(ext:node-set($grossFees-ls)/*),'0')),'0.000')"/>
								</xsl:element>
								<xsl:element name="extendedQty">
									<xsl:value-of select="format-number((sum(ext:node-set($gross-ls)/*/qty) +                     format-number(count(ext:node-set($grossFees-ls)/*),'0')),'0.000')"/>
								</xsl:element>
							</xsl:element>
							<xsl:element name="{$refunds}">
								<xsl:element name="amount">
									<xsl:value-of select="format-number((sum(ext:node-set($refund-ls)//stot) +                  sum(ext:node-set($refundFees-ls)//amt)),'0.000')"/>
								</xsl:element>
								<xsl:element name="qty">
									<xsl:value-of select="format-number((sum(ext:node-set($refund-ls)/*/qty)  +                     format-number(count(ext:node-set($refundFees-ls)/*),'-0')),'0.000')"/>
								</xsl:element>
								<xsl:element name="extendedQty">
									<xsl:value-of select="format-number((sum(ext:node-set($refund-ls)/*/qty)  +                     format-number(count(ext:node-set($refundFees-ls)/*),'-0')),'0.000')"/>
								</xsl:element>								
							</xsl:element>
							<xsl:element name="{$discounts}">
								<xsl:element name="amount">
									<xsl:value-of select="format-number(sum(ext:node-set($discounts-ls)//amt),'0.000')"/>
								</xsl:element>
								<xsl:element name="count">
									<xsl:value-of select="count(ext:node-set($discounts-ls)/*)"/>
								</xsl:element>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
				
				<xsl:for-each select="ext:node-set($catList)">
					<xsl:variable name="curCat" select="."/>
					<xsl:variable name="catTLogEntries">
						<xsl:call-template name="ns2:getTLogEntriesForCategory">
							<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
							<xsl:with-param name="cat" select="$curCat"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="gross-ns">
						<xsl:copy-of select="ext:node-set($catTLogEntries)/t:sale[not                            (@isRefund)]/lines/*                         | t:adjustment/lines/*"/>
					</xsl:variable>
					
					<xsl:variable name="gross-ls">
						<xsl:call-template name="ns2:getLinesForCategory">
							<xsl:with-param name="lineSet" select="$gross-ns"/>
							<xsl:with-param name="cat" select="$curCat"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="grossFees-ns">
						<xsl:variable name="tmp-ns">
							<xsl:call-template name="ns:getTLogEntriesForFeeCat">
								<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
								<xsl:with-param name="cat" select="$curCat"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:copy-of select="ext:node-set($tmp-ns)/t:sale[not(@isRefund)]/lines/*                              | t:adjustment/lines/*"/>
					</xsl:variable>
					<xsl:variable name="grossFees-ls">
						<xsl:call-template name="ns:getFeesForCat">
							<xsl:with-param name="lineSet" select="$grossFees-ns"/>
							<xsl:with-param name="cat" select="$curCat"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="refund-ns">
						<xsl:copy-of select="ext:node-set($catTLogEntries)/t:sale[@isRefund]/lines/*"/>
					</xsl:variable>
					<xsl:variable name="refund-ls">
						<xsl:call-template name="ns2:getLinesForCategory">
							<xsl:with-param name="lineSet" select="$refund-ns"/>
							<xsl:with-param name="cat" select="$curCat"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="refundFees-ns">
						<xsl:variable name="tmp-ns">
							<xsl:call-template name="ns:getTLogEntriesForFeeCat">
								<xsl:with-param name="tlogEntrySet" select="$cshrTLogEntries"/>
								<xsl:with-param name="cat" select="$curCat"/>
							</xsl:call-template>
						</xsl:variable>
						<xsl:copy-of select="ext:node-set($tmp-ns)/t:sale[@isRefund]/lines/*"/>
					</xsl:variable>
					<xsl:variable name="refundFees-ls">
						<xsl:call-template name="ns:getFeesForCat">
							<xsl:with-param name="lineSet" select="$refundFees-ns"/>
							<xsl:with-param name="cat" select="$curCat"/>
						</xsl:call-template>
					</xsl:variable>
					
					
					<xsl:variable name="discounts-ls">
						<xsl:call-template name="ns2:getDiscountSetFromLines">
							<xsl:with-param name="lineSet" select="$gross-ls"/>
						</xsl:call-template>
					</xsl:variable>
					
					
					<xsl:if test="ext:node-set($gross-ls)//*[1]/fid/t:cat or             ext:node-set($refund-ls)//*[1]/fid/t:cat or             ext:node-set($grossFees-ls)//*[1]/t:cat or             ext:node-set($refundFees-ls)//*[1]/t:cat">
						
						<xsl:element name="{$cshTrkCat}">
							
							<xsl:choose>
								<xsl:when test="ext:node-set($gross-ls)//*[1]/fid/t:cat">
									<xsl:copy-of select="ext:node-set($gross-ls)//*[1]/fid/t:cat"/>
								</xsl:when>
								<xsl:when test="ext:node-set($refund-ls)//*[1]/fid/t:dept">
									<xsl:copy-of select="ext:node-set($refund-ls)//*[1]/fid/t:cat"/>
								</xsl:when>
								<xsl:when test="ext:node-set($grossFees-ls)//*[1]/t:dept ">
									<xsl:copy-of select="ext:node-set($grossFees-ls)//*[1]/t:cat "/>
								</xsl:when>
								<xsl:when test="ext:node-set($refundFees-ls)//*[1]/t:dept">
									<xsl:copy-of select="ext:node-set($refundFees-ls)//*[1]/t:cat"/>
								</xsl:when>
							</xsl:choose>
							<xsl:element name="{$grossSales}">
								<xsl:element name="amount">
									
									<xsl:value-of select="format-number(sum(ext:node-set($gross-ls)/*/stot) +                        sum(ext:node-set($discounts-ls)//amt) +                       sum(ext:node-set($grossFees-ls)//amt),'0.000')"/>
									
								</xsl:element>
								<xsl:element name="qty">
									<xsl:value-of select="format-number((sum(ext:node-set($gross-ls)/*/qty) +                     format-number(count(ext:node-set($grossFees-ls)/*),'0')),'0.000')"/>
								</xsl:element>
								<xsl:element name="extendedQty">
									<xsl:value-of select="format-number((sum(ext:node-set($gross-ls)/*/qty) +                     format-number(count(ext:node-set($grossFees-ls)/*),'0')),'0.000')"/>
								</xsl:element>								
							</xsl:element>
							<xsl:element name="{$refunds}">
								<xsl:element name="amount">
									<xsl:value-of select="format-number((sum(ext:node-set($refund-ls)//stot) +                     sum(ext:node-set($refundFees-ls)//amt)),'0.000')"/>
								</xsl:element>
								<xsl:element name="qty">
									<xsl:value-of select="format-number((sum(ext:node-set($refund-ls)/*/qty)  +                     format-number(count(ext:node-set($refundFees-ls)/*),'-0')),'0.000')"/>
								</xsl:element>
								<xsl:element name="extendedQty">
									<xsl:value-of select="format-number((sum(ext:node-set($refund-ls)/*/qty)  +                     format-number(count(ext:node-set($refundFees-ls)/*),'-0')),'0.000')"/>
								</xsl:element>								
							</xsl:element>
							<xsl:element name="{$discounts}">
								<xsl:element name="amount">
									<xsl:value-of select="format-number(sum(ext:node-set($discounts-ls)//amt),'0.000')"/>
								</xsl:element>
								<xsl:element name="count">
									<xsl:value-of select="count(ext:node-set($discounts-ls)/*)"/>
								</xsl:element>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
			</xsl:element>
		</xsl:variable>
		
		<t:cashierTracking>
			
			<xsl:copy-of select="$header"/>
			
			<xsl:copy-of select="$cashier"/>
		</t:cashierTracking>
	</xsl:template>
	
	<xsl:template name="ns:getTLogEntriesForCashier">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="cashier"/>
		<xsl:param name="register"/>
		<xsl:param name="period"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="ns-cashier" select="ext:node-set($cashier)"/>
		<xsl:variable name="ns-register" select="ext:node-set($register)"/>
		<xsl:variable name="ns-period" select="ext:node-set($period)"/>
		<xsl:copy-of select="$ns-set/*[             (t:cashier/@sysid = $ns-cashier            and hdr/t:register/@sysid = $ns-register             and t:cashier/period = $ns-period)              or             (t:cashier/@sysid = $ns-cashier            and recalledTickets/recallTicket/t:register/@sysid = $ns-register             and t:cashier/period = $ns-period)]"/>
	</xsl:template>
	
	<xsl:template name="ns:getFeesForDept">
		<xsl:param name="lineSet"/>
		<xsl:param name="dept"/>
		<xsl:variable name="ns-set" select="ext:node-set($lineSet)"/>
		<xsl:variable name="ns-dept" select="ext:node-set($dept)"/>
		<xsl:copy-of select="$ns-set/t:line[ t:fee/t:dept/@sysid = $ns-dept//@sysid ]/t:fee        | $ns-set/t:cline/t:sline[ t:fee/t:dept/@sysid = $ns-dept//@sysid ]/t:fee        | $ns-set/t:sline[ t:fee/t:dept/@sysid = $ns-dept//@sysid ]/t:fee"/>
	</xsl:template>
	
	<xsl:template name="ns:getFeesForCat">
		<xsl:param name="lineSet"/>
		<xsl:param name="cat"/>
		<xsl:variable name="ns-set" select="ext:node-set($lineSet)"/>
		<xsl:variable name="ns-cat" select="ext:node-set($cat)"/>
		<xsl:copy-of select="$ns-set/t:line[ t:fee/t:cat/@sysid = $ns-cat//@sysid ]/t:fee        | $ns-set/t:cline/t:sline[ t:fee/t:cat/@sysid = $ns-cat//@sysid ]/t:fee        | $ns-set/t:sline[ t:fee/t:cat/@sysid = $ns-cat//@sysid ]/t:fee"/>
	</xsl:template>
	
	<xsl:template name="ns:getTLogEntriesForFeeCat">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="cat"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="ns-cat" select="ext:node-set($cat)"/>
		<xsl:copy-of select="$ns-set/*[ lines/t:line/t:fee/t:cat/@sysid = $ns-cat//@sysid ]         | $ns-set/*[ lines/t:cline/t:fee/t:cat/@sysid = $ns-cat//@sysid ]"/>
	</xsl:template>
</xsl:stylesheet>