<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildTransactionIndicators" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2 jsc xsi base t">
	<xsl:import href="lists-xalan.xslt"/>
	<xsl:import href="../transactionSet/scripts-xalan.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:dcrRegister" select="'9'"/>
	<xsl:param name="ns:currencyType">USD</xsl:param>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>
		
		<xsl:variable name="cashierList">
			<xsl:call-template name="ns2:getCashierList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="allCashiers">
			<xsl:for-each select="ext:nodeset($cashierList)/t:cashier [(not( @sysid = preceding-sibling::t:cashier[1]/@sysid)) and (@sysid !='0') ]">
				<xsl:variable name="currCashier" select="."/>
				<xsl:element name="cashierInfo">
					<xsl:element name="t:cashier">
						<xsl:attribute name="sysid"><xsl:value-of select="$currCashier/@sysid"/></xsl:attribute>
						<xsl:attribute name="number"><xsl:value-of select="$currCashier/@number"/></xsl:attribute>
						<xsl:element name="name">
							<xsl:value-of select="$currCashier/name"/>
						</xsl:element>
					</xsl:element>
					<xsl:variable name="completeCashierTlogEntries">
						<xsl:call-template name="ns:getTLogEntriesForCashier">
							<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
							<xsl:with-param name="cashier" select="$currCashier"/>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:variable name="allRefunds">
						<xsl:call-template name="ns2:getRefundTLogEntrySet">
							<xsl:with-param name="tlogEntrySet" select="$completeCashierTlogEntries"/>
						</xsl:call-template>
					</xsl:variable>
					<refunds>
						<xsl:copy-of select="$allRefunds"/>
					</refunds>
					
					<xsl:variable name="allVoidLines">
						<xsl:copy-of select="ext:nodeset($completeCashierTlogEntries)/*[name() = 't:sale']/lines/t:line[@isVoid ='true']/../.."/>
					</xsl:variable>
					<voidLines>
						<xsl:copy-of select="$allVoidLines"/>
					</voidLines>
					
					<xsl:variable name="allVoids">
						<xsl:copy-of select="ext:nodeset($completeCashierTlogEntries)/t:void"/>
					</xsl:variable>
					<voids>
						<xsl:copy-of select="$allVoids"/>
					</voids>
					
					<xsl:variable name="allPriceOverrides">
						<xsl:copy-of select="ext:nodeset($completeCashierTlogEntries)/*/lines/t:line[priceOverride]/../.."/>
					</xsl:variable>
					<priceOvers>
						<xsl:copy-of select="$allPriceOverrides"/>
					</priceOvers>
					<xsl:variable name="allErrorCorrects">
						<xsl:copy-of select="ext:nodeset($completeCashierTlogEntries)/t:event[@type='errorCorrect']"/>
					</xsl:variable>
					<errorCorrects>
						<xsl:copy-of select="$allErrorCorrects"/>
					</errorCorrects>
					
					<xsl:variable name="allTaxExempts">
						<xsl:copy-of select="ext:nodeset($completeCashierTlogEntries)/*[name() = 't:sale']/lines/t:line[tax/@reversed='true']/../.."/>
					</xsl:variable>
					<taxExempts>
						<xsl:copy-of select="$allTaxExempts"/>
					</taxExempts>
					
				</xsl:element>
				
			</xsl:for-each>
			
		</xsl:variable>
		
		
		<t:cashierTransactionIndicators>
			<xsl:copy-of select="$header"/>
			
			<xsl:apply-templates mode="ns:apply" select="ext:nodeset($allCashiers)/*"/>
		</t:cashierTransactionIndicators>
	</xsl:template>
	
	<xsl:template name="ns:getTLogEntriesForCashier">
		<xsl:param name="tlogEntrySet"/>
		<xsl:param name="cashier"/>
		<xsl:variable name="ns-set" select="ext:nodeset($tlogEntrySet)"/>
		<xsl:variable name="ns-cashier" select="ext:nodeset($cashier)"/>
		<xsl:copy-of select="$ns-set/*[ t:cashier/@sysid = $ns-cashier//@sysid]"/>
	</xsl:template>
	
	<xsl:template mode="ns:apply" match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*" mode="ns:attrs"/>
			<xsl:apply-templates mode="ns:apply"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="@*" mode="ns:attrs">
		<xsl:copy-of select="."/>
	</xsl:template>
	<xsl:template match="refunds" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:for-each select="./*">
				<xsl:element name="refundInfo">
					
					<xsl:copy-of select="./hdr/dateTime"/>
					
					<xsl:copy-of select="./hdr/t:register"/>
					
					<xsl:copy-of select="./t:cashier"/>
					
					<xsl:copy-of select="./vs:transactionSeq"/>
					
					<xsl:element name="lineItems">
						<xsl:copy-of select="./lines/*"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
			
			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(./*/paylines/t:payline/amt), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(./*)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="voidLines" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:for-each select="./*">
				<xsl:element name="voidLineInfo">
					
					<xsl:copy-of select="./hdr/dateTime"/>
					
					<xsl:copy-of select="./hdr/t:register"/>
					
					<xsl:copy-of select="./t:cashier"/>
					
					<xsl:copy-of select="./vs:transactionSeq"/>
					
					<xsl:element name="lineItems">
						<xsl:copy-of select="./lines/*[@isVoid='true']"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
			
			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(./*/lines/*[@isVoid='true']/tot), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(./*/lines/*[@isVoid='true'])"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="voids" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:for-each select="./*">
				<xsl:element name="voidInfo">
					
					<xsl:copy-of select="./hdr/dateTime"/>
					
					<xsl:copy-of select="./hdr/t:register"/>
					
					<xsl:copy-of select="./t:cashier"/>
					
					<xsl:copy-of select="./vs:transactionSeq"/>
					
					<xsl:element name="lineItems">
						<xsl:copy-of select="./lines/*"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
			
			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(./*/lines/*/tot), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(./*)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="priceOvers" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:for-each select="./*">
				<xsl:element name="priceOverrideInfo">
					
					<xsl:copy-of select="./hdr/dateTime"/>
					
					<xsl:copy-of select="./hdr/t:register"/>
					
					<xsl:copy-of select="./t:cashier"/>
					
					<xsl:copy-of select="./vs:transactionSeq"/>
					
					<xsl:element name="lineItems">
						<xsl:copy-of select="./lines/*[priceOverride]"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
			
			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(./*/lines/*[priceOverride]/tot), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(./*/lines/*[priceOverride])"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="errorCorrects" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:variable name="ecd">
				<xsl:for-each select="./*">
					<xsl:element name="errorCorrectInfo">
						
						<xsl:copy-of select="./hdr/dateTime"/>
						
						<xsl:copy-of select="./hdr/t:register"/>
						
						<xsl:copy-of select="./t:cashier"/>
						
						
						<xsl:element name="lineItems">
							<xsl:element name="t:errorCorrectDetail">
								<xsl:choose>
									<xsl:when test="./trLine">
										<xsl:variable name="taxReversedVal">
											<xsl:choose>
												<xsl:when test="not(./trLine/trlTaxes/@reverse = '0')">
													<xsl:value-of select="'true'"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="'false'"/>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
										<xsl:if test="./trLine/trlTaxes/trlTax">
											<xsl:for-each select="./trLine/trlTaxes/trlTax">
												<xsl:element name="tax">
													<xsl:variable name="cat">
														<xsl:value-of select="@cat"/>
													</xsl:variable>
													<xsl:attribute name="reversed"><xsl:value-of select="$taxReversedVal"/></xsl:attribute>
													<xsl:element name="vs:taxrateBase">
														<xsl:element name="name">
															<xsl:value-of select="$cat"/>
														</xsl:element>
														<xsl:element name="taxRate">
															<xsl:value-of select="ancestor::trLine/trlTaxes/trlRate[ @cat = $cat ]"/>
														</xsl:element>
													</xsl:element>
													<xsl:element name="taxable">
														<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
														<xsl:value-of select="."/>
													</xsl:element>
												</xsl:element>
											</xsl:for-each>
										</xsl:if>
										<xsl:element name="qty">
											<xsl:value-of select="./trLine/trlQty"/>
										</xsl:element>
										<xsl:element name="itmprc">
											<xsl:value-of select="./trLine/trlUnitPrice"/>
										</xsl:element>
										<xsl:element name="tot">
											<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
											<xsl:value-of select="./trLine/trlLineTot"/>
										</xsl:element>
										<xsl:element name="desc">
											<xsl:value-of select="./trLine/trlDesc"/>
										</xsl:element>
										<xsl:element name="fid">
											<xsl:element name="t:dept">
												<xsl:attribute name="sysid"><xsl:value-of select="./trLine/trlDept/@number"/></xsl:attribute>
												<xsl:variable name="deptType" select="./trLine/trlDept/@type"/>
												<xsl:if test="not($deptType = 'norm')">
													<xsl:attribute name="deptType"><xsl:value-of select="$deptType"/></xsl:attribute>
												</xsl:if>
												<xsl:element name="name">
													<xsl:value-of select="./trLine/trlDept"/>
												</xsl:element>
											</xsl:element>
											<xsl:if test="./trLine/trlCat">
												<xsl:element name="t:cat">
													<xsl:attribute name="sysid"><xsl:value-of select="./trLine/trlCat/@number"/></xsl:attribute>
													<xsl:element name="name">
														<xsl:value-of select="./trLine/trlCat"/>
													</xsl:element>
												</xsl:element>
											</xsl:if>
											<xsl:element name="t:netw">
												<xsl:attribute name="sysid"><xsl:value-of select="./trLine/trlNetwCode"/></xsl:attribute>
												<xsl:choose>
													<xsl:when test="./trLine/trlFuel">
														<xsl:attribute name="isFuel"><xsl:value-of select="'true'"/></xsl:attribute>
													</xsl:when>
												</xsl:choose>
												<xsl:element name="name"/>
											</xsl:element>
										</xsl:element>
										<xsl:if test="./trLine/trlUPC">
											<xsl:element name="iid">
												<xsl:element name="t:plu">
													<xsl:variable name="mod" select="./trLine/trlModifier"/>
													<xsl:element name="upc">
														<xsl:if test="./trLine/trlFlags/trlDeli">
															<xsl:attribute name="encoding"><xsl:value-of select="'RW'"/></xsl:attribute>
														</xsl:if>
														<xsl:value-of select="./trLine/trlUPC"/>
													</xsl:element>
													<xsl:if test="$mod">
														<xsl:element name="modifier">
															<xsl:value-of select="$mod"/>
														</xsl:element>
													</xsl:if>
													<xsl:element name="name">
														<xsl:value-of select="./trLine/trlDesc"/>
													</xsl:element>
													<xsl:element name="sellunit">
														<xsl:choose>
															<xsl:when test="./trLine/trlSellUnit">
																<xsl:value-of select="format-number(./trLine/trlSellUnit,'#.000')"/>
															</xsl:when>
															<xsl:otherwise>
																<xsl:value-of select="format-number(1,'#.000')"/>
															</xsl:otherwise>
														</xsl:choose>
													</xsl:element>
												</xsl:element>
											</xsl:element>
										</xsl:if>
									</xsl:when>
									<xsl:otherwise>
										<xsl:element name="qty">
											<xsl:value-of select="format-number(jsc:getErrorCorrectQty(string(./text)), '0.000')"/>
										</xsl:element>
										<xsl:element name="tot">
											<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
											<xsl:value-of select="format-number(jsc:getErrorCorrectPrice(string(./text)), '0.00')"/>
										</xsl:element>
										<xsl:element name="desc">
											<xsl:value-of select="jsc:getErrorCorrectItem(string(substring(./text, 40)))"/>
										</xsl:element>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:element>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:variable>
			
			<xsl:copy-of select="$ecd"/>
			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(ext:nodeset($ecd)//tot), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(ext:nodeset($ecd)//t:errorCorrectDetail)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="taxExempts" mode="ns:apply">
		<xsl:element name="{local-name()}">
			<xsl:variable name="taxExEntries">
				<xsl:for-each select="./*">
					<xsl:element name="taxExemptInfo">
						
						<xsl:copy-of select="./hdr/dateTime"/>
						
						<xsl:copy-of select="./hdr/t:register"/>
						
						<xsl:copy-of select="./t:cashier"/>
						
						<xsl:copy-of select="./vs:transactionSeq"/>
						
						<xsl:element name="lineItems">
							
							<xsl:for-each select="./lines/*">
								<xsl:variable name="line" select="."/>
								<xsl:if test="ext:nodeset($line)//tax[@reversed='true']">
									<t:taxExemptDetail>
										<xsl:copy-of select="$line"/>
										<xsl:variable name="sumTax">
										
											<xsl:for-each select="ext:nodeset($line)/tax[@reversed='true']">
												<tax>
													<xsl:choose>
														<xsl:when test="vs:taxrateBase/taxRate">
															<xsl:value-of select="((taxable * vs:taxrateBase/taxRate) div 100)"/>
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="0"/>
														</xsl:otherwise> 
													</xsl:choose>
												</tax>
											</xsl:for-each>
										</xsl:variable>
										<estimatedTaxForgiven>
											<xsl:value-of select="format-number(sum(ext:nodeset($sumTax)//tax),'#.00')"/>
										</estimatedTaxForgiven>
									</t:taxExemptDetail>
								</xsl:if>						
							</xsl:for-each>
						</xsl:element>
					</xsl:element>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="$taxExEntries"/>
			
			<xsl:element name="overAllTotal">
				<xsl:element name="amount">
					<xsl:value-of select="format-number(sum(ext:nodeset($taxExEntries)//estimatedTaxForgiven), '#.00')"/>
				</xsl:element>
				<xsl:element name="count">
					<xsl:value-of select="count(ext:nodeset($taxExEntries)//t:taxExemptDetail)"/>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>