<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildTviewerDoc" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:tv="urn:vfi-tviewer:vt.2004-07-27" xmlns:fuel="urn:vfi-sapphire:fuel.2001-10-01" xmlns:jsc="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns">
	<xsl:import href="../transactionSet/scripts-xalan.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:currencyType">USD</xsl:param>
	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<tv:tlog>
			<xsl:apply-templates select="ext:nodeset($inputDoc)/*"/>
		</tv:tlog>
	</xsl:template>
	<xsl:template match="t:startTotals | t:endTotals | t:event | t:openCashier | t:closeCashier | t:countCashier  | t:printEvent | t:clock | t:fuelReprintEvent | t:prefuel"/>
	
	
	<xsl:template match="t:hdr">
		<xsl:element name="header">
			<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
			<xsl:copy-of select="startDateTime"/>
			<xsl:copy-of select="endDateTime"/>
			<xsl:copy-of select="vs:period"/>
			<xsl:copy-of select="vs:site"/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="t:event">
		<xsl:choose>
			<xsl:when test="@type='fuelPrepaidCancel'">
				<xsl:element name="prePayCancel">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isPrepayCancel"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="@type='drawerAlarm'">
				<xsl:element name="drawerAlarm">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isDrawerAlarm"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="@type='safeDropCancel'">
				<xsl:element name="safeDropCancel">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isCancelSafeDrop"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="@type='errorCorrect'">
				<xsl:element name="errorCorrect">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isErrorCorrect"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:call-template name="ns:createErrorCorrectDetail">
						<xsl:with-param name="ecEntry" select="."/>
					</xsl:call-template>
				</xsl:element>
			</xsl:when>
			<xsl:when test="@type='priceCheckCancel'">
				<xsl:element name="priceCheckCancel">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isPriceCheckCancel"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:call-template name="ns:createPriceCheckCancelDetail">
						<xsl:with-param name="pcEntry" select="."/>
					</xsl:call-template>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="t:tillSafeDrop | t:tillSafeLoan | t:tillPayout | t:tillPayin">
		<xsl:choose>
			<xsl:when test="local-name()='tillSafeDrop'">
				<xsl:element name="safedrop">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isSafeDrop"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='tillSafeLoan'">
				<xsl:element name="safeloan">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isSafeLoan"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='tillPayin'">
				<xsl:element name="payin">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isPayin"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:if test="@isHouseAcct='true'">
						<xsl:attribute name="isHouseAcct"><xsl:value-of select="'true'"/></xsl:attribute>
					</xsl:if>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='tillPayout'">
				<xsl:element name="payout">
					<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
					<xsl:attribute name="isPayout"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="t:tillNosale">
		<xsl:element name="nosale">
			<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
			<xsl:attribute name="isNoSale"><xsl:value-of select="'true'"/></xsl:attribute>
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="t:sale | t:void | t:adjustment | t:suspendedSale | t:pumpTest | t:order">
		<xsl:choose>
			<xsl:when test="local-name()='void'">
				<xsl:element name="void">
					<xsl:attribute name="isVoid"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:call-template name="ns:createAttributes"/>
					
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='sale'">
				<xsl:element name="sale">
					<xsl:call-template name="ns:createAttributes"/>
					
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='adjustment'">
				<xsl:element name="adjustment">
					<xsl:call-template name="ns:createAttributes"/>
					
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='suspendedSale'">
				<xsl:element name="suspend">
					<xsl:attribute name="isSuspend"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:call-template name="ns:createAttributes"/>
					
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='pumpTest'">
				<xsl:element name="pumptest">
					<xsl:attribute name="isPumpTest"><xsl:value-of select="'true'"/></xsl:attribute>
					<xsl:call-template name="ns:createAttributes"/>
					
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
			<xsl:when test="local-name()='order'">
				<xsl:element name="order">
					<xsl:call-template name="ns:createAttributes"/>
					
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="hdr">
		<xsl:copy-of select="dateTime"/>
		<xsl:copy-of select="t:register"/>
	</xsl:template>
	
	<xsl:template match="lines">
		<xsl:apply-templates select="t:line | t:dupLine | t:cline"/>
	</xsl:template>
	<xsl:template match="t:line | t:dupLine | t:cline">
		<xsl:element name="lineItem">
			<xsl:if test="@voidLineIndex">
				<xsl:attribute name="voidLine"><xsl:value-of select="@voidLineIndex"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="local-name()='dupLine'">
				<xsl:attribute name="dup"><xsl:value-of select="'true'"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="tax[@reversed='true']">
				<xsl:attribute name="taxExempt"><xsl:value-of select="'true'"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="local-name()='cline'">
				<xsl:attribute name="combo"><xsl:value-of select="'true'"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="iid/t:plu">
				<xsl:attribute name="pluDesc"><xsl:value-of select="translate(desc,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/></xsl:attribute>
			</xsl:if>
			<xsl:copy-of select="qty"/>
			<xsl:copy-of select="tot"/>
			<xsl:copy-of select="desc"/>
			<xsl:copy-of select="fid/t:dept"/>
			<xsl:copy-of select="fid/t:cat"/>
			<xsl:copy-of select="iid/t:plu/upc"/>
			<xsl:copy-of select="iid/t:plu/modifier"/>
			<xsl:copy-of select="iid/t:plu/sellunit"/>
			<xsl:copy-of select="itmprc"/>
			<xsl:copy-of select="t:disc"/>
			<xsl:copy-of select="t:match"/>
			<xsl:copy-of select="t:fee"/>
			<xsl:copy-of select="carwash"/>
			<xsl:copy-of select="priceOverride"/>
			<xsl:copy-of select="t:fuel"/>
			<xsl:copy-of select="t:fuelPrepay"/>
			<xsl:copy-of select="t:sline"/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="duration | text"/>
	
	<xsl:template match="paylines">
		<xsl:copy>
			<xsl:apply-templates select="t:payline"/>
		</xsl:copy>
	</xsl:template>
	<xsl:template match="t:payline">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<xsl:template match="ageVerification | sum | amount | reference | t:mop | t:cashier | vs:transactionSeq | t:fuelPrepay | recalledTickets">
		
		<xsl:copy-of select="."/>
	</xsl:template>
	
	
	<xsl:template name="ns:createAttributes">
		
		<xsl:attribute name="id"><xsl:value-of select="position()"/></xsl:attribute>
		<xsl:attribute name="isRefund"><xsl:choose><xsl:when test="@isRefund='true'"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="voidReason"><xsl:value-of select="@voidReason"/></xsl:attribute>
		<xsl:attribute name="hasFuel"><xsl:choose><xsl:when test="lines/t:line[t:fuel]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasOpenDept"><xsl:choose><xsl:when test="lines/t:line[not(iid) and not(t:fuel or t:fuelPrepay) and not(fid/t:dept/@sysid='9999')]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasPLU"><xsl:choose><xsl:when test="lines/t:line[iid]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasVoidLine"><xsl:choose><xsl:when test="lines[t:line/@isVoid]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="isPrepay"><xsl:choose><xsl:when test="lines/t:line[t:fuelPrepay]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasNetworkMOP"><xsl:choose><xsl:when test="paylines/t:payline[t:cardInfo]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasCarwash"><xsl:choose><xsl:when test="lines/t:line[carwash]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasPriceOver"><xsl:choose><xsl:when test="lines/t:line[priceOverride]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasDiscount"><xsl:choose><xsl:when test="lines/t:line[t:disc]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasIDCheck"><xsl:choose><xsl:when test="ageVerification"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		
		<xsl:attribute name="isDCR"><xsl:choose><xsl:when test="hdr/t:register[@sysid='9']"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasTaxExempt"><xsl:choose><xsl:when test="lines/t:line/tax[@reversed='true']"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasKiosk"><xsl:choose><xsl:when test="recalledTickets/recallTicket/t:register/@device='kiosk'"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="isKiosk"><xsl:choose><xsl:when test="hdr/t:register/@device='kiosk'"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="hasAutoCollect"><xsl:choose><xsl:when test="lines/t:line/t:fuel[@isAutoCollect='true']"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		<xsl:attribute name="isAutoCollect"><xsl:choose><xsl:when test="hdr/t:register[@sysid='9'] and not(paylines)"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
		
		<xsl:if test="ageVerification[@xsi:nil='true']">
			<xsl:attribute name="skippedIDCheck"><xsl:value-of select="'true'"/></xsl:attribute>
		</xsl:if>
	</xsl:template>
	<xsl:template name="ns:createErrorCorrectDetail">
		<xsl:param name="ecEntry"/>
		<xsl:variable name="ec" select="ext:nodeset($ecEntry)"/>
		<xsl:apply-templates select="$ec//hdr"/>
		<xsl:apply-templates select="$ec//t:cashier"/>
		<xsl:element name="lineItem">
			<xsl:choose>
				<xsl:when test="./trLine">
					<xsl:if test="./trLine/trlDesc">
						<xsl:attribute name="pluDesc">
							<xsl:value-of select="translate(./trLine/trlDesc,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>
						</xsl:attribute>
					</xsl:if>
					<xsl:element name="qty">
						<xsl:value-of select="./trLine/trlQty"/>
					</xsl:element>
					<xsl:element name="tot">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="./trLine/trlLineTot"/>
					</xsl:element>
					<xsl:element name="desc">
						<xsl:value-of select="./trLine/trlDesc"/>
					</xsl:element>
					<xsl:element name="t:dept">
						<xsl:attribute name="sysid"><xsl:value-of select="./trLine/trlDept/@number"/></xsl:attribute>
						<xsl:variable name="deptType" select="./trLine/trlDept/@type"/>
						<xsl:if test="not($deptType = 'norm')">
							<xsl:attribute name="deptType"><xsl:value-of select="$deptType"/></xsl:attribute>
						</xsl:if>
						<xsl:element name="name">
							<xsl:value-of select="./trLine/trlDept"/>
						</xsl:element>
					</xsl:element>
					<xsl:if test="./trLine/trlCat">
						<xsl:element name="t:cat">
							<xsl:attribute name="sysid"><xsl:value-of select="./trLine/trlCat/@number"/></xsl:attribute>
							<xsl:element name="name">
								<xsl:value-of select="./trLine/trlCat"/>
							</xsl:element>
						</xsl:element>
					</xsl:if>
					<xsl:if test="./trLine/trlUPC">
						<xsl:element name="upc">
							<xsl:if test="./trLine/trlFlags/trlDeli">
								<xsl:attribute name="encoding"><xsl:value-of select="'RW'"/></xsl:attribute>
							</xsl:if>
							<xsl:value-of select="./trLine/trlUPC"/>
						</xsl:element>
					</xsl:if>
					<xsl:if test="./trLine/trlModifier">
						<xsl:element name="modifier">
							<xsl:value-of select="./trLine/trlModifier"/>
						</xsl:element>
					</xsl:if>
					<xsl:element name="sellunit">
						<xsl:choose>
							<xsl:when test="./trLine/trlSellUnit">
								<xsl:value-of select="format-number(./trLine/trlSellUnit,'#.000')"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="format-number(1,'#.000')"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="itmprc">
						<xsl:value-of select="./trLine/trlUnitPrice"/>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="qty">
						<xsl:value-of select="format-number(jsc:getErrorCorrectQty(string(./text)), '0.000')"/>
					</xsl:element>
					<xsl:element name="tot">
						<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
						<xsl:value-of select="format-number(jsc:getErrorCorrectPrice(string(./text)), '0.00')"/>
					</xsl:element>
					<xsl:element name="desc">
						<xsl:value-of select="jsc:getErrorCorrectItem(string(substring(./text, 40)))"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ns:createPriceCheckCancelDetail">
		<xsl:param name="pcEntry"/>
		<xsl:variable name="pc" select="ext:node-set($pcEntry)"/>
		<xsl:apply-templates select="$pc//hdr"/>
		<xsl:apply-templates select="$pc//t:cashier"/>
		<xsl:choose>
			<xsl:when test="./priceCheckCancelItem">
			   <xsl:for-each select="./priceCheckCancelItem">
			   <xsl:element name="lineItem">
					<xsl:element name="qty">
						<xsl:value-of select="trlQty"/>
					</xsl:element>
					
					<xsl:element name="tot">
						<xsl:value-of select="trlLineTot"/>
					</xsl:element>
					<xsl:element name="desc">
						<xsl:value-of select="trlDesc"/>
					</xsl:element>  
					<xsl:element name="upc">
						<xsl:value-of select="trlUPC"/>
					</xsl:element>
					<xsl:element name="itmprc">
						<xsl:value-of select="trlUnitPrice"/>
					</xsl:element>
					<xsl:element name="modifier">
						<xsl:value-of select="trlModifier"/>
					</xsl:element>
			    </xsl:element>							
			    </xsl:for-each>
		    </xsl:when>
		    <xsl:otherwise>
				<xsl:element name="qty">
					<xsl:value-of select="format-number(jsc:getPriceCheckCancelQty(string(./text)), '0.000')"/>
				</xsl:element>
				<xsl:element name="tot">
					<xsl:attribute name="currency"><xsl:value-of select="$ns:currencyType"/></xsl:attribute>
					<xsl:value-of select="format-number(jsc:getPriceCheckCancel(string(./text)), '0.00')"/>
				</xsl:element>
				<xsl:element name="desc">
					<xsl:value-of select="jsc:getPriceCheckCancel(string(substring(./text, 40)))"/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
    </xsl:template>
</xsl:stylesheet>