<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildVerifyAge" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:js="javascript:code-transactionSet-scripts" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2 js vs">
	<xsl:import href="lists.xslt"/>
	<xsl:import href="../transactionSet/scripts.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:periodType" select="0"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		
		<xsl:variable name="completeSaleSet">
			<xsl:call-template name="ns2:getSaleSet">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="completeVoidSet">
			<xsl:call-template name="ns2:getVoidSet">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
			
		<xsl:variable name="registerList">
			<xsl:call-template name="ns2:getRegisterList">
				<xsl:with-param name="tlogEntrySet" select="$completeSaleSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		
		<xsl:variable name="rawCashierList">
			<xsl:call-template name="ns2:getCashierList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		
		
		<xsl:variable name="cashierList">
			<xsl:copy-of select="ext:node-set($rawCashierList)/t:cashier[not( @sysid = preceding-sibling::t:cashier[1]/@sysid)]"/>
		</xsl:variable>
		
		
		<xsl:variable name="prdType">
			<vs:period sysid="{$ns:periodType}"/>
		</xsl:variable>
		<xsl:variable name="periodList">
			<xsl:call-template name="ns2:getPeriodList">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
				<xsl:with-param name="period" select="$prdType"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="byRegister">
			<xsl:for-each select="ext:node-set($registerList)/t:register">
				<xsl:variable name="currRegID" select="./@sysid"/>
				<xsl:element name="t:register">
					<xsl:attribute name="regID"><xsl:value-of select="$currRegID"/></xsl:attribute>
					<xsl:for-each select="ext:node-set($completeSaleSet)//t:sale[hdr/t:register/@sysid=$currRegID]">
						<xsl:variable name="sales" select="."/>
						<xsl:if test="$sales/ageVerification and $sales/ageVerification/@minAge != 0">					
							<xsl:variable name="formatDateTime" select="concat(substring($sales/hdr/dateTime,1,10),' ',substring($sales/hdr/dateTime,12,8))"/>	
							<xsl:element name="salesTran">
								<xsl:attribute name="transID"><xsl:value-of select="$sales/vs:transactionSeq"/></xsl:attribute>
								<xsl:attribute name="datetime"><xsl:value-of select="$formatDateTime"/></xsl:attribute>
								<xsl:attribute name="cashierID"><xsl:value-of select="$sales/t:cashier/@number"/></xsl:attribute>
								<xsl:attribute name="dobEntryMeth"><xsl:value-of select="$sales/ageVerification/@dobEntryMeth"/></xsl:attribute>
								<xsl:attribute name="minAge"><xsl:value-of select="$sales/ageVerification/@minAge"/></xsl:attribute>
								<xsl:attribute name="dob"><xsl:value-of select="$sales/ageVerification/@dob"/></xsl:attribute>
								<xsl:attribute name="custAge"><xsl:value-of select="$sales/ageVerification/@custAge"/></xsl:attribute>
							</xsl:element>
						</xsl:if>
					</xsl:for-each>
					<xsl:for-each select="ext:node-set($completeVoidSet)//t:void[hdr/t:register/@sysid=$currRegID]">
						<xsl:variable name="void" select="."/>
						<xsl:if test="$void/ageVerification and $void/ageVerification/@minAge != 0">				
							<xsl:variable name="formatDateTime" select="concat(substring($void/hdr/dateTime,1,10),' ',substring($void/hdr/dateTime,12,8))"/>	
							<xsl:element name="salesTran">
								<xsl:attribute name="transID"><xsl:value-of select="$void/vs:transactionSeq"/></xsl:attribute>
								<xsl:attribute name="datetime"><xsl:value-of select="$formatDateTime"/></xsl:attribute>
								<xsl:attribute name="cashierID"><xsl:value-of select="$void/t:cashier/@number"/></xsl:attribute>
								<xsl:attribute name="dobEntryMeth"><xsl:value-of select="$void/ageVerification/@dobEntryMeth"/></xsl:attribute>
								<xsl:attribute name="minAge"><xsl:value-of select="$void/ageVerification/@minAge"/></xsl:attribute>
								<xsl:attribute name="dob"><xsl:value-of select="$void/ageVerification/@dob"/></xsl:attribute>
								<xsl:attribute name="custAge"><xsl:value-of select="$void/ageVerification/@custAge"/></xsl:attribute>
							</xsl:element>
						</xsl:if>
					</xsl:for-each>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		
				
		<xsl:variable name="byCashiers">
			<xsl:for-each select="ext:node-set($cashierList)/t:cashier">
				<xsl:variable name="currCashier" select="."/>		
					<xsl:element name="t:cashier">
						<xsl:attribute name="sysid"><xsl:value-of select="$currCashier/@sysid"/></xsl:attribute>
						<xsl:attribute name="number"><xsl:value-of select="$currCashier/@number"/></xsl:attribute>
						<xsl:element name="name">
							<xsl:value-of select="$currCashier/name"/>
						</xsl:element>
						<xsl:element name="entryMethInfo">
							<xsl:element name="scanCount">
								<xsl:value-of select="count(ext:node-set($completeSaleSet)//t:sale[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Scanner']) + count(ext:node-set($completeVoidSet)//t:void[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Scanner'])"/>
							</xsl:element>
							<xsl:element name="swipeCount">
								<xsl:value-of select="count(ext:node-set($completeSaleSet)//t:sale[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Swipe']) + count(ext:node-set($completeVoidSet)//t:void[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Swipe']) "/>
							</xsl:element>
							<xsl:element name="manualCount">
								<xsl:value-of select="count(ext:node-set($completeSaleSet)//t:sale[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Manual']) + count(ext:node-set($completeVoidSet)//t:void[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Manual']) "/>
							</xsl:element>
							<xsl:element name="skipCount">
								<xsl:value-of select="count(ext:node-set($completeSaleSet)//t:sale[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Skipped']) + count(ext:node-set($completeVoidSet)//t:void[t:cashier/@number=$currCashier/@number and ./ageVerification/@minAge != 0 and ./ageVerification/@dobEntryMeth = 'Skipped'])"/>
							</xsl:element>
						</xsl:element>
					</xsl:element>
			</xsl:for-each>
		</xsl:variable>

		<xsl:element name="salesTxn">
			<xsl:copy-of select="$baseRawSet/t:hdr"/>
			<xsl:element name="byCashiers">
				<xsl:copy-of select="$byCashiers"/>
			</xsl:element>
			<xsl:element name="byRegister">
				<xsl:copy-of select="$byRegister"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>