<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/chevron/buildNetworkCardTransList" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2  jsc base">

	<xsl:import href="../lists.xslt"/>
	<xsl:import href="../../transactionSet/scripts.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:key name="saleBySeqNr" match="/" use="//t:cardInfo/seq"/>
	
	<xsl:param name="ns:dcrRegister" select="'9'"/>
	<xsl:param name="ns:credit">1</xsl:param>
	<xsl:param name="ns:debit">2</xsl:param>
	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="x">
			<xsl:apply-templates mode="ns:stripeSpace" select="ext:node-set($inputDoc)"/>
		</xsl:variable>
		<xsl:variable name="baseRawSet" select="ext:node-set($x)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>


		<xsl:variable name="rawCreditSales">
			<xsl:call-template name="ns:getCreditTransactions">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="uniqueCreditSales">
			<xsl:apply-templates select="ext:node-set($rawCreditSales)/*" mode="ns:eliminateDup"/>
		</xsl:variable>

		<xsl:variable name="preauths">
			<xsl:copy-of select="$baseRawSet//t:event[@type='preauth'] | $baseRawSet//t:event[@type='NETWORK PREAUTH']"/>
		</xsl:variable>

		<xsl:variable name="allCreditSales">
			<xsl:apply-templates select="ext:node-set($rawCreditSales)/*" mode="ns:ppd"/>
		</xsl:variable>
		

		<xsl:variable name="final">
			<xsl:element name="t:networkJournal">
				<xsl:copy-of select="$header"/>
				<xsl:element name="cardEntries">
					<xsl:call-template name="ns:buildCreditTransactions">
						<xsl:with-param name="lineSet" select="$allCreditSales"/>
					</xsl:call-template>
				</xsl:element>
				
				<xsl:element name="preauths">
					<xsl:call-template name="ns:procPreauths">
						<xsl:with-param name="preauths" select="$preauths"/>
					</xsl:call-template>
				</xsl:element>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$final"/>
	</xsl:template>
		
	<xsl:template name="ns:procPreauths">
		<xsl:param name="preauths"/>
			<xsl:for-each select="ext:node-set($preauths)/*">
				<xsl:choose>
					<xsl:when test="@type='preauth'">
						<xsl:copy-of select="."/>
					</xsl:when>
					<xsl:otherwise>
						<t:event>
							<xsl:attribute name="type"><xsl:value-of select="'preauth'"/></xsl:attribute>
							<xsl:copy-of select="hdr"/>
							<xsl:variable name="text" select="text"/>
							<t:cashier>
								<xsl:attribute name="sysid">
									<xsl:value-of select="substring-before(substring-after($text,'csh:'),'&#10;')"/>
								</xsl:attribute>
							</t:cashier>
							<trPaylines>
								<trPayline>
									<xsl:variable name="amt" select="substring-before(substring-after($text,'amt:'),' tic:')"/>
									<trpAmt>
										<xsl:value-of select="concat(substring($amt,1, string-length($amt)-2),'.', substring($amt,string-length($amt)-1) )"/>
									</trpAmt>
									<trpCardInfo>
										<trpcAccount>
											<xsl:value-of select="substring-before(substring-after($text,'acc:'),' amt:')"/>
										</trpcAccount>
										<trpcAuthCode>
											<xsl:value-of select="substring-before(substring-after($text,'aut:'),' src:')"/>
										</trpcAuthCode>
										<trpcTicket>
											<xsl:value-of select="substring-before(substring-after($text,'tic:'),' aut:')"/>
										</trpcTicket>
										<trpcBatchNr>
											<xsl:value-of select="substring-before(substring-after($text,' bat:'),'&#10;')"/>
										</trpcBatchNr>
										<Extension>
											<trpcEcpTranType>
											<xsl:value-of select="substring-before(substring-after($text,'tt:'),' han:')"/>
											</trpcEcpTranType>
											<trpcEcpTranCode>
												<xsl:value-of select="substring-before(substring-after($text,'tc:'),' tt:')"/>
											</trpcEcpTranCode>
											<trpcHandling>
												<xsl:value-of select="substring-before(substring-after($text,'han:'),' bat:')"/>
											</trpcHandling>
										</Extension>
									</trpCardInfo>
								</trPayline>
							</trPaylines>
						</t:event>					
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
	</xsl:template>
	<xsl:template match="t:sale" mode="ns:eliminateDup">
		<xsl:variable name="salesBySeqNr" select="key('saleBySeqNr', .//t:cardInfo/seq)"/>
		<xsl:variable name="salesNodeSet" select="ext:node-set($salesBySeqNr)"/>
		<xsl:variable name="numSales" select="count($salesNodeSet//t:cardInfo/seq)"/>
		<xsl:choose>
			<xsl:when test="$numSales = 1">
				<xsl:copy-of select="."/>
			</xsl:when>
			<xsl:when test="count(. | key('saleBySeqNr', .//t:cardInfo/seq)[$numSales]) = 1">
					 <xsl:copy-of select="."/>			
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="t:adjustment | t:event" mode="ns:eliminateDup">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<xsl:template match="@* | text()" mode="ns:eliminateDup"/>
	
	<xsl:template match="t:event" mode="ns:ppd">
		<xsl:variable name="lname" select="name()"/>
		<xsl:element name="{$lname}">
			<xsl:copy-of select="./@*"/>
				
			<xsl:copy-of select="hdr"/>
			
			<xsl:choose>
				<xsl:when test="t:cashier">
					<xsl:copy-of select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="t:cashier">
						<xsl:attribute name="sysid"><xsl:value-of select="'0'"/></xsl:attribute>
						<xsl:attribute name="number"><xsl:value-of select="'0'"/></xsl:attribute>
						<xsl:element name="name">
							<xsl:value-of select="'Prepaid'"/>
						</xsl:element>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:choose>
				<xsl:when test="vs:transactionSeq">
					<xsl:copy-of select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="vs:transactionSeq"/>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:element name="paylines">
				<xsl:element name="t:payline">
					<xsl:element name="t:mop">
						<xsl:attribute name="cat"><xsl:value-of select="$ns:credit"/></xsl:attribute>
							<xsl:element name="name">
								<xsl:value-of select="'Prepaid'"/>
							</xsl:element>
					</xsl:element>
					<xsl:element name="amt">
						<xsl:value-of select="ppdFunction/ppdAmount"/>
					</xsl:element>
					
						<xsl:element name="t:cardInfo">
							
							<xsl:element name="acct">
								<xsl:value-of select="ppdFunction/ppdAcctNum"/>
							</xsl:element>
							
							
							<xsl:element name="ccName">
								<xsl:value-of select="ppdFunction/ppdCardType"/>
							</xsl:element>
							
							
							<xsl:element name="exp">
								<xsl:value-of select="'XXXX'"/>
							</xsl:element>
				
							
							<xsl:element name="hostId">
								<xsl:value-of select="'RAN'"/>
							</xsl:element>
		
							
							<xsl:element name="auth">
								<xsl:value-of select="0"/>
							</xsl:element>
							
							
							<xsl:element name="ticket">
									<xsl:value-of select="ppdFunction/ppdAuthNr"/>
							</xsl:element>
							
							
							<xsl:element name="entryMeth">
								<xsl:attribute name="type">
									<xsl:value-of select="jsc:xlateCardEntry(string(ppdFunction/ppdEntryMeth))"/>
								</xsl:attribute>
								<xsl:value-of select="ppdFunction/ppdEntryMeth"/>
							</xsl:element>
							
							
							<xsl:element name="authSrc">
								<xsl:text>prepaid</xsl:text>
							</xsl:element>
							
							
							<xsl:element name="batch">
								<xsl:value-of select="number(ppdFunction/ppdBatchNr)"/>
							</xsl:element>
							
							
							<xsl:element name="seq">
								<xsl:value-of select="ppdFunction/ppdSeqNr"/>
							</xsl:element>
		
							
							<xsl:element name="ref">
								<xsl:value-of select="0"/>
							</xsl:element>
							
							
							<xsl:element name="merchId">
								<xsl:value-of select="0"/>
							</xsl:element>
							
							
							<xsl:element name="termId">
								<xsl:value-of select="0"/>
							</xsl:element>
							
							
							<xsl:if test="ppdFunction/ppdAcceptCancel">
								<xsl:element name="replyMsg">
									<xsl:value-of select="ppdFunction/ppdAcceptCancel"/>
								</xsl:element>
							</xsl:if>
							
							
							<xsl:element name="authDateTime">
								<xsl:value-of select="ppdFunction/ppdTime"/>
							</xsl:element>
							
							
							<xsl:element name="Extension">
								<xsl:element name="trpcEcpTranType">
									<xsl:value-of select="ppdFunction/ppdEcpTranType"/>
								</xsl:element>
								
								<xsl:element name="trpcEcpTranCode">
									<xsl:value-of select="ppdFunction/ppdEcpTranCode"/>
								</xsl:element>
								
								<xsl:element name="trpcHandling">
									<xsl:value-of select="ppdFunction/ppdHandling"/>
								</xsl:element>
								
								<xsl:element name="trpcRubyTranType">
									<xsl:value-of select="ppdFunction/ppdRubyTranType"/>
								</xsl:element>
								
								<xsl:element name="trpcTenderMediaCode">
									<xsl:value-of select="ppdFunction/ppdTenderMediaCode"/>
								</xsl:element>
							</xsl:element>
						</xsl:element>
						
				</xsl:element>				
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="/|*|@*|text()" mode="ns:stripeSpace">
		<xsl:copy>
			<xsl:apply-templates select="* | @* | text()" mode="ns:stripeSpace"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="batch | acct | seq | ppdSeqNr | ppdEntryMeth | entryMeth | trpcBatchNr" mode="ns:stripeSpace">
		<xsl:variable name="lname">
			<xsl:value-of select="name()"/>
		</xsl:variable>
		<xsl:element name="{$lname}">
			<xsl:value-of select="translate(.,' &#9;&#10;&#13;', '')"/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="t:sale | t:adjustment" mode="ns:ppd">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<xsl:template match="@* | text()" mode="ns:ppd"/>
	
	<xsl:template name="ns:getCreditTransactions">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/*/paylines/*[(t:mop/@cat = $ns:credit or t:mop/@cat = $ns:debit) ]/../.. |           $ns-set/t:event[@type='prepaidCard']"/>
	</xsl:template>
	
	<xsl:template name="ns:buildCreditTransactions">
		<xsl:param name="lineSet"/>
		<xsl:variable name="ns-lineSet" select="ext:node-set($lineSet)"/>
		<xsl:for-each select="$ns-lineSet/*">
			<xsl:variable name="node" select="."/>
			<xsl:variable name="dcr">
			<xsl:choose><xsl:when test="./hdr/t:register[@sysid = $ns:dcrRegister]"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose>
			</xsl:variable>
			<xsl:variable name="dt">
			<xsl:copy-of select="./hdr/dateTime"/>
			</xsl:variable> 
			<xsl:variable name="ts">
				<xsl:copy-of select="./vs:transactionSeq"/>
			</xsl:variable>
			<xsl:variable name="reg">
				<xsl:copy-of select="./hdr/t:register"/>
			</xsl:variable>
			<xsl:variable name="csh">
				<xsl:copy-of select="./t:cashier"/>
			</xsl:variable>
			<xsl:for-each select="ext:node-set($node)/paylines/t:payline[t:cardInfo]">
			<xsl:element name="cardEntry">
				<xsl:attribute name="DCR"><xsl:value-of select="$dcr"/></xsl:attribute>
				
				<xsl:copy-of select="./t:mop[@cat = $ns:credit or @cat = $ns:debit]/../t:cardInfo"/>
				
				<xsl:copy-of select="$dt"/>
				
				<xsl:copy-of select="$ts"/>
				
				<xsl:copy-of select="$reg"/>
				
				<xsl:copy-of select="$csh"/>
				
				<xsl:copy-of select="./t:mop[@cat = $ns:credit or @cat = $ns:debit]/../amt"/>
			</xsl:element>
			</xsl:for-each>
		</xsl:for-each>
	</xsl:template>
	
</xsl:stylesheet>