<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.naxml.org/POSBO/Vocabulary/2003-10-16" xmlns:nax="http://www.naxml.org/POSBO/Vocabulary/2003-10-16" xmlns:ns="http://verifone.com/isd/vfit/tlog/naxml3.3/MSMovement-lib" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:ext="urn:schemas-microsoft-com:xslt" version="1.0" exclude-result-prefixes="ns t base vs ext xsl nax">
	<xsl:param name="ns:debug" select="'false'"/>
	
	<xsl:param name="ns:commonMap"/>
	<xsl:param name="ns:xlateMap"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:template name="ns:createTotalizersEntry">
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:param name="amount"/>
		<xsl:param name="currency"/>
		
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="$amount"/>
				</MiscellaneousSummaryAmount>
				
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createSafe-PayInOutEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		
		<xsl:variable name="mopList">
			<xsl:call-template name="ns:getMopList">
				<xsl:with-param name="tlogEntrySet" select="$nodeSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="tenderList">
			<xsl:apply-templates select="ext:node-set($mopList)" mode="ns:xlateMop"/>
		</xsl:variable>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<xsl:apply-templates select="ext:node-set($tenderList)/*" mode="ns:MSMSalesTotals-1">
				<xsl:with-param name="nodeSet" select="$nodeSet"/>
				<xsl:with-param name="mopList" select="$mopList"/>
				<xsl:with-param name="currency" select="$currency"/>
			</xsl:apply-templates>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createNoSaleEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:param name="currency"/>
		<xsl:param name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number('0','0.00')"/>
				</MiscellaneousSummaryAmount>
				
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="count(ext:node-set($nodeSet))"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createSalesEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		
		<xsl:variable name="mopList">
			<xsl:call-template name="ns:getMopList">
				<xsl:with-param name="tlogEntrySet" select="$nodeSet"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="tenderList">
			<xsl:apply-templates select="ext:node-set($mopList)" mode="ns:xlateMop"/>
		</xsl:variable>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<xsl:apply-templates select="ext:node-set($tenderList)/*" mode="ns:MSMSalesTotals-2">
				<xsl:with-param name="nodeSet" select="$nodeSet"/>
				<xsl:with-param name="mopList" select="$mopList"/>
				<xsl:with-param name="currency" select="$currency"/>
			</xsl:apply-templates>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createSalesStatisticEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		<xsl:variable name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				
				
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//sum/total),'#.00 ; #.00')"/>
				</MiscellaneousSummaryAmount>
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="count(ext:node-set($nodeSet))"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createPrcOvrEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		<xsl:variable name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				
				
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)[priceOverride]/itmprc) - sum(ext:node-set($nodeSet)//oldprc),'#.00 ; #.00')"/>
				</MiscellaneousSummaryAmount>
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="count(ext:node-set($nodeSet)[priceOverride])"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createDiscountStatisticEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		<xsl:variable name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				
				
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//t:disc/amt),'#.00 ; #.00')"/>
				</MiscellaneousSummaryAmount>
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="count(ext:node-set($nodeSet)[t:disc])"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createDriveOffStatisticEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:param name="mop"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		<xsl:variable name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				
				
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//t:payline[t:mop/@cat = ext:node-set($mop)//@cat]/amt),'#.00 ; #.00')"/>
				</MiscellaneousSummaryAmount>
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="count(ext:node-set($nodeSet)[paylines/t:payline/t:mop/@cat = ext:node-set($mop)//@cat])"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createDriveOffEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:param name="mop"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		<xsl:variable name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				<xsl:apply-templates select="ext:node-set($mop)[1]" mode="ns:xlateMop"/>
				
				<TenderTransactionsCount>
					<xsl:value-of select="count(ext:node-set($nodeSet))"/>
				</TenderTransactionsCount>
				
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//t:payline[t:mop/@cat = ext:node-set($mop)//@cat]/amt),'#.00 ; #.00')"/>
				</MiscellaneousSummaryAmount>
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="count(ext:node-set($nodeSet)[paylines/t:payline/t:mop/@cat = ext:node-set($mop)//@cat])"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createItemsSoldStatisticEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		<xsl:variable name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				
				
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//t:line[iid]/stot) + sum(ext:node-set($nodeSet)//t:sline[iid]/stot) ,'#.00 ; #.00')"/>
				</MiscellaneousSummaryAmount>
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//t:line[iid]/qty) + sum(ext:node-set($nodeSet)//t:sline[iid]/qty),'#.000 ; #.000')"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createTaxChangeStatisticEntry">
		<xsl:param name="nodeSet"/>
		<xsl:param name="summaryCode"/>
		<xsl:param name="summarySubCode"/>
		<xsl:variable name="currency">
			<xsl:value-of select="ext:node-set($nodeSet)//@currency"/>
		</xsl:variable>
		<xsl:variable name="uom"/>
		<MSMDetail>
			<xsl:call-template name="ns:createMiscSummaryEntry">
				<xsl:with-param name="summaryCode" select="$summaryCode"/>
				<xsl:with-param name="summarySubCode" select="$summarySubCode"/>
			</xsl:call-template>
			<MSMSalesTotals>
				
				
				
				
				
				<MiscellaneousSummaryAmount>
					<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//forgivenTax) ,'#.00 ; #.00')"/>
				</MiscellaneousSummaryAmount>
				
				<MiscellaneousSummaryCount>
					<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
					<xsl:value-of select="count(ext:node-set($nodeSet)//t:line[tax/@reversed='true'])"/>
				</MiscellaneousSummaryCount>
			</MSMSalesTotals>
		</MSMDetail>
	</xsl:template>
	
	<xsl:template name="ns:createSalesMovementHeader">
		<xsl:param name="cshID"/>
		<xsl:param name="empNum"/>
		<xsl:param name="regID"/>
		<xsl:param name="tillID"/>
		<SalesMovementHeader>
			<RegisterID>
				<xsl:value-of select="$regID"/>
			</RegisterID>
			<CashierID>
				<xsl:value-of select="$cshID"/>
			</CashierID>
			<TillID>
				<xsl:value-of select="$tillID"/>
			</TillID>
			<EmployeeNumber>
				<xsl:value-of select="$empNum"/>
			</EmployeeNumber>
		</SalesMovementHeader>
	</xsl:template>
	
	<xsl:template name="ns:getCashierData">
		<xsl:param name="csh"/>
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="si" select="ext:node-set($csh)//@sysid"/>
		<xsl:variable name="pd" select="ext:node-set($csh)//period"/>
		
		<xsl:choose>
			<xsl:when test="(not($pd) and $si= 0)">
				<xsl:copy-of select="ext:node-set($tlogEntrySet)/*[t:cashier/@sysid = ext:node-set($csh)//@sysid] "/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="ext:node-set($tlogEntrySet)/*[t:cashier/@sysid = ext:node-set($csh)//@sysid and t:cashier/period = ext:node-set($csh)//period]"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:createMovementHeader">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="VFIperiodType" select="ext:node-set($tlogEntrySet)/t:hdr/vs:period/@periodType"/>
		<MovementHeader>
			<ReportSequenceNumber>
				<xsl:value-of select="ext:node-set($tlogEntrySet)/t:hdr/vs:period/@periodSeqNum"/>
			</ReportSequenceNumber>
			<PrimaryReportPeriod>
				<xsl:choose>
					<xsl:when test="not(ext:node-set($tlogEntrySet)/t:hdr/vs:period/@periodType)">
						<xsl:attribute name="interval">other</xsl:attribute>
					</xsl:when>
					<xsl:when test="ext:node-set($tlogEntrySet)/t:hdr/vs:period/@periodType =''">
						<xsl:attribute name="interval">other</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="attrValue">
							<xsl:for-each select="$ns:commonMap//PeriodType/pair">
								<xsl:choose>
									<xsl:when test="$VFIperiodType=vfiPeriod/@value">
										<xsl:value-of select="period3.3/@value"/>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
						</xsl:variable>
						<xsl:attribute name="interval"><xsl:choose><xsl:when test="$attrValue!=''"><xsl:value-of select="$attrValue"/></xsl:when><xsl:otherwise><xsl:value-of select="$VFIperiodType"/></xsl:otherwise></xsl:choose></xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:value-of select="ext:node-set($tlogEntrySet)/t:hdr/vs:period/@sysid"/>
			</PrimaryReportPeriod>
			<SecondaryReportPeriod>
				<xsl:value-of select="ext:node-set($tlogEntrySet)/t:hdr/vs:period/@periodSeqNum"/>
			</SecondaryReportPeriod>
			<BusinessDate>
				<xsl:value-of select="ext:node-set($tlogEntrySet)/t:hdr/t:busDate"/>
			</BusinessDate>
			<BeginDate>
				<xsl:value-of select="substring-before(ext:node-set($tlogEntrySet)/t:hdr/startDateTime,'T')"/>
			</BeginDate>
			<BeginTime>
				<xsl:value-of select="substring(ext:node-set($tlogEntrySet)/t:hdr/startDateTime,12,8)"/>
			</BeginTime>
			<EndDate>
				<xsl:value-of select="substring-before(ext:node-set($tlogEntrySet)/t:hdr/endDateTime,'T')"/>
			</EndDate>
			<EndTime>
				<xsl:value-of select="substring(ext:node-set($tlogEntrySet)/t:hdr/endDateTime,12,8)"/>
			</EndTime>
		</MovementHeader>
	</xsl:template>
	
	<xsl:template name="ns:createTransmissionHeader">
		<xsl:param name="siteID"/>
		<xsl:param name="vendor" select="'VeriFone'"/>
		<xsl:param name="vendorModel" select="'Sapphire'"/>
		<TransmissionHeader>
			<StoreLocationID>
				<xsl:value-of select="$siteID"/>
			</StoreLocationID>
			<VendorName>
				<xsl:value-of select="$vendor"/>
			</VendorName>
			<VendorModelVersion>
				<xsl:value-of select="$vendorModel"/>
			</VendorModelVersion>
		</TransmissionHeader>
	</xsl:template>
	
	<xsl:template name="ns:createMiscSummaryEntry">
		<xsl:param name="summaryCode" select="generic"/>
		<xsl:param name="summarySubCode" select="generic"/>
		<MiscellaneousSummaryCodes>
			<MiscellaneousSummaryCode>
				<xsl:value-of select="$summaryCode"/>
			</MiscellaneousSummaryCode>
			<MiscellaneousSummarySubCode>
				<xsl:value-of select="$summarySubCode"/>
			</MiscellaneousSummarySubCode>
		</MiscellaneousSummaryCodes>
	</xsl:template>
	
	<xsl:template name="ns:getMopList">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-tlogEntrySet" select="ext:node-set($tlogEntrySet)"/>
		<xsl:variable name="mopList" select="$ns-tlogEntrySet//t:mop"/>
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:node-set($mopList)">
				<xsl:sort data-type="number" order="ascending" select="@sysid"/>
				<xsl:sort data-type="number" order="ascending" select="@cat"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="ext:node-set($sortedList)/t:mop[         not( @sysid = preceding-sibling::t:mop[1]/@sysid)         or         ( @sysid = preceding-sibling::t:mop[1]/@sysid and @cat != preceding-sibling::t:mop[1]/@cat )         ]"/>
	</xsl:template>
	
	<xsl:template name="ns:xlate-mop">
		<xsl:param name="mop"/>
		<xsl:variable name="pair" select="ext:node-set($ns:xlateMap)/maps/tenderMap/pair[                 (shortID/@sysid = $mop/@sysid and shortID/@cat = $mop/@cat) or                  (not(shortID/@sysid) and shortID/@cat = $mop/@cat)                 ]"/>
		<xsl:choose>
			<xsl:when test="$pair">
				<xsl:choose>
					<xsl:when test="$pair/tender3.3">
						<xsl:copy-of select="$pair/tender3.3"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$pair/tender3.3disc"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="defaultPair" select="ext:node-set($ns:xlateMap)/maps/tenderMap/pair[default]"/>
				<xsl:choose>
					<xsl:when test="$ns:debug != 'true' and $defaultPair">
						<xsl:copy-of select="$defaultPair/tender3.3"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:message terminate="yes">
							<xsl:text>Undefined tender sysid = </xsl:text>
							<xsl:value-of select="$mop/@sysid"/>
							<xsl:text>, cat = </xsl:text>
							<xsl:value-of select="$mop/@cat"/>
						</xsl:message>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:xlateUOM">
		<xsl:param name="uom"/>
		<xsl:choose>
			<xsl:when test="not($uom) or $uom=''">
				<xsl:value-of select="$ns:commonMap//WeightUOM/*[*/@value='default']/weightUOM3.3/@value"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="not($ns:commonMap//WeightUOM/*[*/@value=$uom]/weightUOM3.3/@value)">
						<xsl:value-of select="$uom"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$ns:commonMap//WeightUOM/*[*/@value=$uom]/weightUOM3.3/@value"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:xlateCurrency">
		<xsl:param name="currency"/>
		<xsl:choose>
			<xsl:when test="not($currency) or $currency=''">
				<xsl:value-of select="$ns:commonMap//CurrencyUOM/*[*/@value='default']/currency3.3/@value"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="not($ns:commonMap//CurrencyUOM/*[*/@value=$currency]/currency3.3/@value)">
						<xsl:value-of select="$currency"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$ns:commonMap//CurrencyUOM/*[*/@value=$currency]/currency3.3/@value"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="t:mop" mode="ns:xlateMop">
		<xsl:variable name="mop">
			<xsl:call-template name="ns:xlate-mop">
				<xsl:with-param name="mop" select="."/>
			</xsl:call-template>
		</xsl:variable>
		<Tender>
			<TenderCode>
				<xsl:value-of select="ext:node-set($mop)//@tenderCode"/>
			</TenderCode>
			<TenderSubCode>
				<xsl:value-of select="ext:node-set($mop)//@tenderSubcode"/>
			</TenderSubCode>
		</Tender>
	</xsl:template>
	
	<xsl:template match="* | @* | text()" mode="ns:MSMSalesTotals-1"/>
	
	<xsl:template match="nax:Tender" mode="ns:MSMSalesTotals-1">
		<xsl:param name="nodeSet"/>
		<xsl:param name="mopList"/>
		<xsl:param name="currency"/>
		<xsl:param name="uom"/>
		<xsl:param name="manEntryFlag" select="'no'"/>
		<xsl:variable name="pos" select="position()"/>
		<xsl:variable name="mop" select="ext:node-set($mopList)/*[$pos]"/>
		<MSMSalesTotals>
			
			<xsl:copy-of select="."/>
			
			<TenderTransactionsCount>
				<xsl:value-of select="count(ext:node-set($nodeSet)[t:mop/@sysid = $mop/@sysid and t:mop/@cat = $mop/@cat])"/>
			</TenderTransactionsCount>
			
			
			
			<MiscellaneousSummaryAmount>
				<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
				<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)[t:mop/@sysid = $mop/@sysid and t:mop/@cat = $mop/@cat]/amount),'#.00')"/>
			</MiscellaneousSummaryAmount>
			
			<MiscellaneousSummaryCount>
				<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
				<xsl:value-of select="count(ext:node-set($nodeSet)[t:mop/@sysid = $mop/@sysid and t:mop/@cat = $mop/@cat])"/>
			</MiscellaneousSummaryCount>
		</MSMSalesTotals>
	</xsl:template>
	
	<xsl:template match="* | @* | text()" mode="ns:MSMSalesTotals-2"/>
	
	<xsl:template match="nax:Tender" mode="ns:MSMSalesTotals-2">
		<xsl:param name="nodeSet"/>
		<xsl:param name="mopList"/>
		<xsl:param name="currency"/>
		<xsl:param name="uom"/>
		<xsl:param name="manEntryFlag" select="'no'"/>
		<xsl:variable name="pos" select="position()"/>
		<xsl:variable name="mop" select="ext:node-set($mopList)/*[$pos]"/>
		<MSMSalesTotals>
			
			<xsl:copy-of select="."/>
			
			<TenderTransactionsCount>
				<xsl:value-of select="count(ext:node-set($nodeSet)[paylines/t:payline/t:mop/@sysid = $mop/@sysid and paylines/t:payline/t:mop/@cat = $mop/@cat])"/>
			</TenderTransactionsCount>
			
			
			
			<MiscellaneousSummaryAmount>
				<xsl:attribute name="currency"><xsl:call-template name="ns:xlateCurrency"><xsl:with-param name="currency" select="$currency"/></xsl:call-template></xsl:attribute>
				<xsl:value-of select="format-number(sum(ext:node-set($nodeSet)//paylines/t:payline[t:mop/@sysid = $mop/@sysid and t:mop/@cat = $mop/@cat]/amt),'#.00 ; #.00')"/>
			</MiscellaneousSummaryAmount>
			
			<MiscellaneousSummaryCount>
				<xsl:attribute name="uom"><xsl:call-template name="ns:xlateUOM"><xsl:with-param name="uom" select="$uom"/></xsl:call-template></xsl:attribute>
				<xsl:value-of select="count(ext:node-set($nodeSet)[paylines/t:payline/t:mop/@sysid = $mop/@sysid and paylines/t:payline/t:mop/@cat = $mop/@cat])"/>
			</MiscellaneousSummaryCount>
		</MSMSalesTotals>
	</xsl:template>
</xsl:stylesheet>