<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.naxml.org/POSBO/Vocabulary/2003-10-16" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/tlog/naxml3.3/MSMovement" version="1.0" exclude-result-prefixes="xsl ext ns  t vs">
	<xsl:variable name="mapPeriod" select="document('../../lib/naxml3.3/commonMap.xml')//PeriodType"/>
	<xsl:key name="tender_key" match="commonElements" use="tendercode"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:apply-templates select="ext:nodeset($inputDoc)" mode="ns:msm"/>
	</xsl:template>
	
	<xsl:template match="/" mode="ns:msm">
		<xsl:choose>
			<xsl:when test="count(t:tlog) = 0">
				<xsl:copy>
					<xsl:copy-of select="*"/>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<NAXML-MovementReport>
					
					<TransmissionHeader>
						<StoreLocationID>
							<xsl:value-of select="/t:tlog/code/t:hdr/vs:site"/>
						</StoreLocationID>
						<VendorName>VeriFone</VendorName>
						<VendorModelVersion>Sapphire</VendorModelVersion>
					</TransmissionHeader>
					
					<xsl:call-template name="NAXMSM"/>
				</NAXML-MovementReport>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="NAXMSM">
		<xsl:for-each select="t:tlog/code">
			<xsl:call-template name="NAXMLMSMDisp"/>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="NAXMLHdrDisp">
		<xsl:variable name="tLogNode" select="."/>
		<xsl:variable name="VFIperiodType" select="$tLogNode/t:hdr/vs:period/@periodType"/>
		<MovementHeader>
			<ReportSequenceNumber>
				<xsl:value-of select="$tLogNode/t:hdr/vs:period/@periodSeqNum"/>
			</ReportSequenceNumber>
			<PrimaryReportPeriod>
				<xsl:choose>
					<xsl:when test="not($tLogNode/t:hdr/vs:period/@periodType)">
						<xsl:attribute name="interval">other</xsl:attribute>
					</xsl:when>
					<xsl:when test="current()/t:hdr/vs:period/@periodType =''">
						<xsl:attribute name="interval">other</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="attrValue">
							<xsl:for-each select="$mapPeriod/pair">
								<xsl:choose>
									<xsl:when test="$VFIperiodType=vfiPeriod/@value">
										<xsl:value-of select="period3.3/@value"/>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
						</xsl:variable>
						<xsl:attribute name="interval"><xsl:choose><xsl:when test="$attrValue!=''"><xsl:value-of select="$attrValue"/></xsl:when><xsl:otherwise><xsl:value-of select="$VFIperiodType"/></xsl:otherwise></xsl:choose></xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:value-of select="$tLogNode/t:hdr/vs:period/@sysid"/>
			</PrimaryReportPeriod>
			<SecondaryReportPeriod>
				<xsl:value-of select="$tLogNode/t:hdr/vs:period/@periodSeqNum"/>
			</SecondaryReportPeriod>
			<BusinessDate>
				<xsl:value-of select="$tLogNode/t:hdr/t:busDate"/>
			</BusinessDate>
			<BeginDate>
				<xsl:value-of select="substring-before($tLogNode/t:hdr/startDateTime,'T')"/>
			</BeginDate>
			<BeginTime>
				<xsl:value-of select="substring($tLogNode/t:hdr/startDateTime,12,8)"/>
			</BeginTime>
			<EndDate>
				<xsl:value-of select="substring-before($tLogNode/t:hdr/endDateTime,'T')"/>
			</EndDate>
			<EndTime>
				<xsl:value-of select="substring($tLogNode/t:hdr/endDateTime,12,8)"/>
			</EndTime>
		</MovementHeader>
	</xsl:template>
	
	<xsl:template name="NAXMLMSMDisp">
		<xsl:variable name="tLogNode" select="."/>
		<xsl:variable name="commonElementNodes" select="//commonElements"/>
		<xsl:for-each select="current()/commonElements">
			<xsl:choose>
				<xsl:when test="(not(registerID) and not(cashierID) and not(tillID))">
					<xsl:call-template name="groupWithoutID">
						<xsl:with-param name="commonElementNodes" select="$commonElementNodes"/>
						<xsl:with-param name="tLogNode" select="$tLogNode"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="groupWithID">
						<xsl:with-param name="commonElementNodes" select="$commonElementNodes"/>
						<xsl:with-param name="tLogNode" select="$tLogNode"/>
						<xsl:with-param name="nodeSet" select="."/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="groupWithID">
		<xsl:param name="commonElementNodes"/>
		<xsl:param name="tLogNode"/>
		<xsl:param name="nodeSet"/>
		<xsl:variable name="ManualFlagValue" select="'no'"/>
		
		<xsl:variable name="summaryCodeVal" select="summaryCode"/>
		<xsl:variable name="summarySubCodeVal" select="summarySubCode"/>
		<xsl:if test="generate-id(.)=generate-id($commonElementNodes[registerID=current()/registerID and cashierID=current()/cashierID and tillID=current()/tillID and summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal])">
			<MiscellaneousSummaryMovement>
				<xsl:for-each select="$tLogNode">
					<xsl:call-template name="NAXMLHdrDisp"/>
				</xsl:for-each>
				<SalesMovementHeader>
					<RegisterID>
						<xsl:value-of select="registerID"/>
					</RegisterID>
					<CashierID>
						<xsl:value-of select="cashierID"/>
					</CashierID>
					<TillID>
						<xsl:value-of select="tillID"/>
					</TillID>
					<EmployeeNumber>
						<xsl:value-of select="EmployeeNumber"/>
					</EmployeeNumber>
				</SalesMovementHeader>
				<MSMDetail>
					<MiscellaneousSummaryCodes>
						<MiscellaneousSummaryCode>
							<xsl:value-of select="summaryCode"/>
						</MiscellaneousSummaryCode>
						<MiscellaneousSummarySubCode>
							<xsl:value-of select="summarySubCode"/>
						</MiscellaneousSummarySubCode>
					</MiscellaneousSummaryCodes>
					<xsl:for-each select="$commonElementNodes[registerID=current()/registerID and cashierID=current()/cashierID and tillID=current()/tillID and summaryCode=current()/summaryCode and summarySubCode=current()/summarySubCode]">
						<xsl:if test="generate-id(.)=generate-id($commonElementNodes[registerID=current()/registerID and cashierID=current()/cashierID and tillID=current()/tillID and  summaryCode=current()/summaryCode and summarySubCode=current()/summarySubCode and  tenderCode=current()/tenderCode and tenderSubCode=current()/tenderSubCode])">
							<xsl:variable name="TenderCodeVal" select="tenderCode"/>
							<xsl:variable name="TenderSubCodeVal" select="tenderSubCode"/>
							<xsl:variable name="overVal" select="current()/overallGrand"/>
							<MSMSalesTotals>
								<Tender>
									<TenderCode>
										<xsl:value-of select="tenderCode"/>
									</TenderCode>
									<TenderSubCode>
										<xsl:value-of select="tenderSubCode"/>
									</TenderSubCode>
								</Tender>
								<TenderTransactionsCount>
									<xsl:value-of select="count($commonElementNodes[summaryCode=current()/summaryCode and summarySubCode=current()/summarySubCode and  tenderCode=current()/tenderCode and tenderSubCode=current()/tenderSubCode])"/>
								</TenderTransactionsCount>
								<ManualEntryFlag>
										<xsl:attribute name="value"><xsl:value-of select="$ManualFlagValue"/></xsl:attribute>
								</ManualEntryFlag>
					
								<xsl:if test="count(current()/t:tillSafeDrop)&gt;=1or count(current()/t:tillSafeLoan)&gt;=1or count(current()/t:tillPayout)&gt;=1 or count(t:tillPayin)&gt;=1">
									<Currency>
										<xsl:choose>
											<xsl:when test="not(current()/*/amount/@currency) or current()/*/amount/@currency='' ">
												<xsl:attribute name="currency">USD</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="currency"><xsl:value-of select="current()/*/amount/@currency"/></xsl:attribute>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:value-of select="current()/*/amount"/>
									</Currency>
									<MiscellaneousSummaryAmount>
										<xsl:choose>
											<xsl:when test="not(current()/*/amount/@currency) or current()/*/amount/@currency='' ">
												<xsl:attribute name="currency">USD</xsl:attribute>
											</xsl:when>
											<xsl:otherwise>
												<xsl:attribute name="currency"><xsl:value-of select="current()/*/amount/@currency"/></xsl:attribute>
											</xsl:otherwise>
										</xsl:choose>
										<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/amount),'##0.00')"/>
									</MiscellaneousSummaryAmount>
									<MiscellaneousSummaryCount>
									<xsl:attribute name="uom">each</xsl:attribute>
										<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/amount)"/>
									</MiscellaneousSummaryCount>
								</xsl:if>
					
								<xsl:if test="count( t:sale[@isRefund=true() and @isRefund='true'])&gt;=1">
									<xsl:if test="flag='true'">
										<MiscellaneousSummaryAmount>
										<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count(t:sale/lines/t:line/t:disc)&gt;=1">
									<xsl:if test="current()[flag='disc' and t:sale/lines/t:line/t:disc]">
										<MiscellaneousSummaryAmount>
										<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/lines/t:line/t:disc),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/lines/t:line/t:disc)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if> 
					
								<xsl:if test="count( t:sale/lines/t:line/priceOverride)&gt;=1">
									<xsl:if test="current()[flag='price' and t:sale/lines/t:line/priceOverride]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*[lines/t:line/priceOverride]/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*//t:line/priceOverride)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count(t:tillNosale)&gt;=1">
									<xsl:if test="t:tillNosale">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:choose>
												<xsl:when test="current()/t:tillNoSale/sum/total">
													<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:tillNoSale/sum/total),'##0.00')"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="'0.00'"/>
												</xsl:otherwise>
											</xsl:choose>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:tillNosale)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count( t:suspendedSale)&gt;=1">
									<xsl:if test="current()[flag='suspend' and t:suspendedSale]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if> 
					
								<xsl:if test="count(t:void)&gt;=1">
									<xsl:if test="current()[flag='void' and t:void]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
									<xsl:if test="current()[flag='drive']">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal and flag='drive']/*/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal and flag='drive']/*/sum/total)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
					
							<xsl:if test="count(t:sale[@isRefund=false() or @isRefund='false']/lines[t:line[@isVoid=false() or @isVoid='false'] or t:cline[@isVoid=false() or @isVoid='false'] or t:dupLine[@isVoid=false() or @isVoid='false']])&gt;=1">
									<xsl:if test="current()[flag='items' and t:sale[@isRefund=false() or @isRefund='false']]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale[(@isRefund=false() or @isRefund='false') and lines/t:line[@isVoid=false() or @isVoid='false']]/sum/total)+sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale[(@isRefund=false() or @isRefund='false') and lines/t:cline[@isVoid=false() or @isVoid='false']]/sum/total)+sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale[(@isRefund=false()or @isRefund='false') and lines/t:dupLine[@isVoid=false() or @isVoid='false']]/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale[(@isRefund=false() or @isRefund='false') and lines/t:line[@isVoid=false() or @isVoid='false']])+count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale[(@isRefund=false() or @isRefund='false') and lines/t:cline[@isVoid=false() or @isVoid='false']])+count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale[(@isRefund=false() or @isRefund='false') and lines/t:dupLine[@isVoid=false() or @isVoid='false']])"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count(t:sale/lines/t:line/tax[@reversed=true() and @reversed='true'])&gt;=1">
									<xsl:if test="current()[flag='tax' and t:sale/lines/t:line/tax[@reversed=true() and @reversed='true']]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*[lines/t:line/tax[@reversed=true() and @reversed='true']]/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]//t:line[tax[@reversed=true() and @reversed='true']])"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count(t:sale/sum/total)&gt;=1">
									<xsl:if test="current()[flag='sum' and t:sale/sum/total]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/total)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count(t:sale[@isRefund=false() or @isRefund='false']/sum/total)&gt;=1">
									<xsl:if test="current()[flag='sale' and t:sale[@isRefund=false() or @isRefund='false']/sum/total]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*[@isRefund=false() or @isRefund='false']/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*[@isRefund=false() or @isRefund='false']/sum/total)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count(t:openCashier)&gt;=1">
									<MiscellaneousSummaryAmount>
										<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:openCashier[t:cashier/@sysid=current()/cashierID]/beginCash)+sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:openCashier[t:cashier/@sysid=current()/cashierID]/beginFoodStmp),'##0.00')"/>
									</MiscellaneousSummaryAmount>
									<MiscellaneousSummaryCount>
									<xsl:attribute name="uom">each</xsl:attribute>
										<xsl:value-of select="count($commonElementNodes[cashierID=current()/cashierID and summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:openCashier)"/>
									</MiscellaneousSummaryCount>
								</xsl:if>
					
								<xsl:if test="count(t:closeCashier)&gt;=1">
									<MiscellaneousSummaryAmount>
										<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:closeCashier[t:cashier/@sysid=current()/cashierID]/beginCash)+sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:closeCashier[t:cashier/@sysid=current()/cashierID]/beginFoodStmp),'##0.00')"/>
									</MiscellaneousSummaryAmount>
									<MiscellaneousSummaryCount>
									<xsl:attribute name="uom">each</xsl:attribute>
										<xsl:value-of select="count($commonElementNodes[cashierID=current()/cashierID and summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:closeCashier)"/>
									</MiscellaneousSummaryCount>
								</xsl:if>
					
								<xsl:if test="count(t:countCashier)&gt;=1">
									<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:countCashier[t:cashier/@sysid=current()/cashierID]/tillAmount/actualAmount),'##0.00')"/>
									</MiscellaneousSummaryAmount>
									<MiscellaneousSummaryCount>
									<xsl:attribute name="uom">each</xsl:attribute>
										<xsl:value-of select="count($commonElementNodes[cashierID=current()/cashierID and summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:countCashier)"/>
									</MiscellaneousSummaryCount>
								</xsl:if>
					
								<xsl:if test="count(t:sale/sum/t:sumTax/taxable)&gt;=1">
									<xsl:if test="current()[flag='taxable' and t:sale/sum/t:sumTax/taxable]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/t:sumTax/taxable),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*/sum/t:sumTax/taxable)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
					
								<xsl:if test="count(t:sale/paylines/t:payline/t:cardInfo[hostId!='PROPNET'])&gt;=1">
									<xsl:if test="current()[flag='credit' and t:sale[paylines/t:payline/t:cardInfo[hostId!='PROPNET']]]">
										<MiscellaneousSummaryAmount>
											<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*[paylines/t:payline/t:cardInfo[hostId!='PROPNET']]/paylines/t:payline/amt),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/*[paylines/t:payline/t:cardInfo[hostId!='PROPNET']]/paylines/t:payline/amt)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if> 
					
							<xsl:if test="count(current()[t:sale or t:void or t:suspendedSale or t:pumpTest])&gt;=1">
									<xsl:if test="current()[flag='transaction' and t:sale | t:void | t:suspendedSale | t:pumpTest]">
										<MiscellaneousSummaryAmount>
										<xsl:choose>
												<xsl:when test="not(current()/*/sum/total/@currency) or (current()/*/sum/total/@currency = '')">
													<xsl:attribute name="currency">USD</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale/sum/total)+sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:void/sum/total)+sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:suspendedSale/sum/total)+sum(//commonElements[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:pumpTest/sum/total),'##0.00')"/>
										</MiscellaneousSummaryAmount>
										<MiscellaneousSummaryCount>
										<xsl:attribute name="uom">each</xsl:attribute>
											<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:sale)+count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:void)+count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:suspendedSale)+count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/t:pumpTest)"/>
										</MiscellaneousSummaryCount>
									</xsl:if>
								</xsl:if>
						</MSMSalesTotals>
						</xsl:if>
					</xsl:for-each>
				</MSMDetail>
			</MiscellaneousSummaryMovement>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="groupWithoutID">
		<xsl:param name="commonElementNodes"/>
		<xsl:param name="tLogNode"/>
		<xsl:variable name="ManualFlagValue" select="'no'"/>
		<xsl:if test="generate-id(.)=generate-id($commonElementNodes[(registerID=current()/registerID and cashierID=current()/cashierID and tillID=current()/tillID) or summaryCode=current()/summaryCode and summarySubCode=current()/summarySubCode])">
			<xsl:variable name="summaryCodeVal" select="summaryCode"/>
			<xsl:variable name="summarySubCodeVal" select="summarySubCode"/>
			<MiscellaneousSummaryMovement>
				<xsl:for-each select="$tLogNode">
					<xsl:call-template name="NAXMLHdrDisp"/>
				</xsl:for-each>
				<MSMDetail>
					<MiscellaneousSummaryCodes>
						<MiscellaneousSummaryCode>
							<xsl:value-of select="summaryCode"/>
						</MiscellaneousSummaryCode>
						<MiscellaneousSummarySubCode>
							<xsl:value-of select="summarySubCode"/>
						</MiscellaneousSummarySubCode>
					</MiscellaneousSummaryCodes>
					<xsl:for-each select="$commonElementNodes[summaryCode=current()/summaryCode and summarySubCode=current()/summarySubCode]">
						<xsl:if test="generate-id(.)=generate-id($commonElementNodes[summaryCode=current()/summaryCode and summarySubCode=current()/summarySubCode and  tenderCode=current()/tenderCode and tenderSubCode=current()/tenderSubCode])">
							<xsl:variable name="TenderCodeVal" select="tenderCode"/>
							<xsl:variable name="TenderSubCodeVal" select="tenderSubCode"/>
							<MSMSalesTotals>
								<Tender>
									<TenderCode>
										<xsl:value-of select="tenderCode"/>
									</TenderCode>
									<TenderSubCode>
										<xsl:value-of select="tenderSubCode"/>
									</TenderSubCode>
								</Tender>
								<TenderTransactionsCount>
									<xsl:value-of select="count($commonElementNodes[summaryCode=current()/summaryCode and summarySubCode=current()/summarySubCode and  tenderCode=current()/tenderCode and tenderSubCode=current()/tenderSubCode])"/>
								</TenderTransactionsCount>
								<ManualEntryFlag>
									<xsl:attribute name="value"><xsl:value-of select="$ManualFlagValue"/></xsl:attribute>
								</ManualEntryFlag>
					
								<xsl:if test="count(current()/overallGrand)&gt;=1 or count(current()/overallSales)&gt;=1">
									<xsl:choose>
										<xsl:when test="overallGrand">
											<xsl:choose>
												<xsl:when test="current()/*/amount">
													<Currency>
														<xsl:choose>
															<xsl:when test="not(current()/*/amount/@currency) or (current()/*/amount/@currency = '')">
																<xsl:attribute name="currency">USD</xsl:attribute>
															</xsl:when>
															<xsl:otherwise>
																<xsl:attribute name="currency"><xsl:value-of select="current()/*/amount/@currency"/></xsl:attribute>
															</xsl:otherwise>
														</xsl:choose>
														<xsl:value-of select="current()/*/amount"/>
													</Currency>
												</xsl:when>
											</xsl:choose>
											<MiscellaneousSummaryAmount>
												<xsl:choose>
													<xsl:when test="not(current()/*/amount/@currency) or (current()/*/amount/@currency = '')">
														<xsl:attribute name="currency">USD</xsl:attribute>
													</xsl:when>
													<xsl:otherwise>
														<xsl:attribute name="currency"><xsl:value-of select="current()/*/sum/total/@currency"/></xsl:attribute>
													</xsl:otherwise>
												</xsl:choose>
												<xsl:value-of select="format-number(sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/overallGrand),'##0.00')"/>
											</MiscellaneousSummaryAmount>
											<MiscellaneousSummaryCount>
											<xsl:attribute name="uom">each</xsl:attribute>
												<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/overallGrand)"/>
											</MiscellaneousSummaryCount>
										</xsl:when>
										<xsl:otherwise>
											<xsl:if test="overallSales">
												<xsl:choose>
													<xsl:when test="current()/*/amount">
														<Currency>
															<xsl:choose>
																<xsl:when test="not(current()/*/amount/@currency) or (current()/*/amount/@currency = '')">
																	<xsl:attribute name="currency">USD</xsl:attribute>
																</xsl:when>
																<xsl:otherwise>
																	<xsl:attribute name="currency"><xsl:value-of select="current()/*/amount/@currency"/></xsl:attribute>
																</xsl:otherwise>
															</xsl:choose>
															<xsl:value-of select="current()/*/amount"/>
														</Currency>
													</xsl:when>
												</xsl:choose>
												<MiscellaneousSummaryAmount>
													<xsl:choose>
															<xsl:when test="not(current()/*/amount/@currency) or (current()/*/amount/@currency = '')">
																<xsl:attribute name="currency">USD</xsl:attribute>
															</xsl:when>
															<xsl:otherwise>
																<xsl:attribute name="currency"><xsl:value-of select="current()/*/amount/@currency"/></xsl:attribute>
															</xsl:otherwise>
														</xsl:choose>
													<xsl:value-of select="sum($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/overallSales)"/>
												</MiscellaneousSummaryAmount>
												<MiscellaneousSummaryCount>
													<xsl:attribute name="uom">each</xsl:attribute>
													<xsl:value-of select="count($commonElementNodes[summaryCode=$summaryCodeVal and summarySubCode=$summarySubCodeVal and tenderCode=$TenderCodeVal and tenderSubCode=$TenderSubCodeVal]/overallSales)"/>
												</MiscellaneousSummaryCount>
											</xsl:if>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
					</MSMSalesTotals>
						</xsl:if>
					</xsl:for-each>
				</MSMDetail>
			</MiscellaneousSummaryMovement>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>