<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.naxml.org/POSBO/Vocabulary/2003-10-16" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/naxml3.3/TaxLevelMovement" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" version="1.0" exclude-result-prefixes="xsl ext ns vs t">
	<xsl:variable name="mapPeriod" select="document('../../lib/naxml3.3/commonMap.xml')//PeriodType"/>
	<xsl:variable name="mapMoney" select="document('../../lib/naxml3.3/commonMap.xml')//CurrencyUOM"/>
	<xsl:key name="register_keyn" match="t:sale" use="hdr/t:register/@sysid"/>
	<xsl:key name="cashier_keyn" match="t:sale" use="t:cashier/@sysid"/>
	<xsl:key name="till_key" match="t:sale" use="hdr/t:register/@till"/>
	<xsl:key name="employee_key" match="t:sale" use="t:cashier/@number"/>
	<xsl:key name="taxLevel_key" match="t:sumTax" use="vs:taxrateBase/@sysid"/>
	<xsl:key name="taxLevel_keyn" match="t:sale/sum" use="t:sumTax/vs:taxrateBase/@sysid"/>
	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:apply-templates select="ext:node-set($inputDoc)" mode="ns:report"/>
	</xsl:template>
	
	<xsl:template match="/" mode="ns:report">
		<xsl:choose>
			<xsl:when test="count(t:tlog) = 0">
				<xsl:copy>
					<xsl:copy-of select="*"/>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="t:tlog"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="t:tlog">
		<NAXML-MovementReport>
			
			<TransmissionHeader>
				<StoreLocationID>
					<xsl:value-of select="t:hdr/vs:site"/>
				</StoreLocationID>
				<VendorName>VeriFone</VendorName>
				<VendorModelVersion>Commander Site Controller</VendorModelVersion>
			</TransmissionHeader>
			
			
			<xsl:variable name="VFIperiodType" select="t:hdr/vs:period/@periodType"/>
			<xsl:variable name="sumTaxNode" select="t:sale"/>
			<xsl:for-each select="t:sale[generate-id(.)=generate-id(key('register_keyn',hdr/t:register/@sysid)[1]) or (generate-id(.)=generate-id(key('cashier_keyn', t:cashier/@sysid)) or generate-id(.)=generate-id(key('till_key',hdr/t:register/@till)))=1]">
				<xsl:variable name="lngRegisterID">
					<xsl:value-of select="hdr/t:register/@sysid"/>
				</xsl:variable>
				<xsl:variable name="lngCashierID">
					<xsl:value-of select="t:cashier/@sysid"/>
				</xsl:variable>
				<xsl:variable name="lngTillID">
					<xsl:value-of select="hdr/t:register/@till"/>
				</xsl:variable>
				<xsl:variable name="fstRegiterID" select="//t:sale[hdr/t:register/@sysid=$lngRegisterID]"/>
				<TaxLevelMovement>
					<MovementHeader>
						<ReportSequenceNumber>
							<xsl:value-of select="ancestor::t:tlog/t:hdr/seq"/>
						</ReportSequenceNumber>
						<PrimaryReportPeriod>
							<xsl:choose>
								<xsl:when test="not(ancestor::t:tlog/t:hdr/vs:period/@periodType)">
									<xsl:attribute name="interval">other</xsl:attribute>
								</xsl:when>
								<xsl:when test="ancestor::t:tlog/t:hdr/vs:period/@periodType =''">
									<xsl:attribute name="interval">other</xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:variable name="attrValue">
										<xsl:for-each select="$mapPeriod/pair">
											<xsl:choose>
												<xsl:when test="$VFIperiodType=vfiPeriod/@value">
													<xsl:value-of select="period3.3/@value"/>
												</xsl:when>
											</xsl:choose>
										</xsl:for-each>
									</xsl:variable>
									<xsl:attribute name="interval"><xsl:choose><xsl:when test="$attrValue!=''"><xsl:value-of select="$attrValue"/></xsl:when><xsl:otherwise><xsl:value-of select="$VFIperiodType"/></xsl:otherwise></xsl:choose></xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:value-of select="ancestor::t:tlog/t:hdr/vs:period/@periodSeqNum"/>
						</PrimaryReportPeriod>
						<SecondaryReportPeriod>
							<xsl:value-of select="ancestor::t:tlog/t:hdr/seq"/>
						</SecondaryReportPeriod>
						<BusinessDate>
							<xsl:value-of select="ancestor::t:tlog/t:hdr/t:busDate"/>
						</BusinessDate>
						<BeginDate>
							<xsl:value-of select="substring-before(ancestor::t:tlog/t:hdr/startDateTime ,'T')"/>
						</BeginDate>
						<BeginTime>
							<xsl:value-of select="substring(ancestor::t:tlog/t:hdr/startDateTime,12,8)"/>
						</BeginTime>
						<EndDate>
							<xsl:value-of select="substring-before(ancestor::t:tlog/t:hdr/endDateTime,'T')"/>
						</EndDate>
						<EndTime>
							<xsl:value-of select="substring(ancestor::t:tlog/t:hdr/endDateTime,12,8)"/>
						</EndTime>
					</MovementHeader>
					<SalesMovementHeader>
						<RegisterID>
							<xsl:value-of select="hdr/t:register/@sysid"/>
						</RegisterID>
						<CashierID>
							<xsl:value-of select="t:cashier/@sysid"/>
						</CashierID>
						<TillID>
							<xsl:value-of select="hdr/t:register/@till"/>
						</TillID>
						<EmployeeNumber>
							<xsl:value-of select="t:cashier/@number"/>
						</EmployeeNumber>
					</SalesMovementHeader>
					<xsl:for-each select="$fstRegiterID[hdr/t:register/@till=$lngTillID and t:cashier/@sysid=$lngCashierID]">
						<xsl:for-each select="./sum/t:sumTax[count(. | key('taxLevel_key', vs:taxrateBase/@sysid)[1])=1]">
							<xsl:variable name="testParentNode" select="parent::node()/../."/>
							<TLMDetail>
								<TaxLevelID>
									<xsl:value-of select="vs:taxrateBase/@sysid"/>
								</TaxLevelID>
								<MerchandiseCode>
									
								</MerchandiseCode>
								<TaxStrategyID>
									<xsl:value-of select="vs:taxrateBase/@sysid"/>
								</TaxStrategyID>
								<TaxableSalesAmount>
									<xsl:choose>
										<xsl:when test="not($testParentNode[(not(@isRefund) or @isRefund='false')]/sum/t:sumTax/taxable/@currency)">
											<xsl:attribute name="currency">USD</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:choose>
												<xsl:when test="$testParentNode[(not(@isRefund) or @isRefund='false')]/sum/t:sumTax/taxable/@currency=''">
													<xsl:attribute name="currency">other</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="$testParentNode[(not(@isRefund) or @isRefund='false')]/sum/t:sumTax/taxable/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:variable name="taxableSalesAmt" select="sum(//t:sale[(not(@isRefund) or @isRefund='false') and hdr/t:register/@sysid=$lngRegisterID and t:cashier/@sysid=$lngCashierID and hdr/t:register/@till=$lngTillID]/sum/t:sumTax[vs:taxrateBase/@sysid=current()/vs:taxrateBase/@sysid]/taxable)"/>
									<xsl:choose>
										<xsl:when test="$taxableSalesAmt = 0">
											<xsl:value-of select="$taxableSalesAmt"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number($taxableSalesAmt, '##.##')"/>
										</xsl:otherwise>
									</xsl:choose>
								</TaxableSalesAmount>
								<TaxableSalesRefundedAmount>
									<xsl:choose>
										<xsl:when test="not($testParentNode[@isRefund='true']/sum/t:sumTax/taxable/@currency)">
											<xsl:attribute name="currency">USD</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:choose>
												<xsl:when test="$testParentNode[@isRefund='true']/sum/t:sumTax/taxable/@currency=''">
													<xsl:attribute name="currency">other</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="$testParentNode[@isRefund='true']/sum/t:sumTax/taxable/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:variable name="taxableSalesRefundedAmt" select="sum(//t:sale[@isRefund='true' and hdr/t:register/@sysid=$lngRegisterID and t:cashier/@sysid=$lngCashierID and hdr/t:register/@till=$lngTillID]/sum/t:sumTax[vs:taxrateBase/@sysid=current()/vs:taxrateBase/@sysid]/taxable)"/>
									<xsl:choose>
										<xsl:when test="$taxableSalesRefundedAmt = 0">
											<xsl:value-of select="$taxableSalesRefundedAmt"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number($taxableSalesRefundedAmt, '##.##')"/>
										</xsl:otherwise>
									</xsl:choose>
								</TaxableSalesRefundedAmount>
								<TaxCollectedAmount>
									<xsl:choose>
										<xsl:when test="not($testParentNode[(not(@isRefund) or @isRefund='false')]/sum/t:sumTax/amt/@currency)">
											<xsl:attribute name="currency">USD</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:choose>
												<xsl:when test="$testParentNode[(not(@isRefund) or @isRefund='false')]/sum/t:sumTax/amt/@currency=''">
													<xsl:attribute name="currency">other</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="$testParentNode[(not(@isRefund) or @isRefund='false')]/sum/t:sumTax/amt/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:variable name="taxCollectedAmt" select="sum(//t:sale[(not(@isRefund) or @isRefund='false') and hdr/t:register/@sysid=$lngRegisterID and t:cashier/@sysid=$lngCashierID and hdr/t:register/@till=$lngTillID]/sum/t:sumTax[vs:taxrateBase/@sysid=current()/vs:taxrateBase/@sysid]/amt)"/>
									<xsl:choose>
										<xsl:when test="$taxCollectedAmt = 0">
											<xsl:value-of select="$taxCollectedAmt"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number($taxCollectedAmt, '##.##')"/>
										</xsl:otherwise>
									</xsl:choose>
								</TaxCollectedAmount>
								<TaxExemptSalesAmount>
									<xsl:choose>
										<xsl:when test="not($testParentNode[(not(@isRefund) or @isRefund='false')]/lines/t:line/tax[@reversed='true']/taxable/@currency)">
											<xsl:attribute name="currency">USD</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:choose>
												<xsl:when test="$testParentNode[(not(@isRefund) or @isRefund='false')]/lines/t:line/tax[@reversed='true']/taxable/@currency=''">
													<xsl:attribute name="currency">other</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="$testParentNode[(not(@isRefund) or @isRefund='false')]/lines/t:line/tax[@reversed='true']/taxable/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:variable name="taxExemptSalesAmt" select="sum(//t:sale[(not(@isRefund) or @isRefund='false') and hdr/t:register/@sysid=$lngRegisterID and t:cashier/@sysid=$lngCashierID and hdr/t:register/@till=$lngTillID and sum/t:sumTax[vs:taxrateBase/@sysid=current()/vs:taxrateBase/@sysid]]/lines/t:line/tax[@reversed='true']/taxable)"/>
									<xsl:choose>
										<xsl:when test="$taxExemptSalesAmt = 0">
											<xsl:value-of select="$taxExemptSalesAmt"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number($taxExemptSalesAmt, '##.##')"/>
										</xsl:otherwise>
									</xsl:choose>
								</TaxExemptSalesAmount>
								<TaxExemptSalesRefundedAmount>
									<xsl:choose>
										<xsl:when test="not($testParentNode[@isRefund='true']/lines/t:line/tax[@reversed='true']/taxable/@currency)">
											<xsl:attribute name="currency">USD</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:choose>
												<xsl:when test="$testParentNode[@isRefund='true']/lines/t:line/tax[@reversed='true']/taxable/@currency=''">
													<xsl:attribute name="currency">other</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="$testParentNode[@isRefund='true']/lines/t:line/tax[@reversed='true']/taxable/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:variable name="taxExemptSalesRefundedAmt" select="sum(//t:sale[@isRefund='true' and hdr/t:register/@sysid=$lngRegisterID and t:cashier/@sysid=$lngCashierID and hdr/t:register/@till=$lngTillID]/lines/t:line/tax[@reversed='true' and vs:taxrateBase/@sysid=current()/vs:taxrateBase/@sysid]/taxable)"/>
									<xsl:choose>
										<xsl:when test="$taxExemptSalesRefundedAmt = 0">
											<xsl:value-of select="$taxExemptSalesRefundedAmt"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number($taxExemptSalesRefundedAmt, '##.##')"/>
										</xsl:otherwise>
									</xsl:choose>
								</TaxExemptSalesRefundedAmount>
								
								<TaxRefundedAmount>
									<xsl:choose>
										<xsl:when test="not($testParentNode[@isRefund='true']/sum/t:sumTax/amt/@currency)">
											<xsl:attribute name="currency">USD</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:choose>
												<xsl:when test="$testParentNode[@isRefund='true']/sum/t:sumTax/amt/@currency=''">
													<xsl:attribute name="currency">other</xsl:attribute>
												</xsl:when>
												<xsl:otherwise>
													<xsl:attribute name="currency"><xsl:value-of select="$testParentNode[@isRefund='true']/sum/t:sumTax/amt/@currency"/></xsl:attribute>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:variable name="taxRefundedAmt" select="sum(//t:sale[@isRefund='true' and hdr/t:register/@sysid=$lngRegisterID and t:cashier/@sysid=$lngCashierID and hdr/t:register/@till=$lngTillID]/sum/t:sumTax[vs:taxrateBase/@sysid=current()/vs:taxrateBase/@sysid]/amt)"/>
									<xsl:choose>
										<xsl:when test="$taxRefundedAmt = 0">
											<xsl:value-of select="$taxRefundedAmt"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number($taxRefundedAmt, '##.##')"/>
										</xsl:otherwise>
									</xsl:choose>
								</TaxRefundedAmount>
							</TLMDetail>
						</xsl:for-each>
					</xsl:for-each>
				</TaxLevelMovement>
			</xsl:for-each>
		</NAXML-MovementReport>
	</xsl:template>
</xsl:stylesheet>