<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns="http://www.naxml.org/POSBO/Vocabulary/2003-10-16" xmlns:ns="http://verifone.com/isd/vfit/tlog/naxml3.3/buildMSMovement" xmlns:lib="http://verifone.com/isd/vfit/tlog/naxml3.3/MSMovement-lib" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:lists="http://verifone.com/isd/vfit/tlog/lists" version="1.0" exclude-result-prefixes="xsl ext ns lists lib t vs base">
	<xsl:include href="../lists-xalan.xslt"/>
	<xsl:include href="MSMovement-lib-xalan.xslt"/>
	<xsl:param name="ns:driveOff" select="14"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="cashierList">
			<xsl:call-template name="lists:getCashierList">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($inputDoc)/t:tlog"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="movementHeader">
			<xsl:call-template name="lib:createMovementHeader">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($inputDoc)/t:tlog"/>
			</xsl:call-template>
		</xsl:variable>
		<NAXML-MovementReport>
			
			<xsl:call-template name="lib:createTransmissionHeader">
				<xsl:with-param name="siteID" select="ext:nodeset($inputDoc)/t:tlog/t:hdr/vs:site"/>
			</xsl:call-template>
			
			<xsl:apply-templates select="ext:nodeset($inputDoc)/t:tlog/t:startTotals |                ext:nodeset($inputDoc)/t:tlog/t:endTotals" mode="ns:process">
				<xsl:with-param name="movementHeader" select="$movementHeader"/>
			</xsl:apply-templates>
			
			<xsl:apply-templates select="ext:nodeset($cashierList)/t:cashier" mode="ns:process">
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($inputDoc)/t:tlog"/>
				<xsl:with-param name="movementHeader" select="$movementHeader"/>
			</xsl:apply-templates>
		</NAXML-MovementReport>
	</xsl:template>
	
	
	<xsl:template match="* | @* | text()" mode="ns:process"/>
	
	<xsl:template match="t:startTotals | t:endTotals" mode="ns:process">
		<xsl:param name="movementHeader"/>
		<xsl:choose>
			<xsl:when test="local-name() = 'startTotals'">
				
				<MiscellaneousSummaryMovement>
					<xsl:copy-of select="$movementHeader"/>
					<xsl:call-template name="lib:createTotalizersEntry">
						<xsl:with-param name="summaryCode" select="'totalizer'"/>
						<xsl:with-param name="summarySubCode" select="'beginningGrand'"/>
						<xsl:with-param name="amount" select="./overallGrand"/>
					</xsl:call-template>
				</MiscellaneousSummaryMovement>
				
				<MiscellaneousSummaryMovement>
					<xsl:copy-of select="$movementHeader"/>
					<xsl:call-template name="lib:createTotalizersEntry">
						<xsl:with-param name="summaryCode" select="'totalizer'"/>
						<xsl:with-param name="summarySubCode" select="'beginningSales'"/>
						<xsl:with-param name="amount" select="./overallSales"/>
					</xsl:call-template>
				</MiscellaneousSummaryMovement>
			</xsl:when>
			<xsl:otherwise>
				
				<MiscellaneousSummaryMovement>
					<xsl:copy-of select="$movementHeader"/>
					<xsl:call-template name="lib:createTotalizersEntry">
						<xsl:with-param name="summaryCode" select="'totalizer'"/>
						<xsl:with-param name="summarySubCode" select="'endingGrand'"/>
						<xsl:with-param name="amount" select="./overallGrand"/>
					</xsl:call-template>
				</MiscellaneousSummaryMovement>
				
				<MiscellaneousSummaryMovement>
					<xsl:copy-of select="$movementHeader"/>
					<xsl:call-template name="lib:createTotalizersEntry">
						<xsl:with-param name="summaryCode" select="'totalizer'"/>
						<xsl:with-param name="summarySubCode" select="'endingSales'"/>
						<xsl:with-param name="amount" select="./overallSales"/>
					</xsl:call-template>
				</MiscellaneousSummaryMovement>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="t:cashier" mode="ns:process">
		<xsl:param name="movementHeader"/>
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="si" select="./@sysid"/>
		<xsl:variable name="pd" select="./period"/>
		
		<xsl:variable name="cashierData">
			<xsl:call-template name="lib:getCashierData">
				<xsl:with-param name="csh" select="."/>
				<xsl:with-param name="tlogEntrySet" select="ext:nodeset($tlogEntrySet)"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
			
			<xsl:when test="count(ext:nodeset($cashierData)/*) &gt; 0">
				
				<xsl:variable name="registerList">
					<xsl:call-template name="lists:getRegisterList">
						<xsl:with-param name="tlogEntrySet" select="ext:nodeset($cashierData)"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:apply-templates select="ext:nodeset($registerList)/t:register" mode="ns:process">
					<xsl:with-param name="cashierData" select="ext:nodeset($cashierData)"/>
					<xsl:with-param name="movementHeader" select="$movementHeader"/>
					<xsl:with-param name="csh" select="."/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="t:register" mode="ns:process">
		<xsl:param name="csh"/>
		<xsl:param name="movementHeader"/>
		<xsl:param name="cashierData"/>
		<xsl:variable name="c" select="ext:nodeset($csh)"/>
		<xsl:variable name="si" select="./@sysid"/>
		<xsl:variable name="till" select="./@till"/>
		<MiscellaneousSummaryMovement>
			<xsl:copy-of select="$movementHeader"/>
			<xsl:call-template name="lib:createSalesMovementHeader">
				<xsl:with-param name="cshID" select="$c//@sysid"/>
				<xsl:with-param name="empNum" select="$c//@number"/>
				<xsl:with-param name="regID" select="$si"/>
				<xsl:with-param name="tillID" select="$till"/>
			</xsl:call-template>
			
			<xsl:variable name="cshSet">
				<xsl:choose>
					
					<xsl:when test="not($till) and $c//@sysid=0 and not($c//period)">
						<xsl:copy-of select="ext:nodeset($cashierData)/*[(t:cashier/@sysid = $c//@sysid)                        and (hdr/t:register/@sysid = $si)]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="ext:nodeset($cashierData)/*[(t:cashier/@sysid = $c//@sysid)                        and (t:cashier/period = $c//period)                       and (hdr/t:register/@sysid = $si)                       and (hdr/t:register/@till = $till)]"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			
			<xsl:call-template name="lib:createSalesStatisticEntry">
				<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale |                      ext:nodeset($cshSet)//t:void |                      ext:nodeset($cshSet)//t:pumpTest |                      ext:nodeset($cshSet)//t:suspendedSale"/>
				<xsl:with-param name="summaryCode" select="'statistics'"/>
				<xsl:with-param name="summarySubCode" select="'transactions'"/>
			</xsl:call-template>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:tillSafeDrop) &gt; 0">
				<xsl:call-template name="lib:createSafe-PayInOutEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:tillSafeDrop"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'safeDrop'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:tillSafeLoan) &gt; 0">
				<xsl:call-template name="lib:createSafe-PayInOutEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:tillSafeLoan"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'safeLoan'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:tillPayout) &gt; 0">
				<xsl:call-template name="lib:createSafe-PayInOutEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:tillPayout"/>
					<xsl:with-param name="summaryCode" select="'totals'"/>
					<xsl:with-param name="summarySubCode" select="'payouts'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:tillPayin) &gt; 0">
				<xsl:call-template name="lib:createSafe-PayInOutEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:tillPayin"/>
					<xsl:with-param name="summaryCode" select="'totals'"/>
					<xsl:with-param name="summarySubCode" select="'payins'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:tillNosale) &gt; 0">
				<xsl:call-template name="lib:createNoSaleEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:tillNosale"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'noSales'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:sale[@isRefund='true']) &gt; 0">
				<xsl:call-template name="lib:createSalesEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale[@isRefund='true']"/>
					<xsl:with-param name="summaryCode" select="'refunds'"/>
					<xsl:with-param name="summarySubCode" select="'totals'"/>
				</xsl:call-template>
				
				<xsl:call-template name="lib:createSalesStatisticEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale[@isRefund='true']"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'refunds'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:sale[not(@isRefund) and lines/*/priceOverride]) &gt; 0">
				<xsl:call-template name="lib:createPrcOvrEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale[not(@isRefund)]/lines/*[priceOverride]"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'correction'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:sale[not(@isRefund) and lines/*/t:disc]) &gt; 0">
				<xsl:call-template name="lib:createDiscountStatisticEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale[not(@isRefund)]/lines/*[t:disc]"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'discounts'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:void) &gt; 0">
				<xsl:call-template name="lib:createSalesStatisticEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:void"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'voidTransactions'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:suspendedSale) &gt; 0">
				<xsl:call-template name="lib:createSalesStatisticEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:suspendedSale"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'suspends'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:sale[not(@isRefund)]) &gt; 0">
				<xsl:call-template name="lib:createSalesEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale[not(@isRefund)]"/>
					<xsl:with-param name="summaryCode" select="'sales'"/>
					<xsl:with-param name="summarySubCode" select="'totals'"/>
				</xsl:call-template>
				
				<xsl:call-template name="lib:createItemsSoldStatisticEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale[not(@isRefund)]"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'itemsSold'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:sale[paylines/t:payline/t:mop/@cat=$ns:driveOff]) &gt; 0">
				<xsl:call-template name="lib:createDriveOffStatisticEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)//t:sale[paylines/t:payline/t:mop/@cat=$ns:driveOff]"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'driveoffs'"/>
					<xsl:with-param name="mop" select="ext:nodeset($cshSet)//t:sale[1]/paylines/t:payline/t:mop[@cat=$ns:driveOff]"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="count(ext:nodeset($cshSet)//t:sale[sum/t:sumTaxExempt]) &gt; 0">
				<xsl:call-template name="lib:createTaxChangeStatisticEntry">
					<xsl:with-param name="nodeSet" select="ext:nodeset($cshSet)/t:sale[sum/t:sumTaxExempt]"/>
					<xsl:with-param name="summaryCode" select="'statistics'"/>
					<xsl:with-param name="summarySubCode" select="'taxCodeChanges'"/>
				</xsl:call-template>
			</xsl:if>
		</MiscellaneousSummaryMovement>
	</xsl:template>
	
</xsl:stylesheet>