<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:js="javascript:code-transactionSet-scripts" xmlns:dts="javascript:code-transactionSet-dateTimeScripts" xmlns:ns="http://verifone.com/isd/vfit/tlog/naxml3.3/tlog2naxml-lib" xmlns:nsl="http://verifone.com/isd/vfit/tlog/naxml3.3/tlog2naxml-lib.1" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:nax="http://www.naxml.org/POSBO/Vocabulary/2003-10-16" version="1.0" exclude-result-prefixes="xsl ext js ns nsl t dts">
	<xsl:import href="../../transactionSet/scripts.xslt"/>
	<xsl:import href="../../transactionSet/dateTimeScripts.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:debug" select="'false'"/>
	<xsl:param name="ns:currencyMask" select="'#.00'"/>
	<xsl:param name="ns:fuelCurrencyMask" select="'#.000'"/>
	
	<xsl:param name="ns:naxmlPrefs"/>
	
	
	<xsl:template name="ns:group-currency">
		<xsl:param name="amt"/>
		<xsl:param name="mask"/>
		
		<xsl:if test="$amt/@currency">
			<xsl:attribute name="currency"><xsl:value-of select="$amt/@currency"/></xsl:attribute>
		</xsl:if>
		<xsl:variable name="msk">
			<xsl:choose>
				<xsl:when test="not($mask)">
					<xsl:value-of select="$ns:currencyMask"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$mask"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$amt">
				<xsl:value-of select="format-number($amt,$msk)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:group-currency-abs">
		<xsl:param name="amt"/>
		
		<xsl:if test="$amt/@currency">
			<xsl:attribute name="currency"><xsl:value-of select="$amt/@currency"/></xsl:attribute>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$amt">
				<xsl:value-of select="format-number(concat(substring('-', 2 - ($amt &lt;0)),  '1' ) * $amt,'#.00')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="nsl:xlate-volume-uom">
		<xsl:param name="uom"/>
		<xsl:choose>
			<xsl:when test="$uom = 'USG'">
				<xsl:value-of select="'gallonUS'"/>
			</xsl:when>
			<xsl:when test="$uom = 'LITERS'">
				<xsl:value-of select="'liter'"/>
			</xsl:when>
			<xsl:when test="$uom = 'IMPG'">
				<xsl:value-of select="'gallonUK'"/>
			</xsl:when>
			<xsl:when test="$uom = 'PINT'">
				<xsl:value-of select="'pint'"/>
			</xsl:when>
			<xsl:when test="$uom = 'QUART'">
				<xsl:value-of select="'quart'"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="nsl:xlate-weight-uom">
		<xsl:param name="uom"/>
		<xsl:choose>
			<xsl:when test="$uom = 'LB'">
				<xsl:value-of select="'lb'"/>
			</xsl:when>
			<xsl:when test="$uom = 'OZ'">
				<xsl:value-of select="'oz'"/>
			</xsl:when>
			<xsl:when test="$uom = 'KGRAM'">
				<xsl:value-of select="'kg'"/>
			</xsl:when>
			<xsl:when test="$uom = 'GRAM'">
				<xsl:value-of select="'gram'"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="nsl:xlate-quantity-uom">
		<xsl:param name="uom"/>
		<xsl:variable name="vol-uom">
			<xsl:call-template name="nsl:xlate-volume-uom">
				<xsl:with-param name="uom" select="$uom"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="string-length($vol-uom) &gt; 0">
				<xsl:value-of select="$vol-uom"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="weight-uom">
					<xsl:call-template name="nsl:xlate-weight-uom">
						<xsl:with-param name="uom" select="$uom"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="string-length($weight-uom) &gt; 0">
						<xsl:value-of select="$weight-uom"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="$uom = 'EACH'">
								<xsl:value-of select="'each'"/>
							</xsl:when>
							
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:group-volume">
		<xsl:param name="vol"/>
		<xsl:variable name="uom">
			<xsl:call-template name="nsl:xlate-volume-uom">
				<xsl:with-param name="uom" select="$vol/@uom"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:if test="string-length($uom) &gt; 0">
			<xsl:attribute name="uom"><xsl:value-of select="$uom"/></xsl:attribute>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$vol">
				<xsl:value-of select="$vol"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:group-quantity">
		<xsl:param name="qty"/>
		<xsl:variable name="uom">
			<xsl:call-template name="nsl:xlate-quantity-uom">
				<xsl:with-param name="qty" select="$qty"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:if test="string-length($uom) &gt; 0">
			<xsl:attribute name="uom"><xsl:value-of select="$uom"/></xsl:attribute>
		</xsl:if>
		<xsl:value-of select="$qty"/>
	</xsl:template>
	
	<xsl:template name="ns:group-quantity-abs">
		<xsl:param name="qty"/>
		<xsl:variable name="uom">
			<xsl:call-template name="nsl:xlate-quantity-uom">
				<xsl:with-param name="qty" select="$qty"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:if test="string-length($uom) &gt; 0">
			<xsl:attribute name="uom"><xsl:value-of select="$uom"/></xsl:attribute>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$qty">
				<xsl:value-of select="format-number(concat(substring('-', 2 - ($qty &lt;0)),  '1' ) * $qty,'#.00')"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="0"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:xlate-payline">
		<xsl:param name="payline"/>
		<xsl:element name="nax:Tender">
			<xsl:element name="nax:TenderCode">
				<xsl:choose>
				<xsl:when test="ext:node-set($payline)/t:mop/@nacstendercode">
					<xsl:value-of select="ext:node-set($payline)/t:mop/@nacstendercode"/>
				</xsl:when>
				<xsl:otherwise>
						<xsl:value-of select="ext:node-set($payline)/t:mop/@sysid"/>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="nax:TenderSubCode">

				<xsl:choose>
				<xsl:when test="ext:node-set($payline)/t:cardInfo[ccName !='']">
					<xsl:value-of select="ext:node-set($payline)/t:cardInfo/ccName"/>
				</xsl:when>
				<xsl:when test="ext:node-set($payline)/t:mop/@nacstendersubcode">
					<xsl:value-of select="ext:node-set($payline)/t:mop/@nacstendersubcode"/>
				</xsl:when>
				<xsl:otherwise>
						<xsl:value-of select="ext:node-set($payline)/t:mop/@cat"/>
				</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</xsl:element>
	</xsl:template>

	
	<xsl:template name="ns:create-eventDates">
		<xsl:param name="trans"/>
		<xsl:variable name="startDateTime">
			<xsl:choose>
				<xsl:when test="name($trans) = 't:openCashier'">
					<xsl:value-of select="$trans/open"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:countCashier'">
					<xsl:value-of select="$trans/close"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:closeCashier'">
					<xsl:value-of select="$trans/close"/>
				</xsl:when>
				<xsl:when test="starts-with(local-name($trans),'till')">
					<xsl:value-of select="$trans/hdr/dateTime"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:event' and $trans/@type = 'errorCorrect'">
					<xsl:value-of select="$trans/hdr/dateTime"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:clock'">
					<xsl:value-of select="$trans/hdr/dateTime"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:managerWSEvent'">
					<xsl:value-of select="$trans/hdr/dateTime"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>1979-12-31T00:00:00</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="endDateTime">
			<xsl:choose>
				<xsl:when test="name($trans) = 't:openCashier'">
					<xsl:value-of select="$trans/open"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:closeCashier'">
					<xsl:value-of select="$trans/close"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:countCashier'">
					<xsl:value-of select="$trans/close"/>
				</xsl:when>
				<xsl:when test="starts-with(local-name($trans),'till')">
					<xsl:value-of select="dts:incrementDateTime(string($startDateTime),string($trans/duration))"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:event' and $trans/@type = 'errorCorrect'">
					<xsl:value-of select="$startDateTime"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:clock'">
					<xsl:value-of select="$trans/hdr/dateTime"/>
				</xsl:when>
				<xsl:when test="name($trans) = 't:managerWSEvent'">
					<xsl:value-of select="$trans/hdr/dateTime"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>1979-12-31T00:00:00</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:element name="nax:EventStartDate">
			<xsl:value-of select="js:parseDate(string($startDateTime))"/>
		</xsl:element>
		<xsl:element name="nax:EventStartTime">
			<xsl:value-of select="js:parseTime(string($startDateTime))"/>
		</xsl:element>
		<xsl:element name="nax:EventEndDate">
			<xsl:value-of select="js:parseDate(string($endDateTime))"/>
		</xsl:element>
		<xsl:element name="nax:EventEndTime">
			<xsl:value-of select="js:parseTime(string($endDateTime))"/>
		</xsl:element>
		<xsl:element name="nax:BusinessDate">
			<xsl:value-of select="$trans/hdr/t:busDate"/>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>