<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/tlog/buildNetworkJrnl" xmlns:ns1="http://verifone.com/isd/vfit/transactionSet/tlogDoc" xmlns:ns2="http://verifone.com/isd/vfit/tlog/lists" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns ns1 ns2 jsc base">

	<xsl:import href="../lists.xslt"/>
	<xsl:import href="../../transactionSet/scripts.xslt"/>
	
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:dcrRegister" select="'9'"/>
	<xsl:param name="ns:credit">1</xsl:param>
	<xsl:param name="ns:debit">2</xsl:param>
	<xsl:param name="ns:ebtFS">20</xsl:param>
	<xsl:param name="ns:ebtCshBen">21</xsl:param>
	<xsl:param name="ns:storedValue">28</xsl:param>
	<xsl:param name="ns:forcePost">29</xsl:param>


	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
	
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/t:tlog"/>
		<xsl:variable name="header" select="$baseRawSet/t:hdr"/>


		<xsl:variable name="rawCreditSales">
			<xsl:call-template name="ns:getCreditTransactions">
				<xsl:with-param name="tlogEntrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>
		

		<xsl:variable name="allCreditSales">
			<xsl:apply-templates select="ext:node-set($rawCreditSales)/*" mode="ns:ebt"/>
		</xsl:variable>


		<xsl:variable name="final">
			<xsl:element name="t:networkJournal">
				<xsl:copy-of select="$header"/>
				<xsl:element name="cardEntries">
					<xsl:call-template name="ns:buildCreditTransactions">
						<xsl:with-param name="lineSet" select="$allCreditSales"/>
					</xsl:call-template>
				</xsl:element>
			</xsl:element>
		</xsl:variable>
		<xsl:copy-of select="$final"/>
	</xsl:template>

	<xsl:template match="t:event[@type='prepaidCard']" mode="ns:ebt">
		<xsl:variable name="lname" select="name()"/>
		<xsl:element name="{$lname}">
			<xsl:copy-of select="./@*"/>
			<xsl:attribute name="ppdEventType"><xsl:value-of select="ppdFunction/ppdFuncType"/></xsl:attribute>
				
			<xsl:copy-of select="hdr"/>
			
			<xsl:choose>
				<xsl:when test="t:cashier">
					<xsl:copy-of select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="t:cashier">
						<xsl:attribute name="sysid"><xsl:value-of select="'0'"/></xsl:attribute>
						<xsl:attribute name="number"><xsl:value-of select="'0'"/></xsl:attribute>
						<xsl:element name="name">
							<xsl:value-of select="'Prepaid Activity'"/>
						</xsl:element>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:choose>
				<xsl:when test="vs:transaction">
					<xsl:copy-of select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="vs:transaction"/>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:element name="paylines">
				<xsl:element name="t:payline">
					<xsl:element name="t:mop">
						<xsl:attribute name="cat"><xsl:value-of select="$ns:credit"/></xsl:attribute>
					</xsl:element>
					<xsl:element name="amt">
						<xsl:value-of select="ppdFunction/ppdAmount"/>
					</xsl:element>
					
					<xsl:element name="t:cardInfo">

						
						<xsl:element name="acct">
							<xsl:value-of select="ppdFunction/ppdAcctNum"/>
						</xsl:element>
						
						<xsl:element name="ccName">
							<xsl:value-of select="ppdFunction/ppdCardType"/>
						</xsl:element>
						
						<xsl:element name="ticket">
							<xsl:value-of select="ppdFunction/ppdAuthNr"/>
						</xsl:element>
						
						<xsl:element name="batch">
							<xsl:value-of select="ppdFunction/ppdBatchNr"/>
						</xsl:element>
						
						<xsl:element name="seq">
							<xsl:value-of select="ppdFunction/ppdSeqNr"/>
						</xsl:element>


					</xsl:element>
				</xsl:element>				
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template match="t:event[@type='ebtVoucherClear']" mode="ns:ebt">
		<xsl:variable name="lname" select="name()"/>
		<xsl:element name="{$lname}">
			<xsl:copy-of select="./@*"/>
				
			<xsl:copy-of select="hdr"/>
			
			<xsl:choose>
				<xsl:when test="t:cashier">
					<xsl:copy-of select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="t:cashier">
						<xsl:attribute name="sysid"><xsl:value-of select="'0'"/></xsl:attribute>
						<xsl:attribute name="number"><xsl:value-of select="'0'"/></xsl:attribute>
						<xsl:element name="name">
							<xsl:value-of select="'EBT Voucher Clear'"/>
						</xsl:element>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:choose>
				<xsl:when test="vs:transaction">
					<xsl:copy-of select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="vs:transaction"/>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:element name="paylines">
				<xsl:element name="t:payline">
					<xsl:element name="t:mop">
						<xsl:choose>
							<xsl:when test="trPayline/trpPaycode">
								<xsl:attribute name="sysid"><xsl:value-of select="trPayline/trpPaycode/@mop"/></xsl:attribute>
								<xsl:attribute name="cat"><xsl:value-of select="trPayline/trpPaycode/@cat"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="trPayline/trpPaycode"/>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="cat"><xsl:value-of select="$ns:ebtFS"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="'EBT Voucher Clear'"/>
								</xsl:element>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
					<xsl:element name="amt">
						<xsl:value-of select="trPayline/trpAmt"/>
					</xsl:element>
					
					<xsl:if test="trPayline/trpCardInfo">
						<xsl:element name="t:cardInfo">
							
							<xsl:element name="acct">
								<xsl:value-of select="trPayline/trpCardInfo/trpcAccount"/>
							</xsl:element>
							
							<xsl:element name="ccName">
								<xsl:value-of select="trPayline/trpCardInfo/trpcCCName"/>
							</xsl:element>
							
							
							<xsl:if test="trPayline/trpCardInfo/trpcSvcCode">
								<xsl:element name="svcCode">
									<xsl:value-of select="trPayline/trpCardInfo/trpcSvcCode"/>
								</xsl:element>
							</xsl:if>
		
							
							<xsl:element name="exp">
								<xsl:value-of select="trPayline/trpCardInfo/trpcExpire"/>
							</xsl:element>
		
							
							<xsl:element name="hostId">
								<xsl:value-of select="trPayline/trpCardInfo/trpcHostID"/>
							</xsl:element>
		
							
							<xsl:element name="auth">
								<xsl:value-of select="trPayline/trpCardInfo/trpcAuthCode"/>
							</xsl:element>
							
							
							<xsl:if test="trPayline/trpCardInfo/trpcTicket">
								<xsl:element name="ticket">
									<xsl:value-of select="trPayline/trpCardInfo/trpcTicket"/>
								</xsl:element>
							</xsl:if>
							
							
							<xsl:element name="entryMeth">
								<xsl:attribute name="type">
									<xsl:choose>
										<xsl:when test="trPayline/trpCardInfo/trpcImprint">
											<xsl:value-of select="'imprint'"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="jsc:xlateCardEntry(string(trPayline/trpCardInfo/trpcEntryMeth))"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:attribute>
								<xsl:value-of select="trPayline/trpCardInfo/trpcEntryMeth"/>
							</xsl:element>
							
							
							<xsl:element name="authSrc">
								<xsl:variable name="authSrc" select="trPayline/trpCardInfo/trpcAuthSrc"/>
								<xsl:choose>
									<xsl:when test="$authSrc = 'I'">
										<xsl:text>interchange</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'H'">
										<xsl:text>host</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'T'">
										<xsl:text>terminal</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'V'">
										<xsl:text>voice</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'N'">
										<xsl:text>negFile</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'P'">
										<xsl:text>posFile</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'L'">
										<xsl:text>localNegFile</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'X'">
										<xsl:text>simulator</xsl:text>
									</xsl:when>
									<xsl:when test="$authSrc = 'A'">
										<xsl:text>authTable</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<xsl:text>ebtVoucherClear</xsl:text>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:element>
							
							
							<xsl:element name="batch">
								<xsl:value-of select="trPayline/trpCardInfo/trpcBatchNr"/>
							</xsl:element>
							
							
							<xsl:element name="seq">
								<xsl:value-of select="trPayline/trpCardInfo/trpcSeqNr"/>
							</xsl:element>
		
							
							<xsl:element name="ref">
								<xsl:value-of select="trPayline/trpCardInfo/trpcRefNum"/>
							</xsl:element>
							
							
							<xsl:element name="merchId">
								<xsl:value-of select="trPayline/trpCardInfo/trpcMerchInfo/trpcmMerchID"/>
							</xsl:element>
							
							
							<xsl:element name="termId">
								<xsl:value-of select="trPayline/trpCardInfo/trpcMerchInfo/trpcmTermID"/>
							</xsl:element>
						</xsl:element>
					</xsl:if>
				</xsl:element>				
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template match="t:sale | t:adjustment" mode="ns:ebt">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<xsl:template match="@* | text()" mode="ns:ebt"/>
	
	<xsl:template name="ns:getCreditTransactions">
		<xsl:param name="tlogEntrySet"/>
		<xsl:variable name="ns-set" select="ext:node-set($tlogEntrySet)"/>
		<xsl:copy-of select="$ns-set/*/paylines/*[t:mop/@cat = $ns:credit or t:mop/@cat = $ns:debit or t:mop/@cat = $ns:ebtFS or t:mop/@cat = $ns:ebtCshBen or t:mop/@cat = $ns:storedValue or t:mop/@cat = $ns:forcePost]/../.. |           $ns-set/t:event[@type='ebtVoucherClear' or @type='prepaidCard']"/>
	</xsl:template>
	
	<xsl:template name="ns:buildCreditTransactions">
		<xsl:param name="lineSet"/>
		<xsl:variable name="ns-lineSet" select="ext:node-set($lineSet)"/>
			<xsl:for-each select="$ns-lineSet/*">
				<xsl:element name="cardEntry">
					<xsl:attribute name="DCR">
						<xsl:choose>
							<xsl:when test="./hdr/t:register[@sysid = $ns:dcrRegister]">
								 <xsl:value-of select="'true'"/>
							</xsl:when>
							<xsl:otherwise>
								 <xsl:value-of select="'false'"/>						
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="EBT">
						<xsl:choose>
							<xsl:when test="./paylines/*[t:mop/@cat = $ns:ebtFS or t:mop/@cat = $ns:ebtCshBen]">
								 <xsl:value-of select="'true'"/>
							</xsl:when>
							<xsl:otherwise>
								 <xsl:value-of select="'false'"/>						
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="PPD">
						<xsl:choose>
							<xsl:when test="./@ppdEventType">
								<xsl:value-of select="./@ppdEventType"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'none'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>


					<xsl:copy-of select="./paylines/*[t:mop/@cat = $ns:credit or t:mop/@cat = $ns:debit or t:mop/@cat = $ns:ebtFS or t:mop/@cat = $ns:ebtCshBen or t:mop/@cat = $ns:storedValue or t:mop/@cat = $ns:forcePost]/t:cardInfo"/>

					<xsl:copy-of select="./hdr/dateTime"/>

					<xsl:copy-of select="./vs:transactionSeq"/>

					<xsl:copy-of select="./hdr/t:register"/>

					<xsl:copy-of select="./t:cashier"/>

					<xsl:copy-of select="./paylines/*[t:mop/@cat = $ns:credit or t:mop/@cat = $ns:debit or t:mop/@cat = $ns:ebtFS or t:mop/@cat = $ns:ebtCshBen or t:mop/@cat = $ns:storedValue or t:mop/@cat = $ns:forcePost]/amt"/>
				</xsl:element>
			</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>