<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="http://xml.apache.org/xalan" xmlns:ns="http://verifone.com/isd/vfit/transSet/buildFuelTaxExempt" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0" exclude-result-prefixes="xsl ext ns xsi">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:nodeset($inputDoc)/transSet"/>
		
		<xsl:variable name="rawFte">
			<xsl:copy-of select="$baseRawSet/*/trLines/trLine/trlFuel/trlFuelTaxExemption"/>
		</xsl:variable>
		<xsl:variable name="fteList">
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:nodeset($rawFte)/*">
					<xsl:sort order="ascending" select="sysid" data-type="number"/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="ext:nodeset($sortedList)/trlFuelTaxExemption[not(sysid = preceding-sibling::trlFuelTaxExemption[1]/sysid)]/sysid"/>
		</xsl:variable>
		
		<xsl:variable name="rawFteAdd">
			<xsl:copy-of select="$baseRawSet/*/trLines/trLine/trlFuel/trlFuelTaxAddition"/>
		</xsl:variable>
		<xsl:variable name="fteAddList">
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:nodeset($rawFteAdd)/*">
					<xsl:sort order="ascending" select="sysid" data-type="number"/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="ext:nodeset($sortedList)/trlFuelTaxAddition[not(sysid = preceding-sibling::trlFuelTaxAddition[1]/sysid)]/sysid"/>
		</xsl:variable>

		
		<xsl:variable name="rawFteAddDept">
			<xsl:copy-of select="$baseRawSet/trans[ (@type='sale' or @type='network sale') and (not(@suspended) or @suspended ='false') ]/trLines/trLine/trlFuel/trlFuelTaxAdditionByDept"/>
		</xsl:variable>
		<xsl:variable name="fteAddDeptList">
			<xsl:variable name="sortedList">
				<xsl:for-each select="ext:nodeset($rawFteAddDept)/*">
					<xsl:sort order="ascending" select="sysid" data-type="number"/>
					<xsl:copy-of select="."/>
				</xsl:for-each>
			</xsl:variable>
			<xsl:copy-of select="ext:nodeset($sortedList)/trlFuelTaxAdditionByDept[not(sysid = preceding-sibling::trlFuelTaxAdditionByDept[1]/sysid)]/sysid"/>
		</xsl:variable>

		
		<t:fuelTaxExemption>
			<xsl:element name="t:hdr">
				<xsl:variable name="isCurrent" select="$baseRawSet/@longId='CURRENT'"/>
				<xsl:element name="vs:period">
					<xsl:attribute name="sysid">
						<xsl:choose>
							<xsl:when test="$isCurrent">
								<xsl:value-of select="'1'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'2'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</xsl:element>
				<xsl:element name="vs:site">
					<xsl:attribute name="locationId"><xsl:value-of select="$baseRawSet/@locationId"/></xsl:attribute>
					<xsl:value-of select="$baseRawSet/@site"/>
				</xsl:element>
				<xsl:element name="startDateTime">
					<xsl:choose>
						<xsl:when test="$isCurrent">
							<xsl:value-of select="$baseRawSet/trans[ @type = 'journal' ][1]/trHeader/date"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$baseRawSet/openedTime"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="endDateTime">
					<xsl:choose>
						<xsl:when test="$isCurrent">
							<xsl:value-of select="'PENDING'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$baseRawSet/closedTime"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:element>
			<xsl:for-each select="ext:nodeset($fteList)/sysid">
				<xsl:variable name="curSysid" select="."/>				
				<xsl:element name="trlFuelTaxExemption">
					<xsl:element name="sysid">
						<xsl:value-of select="$curSysid"/>
					</xsl:element>
					<xsl:element name="desc">
						<xsl:value-of select="ext:nodeset($rawFte)/*[sysid=$curSysid]/description"/>
					</xsl:element>
					<xsl:element name="count">
						<xsl:value-of select="count(ext:nodeset($rawFte)/*[sysid=$curSysid])"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:value-of select="format-number(sum(ext:nodeset($rawFte)/*[sysid=$curSysid]/amount | ext:nodeset($rawFte)/*[sysid=$curSysid]/amt),'0.00')"/>
					</xsl:element>
					<xsl:element name="volume">
						<xsl:value-of select="format-number(sum(ext:nodeset($rawFte)/*[sysid=$curSysid]/volume),'0.000')"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
			<xsl:for-each select="ext:nodeset($fteAddList)/sysid">
				<xsl:variable name="curSysid" select="."/>
				<xsl:element name="trlFuelTaxAddition">
					<xsl:element name="sysid">
						<xsl:value-of select="$curSysid"/>
					</xsl:element>
					<xsl:element name="desc">
						<xsl:value-of select="ext:nodeset($rawFteAdd)/*[sysid=$curSysid]/description"/>
					</xsl:element>
					<xsl:element name="count">
						<xsl:value-of select="count(ext:nodeset($rawFteAdd)/*[sysid=$curSysid])"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:value-of select="format-number(sum(ext:nodeset($rawFteAdd)/*[sysid=$curSysid]/amount | ext:nodeset($rawFteAdd)/*[sysid=$curSysid]/amt),'0.00')"/>
					</xsl:element>
					<xsl:element name="volume">
						<xsl:value-of select="format-number(sum(ext:nodeset($rawFteAdd)/*[sysid=$curSysid]/volume),'0.000')"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>
			<xsl:for-each select="ext:nodeset($fteAddDeptList)/sysid">
				<xsl:variable name="curSysid" select="."/>				
				<xsl:element name="trlFuelTaxAdditionByDept">
					<xsl:element name="sysid">
						<xsl:value-of select="$curSysid"/>
					</xsl:element>
					<xsl:element name="desc">
						<xsl:value-of select="ext:nodeset($rawFteAddDept)/*[sysid=$curSysid]/description"/>
					</xsl:element>
					<xsl:element name="count">
						<xsl:value-of select="count(ext:nodeset($rawFteAddDept)/*[sysid=$curSysid])"/>
					</xsl:element>
					<xsl:element name="amount">
						<xsl:value-of select="format-number(sum(ext:nodeset($rawFteAddDept)/*[sysid=$curSysid]/amount | ext:nodeset($rawFteAddDept)/*[sysid=$curSysid]/amt),'0.00')"/>
					</xsl:element>
					<xsl:element name="volume">
						<xsl:value-of select="format-number(sum(ext:nodeset($rawFteAddDept)/*[sysid=$curSysid]/volume),'0.000')"/>
					</xsl:element>
				</xsl:element>
			</xsl:for-each>

		</t:fuelTaxExemption>
	</xsl:template>
</xsl:stylesheet>