<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ext="urn:schemas-microsoft-com:xslt" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:ns="http://verifone.com/isd/vfit/transSet/buildLoyaltyTransDetail" version="1.0" exclude-result-prefixes="xsl ext ns xsi">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>


	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		<xsl:variable name="baseRawSet" select="ext:node-set($inputDoc)/transSet"/>
		
		<xsl:variable name="fpList">
			<xsl:call-template name="ns:fuelProdList">
				<xsl:with-param name="entrySet" select="$baseRawSet"/>
			</xsl:call-template>
		</xsl:variable>

		
		<xsl:variable name="rawLoyTxFirstPass">
			<xsl:variable name="raw">
				<xsl:copy-of select="$baseRawSet/*[trLoyalty]"/>
			</xsl:variable>
			<xsl:apply-templates select="ext:node-set($raw)" mode="ns:replaceGrade">
				<xsl:with-param name="fp-list" select="ext:node-set($fpList)"/>
			</xsl:apply-templates>
		</xsl:variable>

		<xsl:variable name="rawLoyTx">
			<xsl:copy-of select="ext:node-set($rawLoyTxFirstPass)/*"/>
		</xsl:variable>

		
		<t:loyaltyTotals>
				<xsl:variable name="isCurrent" select="$baseRawSet/@longId='CURRENT'"/>
				<xsl:variable name="periodType" select="$baseRawSet/@periodID"/>
				<xsl:variable name="seq">
					<xsl:choose>
						<xsl:when test="$isCurrent">
							<xsl:value-of select="$baseRawSet/trans[ @type = 'journal' ][1]/trHeader/period[@level = $periodType]/@seq"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$baseRawSet/@shortId"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:element name="vs:period">
					<xsl:attribute name="sysid">
						<xsl:choose>
							<xsl:when test="$isCurrent">
								<xsl:value-of select="'1'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'2'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="periodEndDate">
						<xsl:choose>
							<xsl:when test="$isCurrent">
								<xsl:value-of select="'PENDING'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="$baseRawSet/closedTime"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:attribute name="periodSeqNum"> 
						<xsl:value-of select="$seq"/>
					</xsl:attribute>
					<xsl:choose>
						<xsl:when test="$periodType = '1'">
							<xsl:attribute name="periodType"><xsl:text>SHIFT</xsl:text></xsl:attribute>
						</xsl:when>
						<xsl:when test="$periodType = '2'">
							<xsl:attribute name="periodType"><xsl:text>DAY</xsl:text></xsl:attribute>
						</xsl:when>
					</xsl:choose>
					<xsl:attribute name="periodBeginDate">
							<xsl:value-of select="$baseRawSet/openedTime"/>
					</xsl:attribute>
					<xsl:attribute name="name"> 
						<xsl:value-of select="$baseRawSet/@periodname"/>
					</xsl:attribute>
				</xsl:element>
				
				<xsl:element name="vs:site">
					<xsl:value-of select="$baseRawSet/@site"/>
				</xsl:element>
				<loyaltyDetailTotals>
					<xsl:apply-templates select="ext:node-set($rawLoyTx)/*" mode="ns:loyal">
						<xsl:with-param name="periodType" select="$periodType"/>
					</xsl:apply-templates> 
				</loyaltyDetailTotals>
			</t:loyaltyTotals>
	</xsl:template>
	<xsl:template match="/ | * | @* | text()" mode="ns:replaceGrade">
		<xsl:param name="fp-list"/>
			<xsl:copy>
				<xsl:apply-templates select="* | @* | text()" mode="ns:replaceGrade">
					<xsl:with-param name="fp-list" select="ext:node-set($fp-list)"/>
				</xsl:apply-templates>
			</xsl:copy>
	</xsl:template>
	
	<xsl:template match="grade" mode="ns:replaceGrade">
		<xsl:param name="fp-list"/>
			<xsl:variable name="fp" select="ext:node-set($fp-list)"/>
			<xsl:variable name="curSysid" select="."/>
			<grade><xsl:value-of select="$fp//fuelProd[@sysid = $curSysid]"/></grade>
	</xsl:template>
	<xsl:template name="ns:fuelProdList">
		<xsl:param name="entrySet"/>
		<xsl:variable name="rawList">
			<xsl:copy-of select="ext:node-set($entrySet)//fuelProd"/>
		</xsl:variable>
		<xsl:variable name="sortedList">
			<xsl:for-each select="ext:node-set($rawList)/fuelProd">
				<xsl:sort data-type="number" select="@sysid"/>
				<xsl:copy-of select="."/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="ext:node-set($sortedList)/fuelProd[ not(./@sysid = preceding-sibling::fuelProd[1]/@sysid)]"/>
	</xsl:template>
	<xsl:template match="trans" mode="ns:loyal">
		<xsl:param name="periodType"/>
		<xsl:if test="@type  != 'void' and @type != 'network preauth'">
		<loyaltyDetail>
			<xsl:call-template name="ns:cashierElem">
				<xsl:with-param name="periodType" select="$periodType"/>
			</xsl:call-template>
			<xsl:element name="TXTime">
					<xsl:value-of select="trHeader/date"/>
			</xsl:element>
			<xsl:element name="TXNumber">
				<xsl:choose>
					<xsl:when test="trHeader/trTickNum">
						<xsl:value-of select="trHeader/trTickNum/trSeq"/>		
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="0"/>					
					</xsl:otherwise>
				</xsl:choose>					
			</xsl:element>
			
			<xsl:element name="totalDiscAmt">
				<xsl:value-of select="format-number(sum(trLoyalty/trloAutoDisc | trLoyalty/trloCustDisc | trLoyalty/trloLnItemTotDisc | trLoyalty/trloPPGDisc/PPGTotDisc),'0.00')"/>
			</xsl:element>
			
			<xsl:element name="accountNumber">
					<xsl:value-of select="trLoyalty/trloAccount"/>
			</xsl:element>
			
			<xsl:element name="refundFlag">
					<xsl:value-of select="trLoyalty/trloRefundFlg"/>
			</xsl:element>
			
			<xsl:element name="ticketTotal">
					<xsl:value-of select="trLoyalty/trloSubTotal"/>
			</xsl:element>
			
			<xsl:element name="automaticDiscAmt">
					<xsl:value-of select="trLoyalty/trloAutoDisc"/>
			</xsl:element>
			
			<xsl:element name="custAuthDiscAmt">
					<xsl:value-of select="trLoyalty/trloCustDisc"/>
			</xsl:element>
			
			<xsl:if test="trLoyalty/trloTaxCredTot">
				<xsl:element name="taxCreditAmt">
						<xsl:value-of select="trLoyalty/trloTaxCredTot"/>
				</xsl:element>
			</xsl:if>
			
			<xsl:if test="trLoyalty/trloLnItemTotDisc">
				<xsl:element name="lineItemDiscAmt">
						<xsl:value-of select="trLoyalty/trloLnItemTotDisc"/>
				</xsl:element>
			</xsl:if>
			
			<xsl:if test="trLoyalty/trloLnItemDiscs">
				<xsl:for-each select="trLoyalty/trloLnItemDiscs/trloLnItemDisc">
					<xsl:variable name="lineNumber">
						<xsl:value-of select="number(@lineID)"/>
					</xsl:variable>
					<xsl:element name="lineItemDiscDetail">
						<xsl:variable name="isFuel">
							<xsl:choose> 
								<xsl:when test="ancestor::*[3]/trLines/trLine[position()=$lineNumber]/@type= 'preFuel' or ancestor::*[3]/trLines/trLine[position()=$lineNumber]/trlFuel">
									<xsl:value-of select="'true'"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'false'"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:attribute name="isFuel">
							<xsl:value-of select="$isFuel"/>
						</xsl:attribute>
						
						<xsl:element name="discAmt">
							<xsl:value-of select="discAmt"/>
						</xsl:element>
						
						<xsl:element name="qty">
							<xsl:value-of select="qty"/>
						</xsl:element>
						
						
						
						<xsl:choose> 
							<xsl:when test="ancestor::*[3]/trLines/trLine[position()=$lineNumber]/trlUPC">
								<xsl:element name="loyUPC">
									<xsl:value-of select="ancestor::*[3]/trLines/trLine[position()=$lineNumber]/trlUPC"/>				
								</xsl:element>
								
								<xsl:element name="loyModfr">
									<xsl:value-of select="ancestor::*[3]/trLines/trLine[position()=$lineNumber]/trlModifier"/>
								</xsl:element>
							</xsl:when>
							<xsl:when test="$isFuel = 'true'">
								<xsl:element name="loyUPC">
									<xsl:value-of select="'FUEL'"/>				
								</xsl:element>
								<xsl:element name="loyModfr">
									<xsl:value-of select="0"/>				
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:element name="loyUPC">
									<xsl:value-of select="'DEPARTMENT'"/>				
								</xsl:element>
								<xsl:element name="loyModfr">
									<xsl:value-of select="0"/>				
								</xsl:element>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
				</xsl:for-each>
			</xsl:if>
			
			<xsl:if test="trLoyalty/trloPPGDisc">
				<xsl:element name="ppgDiscDetail">
					<xsl:attribute name="fuelPosition">
						<xsl:value-of select="trLoyalty/trloPPGDisc/PPGFPosition"/>
					</xsl:attribute>
					<xsl:choose>
						<xsl:when test="trLoyalty/trloPPGDisc/PPGEntryType = 1">
							<xsl:attribute name="isOverrun">
									<xsl:value-of select="'true'"/>
							</xsl:attribute>
						</xsl:when>
						<xsl:when test="trLoyalty/trloPPGDisc/PPGEntryType = 2">
							<xsl:attribute name="isUnderrun">
									<xsl:value-of select="'true'"/>
							</xsl:attribute>
						</xsl:when>
					</xsl:choose>
					<xsl:element name="grade">
						<xsl:value-of select="trLoyalty/trloPPGDisc/grade"/>
					</xsl:element>
					<xsl:element name="PPGVol">
						<xsl:value-of select="format-number(trLoyalty/trloPPGDisc/PPGVol,'0.000')"/>
					</xsl:element>
					<xsl:element name="PPGTotDisc">
						<xsl:value-of select="format-number(trLoyalty/trloPPGDisc/PPGTotDisc,'0.00')"/>
					</xsl:element>
					<xsl:element name="PPGOrgPrice">
						<xsl:value-of select="format-number(trLoyalty/trloPPGDisc/PPGOrgPrice,'0.000')"/>
					</xsl:element>
					<xsl:element name="PPGGalDisc">
						<xsl:value-of select="format-number(trLoyalty/trloPPGDisc/PPGGalDisc,'0.000')"/>
					</xsl:element>	
					<xsl:if test="trLoyalty/trloPPGDisc/PPGOrigTXNum != 0">
						<xsl:element name="PPGOrigTXNum">
							<xsl:value-of select="trLoyalty/trloPPGDisc/PPGOrigTXNum"/>
						</xsl:element>	
					</xsl:if>					
				</xsl:element> 
			</xsl:if>		
			
			<xsl:if test="trLoyalty/trloAutoDisc != 0 or trLoyalty/trloCustDisc != 0">
				<xsl:for-each select="trLines/trLine[@type = 'postFuel']">		
					<xsl:element name="postFuelDetails">
						<xsl:attribute name="fuelPosition">
							<xsl:value-of select="trlFuel/fuelPosition"/>
						</xsl:attribute>
						<xsl:element name="grade">
							<xsl:value-of select="trlFuel/fuelProd"/>
						</xsl:element>
						<xsl:element name="PostFuelVol">
							<xsl:value-of select="trlFuel/fuelVolume"/>
						</xsl:element>
						<xsl:element name="PostFuelPrice">
							<xsl:value-of select="trlUnitPrice"/>
						</xsl:element>
						<xsl:element name="PostFuelAmt">
							<xsl:value-of select="trlLineTot"/>
						</xsl:element>						
					</xsl:element> 
				</xsl:for-each>			
			</xsl:if>	
			
			<xsl:if test="trLoyalty/trloFuelLimit">
				<xsl:element name="loyFuelLimits">
						<xsl:value-of select="trLoyalty/trloFuelLimit"/>
				</xsl:element>
			</xsl:if>		
			<xsl:element name="loyAuthReply">
				<xsl:value-of select="trLoyalty/trloAuthReply"/>
			</xsl:element>
		</loyaltyDetail>		
		</xsl:if>
	</xsl:template>

	
	<xsl:template match="* | @* | text()" mode="ns:loyal"/>
	
	
	<xsl:template name="ns:cashierElem">
		<xsl:param name="periodType"/>
		<xsl:variable name="regNum">
			<xsl:value-of select="trHeader/trTickNum/posNum"/>
		</xsl:variable>
		<xsl:choose>
			
			<xsl:when test="$regNum &gt; 900 or trLines/trLine/@type = 'preFuelCompletion'">
				<xsl:element name="cashier">
					<xsl:attribute name="sysid"><xsl:value-of select="'0'"/></xsl:attribute>
					<xsl:attribute name="empNum"><xsl:value-of select="'0'"/></xsl:attribute>
					<xsl:attribute name="posNum"><xsl:value-of select="'9'"/></xsl:attribute>
					<xsl:attribute name="period"><xsl:value-of select="$periodType"/></xsl:attribute>
					<xsl:value-of select="'Automatic Fuel'"/>
				</xsl:element>
			</xsl:when>
			
			<xsl:when test="trHeader/cashier">
				<xsl:element name="cashier">
					<xsl:attribute name="sysid"><xsl:value-of select="trHeader/cashier/@sysid"/></xsl:attribute>
					<xsl:if test="boolean(trHeader/cashier/@empNum)">
						<xsl:attribute name="empNum"><xsl:value-of select="trHeader/cashier/@empNum"/></xsl:attribute>
					</xsl:if>
					<xsl:attribute name="posNum"><xsl:value-of select="trHeader/trTickNum/posNum"/></xsl:attribute>
					<xsl:attribute name="period"><xsl:value-of select="$periodType"/></xsl:attribute>
					<xsl:value-of select="trHeader/cashier"/>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	


</xsl:stylesheet>