<?xml version="1.0" encoding="UTF-8"?><xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:ns="http://verifone.com/isd/vfit/transSet/tlogSet" xmlns:nsc="http://verifone.com/isd/vfit/transactionSet/scripts" xmlns:jsc="javascript:code-transactionSet-scripts" xmlns:base="urn:vfi-sapphire:base.2001-10-01" xmlns:vs="urn:vfi-sapphire:vs.2001-10-01" xmlns:t="urn:vfi-sapphire:tlog.2003-06-27" version="1.0" exclude-result-prefixes="xsl msxsl ns nsc jsc">
	<xsl:import href="../transactionSet/scripts.xslt"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:param name="ns:dcrRegister" select="'9'"/>
	<xsl:param name="ns:minOutdoorRegister" select="'401'"/>
	<xsl:param name="ns:currencyMask" select="'#.00'"/>
	<xsl:param name="ns:fuelCurrencyMask" select="'#.000'"/>
	<xsl:param name="ns:uomMask" select="'#.000'"/>
	
	<xsl:param name="ns:debitCat" select="2"/>
	
	<xsl:template match="/">
		<xsl:call-template name="ns:main">
			<xsl:with-param name="inputDoc" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:main">
		<xsl:param name="inputDoc"/>
		
		<xsl:variable name="site" select="$inputDoc/transSet/@site"/>
		<xsl:variable name="locationId" select="$inputDoc/transSet/@locationId"/>
		<xsl:variable name="periodType" select="$inputDoc/transSet/@periodID"/>
		<xsl:variable name="isCurrentPeriod" select="$inputDoc/transSet/@longId = 'CURRENT'"/>
		<xsl:variable name="busDate">
			<xsl:choose>
				<xsl:when test="$isCurrentPeriod">
					<xsl:value-of select="jsc:parseDate(string($inputDoc/transSet/trans[ @type = 'journal' ][1]/trHeader/date))"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="jsc:parseDate(string($inputDoc/transSet/@longId))"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="seq">
			<xsl:choose>
				<xsl:when test="$isCurrentPeriod">
					<xsl:value-of select="$inputDoc/transSet/trans[ @type = 'journal' ][1]/trHeader/period[@level = $periodType]/@seq"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$inputDoc/transSet/@shortId"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="startDateTime">
			<xsl:choose>
				<xsl:when test="$isCurrentPeriod">
					<xsl:value-of select="$inputDoc/transSet/trans[ @type = 'journal' ][1]/trHeader/date"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$inputDoc/transSet/openedTime"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="endDateTime">
			<xsl:if test="not($isCurrentPeriod)">
				<xsl:value-of select="$inputDoc/transSet/closedTime"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="tlogHeader">
			<xsl:call-template name="ns:tlogHeaderType">
				<xsl:with-param name="inputDoc" select="$inputDoc"/>
				<xsl:with-param name="site" select="$site"/>
				<xsl:with-param name="locationID" select="$locationId"/>
				<xsl:with-param name="periodType" select="$periodType"/>
				<xsl:with-param name="busDate" select="$busDate"/>
				<xsl:with-param name="seq" select="$seq"/>
				<xsl:with-param name="startDateTime" select="$startDateTime"/>
				<xsl:with-param name="endDateTime" select="$endDateTime"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:element name="t:hdr">
			<xsl:copy-of select="$tlogHeader"/>
		</xsl:element>
		<xsl:call-template name="ns:transactionProc">
			<xsl:with-param name="inputDoc" select="$inputDoc"/>
			<xsl:with-param name="tlogHeader" select="$tlogHeader"/>
			<xsl:with-param name="site" select="$site"/>
			<xsl:with-param name="busDate" select="$busDate"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="ns:tlogHeaderType">
		<xsl:param name="inputDoc"/>
		<xsl:param name="site"/>
		<xsl:param name="locationID"/>
		<xsl:param name="periodType"/>
		<xsl:param name="busDate"/>
		<xsl:param name="seq"/>
		<xsl:param name="startDateTime"/>
		<xsl:param name="endDateTime"/>
		<xsl:element name="vs:period">
			<xsl:attribute name="sysid"><xsl:value-of select="$periodType"/></xsl:attribute>
			
            <xsl:choose>
                <xsl:when test="$inputDoc/transSet/@shortId">
                    <xsl:attribute name="periodSeqNum"><xsl:value-of select="$inputDoc/transSet/@shortId"/></xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:attribute name="periodSeqNum"><xsl:value-of select="$seq"/></xsl:attribute>
                </xsl:otherwise>
            </xsl:choose>
			<xsl:choose>
				<xsl:when test="$periodType = '1'">
					<xsl:attribute name="periodType"><xsl:text>SHIFT</xsl:text></xsl:attribute>
				</xsl:when>
				<xsl:when test="$periodType = '2'">
					<xsl:attribute name="periodType"><xsl:text>DAY</xsl:text></xsl:attribute>
				</xsl:when>
			</xsl:choose>
		</xsl:element>
		<xsl:element name="t:busDate">
			<xsl:value-of select="$busDate"/>
		</xsl:element>
		<xsl:element name="seq">
			<xsl:value-of select="$seq"/>
		</xsl:element>
		<xsl:element name="vs:site">
			<xsl:if test="$locationID!=' '">
				<xsl:attribute name="locationId"><xsl:value-of select="$locationID"/></xsl:attribute>
			</xsl:if>
			<xsl:value-of select="$site"/>
		</xsl:element>
		<xsl:element name="startDateTime">
			<xsl:value-of select="$startDateTime"/>
		</xsl:element>
		<xsl:if test="string-length($endDateTime) &gt; 0">
			<xsl:element name="endDateTime">
				<xsl:value-of select="$endDateTime"/>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="ns:transactionProc">
		<xsl:param name="inputDoc"/>
		<xsl:param name="tlogHeader"/>
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:for-each select="$inputDoc/transSet/*">
			<xsl:choose>
				<xsl:when test="local-name() = 'startTotals' or local-name() = 'endTotals'">
					<xsl:call-template name="ns:totalsProc">
						<xsl:with-param name="tlogHeader" select="$tlogHeader"/>
						<xsl:with-param name="site" select="$site"/>
						<xsl:with-param name="busDate" select="$busDate"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="local-name() = 'openCashier' or local-name() = 'closeCashier' or local-name() = 'printCashier'">
					<xsl:call-template name="ns:cashierProc">
						<xsl:with-param name="site" select="$site"/>
						<xsl:with-param name="busDate" select="$busDate"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="local-name() = 'mwsMgrCorrectionEvent' or local-name() = 'mwsMgrAcceptedEvent' or local-name() = 'mwsMgrAdjustmentEvent' or local-name() = 'mwsMgrVerifiedCsrPds' or local-name() = 'mwsMgrFinalizeEvent' or local-name() = 'mwsMgrReviewEvent'">
					<xsl:call-template name="ns:mwsEventsProc">
						<xsl:with-param name="mwsEventName" select="local-name()"/>
						<xsl:with-param name="eventType" select="@type"/>
						<xsl:with-param name="site" select="$site"/>
						<xsl:with-param name="busDate" select="$busDate"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="local-name() = 'trans'">
					<xsl:choose>
						
						<xsl:when test="@type = 'sale' or                                  @type = 'refund sale' or                                 @type = 'network sale' or                                 @type = 'refund network sale' or                                 @type = 'void' or                                 @type = 'refund void' or                                 @type = 'suspended sale' or                                 @type = 'suspended network sale' or                                 @type = 'claimed sale' or                                 @type = 'transferred sale' or                                 @type = 'pumptest' or                                 @type = 'autocollect' or                                 @type = 'kioskOrder' or                                 @type = 'kioskOrder void'                                                                 ">
							<xsl:call-template name="ns:saleProc">
								<xsl:with-param name="site" select="$site"/>
								<xsl:with-param name="busDate" select="$busDate"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="@type = 'payin' or                                  @type = 'payout' or                                  @type = 'safedrop' or                                  @type = 'safeloan' or                                  @type = 'nosale' or                                 @type = 'safedropcorrection'                                 ">
							<xsl:call-template name="ns:tillTransactionProc">
								<xsl:with-param name="site" select="$site"/>
								<xsl:with-param name="busDate" select="$busDate"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="@type='clock'">
							<xsl:call-template name="ns:clockProc">
								<xsl:with-param name="site" select="$site"/>
								<xsl:with-param name="busDate" select="$busDate"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="@type = 'journal' or @type='fuelpriceChange'">
							<xsl:choose>
								<xsl:when test="trClock">
									<xsl:call-template name="ns:clockProc">
										<xsl:with-param name="site" select="$site"/>
										<xsl:with-param name="busDate" select="$busDate"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="ns:eventProc">
										<xsl:with-param name="site" select="$site"/>
										<xsl:with-param name="busDate" select="$busDate"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="ns:periodElem">
		<xsl:element name="vs:period">
			<xsl:attribute name="sysid"><xsl:value-of select="@level"/></xsl:attribute>
			<xsl:attribute name="periodSeqNum"><xsl:value-of select="@seq"/></xsl:attribute>
			<xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute>
		</xsl:element>
	</xsl:template>
	
	
	<xsl:template name="ns:cashierElem">
		<xsl:variable name="register">
			<xsl:call-template name="ns:registerElem"/>
		</xsl:variable>
		<xsl:variable name="regNum">
			<xsl:value-of select="msxsl:node-set($register)/t:register/@sysid"/>
		</xsl:variable>
		<xsl:variable name="originalCashier" select="trHeader/originalCashier"/>
		<xsl:choose>
			<xsl:when test="$originalCashier = true()">
				<xsl:element name="t:cashier">
					<xsl:attribute name="sysid"><xsl:value-of select="trHeader/originalCashier/@sysid"/></xsl:attribute>
					<xsl:if test="boolean(trHeader/originalCashier/@empNum) and trHeader/originalCashier/@empNum != ''">
						<xsl:attribute name="number"><xsl:value-of select="trHeader/originalCashier/@empNum"/></xsl:attribute>
					</xsl:if>
					
					<xsl:choose>
						<xsl:when test="trHeader/originalCashier/@sysid = 0">
							<xsl:element name="name">
								<xsl:value-of select="'Non-CSR'"/>
							</xsl:element>
						</xsl:when>
						<xsl:otherwise>
							<xsl:element name="name">
								<xsl:value-of select="trHeader/originalCashier"/>
							</xsl:element>
							<xsl:element name="period">
								<xsl:value-of select="trHeader/originalCashier/@period"/>
							</xsl:element>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					
					<xsl:when test="$regNum = $ns:dcrRegister or trLines/trLine/@type = 'preFuelCompletion'">
						<xsl:element name="t:cashier">
							<xsl:attribute name="sysid"><xsl:value-of select="'0'"/></xsl:attribute>
							<xsl:attribute name="number"><xsl:value-of select="'0'"/></xsl:attribute>
							<xsl:element name="name">
								
								<xsl:value-of select="'Non-CSR'"/>
							</xsl:element>
						</xsl:element>
					</xsl:when>
					
					<xsl:when test="trHeader/cashier">
						<xsl:element name="t:cashier">
							<xsl:attribute name="sysid"><xsl:value-of select="trHeader/cashier/@sysid"/></xsl:attribute>
							<xsl:if test="boolean(trHeader/cashier/@empNum) and trHeader/cashier/@empNum != ''">
								<xsl:attribute name="number"><xsl:value-of select="trHeader/cashier/@empNum"/></xsl:attribute>
							</xsl:if>
							
							<xsl:choose>
								<xsl:when test="trHeader/cashier/@sysid = 0">
									<xsl:element name="name">
										<xsl:value-of select="'Non-CSR'"/>
									</xsl:element>
								</xsl:when>
								<xsl:otherwise>
									<xsl:element name="name">
										<xsl:value-of select="trHeader/cashier"/>
									</xsl:element>
									<xsl:element name="period">
										<xsl:value-of select="trHeader/cashier/@period"/>
									</xsl:element>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:element>
					</xsl:when>
					
					<xsl:when test="cashier">
						<xsl:element name="t:cashier">
							<xsl:attribute name="sysid"><xsl:value-of select="cashier/@sysid"/></xsl:attribute>
							<xsl:if test="boolean(cashier/@empNum)">
								<xsl:attribute name="number"><xsl:value-of select="cashier/@empNum"/></xsl:attribute>
							</xsl:if>
							<xsl:element name="name">
								<xsl:value-of select="cashier"/>
							</xsl:element>
							<xsl:element name="period">
								<xsl:value-of select="cashier/@period"/>
							</xsl:element>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:element name="t:cashier">
							<xsl:attribute name="sysid"><xsl:value-of select="'0'"/></xsl:attribute>
							<xsl:attribute name="number"><xsl:value-of select="'0'"/></xsl:attribute>
							<xsl:element name="name">
								<xsl:value-of select="'Unknown'"/>
							</xsl:element>
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ns:registerElem">
		<xsl:param name="forceTillNum"/>
		<xsl:param name="posNum"/>
		<xsl:param name="device"/>
		<xsl:element name="t:register">
			<xsl:attribute name="sysid"><xsl:choose><xsl:when test="$posNum"><xsl:value-of select="$posNum"/></xsl:when><xsl:when test="trHeader/posNum"><xsl:value-of select="trHeader/posNum"/></xsl:when><xsl:when test="posNum"><xsl:value-of select="posNum"/></xsl:when><xsl:when test="trLines/trLine[@type = 'preFuelCompletion']"><xsl:value-of select="'9'"/></xsl:when><xsl:otherwise><xsl:value-of select="trHeader/trTickNum/posNum"/></xsl:otherwise></xsl:choose></xsl:attribute>
			<xsl:choose>
				<xsl:when test="trHeader/till">
					<xsl:attribute name="till"><xsl:value-of select="trHeader/till"/></xsl:attribute>
				</xsl:when>
				<xsl:when test="$forceTillNum">
					<xsl:attribute name="till"><xsl:value-of select="$forceTillNum"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="till"><xsl:value-of select="'0'"/></xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$device">
					<xsl:attribute name="device"><xsl:value-of select="$device"/></xsl:attribute>
				</xsl:when>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:tlogEntryHeaderType">
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:param name="device"/>
		<xsl:if test="trHeader/termMsgSN">
			<xsl:element name="seq">
				<xsl:attribute name="type"><xsl:value-of select="trHeader/termMsgSN/@type"/></xsl:attribute>
				<xsl:attribute name="term"><xsl:value-of select="trHeader/termMsgSN/@term"/></xsl:attribute>
				<xsl:value-of select="trHeader/termMsgSN"/>
			</xsl:element>
		</xsl:if>
		<xsl:if test="trHeader/date">
			<xsl:element name="dateTime">
				<xsl:value-of select="trHeader/date"/>
			</xsl:element>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$device">
				<xsl:call-template name="ns:registerElem">
					<xsl:with-param name="device" select="$device"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="ns:registerElem"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:element name="vs:site">
			<xsl:value-of select="$site"/>
		</xsl:element>
		<xsl:for-each select="trHeader/period">
			<xsl:call-template name="ns:periodElem"/>
		</xsl:for-each>
		<xsl:element name="t:busDate">
			<xsl:value-of select="$busDate"/>
		</xsl:element>
		<xsl:for-each select="trHeader/trOvrdCshr">
			<xsl:element name="t:authorizingAuthority">
				<xsl:attribute name="sysid"><xsl:value-of select="@sysid"/></xsl:attribute>
				<xsl:attribute name="softKeyCode"><xsl:value-of select="@softKeyCode"/></xsl:attribute>
			<xsl:element name="name">
				<xsl:value-of select="."/>
			</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="ns:totalsProc">
		<xsl:param name="tlogHeader"/>
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:element name="t:{local-name()}">
			<xsl:element name="t:hdr">
				<xsl:copy-of select="$tlogHeader"/>
			</xsl:element>
			<xsl:for-each select="*">
				<xsl:element name="{local-name()}">
					<xsl:value-of select="."/>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:clockProc">
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:element name="t:clock">
			<xsl:element name="hdr">
				<xsl:call-template name="ns:tlogEntryHeaderType">
					<xsl:with-param name="site" select="$site"/>
					<xsl:with-param name="busDate" select="$busDate"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:call-template name="ns:cashierElem"/>
			<xsl:if test="trClock/trClockIn">
				<xsl:element name="clockIn">
					<xsl:value-of select="trClock/trClockIn"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="trClock/trClockOut">
				<xsl:element name="clockOut">
					<xsl:value-of select="trClock/trClockOut"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="@choice='in'">
				<xsl:element name="clockIn">
					<xsl:value-of select="trHeader/clockDate"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="@choice='out'">
				<xsl:element name="clockOut">
					<xsl:value-of select="trHeader/clockDate"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:cashierProc">
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:variable name="lname">
			<xsl:choose>
				<xsl:when test="local-name() = 'printCashier'">
					<xsl:value-of select="'countCashier'"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="local-name()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:element name="t:{$lname}">
			<xsl:element name="hdr">
				<xsl:choose>
					<xsl:when test="$lname = 'openCashier'">
						<xsl:element name="dateTime">
							<xsl:value-of select="cOpenTime"/>
						</xsl:element>
					</xsl:when>
					<xsl:when test="$lname = 'closeCashier'">
						<xsl:element name="dateTime">
							<xsl:value-of select="cCloseTime"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:call-template name="ns:registerElem">
					<xsl:with-param name="forceTillNum" select="'1'"/>
				</xsl:call-template>
				<xsl:element name="vs:site">
					<xsl:value-of select="$site"/>
				</xsl:element>
				<xsl:variable name="sibSet">
					<xsl:choose>
						<xsl:when test="following-sibling::trans/trHeader/period">
							<xsl:copy-of select="following-sibling::trans[ trHeader/period ]/../trans[1]/trHeader/period"/>
						</xsl:when>
						<xsl:when test="preceding-sibling::trans/trHeader/period">
							<xsl:copy-of select="preceding-sibling::trans[ trHeader/period ]/../trans[1]/trHeader/period"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="count(msxsl:node-set($sibSet)/*)=0">
						<xsl:element name="vs:period">
							<xsl:attribute name="periodSeqNum">
								<xsl:value-of select="cashierPeriod"/>
							</xsl:attribute>
							<xsl:attribute name="periodType">
								<xsl:value-of select="'CASHIER'"/>
							</xsl:attribute>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="msxsl:node-set($sibSet)/*">
							<xsl:call-template name="ns:periodElem"/>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:element name="t:busDate">
					<xsl:value-of select="$busDate"/>
				</xsl:element>
			</xsl:element>
			<xsl:call-template name="ns:cashierElem"/>
			<xsl:copy-of select="beginCash"/>
			<xsl:choose>
				<xsl:when test="beginFoodStmp">
					<xsl:copy-of select="beginFoodStmp"/>
				</xsl:when>
				<xsl:otherwise>
					<beginFoodStmp>0</beginFoodStmp>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="$lname = 'openCashier' or $lname = 'closeCashier'">
				<xsl:element name="open">
					<xsl:value-of select="cOpenTime"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="$lname = 'closeCashier' or $lname = 'countCashier'">
				<xsl:element name="close">
					<xsl:value-of select="cCloseTime"/>
				</xsl:element>
				<xsl:choose>
					<xsl:when test="$lname = 'closeCashier'">
						<xsl:copy-of select="beginTicket"/>
						<xsl:copy-of select="endTicket"/>
						<xsl:copy-of select="ticketCount"/>
					</xsl:when>
					<xsl:when test="$lname = 'countCashier'">
						<xsl:for-each select="drawerAmounts/drawerAmount">
							<xsl:element name="tillAmount">
								<xsl:element name="t:mop">
									<xsl:attribute name="sysid"><xsl:value-of select="paymentName/@mop"/></xsl:attribute>
									<xsl:attribute name="cat"><xsl:value-of select="paymentName/@cat"/></xsl:attribute>
									
									<xsl:choose>
										<xsl:when test="paymentName/@nacstendercode">
											<xsl:attribute name="nacstendercode"><xsl:value-of select="paymentName/@nacstendercode"/></xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="nacstendercode"><xsl:value-of select="paymentName/@mop"/></xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:choose>
										<xsl:when test="paymentName/@nacstendersubcode">
											<xsl:attribute name="nacstendersubcode"><xsl:value-of select="paymentName/@nacstendersubcode"/></xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="nacstendersubcode"><xsl:value-of select="paymentName/@cat"/></xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:element name="name">
										<xsl:value-of select="paymentName"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="ecrAmount">
									<xsl:if test="ECRAmount/@locale">
										<xsl:attribute name="currency"><xsl:value-of select="ECRAmount/@locale"/></xsl:attribute>
									</xsl:if>
									<xsl:value-of select="ECRAmount"/>
								</xsl:element>
								<xsl:element name="actualAmount">
									<xsl:if test="actualAmount/@locale">
										<xsl:attribute name="currency"><xsl:value-of select="actualAmount/@locale"/></xsl:attribute>
									</xsl:if>
									<xsl:value-of select="actualAmount"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
						<xsl:element name="reconciledManagerID">
							<xsl:value-of select="reconciledByID"/>
						</xsl:element>
						<xsl:element name="reconciledMgrName">
							<xsl:value-of select="reconciledByName"/>
						</xsl:element>
					</xsl:when>
				</xsl:choose>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:tillTransactionProc">
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:variable name="lname">
			<xsl:choose>
				<xsl:when test="@type = 'payin'">
					<xsl:value-of select="'tillPayin'"/>
				</xsl:when>
				<xsl:when test="@type = 'payout'">
					<xsl:value-of select="'tillPayout'"/>
				</xsl:when>
				<xsl:when test="@type = 'safedrop' or @type='safedropcorrection'">
					<xsl:value-of select="'tillSafeDrop'"/>
				</xsl:when>
				<xsl:when test="@type = 'safeloan'">
					<xsl:value-of select="'tillSafeLoan'"/>
				</xsl:when>
				<xsl:when test="@type = 'nosale'">
					<xsl:value-of select="'tillNosale'"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:element name="t:{$lname}">
			<xsl:if test="@type = 'payin' and trHeader/trHouseAcct">
				<xsl:attribute name="isHouseAcct"><xsl:value-of select="'true'"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@type = 'payout' and trHeader/trHouseAcct">
				<xsl:attribute name="isHouseAcct"><xsl:value-of select="'true'"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@type='safedropcorrection'">
				<xsl:attribute name="correction"><xsl:value-of select="'true'"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="trHeader/eSafeId">
				<xsl:attribute name="sysid"><xsl:value-of select="trHeader/eSafeId/@sysid"/></xsl:attribute>
				<xsl:if test="trHeader/eSafeId/@name">
					<xsl:value-of select="trHeader/eSafeId/@name"/>
				</xsl:if>
			</xsl:if>
			<xsl:element name="hdr">
				<xsl:call-template name="ns:tlogEntryHeaderType">
					<xsl:with-param name="site" select="$site"/>
					<xsl:with-param name="busDate" select="$busDate"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:call-template name="ns:cashierElem"/>
			<xsl:element name="vs:transactionSeq">
				<xsl:value-of select="trHeader/trTickNum/trSeq"/>
			</xsl:element>
			<xsl:if test="@type != 'nosale'">
				<xsl:element name="amount">
					<xsl:call-template name="ns:currencyProc">
						<xsl:with-param name="location" select="trValue/trCurrTot"/>
					</xsl:call-template>
				</xsl:element>
				<xsl:if test="trPaylines/trPayline/trpPaycode">
					<xsl:element name="t:mop">
						<xsl:attribute name="sysid"><xsl:value-of select="trPaylines/trPayline[1]/trpPaycode/@mop"/></xsl:attribute>
						<xsl:attribute name="cat"><xsl:value-of select="trPaylines/trPayline[1]/trpPaycode/@cat"/></xsl:attribute>
						
						<xsl:choose>
							<xsl:when test="trPaylines/trPayline[1]/trpPaycode/@nacstendercode">
								<xsl:attribute name="nacstendercode"><xsl:value-of select="trPaylines/trPayline[1]/trpPaycode/@nacstendercode"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="nacstendercode"><xsl:value-of select="trPaylines/trPayline[1]/trpPaycode/@mop"/></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:choose>
							<xsl:when test="trPaylines/trPayline[1]/trpPaycode/@nacstendersubcode">
								<xsl:attribute name="nacstendersubcode"><xsl:value-of select="trPaylines/trPayline[1]/trpPaycode/@nacstendersubcode"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="nacstendersubcode"><xsl:value-of select="trPaylines/trPayline[1]/trpPaycode/@cat"/></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:element name="name">
							<xsl:value-of select="trPaylines/trPayline[1]/trpPaycode"/>
						</xsl:element>
					</xsl:element>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="string-length(trHeader/trHouseAcct)&gt; 0">
						<xsl:element name="reference">
							<xsl:if test="trHeader/trHouseAcct/@name">
								<xsl:attribute name="name"><xsl:value-of select="trHeader/trHouseAcct/@name"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="trHeader/trHouseAcct/@subAccount">
								<xsl:attribute name="subAccount"><xsl:value-of select="trHeader/trHouseAcct/@subAccount"/></xsl:attribute>
							</xsl:if>
							<xsl:value-of select="trHeader/trHouseAcct"/>
						</xsl:element>
					</xsl:when>
					<xsl:when test="trHeader/trMiscRefNum">
						<xsl:element name="reference">
							<xsl:value-of select="trHeader/trMiscRefNum"/>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="@type = 'payout' and trLines/trLine/trlMO">
					<xsl:if test="trLines/trLine[@type = 'moneyOrder'] and trLines/trLine/trlMO">
						<xsl:element name="moneyOrder">
							<xsl:element name="serialNum">
								<xsl:value-of select="trLines/trLine/trlMO/trlMOSerialNum"/>
							</xsl:element>
							<xsl:if test="trLines/trLine/trlMO/trlMOPayee">
								<xsl:element name="payee">
									<xsl:value-of select="trLines/trLine/trlMO/trlMOPayee"/>
								</xsl:element>
							</xsl:if>
						</xsl:element>
					</xsl:if>
				</xsl:if>
				<xsl:if test="@type='safedropcorrection'">
					<xsl:element name="origSafedropInfo">
						<xsl:element name="t:cashier">
							<xsl:attribute name="sysid"><xsl:value-of select="trHeader/originalSafeDropInfo/cashier/@sysid"/></xsl:attribute>
							<xsl:if test="boolean(trHeader/originalSafeDropInfo/cashier/@empNum)">
								<xsl:attribute name="number"><xsl:value-of select="trHeader/originalSafeDropInfo/cashier/@empNum"/></xsl:attribute>
							</xsl:if>
							<xsl:element name="name">
								<xsl:value-of select="trHeader/originalSafeDropInfo/cashier"/>
							</xsl:element>
							<xsl:if test="boolean(trHeader/originalSafeDropInfo/cashier/@period)">
								<xsl:element name="period">
									<xsl:value-of select="trHeader/originalSafeDropInfo/cashier/@period"/>
								</xsl:element>
							</xsl:if>
						</xsl:element>
						<xsl:element name="t:register">
							<xsl:attribute name="sysid"><xsl:value-of select="trHeader/originalSafeDropInfo/cashier/@posNum"/></xsl:attribute>
							<xsl:if test="boolean(trHeader/originalSafeDropInfo/cashier/@drawer)">
								<xsl:attribute name="till"><xsl:value-of select="trHeader/originalSafeDropInfo/cashier/@drawer"/></xsl:attribute>
							</xsl:if>
							<xsl:attribute name="device"><xsl:value-of select="'pos'"/></xsl:attribute>
						</xsl:element>
						<xsl:element name="amount">
							<xsl:call-template name="ns:currencyProc">
								<xsl:with-param name="location" select="trHeader/originalSafeDropInfo/trpAmt"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="vs:transactionSeq">
							<xsl:value-of select="trHeader/originalSafeDropInfo/trTickNum/trSeq"/>
						</xsl:element>
						<xsl:if test="trHeader/originalSafeDropInfo/trMiscRefNum">
							<xsl:element name="reference">
								<xsl:value-of select="trHeader/originalSafeDropInfo/trMiscRefNum"/>
							</xsl:element>
						</xsl:if>
					</xsl:element>
				</xsl:if>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:saleProc">
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:variable name="lname">
			<xsl:choose>
				<xsl:when test=" @type = 'sale' or            @type = 'network sale' or           @type = 'refund sale' or            @type = 'refund network sale' or           @type = 'autocollect'              ">
					<xsl:choose>
						<xsl:when test="@suspended = 'true'">
							<xsl:value-of select="'suspendedSale'"/>
						</xsl:when>
						<xsl:when test="@rollback = 'true'">
							<xsl:value-of select="'rollback'"/>
						</xsl:when>
						<xsl:when test="trLines/trLine[@type='preFuel']">
							<xsl:value-of select="'preFuel'"/>
						</xsl:when>
						
						<xsl:when test="trPaylines/trPayline/trpPaycode[@cat='19']">
							<xsl:value-of select="'pumpTest'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'sale'"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@type = 'void'">
					<xsl:value-of select="'void'"/>
				</xsl:when>
				<xsl:when test="@type = 'refund void'">
					<xsl:value-of select="'void'"/>
				</xsl:when>
				<xsl:when test="@type = 'suspended sale' or @type = 'suspended network sale'">
					<xsl:value-of select="'suspendedSale'"/>
				</xsl:when>
				<xsl:when test="@type = 'claimed sale' or @type = 'transferred sale'">
				</xsl:when>
				<xsl:when test="@type = 'pumptest'">
					<xsl:value-of select="'pumpTest'"/>
				</xsl:when>
				<xsl:when test="@type = 'kioskOrder void'">
					<xsl:value-of select="'void'"/>
				</xsl:when>
				<xsl:when test="@type = 'kioskOrder'">
					<xsl:value-of select="'order'"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="isRefund" select="starts-with(@type,'refund')"/>
		<xsl:variable name="isAutoCollectInside" select=" trLines/trLine/trlFuel[@type = 'autocollect'] and trHeader/trTickNum[posNum &lt; $ns:minOutdoorRegister]"/>
		<xsl:variable name="prepayCompletion" select="@fuelPrepayCompletion"/>
		<xsl:variable name="voidReason" select="@voidReason"/>
		<xsl:element name="t:{$lname}">
			<xsl:variable name="locale" select="trValue/trCurrTot/@locale"/>
			<xsl:variable name="needsLocale" select="not($locale = 'USD') and string-length($locale) &gt; 0"/>
			<xsl:if test="not($lname = 'pumpTest')">
				<xsl:choose>
					<xsl:when test="$isRefund">
						<xsl:attribute name="isRefund"><xsl:value-of select="'true'"/></xsl:attribute>
					</xsl:when>
				</xsl:choose>
			</xsl:if>
			<xsl:if test="($lname = 'void')">
				<xsl:choose>
					<xsl:when test="$voidReason">
						<xsl:attribute name="voidReason"><xsl:value-of select="$voidReason"/></xsl:attribute>
					</xsl:when>
				</xsl:choose>
			</xsl:if>
			<xsl:element name="hdr">
				<xsl:choose>
					<xsl:when test="not(@type = 'kioskOrder void' or @type = 'kioskOrder')">
						<xsl:call-template name="ns:tlogEntryHeaderType">
							<xsl:with-param name="site" select="$site"/>
							<xsl:with-param name="busDate" select="$busDate"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="ns:tlogEntryHeaderType">
							<xsl:with-param name="site" select="$site"/>
							<xsl:with-param name="busDate" select="$busDate"/>
							<xsl:with-param name="device" select="'kiosk'"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:call-template name="ns:cashierElem"/>
			<xsl:element name="vs:transactionSeq">
				<xsl:value-of select="trHeader/trTickNum/trSeq"/>
			</xsl:element>
			<xsl:if test="trHeader/trRecall or trHeader/trKioskOrder or trHeader/trOriginalTickNum">
				<xsl:element name="recalledTickets">
					<xsl:for-each select="trHeader/trRecall[not(@type='kioskOrder')] | trHeader/trRecall[not(@transType='kioskOrder')] | trHeader/trKioskOrder | trHeader/trOriginalTickNum">
						<xsl:variable name="device">
							<xsl:choose>
								<xsl:when test="name() = 'trKioskOrder'">
									<xsl:value-of select="'kiosk'"/>
								</xsl:when>
								<xsl:when test="../../@type='suspended sale' or ../../@type='sale' or ../../@type='refund sale'">
									<xsl:value-of select="'pos'"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'unknown'"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:element name="recallTicket">
							<xsl:call-template name="ns:registerElem">
								<xsl:with-param name="pos" select="posNum"/>
								<xsl:with-param name="device" select="$device"/>
							</xsl:call-template>
							<xsl:element name="vs:transactionSeq">
								<xsl:value-of select="trSeq"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:element>
			</xsl:if>
			
			<xsl:element name="lines">
				<xsl:for-each select="trLines/trLine">
					<xsl:variable name="taxReversedVal">
						<xsl:choose>
							<xsl:when test="not(trlTaxes/@reverse = '0')">
								<xsl:value-of select="'true'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'false'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="isVoid" select="following-sibling::trLine/trlVoidLineIx = position()"/>
					<xsl:variable name="voidLineIndex" select="trlVoidLineIx"/>
					<xsl:variable name="isVoiderLine" select="$voidLineIndex &gt; 0"/>
					<xsl:variable name="isPopDisc" select="trlPopDisc"/>
					<xsl:variable name="hasMatch" select="trlMixMatches"/>
					<xsl:variable name="isAutoCollect" select="starts-with(trlFuel/@type,'autocollect')"/>
					<xsl:variable name="isLoyalty" select="trloLnItemDisc | trloPPGDisc"/>
					<xsl:variable name="hasOverrideCashierID" select="trlOvrdCshr"/>
					
					<xsl:variable name="lineType">
						<xsl:value-of select="'line'"/>
					</xsl:variable>
					<xsl:element name="t:{$lineType}">
						<xsl:if test="$isVoid">
							<xsl:attribute name="isVoid"><xsl:value-of select="'true'"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="$voidLineIndex &gt; 0">
							<xsl:attribute name="voidLineIndex"><xsl:value-of select="$voidLineIndex"/></xsl:attribute>
						</xsl:if>
						<xsl:element name="flags">
							<xsl:if test="trlFlags/trlFstmp">
								<xsl:attribute name="foodStamp"><xsl:value-of select="'true'"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="trlFlags/trlSpDisc">
								<xsl:attribute name="specialDisc"><xsl:value-of select="'true'"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="trlFlags/trlBdayVerif">
								<xsl:attribute name="ageVerifReqd"><xsl:value-of select="'true'"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="trlFlags/trlPLUNotFnd">
								<xsl:attribute name="pluNotFound"><xsl:value-of select="'true'"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="trlUPCentry/@type = 'scanned' or trlUPCEntry/@type = 'scanned'">
								<xsl:attribute name="scanned"><xsl:value-of select="'true'"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="trlFlags/trlMoneyOrder">
								<xsl:attribute name="moneyOrder"><xsl:value-of select="'true'"/></xsl:attribute>
							</xsl:if>
							<xsl:if test="trlFlags/taxableRebate">
								<xsl:for-each select="trlFlags/taxableRebate">
									<xsl:element name="taxableRebateFlag">
										<xsl:attribute name="sysid"><xsl:value-of select="@sysid"/></xsl:attribute>
										<xsl:if test="@cat">
											<xsl:attribute name="name"><xsl:value-of select="@cat"/></xsl:attribute>
										</xsl:if>
										<xsl:if test="@promoID">
											<xsl:attribute name="promoID"><xsl:value-of select="@promoID"/></xsl:attribute>
										</xsl:if>
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="."/>
											<xsl:with-param name="value" select="."/>
										</xsl:call-template>
									</xsl:element>
								</xsl:for-each>
							</xsl:if>
						</xsl:element>
												
						<xsl:if test="$hasOverrideCashierID">
							<xsl:for-each select="trlOvrdCshr">
								<xsl:element name="t:authorizingAuthority">
									<xsl:attribute name="sysid"><xsl:value-of select="@sysid"/></xsl:attribute>
									<xsl:attribute name="softKeyCode"><xsl:value-of select="@softKeyCode"/></xsl:attribute>
								<xsl:element name="name">
									<xsl:value-of select="."/>
								</xsl:element>
								</xsl:element>
							</xsl:for-each>
						</xsl:if>
								
						
						
						<xsl:for-each select="trlTaxes/trlTax | trlTaxes/trlTaxex">
							<xsl:element name="tax">
								<xsl:variable name="cat">
									<xsl:value-of select="@cat"/>
								</xsl:variable>
								<xsl:attribute name="reversed"><xsl:choose><xsl:when test="local-name()='trlTaxex'"><xsl:value-of select="'true'"/></xsl:when><xsl:when test="@reverse = 'true' or @reverse = 1"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
								<xsl:element name="vs:taxrateBase">
									<xsl:attribute name="sysid"><xsl:value-of select="@sysid"/></xsl:attribute>
									<xsl:element name="name">
										<xsl:value-of select="$cat"/>
									</xsl:element>
									<xsl:if test="local-name()='trlTax'">
										<xsl:element name="taxRate">
											<xsl:value-of select="ancestor::trlTaxes/trlRate[ @cat = $cat ]"/>
										</xsl:element>
									</xsl:if>
								</xsl:element>
								<xsl:element name="taxable">
									<xsl:variable name="taxVal">
										<xsl:choose>
											<xsl:when test="local-name()='trlTax'">
												<xsl:value-of select="."/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="'0.00'"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:variable>
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="."/>
										<xsl:with-param name="value" select="$taxVal"/>
									</xsl:call-template>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
						<xsl:variable name="rqty">
							<xsl:choose>
								<xsl:when test="trlFuel">
									<xsl:value-of select="trlFuel/fuelVolume"/>
								</xsl:when>
								<xsl:when test="trlXQty">
									<xsl:value-of select="trlXQty"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="trlQty"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="qty">
							<xsl:choose>
								<xsl:when test="$isRefund or $isVoiderLine">
									<xsl:value-of select="format-number(-$rqty,'#.000')"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="format-number($rqty,'#.000')"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="itmprc">
							<xsl:choose>
								
								<xsl:when test="trlXQty">
									<xsl:value-of select="trlQty"/>
								</xsl:when>
								<xsl:when test="@type = 'preFuel'">
									<xsl:value-of select="trlLineTot"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="trlUnitPrice"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:element name="qty">
							<xsl:call-template name="ns:uomProc">
								<xsl:with-param name="location" select="trlQty"/>
								<xsl:with-param name="value" select="$qty"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="itmprc">
							<xsl:choose>
								<xsl:when test="@type = 'preFuel'">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlLineTot"/>
										<xsl:with-param name="value" select="$itmprc"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:when test="trlXQty">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlUnitPrice"/>
										<xsl:with-param name="value" select="$itmprc"/>
										<xsl:with-param name="mask" select="$ns:fuelCurrencyMask"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlUnitPrice"/>
										<xsl:with-param name="value" select="$itmprc"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:element>
						<xsl:if test="trlPrcOvrd">
							<xsl:element name="priceOverride">
								<xsl:element name="oldprc">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlPrcOvrd"/>
									</xsl:call-template>
								</xsl:element>
							</xsl:element>
						</xsl:if>
						<xsl:if test="trlXQty">
							<xsl:element name="atForInfo">
								<xsl:element name="qty">
									<xsl:call-template name="ns:uomProc">
										<xsl:with-param name="location" select="trlYQty"/>
									</xsl:call-template>
								</xsl:element>
								<xsl:element name="prc">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlUnitPrice"/>
									</xsl:call-template>
								</xsl:element>
							</xsl:element>
						</xsl:if>
						
						<xsl:if test="trlDisc">
							<xsl:variable name="discName">
								<xsl:value-of select="'t:disc'"/>
							</xsl:variable>
							<xsl:for-each select="trlDisc">
								<xsl:element name="{$discName}">
									<xsl:attribute name="type"><xsl:value-of select="@type"/></xsl:attribute>
									<xsl:if test="./@reason">
										<xsl:attribute name="reason"><xsl:value-of select="./@reason"/></xsl:attribute>
									</xsl:if>
									<xsl:element name="amt">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="."/>
										</xsl:call-template>
									</xsl:element>
								</xsl:element>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="(trlPromo | trlCw/trlCwPromo)">
							<xsl:variable name="discName">
								<xsl:choose>
									<xsl:when test="trlPromo">
										<xsl:value-of select="'t:promo'"/>
									</xsl:when>
									<xsl:when test="trlCw/trlCwPromo">
										<xsl:value-of select="'t:promo'"/>
									</xsl:when>
								</xsl:choose>
							</xsl:variable>
							<xsl:element name="{$discName}">
								<xsl:attribute name="type"><xsl:choose><xsl:when test="$isPopDisc"><xsl:value-of select="'pop'"/></xsl:when><xsl:otherwise><xsl:value-of select="trlPromo/@type |  trlCw/trlCwPromo/@type"/></xsl:otherwise></xsl:choose></xsl:attribute>
								<xsl:element name="amt">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlPromo |  trlCw/trlCwPromo"/>
									</xsl:call-template>
								</xsl:element>
							</xsl:element>
						</xsl:if>
						
						<xsl:if test="trloLnItemDisc">
							<xsl:for-each select="trloLnItemDisc">
								<xsl:element name="t:loyalty">
									<xsl:attribute name="type"><xsl:value-of select="'amt'"/></xsl:attribute>
									<xsl:element name="amt">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="discAmt"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:element name="name">
										<xsl:if test="@programID">
											<xsl:value-of select="@programID"/>
										</xsl:if>
									</xsl:element>
									<xsl:element name="qty">
										<xsl:call-template name="ns:uomProc">
											<xsl:with-param name="location" select="qty"/>
											<xsl:with-param name="value" select="qty"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:element name="taxCredit">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="taxCred"/>
										</xsl:call-template>
									</xsl:element>
								</xsl:element>
							</xsl:for-each>
						</xsl:if>
						<xsl:variable name="matches">
							
							<xsl:if test="$hasMatch">
								<xsl:for-each select="trlMixMatches/trlMatchLine">
									<xsl:variable name="hasPromoAmt" select="./trlPromoAmount"/>
									
									<xsl:element name="t:match">
										
										
										<xsl:if test="trlMatchNumber">
											<xsl:attribute name="sysid"><xsl:value-of select="trlMatchNumber"/></xsl:attribute>
										</xsl:if>
										<xsl:attribute name="mixId"><xsl:value-of select="trlMatchMixes"/></xsl:attribute>
										<xsl:attribute name="count"><xsl:value-of select="trlMatchQuantity"/></xsl:attribute>
										<xsl:attribute name="type"><xsl:value-of select="'fixed'"/></xsl:attribute>
										<xsl:element name="amt">
											
											<xsl:choose>
												<xsl:when test="$hasPromoAmt">
													<xsl:attribute name="promoAmount"><xsl:value-of select="'true'"/></xsl:attribute>
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="trlPromoAmount"/>
														<xsl:with-param name="value" select="trlPromoAmount"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>
													<xsl:choose>
														
														<xsl:when test="$isRefund">
															<xsl:call-template name="ns:currencyProc">
																<xsl:with-param name="location" select="trlMatchPrice"/>
																<xsl:with-param name="value" select="-(($itmprc + trlMatchPrice) *trlMatchQuantity)"/>
															</xsl:call-template>
														</xsl:when>
														<xsl:otherwise>
															<xsl:call-template name="ns:currencyProc">
																<xsl:with-param name="location" select="trlMatchPrice"/>
																<xsl:with-param name="value" select="(($itmprc - trlMatchPrice) * trlMatchQuantity)"/>
															</xsl:call-template>
														</xsl:otherwise>
													</xsl:choose>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:element>
										<xsl:element name="name">
											<xsl:value-of select="trlMatchName"/>
										</xsl:element>
										<xsl:element name="qty">
											<xsl:call-template name="ns:uomProc">
												<xsl:with-param name="location" select="trlMatchQuantity"/>
												<xsl:with-param name="value" select="trlMatchQuantity"/>
											</xsl:call-template>
										</xsl:element>
										<xsl:if test="$hasPromoAmt">
											<xsl:element name="promoID">
												<xsl:attribute name="type"><xsl:choose><xsl:when test="trlPromotionID/@promotype = 'combinationOffer'"><xsl:value-of select=" 'combo'"/></xsl:when><xsl:when test="trlPromotionID/@promotype = 'mixAndMatchOffer'"><xsl:value-of select="'mix-match'"/></xsl:when><xsl:otherwise><xsl:value-of select="'undefined'"/></xsl:otherwise></xsl:choose></xsl:attribute>
												<xsl:value-of select="trlPromotionID"/>
											</xsl:element>
											<xsl:element name="promoListID">
												<xsl:attribute name="type"><xsl:choose><xsl:when test="trlPromotionItemListID/@itemlisttype = 'PLU'"><xsl:value-of select="'plu'"/></xsl:when><xsl:when test="trlPromotionItemListID/@itemlisttype = 'DEPT'"><xsl:value-of select="'dep'"/></xsl:when><xsl:otherwise><xsl:value-of select="'undefined'"/></xsl:otherwise></xsl:choose></xsl:attribute>
												<xsl:value-of select="trlPromotionItemListID"/>
											</xsl:element>
										</xsl:if>
									</xsl:element>
								</xsl:for-each>
							</xsl:if>
						</xsl:variable>
						<xsl:copy-of select="$matches"/>
						<xsl:variable name="lineTot">
							<xsl:choose>
								<xsl:when test="$hasMatch">
									
									
									<xsl:choose>
										<xsl:when test="$isRefund">
											<xsl:if test="sum(msxsl:node-set($matches)/*/amt) &lt;= 0">
												<xsl:value-of select="format-number(trlLineTot - (sum(msxsl:node-set($matches)/*/amt)),'0.00')"/>
											</xsl:if>
											<xsl:if test="sum(msxsl:node-set($matches)/*/amt) &gt; 0">
												<xsl:value-of select="format-number(trlLineTot + (sum(msxsl:node-set($matches)/*/amt)),'0.00')"/>
											</xsl:if>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number(trlLineTot - (sum(msxsl:node-set($matches)/*/amt)),'0.00')"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="trlLineTot"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="feeAmt">
							<xsl:choose>
								<xsl:when test="trlFee/trlFeeAmount and ($isRefund or $isVoiderLine)">
									<xsl:value-of select="-(sum(trlFee/trlFeeAmount) * $qty)"/>
								</xsl:when>
								<xsl:when test="trlFee/trlFeeAmount">
									<xsl:value-of select="(sum(trlFee/trlFeeAmount) * $qty)"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'0'"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:element name="stot">
							<xsl:call-template name="ns:currencyProc">
								<xsl:with-param name="location" select="trlLineTot"/>
								<xsl:with-param name="value" select="format-number($lineTot - $feeAmt,'0.00')"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:if test="trlFee">
							<xsl:for-each select="trlFee">
								<xsl:element name="t:fee">
									<xsl:attribute name="sysid"><xsl:value-of select="trlFeeNum"/></xsl:attribute>
									<xsl:element name="name">
										<xsl:value-of select="trlFeeName"/>
									</xsl:element>
									<xsl:element name="amt">
										<xsl:choose>
											<xsl:when test="$isRefund or $isVoiderLine">
												<xsl:call-template name="ns:currencyProc">
													<xsl:with-param name="location" select="trlFeeAmount"/>
													<xsl:with-param name="value" select="-(trlFeeAmount)"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="ns:currencyProc">
													<xsl:with-param name="location" select="trlFeeAmount"/>
													<xsl:with-param name="value" select="(trlFeeAmount)"/>
												</xsl:call-template>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:element>
									<xsl:element name="t:dept">
										<xsl:attribute name="sysid"><xsl:value-of select="trlFeeDepNum"/></xsl:attribute>
										<xsl:element name="name">
											<xsl:value-of select="trlFeeDepName"/>
										</xsl:element>
									</xsl:element>
									<xsl:if test="trlFeeCat">
										<xsl:element name="t:cat">
											<xsl:attribute name="sysid"><xsl:value-of select="trlFeeCat/@number"/></xsl:attribute>
											<xsl:element name="name">
												<xsl:value-of select="trlFeeCat"/>
											</xsl:element>
										</xsl:element>
									</xsl:if>
								</xsl:element>
							</xsl:for-each>
						</xsl:if>
						<xsl:element name="tot">
							<xsl:call-template name="ns:currencyProc">
								<xsl:with-param name="location" select="trlLineTot"/>
								<xsl:with-param name="value" select="$lineTot"/>
							</xsl:call-template>
						</xsl:element>
						<xsl:element name="desc">
							<xsl:value-of select="trlDesc"/>
						</xsl:element>
						<xsl:if test="trlSerialNum">
							<xsl:element name="serialNum">
								<xsl:value-of select="trlSerialNum"/>
							</xsl:element>
						</xsl:if>
						<xsl:element name="fid">
							<xsl:element name="t:dept">
								<xsl:attribute name="sysid"><xsl:value-of select="trlDept/@number"/></xsl:attribute>
								<xsl:variable name="deptType" select="trlDept/@type"/>
								<xsl:if test="not($deptType = 'norm')">
									<xsl:attribute name="deptType"><xsl:value-of select="$deptType"/></xsl:attribute>
								</xsl:if>
								<xsl:element name="name">
									<xsl:value-of select="trlDept"/>
								</xsl:element>
							</xsl:element>
							<xsl:if test="trlSubDept">
								<xsl:element name="t:subDept">
									<xsl:attribute name="sysid"><xsl:value-of select="trlSubDept/@number"/></xsl:attribute>
									<xsl:variable name="subDeptType" select="trlSubDept/@type"/>
									<xsl:if test="not($subDeptType = 'norm')">
										<xsl:attribute name="deptType"><xsl:value-of select="$subDeptType"/></xsl:attribute>
									</xsl:if>
									<xsl:element name="name">
										<xsl:value-of select="trlSubDept"/>
									</xsl:element>
								</xsl:element>
							</xsl:if>
							<xsl:if test="trlCat">
								<xsl:element name="t:cat">
									<xsl:attribute name="sysid"><xsl:value-of select="trlCat/@number"/></xsl:attribute>
									<xsl:element name="name">
										<xsl:value-of select="trlCat"/>
									</xsl:element>
								</xsl:element>
							</xsl:if>
							<xsl:element name="t:netw">
								<xsl:attribute name="sysid"><xsl:value-of select="trlNetwCode"/></xsl:attribute>
								<xsl:choose>
									<xsl:when test="trlFuel">
										<xsl:attribute name="isFuel"><xsl:value-of select="'true'"/></xsl:attribute>
									</xsl:when>
								</xsl:choose>
								<xsl:element name="name"/>
							</xsl:element>
						</xsl:element>
						<xsl:if test="trlUPC">
							<xsl:element name="iid">
								<xsl:element name="t:plu">
									<xsl:variable name="mod" select="trlModifier"/>
									<xsl:variable name="itemID" select="trlInvItemId"/>
									<xsl:element name="upc">
										<xsl:if test="trlFlags/trlDeli">
											<xsl:attribute name="encoding"><xsl:value-of select="'RW'"/></xsl:attribute>
										</xsl:if>
										<xsl:value-of select="trlUPC"/>
									</xsl:element>
									<xsl:if test="$mod">
										<xsl:element name="modifier">
											<xsl:value-of select="$mod"/>
										</xsl:element>
									</xsl:if>
									<xsl:element name="name">
										<xsl:value-of select="trlDesc"/>
									</xsl:element>
									<xsl:element name="sellunit">
										<xsl:choose>
											<xsl:when test="trlSellUnit">
												<xsl:value-of select="format-number(trlSellUnit,'#.000')"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="format-number(1,'#.000')"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:element>
									<xsl:if test="$itemID">
										<xsl:element name="invItemID">
											<xsl:value-of select="$itemID"/>
										</xsl:element>
									</xsl:if>
								</xsl:element>
							</xsl:element>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="trlFuel/fuelVolume &gt; 0">
								<xsl:element name="t:fuel">
									<xsl:choose>
										<xsl:when test="trlFuel/@type = 'manualFuel' or trlFuel/@type = 'manualFuelWithManualDiscount'">
											<xsl:attribute name="isManualFuel"><xsl:value-of select="'true'"/></xsl:attribute>
										</xsl:when>
										<xsl:when test="trlFuel[@type = 'cashAcceptor']">
											<xsl:attribute name="isCashAcceptor"><xsl:value-of select="'true'"/></xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="completion"><xsl:value-of select="'true'"/></xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:element name="pos">
										<xsl:value-of select="trlFuel/fuelPosition"/>
									</xsl:element>
									<xsl:element name="amt">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="trlLineTot"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:element name="prc">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="trlUnitPrice"/>
											<xsl:with-param name="mask" select="$ns:fuelCurrencyMask"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:element name="vol">
										<xsl:call-template name="ns:uomProc">
											<xsl:with-param name="location" select="trlFuel/fuelVolume"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:if test="$isPopDisc">
										<xsl:for-each select="trlPopDisc">
											<xsl:element name="popDisc">
												<xsl:attribute name="membership"><xsl:choose><xsl:when test="trlpdMemberID"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
												<xsl:element name="name">
													<xsl:value-of select="trlpdDescrip"/>
												</xsl:element>
												<xsl:element name="amt">
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="trlpdAmount"/>
													</xsl:call-template>
												</xsl:element>
												<xsl:if test="trlpdPGUnit">
													<xsl:element name="ppuDisc">
														<xsl:call-template name="ns:currencyProc">
															<xsl:with-param name="location" select=" trlpdPGUnit"/>
														</xsl:call-template>
													</xsl:element>
												</xsl:if>
												<xsl:if test="trlpdTime">
													<xsl:element name="time">
														<xsl:attribute name="sysid"><xsl:value-of select="trlpdTime/@type"/></xsl:attribute>
														<xsl:value-of select="trlpdTime"/>
													</xsl:element>
												</xsl:if>
												<xsl:if test="trlpdMatch">
													<xsl:element name="match">
														<xsl:attribute name="sysid"><xsl:value-of select="trlpdMatch/@type"/></xsl:attribute>
														<xsl:value-of select="trlpdMatch"/>
													</xsl:element>
												</xsl:if>
												<xsl:if test="trlpdMemberID | trlpdCodeUsed">
													<xsl:element name="popID">
														<xsl:attribute name="entryMeth"><xsl:choose><xsl:when test="trlpdCodeUsed"><xsl:value-of select="'popcode'"/></xsl:when><xsl:when test="trlpdMemEMeth/@type='1' or                        trlpdMemEMeth/@type='2' or                        trlpdMemEMeth/@type='3' or                        trlpdMemEMeth/@type='7'"><xsl:value-of select="'barcode'"/></xsl:when><xsl:when test="trlpdMemEMeth/@type='5' or                         trlpdMemEMeth/@type='6'"><xsl:value-of select="'magstripe'"/></xsl:when><xsl:when test="trlpdMemEMeth/@type='4'"><xsl:value-of select="'manual'"/></xsl:when><xsl:otherwise><xsl:value-of select="'unkown'"/></xsl:otherwise></xsl:choose></xsl:attribute>
														<xsl:value-of select="trlpdMemberID | trlpdCodeUsed"/>
													</xsl:element>
												</xsl:if>
												<xsl:if test="trlpdFuelDef">
													<xsl:element name="popDefinitionID">
														<xsl:value-of select="trlpdFuelDef"/>
													</xsl:element>
												</xsl:if>
												<xsl:if test="trlpdDiscProgramId">
													<xsl:element name="popDiscountID">
														<xsl:value-of select="trlpdDiscProgramId"/>
													</xsl:element>
												</xsl:if>
											</xsl:element>
										</xsl:for-each>
									</xsl:if>
									<xsl:element name="grade">
										<xsl:attribute name="sysid"><xsl:value-of select="trlFuel/fuelProd/@sysid"/></xsl:attribute>
										
										<xsl:if test="trlFuel/fuelProd/@NAXMLFuelGradeID">
											<xsl:attribute name="NAXMLFuelGradeID"><xsl:value-of select="trlFuel/fuelProd/@NAXMLFuelGradeID"/></xsl:attribute>
										</xsl:if>
										<xsl:element name="name">
											<xsl:value-of select="trlFuel/fuelProd"/>
										</xsl:element>
									</xsl:element>
									<xsl:element name="svcLevel">
										<xsl:attribute name="sysid"><xsl:value-of select="trlFuel/fuelSvcMode/@sysid"/></xsl:attribute>
										<xsl:element name="name">
											<xsl:value-of select="trlFuel/fuelSvcMode"/>
										</xsl:element>
									</xsl:element>
									<xsl:element name="mop">
										<xsl:attribute name="sysid"><xsl:value-of select="trlFuel/fuelMOP/@sysid"/></xsl:attribute>
										<xsl:element name="name">
											<xsl:value-of select="trlFuel/fuelMOP"/>
										</xsl:element>
									</xsl:element>
									<xsl:if test="trlFuel/trlFuelTaxExemption | trlFuel/trlFuelTaxAddition | trlFuel/trlFuelTaxAdditionByDept">
										<xsl:for-each select="trlFuel/trlFuelTaxExemption | trlFuel/trlFuelTaxAddition | trlFuel/trlFuelTaxAdditionByDept">
											<xsl:element name="fuelTaxExemption">
												<xsl:if test="local-name() = 'trlFuelTaxAddition' or local-name() = 'trlFuelTaxAdditionByDept'">
													<xsl:attribute name="reversed"><xsl:value-of select="'true'"/></xsl:attribute>
												</xsl:if>
												<xsl:element name="desc">
													<xsl:attribute name="sysid"><xsl:value-of select="sysid"/></xsl:attribute>
													<xsl:value-of select="description"/>
												</xsl:element>
												<xsl:element name="amt">
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="amt"/>
													</xsl:call-template>
												</xsl:element>
											</xsl:element>
										</xsl:for-each>
									</xsl:if>
									<xsl:if test="trlFuel/basePrice">
										<xsl:element name="origPrc">
											<xsl:call-template name="ns:currencyProc">
												<xsl:with-param name="location" select="trlFuel/basePrice"/>
												<xsl:with-param name="mask" select="$ns:fuelCurrencyMask"/>
											</xsl:call-template>
										</xsl:element>
									</xsl:if>
									<xsl:if test="trloPPGDisc">
										<xsl:for-each select="trloPPGDisc">
											<xsl:element name="loyaltyDisc">
												<xsl:element name="name">
													<xsl:if test="@programID">
														<xsl:value-of select="@programID"/>
													</xsl:if>
												</xsl:element>
												<xsl:element name="amt">
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="PPGTotDisc"/>
													</xsl:call-template>
												</xsl:element>
												<xsl:element name="ppuDisc">
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="PPGGalDisc"/>
													</xsl:call-template>
												</xsl:element>
												<xsl:element name="origPPU">
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="PPGOrgPrice"/>
														<xsl:with-param name="mask" select="$ns:fuelCurrencyMask"/>
													</xsl:call-template>
												</xsl:element>
												<xsl:element name="ref">
													<xsl:value-of select="PPGOrigTXNum"/>
												</xsl:element>
											</xsl:element>
										</xsl:for-each>
									</xsl:if>
								</xsl:element>
							</xsl:when>
							<xsl:when test="@type = 'preFuel'">
								<xsl:element name="t:fuelPrepay">
									<xsl:element name="pos">
										<xsl:value-of select="jsc:getPrepayFP(string(trlDesc))"/>
									</xsl:element>
									<xsl:element name="amt">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="trlLineTot"/>
										</xsl:call-template>
									</xsl:element>
								</xsl:element>
							</xsl:when>
						</xsl:choose>
						<xsl:if test="trlCw">
							<xsl:element name="carwash">
								<xsl:if test="trlCw/trlCwCode/@sysid &gt; 0">
									<xsl:attribute name="sysid"><xsl:value-of select="trlCw/trlCwCode/@sysid"/></xsl:attribute>
								</xsl:if>
								<xsl:if test="trlCw/trlCwLineIx &gt; 0">
									<xsl:attribute name="lineItemIx"><xsl:value-of select="trlCw/trlCwLineIx"/></xsl:attribute>
								</xsl:if>
								<xsl:element name="code">
									<xsl:value-of select="trlCw/trlCwCode"/>
								</xsl:element>
							</xsl:element>
						</xsl:if>
						<xsl:if test="trlOrigTickNum">
							<xsl:element name="origTranSeq">
								<xsl:attribute name="lineIndex"><xsl:value-of select="position()"/></xsl:attribute>
								<xsl:element name="vs:transactionSeq">
									<xsl:value-of select="trlOrigTickNum/trSeq"/>
								</xsl:element>
							</xsl:element>
						</xsl:if>
					</xsl:element>
					
					<xsl:choose>
						<xsl:when test="$isAutoCollectInside = true() and $isAutoCollect = true()">
							<xsl:element name="t:line">
								<xsl:element name="flags"/>
								<xsl:element name="qty">
									<xsl:call-template name="ns:uomProc">
										<xsl:with-param name="location" select="trlFuel/fuelVolume"/>
										<xsl:with-param name="value" select="-trlFuel/fuelVolume"/>
									</xsl:call-template>
								</xsl:element>
								<xsl:element name="itmprc">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlUnitPrice"/>
										<xsl:with-param name="mask" select="$ns:fuelCurrencyMask"/>
									</xsl:call-template>
								</xsl:element>
								
								<xsl:element name="stot">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlLineTot"/>
										<xsl:with-param name="value" select="-trlLineTot"/>
									</xsl:call-template>
								</xsl:element>
								<xsl:element name="tot">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trlLineTot"/>
										<xsl:with-param name="value" select="-trlLineTot"/>
									</xsl:call-template>
								</xsl:element>
								<xsl:element name="desc">
									<xsl:value-of select="'AUTO COLLECT   '"/>
								</xsl:element>
								<xsl:element name="fid">
									<xsl:element name="t:dept">
										<xsl:attribute name="sysid"><xsl:value-of select="trlDept/@number"/></xsl:attribute>
										<xsl:variable name="deptType" select="trlDept/@type"/>
										<xsl:if test="not($deptType = 'norm')">
											<xsl:attribute name="deptType"><xsl:value-of select="$deptType"/></xsl:attribute>
										</xsl:if>
										<xsl:element name="name">
											<xsl:value-of select="trlDept"/>
										</xsl:element>
									</xsl:element>
									<xsl:if test="trlSubDept">
										<xsl:element name="t:subDept">
											<xsl:attribute name="sysid"><xsl:value-of select="trlSubDept/@number"/></xsl:attribute>
											<xsl:variable name="subDeptType" select="trlSubDept/@type"/>
											<xsl:if test="not($subDeptType = 'norm')">
												<xsl:attribute name="deptType"><xsl:value-of select="$subDeptType"/></xsl:attribute>
											</xsl:if>
											<xsl:element name="name">
												<xsl:value-of select="trlSubDept"/>
											</xsl:element>
										</xsl:element>
									</xsl:if>
									<xsl:if test="trlCat">
										<xsl:element name="t:cat">
											<xsl:attribute name="sysid"><xsl:value-of select="trlCat/@number"/></xsl:attribute>
											<xsl:element name="name">
												<xsl:value-of select="trlCat"/>
											</xsl:element>
										</xsl:element>
									</xsl:if>
									<xsl:element name="t:netw">
										<xsl:attribute name="sysid"><xsl:value-of select="trlNetwCode"/></xsl:attribute>
										<xsl:choose>
											<xsl:when test="trlFuel">
												<xsl:attribute name="isFuel"><xsl:value-of select="'true'"/></xsl:attribute>
											</xsl:when>
										</xsl:choose>
										<xsl:element name="name"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="t:fuel">
									<xsl:if test="$isAutoCollect">
										<xsl:attribute name="isAutoCollect"><xsl:value-of select="'true'"/></xsl:attribute>
									</xsl:if>
									<xsl:element name="pos">
										<xsl:value-of select="trlFuel/fuelPosition"/>
									</xsl:element>
									<xsl:element name="amt">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="trlLineTot"/>
											<xsl:with-param name="value" select="-trlLineTot"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:element name="prc">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="trlUnitPrice"/>
											<xsl:with-param name="mask" select="$ns:fuelCurrencyMask"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:element name="vol">
										<xsl:call-template name="ns:uomProc">
											<xsl:with-param name="location" select="trlFuel/fuelVolume"/>
											<xsl:with-param name="value" select="-trlFuel/fuelVolume"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:if test="$isPopDisc">
										<xsl:element name="popDisc">
											<xsl:element name="name">
												<xsl:value-of select="trlPopDisc/trlpdDescrip"/>
											</xsl:element>
											<xsl:element name="amt">
												<xsl:call-template name="ns:currencyProc">
													<xsl:with-param name="location" select="trlPopDisc/trlpdAmount"/>
												</xsl:call-template>
											</xsl:element>
											<xsl:if test="trlPopDisc/trlpdPGUnit">
												<xsl:element name="ppuDisc">
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="trlPopDisc/trlpdPGUnit"/>
													</xsl:call-template>
												</xsl:element>
											</xsl:if>
											<xsl:if test="trlPopDisc/trlpdTime">
												<xsl:element name="time">
													<xsl:attribute name="sysid"><xsl:value-of select="trlPopDisc/trlpdTime/@type"/></xsl:attribute>
													<xsl:value-of select="trlPopDisc/trlpdTime"/>
												</xsl:element>
											</xsl:if>
											<xsl:if test="trlPopDisc/trlpdMatch">
												<xsl:element name="match">
													<xsl:attribute name="sysid"><xsl:value-of select="trlPopDisc/trlpdMatch/@type"/></xsl:attribute>
													<xsl:value-of select="trlPopDisc/trlpdMatch"/>
												</xsl:element>
											</xsl:if>
										</xsl:element>
									</xsl:if>
									<xsl:element name="grade">
										<xsl:attribute name="sysid"><xsl:value-of select="trlFuel/fuelProd/@sysid"/></xsl:attribute>
										
										<xsl:if test="trlFuel/fuelProd/@NAXMLFuelGradeID">
											<xsl:attribute name="NAXMLFuelGradeID"><xsl:value-of select="trlFuel/fuelProd/@NAXMLFuelGradeID"/></xsl:attribute>
										</xsl:if>
										<xsl:element name="name">
											<xsl:value-of select="trlFuel/fuelProd"/>
										</xsl:element>
									</xsl:element>
									<xsl:element name="svcLevel">
										<xsl:attribute name="sysid"><xsl:value-of select="trlFuel/fuelSvcMode/@sysid"/></xsl:attribute>
										<xsl:element name="name">
											<xsl:value-of select="trlFuel/fuelSvcMode"/>
										</xsl:element>
									</xsl:element>
									<xsl:element name="mop">
										<xsl:attribute name="sysid"><xsl:value-of select="trlFuel/fuelMOP/@sysid"/></xsl:attribute>
										<xsl:element name="name">
											<xsl:value-of select="trlFuel/fuelMOP"/>
										</xsl:element>
									</xsl:element>
									<xsl:if test="trlFuel/trlFuelTaxExemption | trlFuel/trlFuelTaxAddition | trlFuel/trlFuelTaxAdditionByDept">
										<xsl:for-each select="trlFuel/trlFuelTaxExemption | trlFuel/trlFuelTaxAddition | trlFuel/trlFuelTaxAdditionByDept">
											<xsl:element name="fuelTaxExemption">
												<xsl:if test="local-name() = 'trlFuelTaxAddition' or local-name() = 'trlFuelTaxAdditionByDept'">
													<xsl:attribute name="reversed"><xsl:value-of select="'true'"/></xsl:attribute>
												</xsl:if>
												<xsl:element name="desc">
													<xsl:attribute name="sysid"><xsl:value-of select="sysid"/></xsl:attribute>
													<xsl:value-of select="description"/>
												</xsl:element>
												<xsl:element name="amt">
													<xsl:call-template name="ns:currencyProc">
														<xsl:with-param name="location" select="amt"/>
													</xsl:call-template>
												</xsl:element>
											</xsl:element>
										</xsl:for-each>
									</xsl:if>
									<xsl:if test="trlFuel/basePrice">
										<xsl:element name="origPrc">
											<xsl:call-template name="ns:currencyProc">
												<xsl:with-param name="location" select="trlFuel/basePrice"/>
												<xsl:with-param name="mask" select="$ns:fuelCurrencyMask"/>
											</xsl:call-template>
										</xsl:element>
									</xsl:if>
								</xsl:element>
								<xsl:if test="trlOrigTickNum">
									<xsl:element name="origTranSeq">
										<xsl:attribute name="lineIndex"><xsl:value-of select="position()"/></xsl:attribute>
										<xsl:element name="vs:transactionSeq">
											<xsl:value-of select="trlOrigTickNum/trSeq"/>
										</xsl:element>
									</xsl:element>
								</xsl:if>
							</xsl:element>
						</xsl:when>
					</xsl:choose>
				</xsl:for-each>
			</xsl:element>
			<xsl:if test="trPaylines/trPayline">
				
				<xsl:variable name="cshBack" select="trValue/trCshBk"/>
				
				<xsl:element name="paylines">
					<xsl:for-each select="trPaylines/trPayline">
						<xsl:element name="t:payline">
							
							<xsl:if test="$prepayCompletion and (not(@duplicate or @originalPreauth))">
								<xsl:element name="t:authorizingAuthority">
									<xsl:attribute name="sysid"><xsl:value-of select="../../trHeader/cashier/@sysid"/></xsl:attribute>
									<xsl:if test="../../trHeader/cashier/@empNum">
										<xsl:attribute name="number"><xsl:value-of select="../../trHeader/cashier/@empNum"/></xsl:attribute>
									</xsl:if>
									<xsl:element name="name">
										<xsl:value-of select="../../trHeader/cashier"/>
									</xsl:element>

								</xsl:element>
							</xsl:if>
							<xsl:element name="t:mop">
								<xsl:attribute name="sysid"><xsl:value-of select="trpPaycode/@mop"/></xsl:attribute>
								<xsl:attribute name="cat"><xsl:value-of select="trpPaycode/@cat"/></xsl:attribute>
								
								<xsl:choose>
									<xsl:when test="trpPaycode/@nacstendercode">
										<xsl:attribute name="nacstendercode"><xsl:value-of select="trpPaycode/@nacstendercode"/></xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="nacstendercode"><xsl:value-of select="trpPaycode/@mop"/></xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:choose>
									<xsl:when test="trpPaycode/@nacstendersubcode">
										<xsl:attribute name="nacstendersubcode"><xsl:value-of select="trpPaycode/@nacstendersubcode"/></xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="nacstendersubcode"><xsl:value-of select="trpPaycode/@cat"/></xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:element name="name">
									<xsl:value-of select="trpPaycode"/>
								</xsl:element>
							</xsl:element>
							<xsl:element name="amt">
								<xsl:value-of select="trpAmt"/>
							</xsl:element>
							<xsl:if test="trpCardInfo/trpcAccount">
								<xsl:element name="t:cardInfo">
									<xsl:attribute name="isAboveSite"><xsl:value-of select="trPayline/trpCardInfo/@isAboveSite"/></xsl:attribute>
									<xsl:element name="acct">
										<xsl:value-of select="trpCardInfo/trpcAccount"/>
									</xsl:element>
									<xsl:if test="trpCardInfo/trpcName">
										<xsl:element name="cardHolderName">
											<xsl:value-of select="trpCardInfo/trpcName"/>
										</xsl:element>
									</xsl:if>
									
									<xsl:element name="ccName">
										<xsl:choose>								
											<xsl:when test="trpCardInfo/@isAboveSite='true'">
												<xsl:value-of select="concat('^',trpCardInfo/trpcCCName)"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="trpCardInfo/trpcCCName"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:element>
									
									<xsl:if test="trpCardInfo/trpcSvcCode">
										<xsl:element name="svcCode">
											<xsl:value-of select="trpCardInfo/trpcSvcCode"/>
										</xsl:element>
									</xsl:if>
									<xsl:element name="exp">
										<xsl:value-of select="trpCardInfo/trpcExpire"/>
									</xsl:element>
									<xsl:element name="hostId">
										<xsl:value-of select="trpCardInfo/trpcHostID"/>
									</xsl:element>
									<xsl:element name="auth">
										<xsl:value-of select="trpCardInfo/trpcAuthCode"/>
									</xsl:element>
									<xsl:if test="trpCardInfo/trpcTicket">
										<xsl:element name="ticket">
											<xsl:value-of select="trpCardInfo/trpcTicket"/>
										</xsl:element>
									</xsl:if>
									<xsl:element name="entryMeth">
										<xsl:attribute name="type"><xsl:value-of select="jsc:xlateCardEntry(string(trpCardInfo/trpcEntryMeth))"/></xsl:attribute>
										<xsl:value-of select="trpCardInfo/trpcEntryMeth"/>
									</xsl:element>
									<xsl:element name="authSrc">
										<xsl:variable name="authSrc" select="trpCardInfo/trpcAuthSrc"/>
										<xsl:choose>
											<xsl:when test="$authSrc = 'I'">
												<xsl:text>interchange</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'H'">
												<xsl:text>host</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'T'">
												<xsl:text>terminal</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'V'">
												<xsl:text>voice</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'N'">
												<xsl:text>negFile</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'P'">
												<xsl:text>posFile</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'L'">
												<xsl:text>localNegFile</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'X'">
												<xsl:text>simulator</xsl:text>
											</xsl:when>
											<xsl:when test="$authSrc = 'A'">
												<xsl:text>authTable</xsl:text>
											</xsl:when>
											<xsl:otherwise>
												<xsl:text>simulator</xsl:text>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:element>
									<xsl:element name="batch">
										<xsl:value-of select="trpCardInfo/trpcBatchNr"/>
									</xsl:element>
									<xsl:element name="seq">
										<xsl:value-of select="trpCardInfo/trpcSeqNr"/>
									</xsl:element>
									<xsl:element name="ref">
										<xsl:value-of select="trpCardInfo/trpcRefNum"/>
									</xsl:element>
									<xsl:element name="merchId">
										<xsl:value-of select="trpCardInfo/trpcMerchInfo/trpcmMerchID"/>
									</xsl:element>
									<xsl:element name="termId">
										<xsl:value-of select="trpCardInfo/trpcMerchInfo/trpcmTermID"/>
									</xsl:element>
									<xsl:if test="trpCardInfo/trpcReplyMsg">
										<xsl:element name="replyMsg">
											<xsl:value-of select="trpCardInfo/trpcReplyMsg"/>
										</xsl:element>
									</xsl:if>
									<xsl:if test="trpCardInfo/trpcAuthDateTime">
										<xsl:element name="authDateTime">
											<xsl:value-of select="trpCardInfo/trpcAuthDateTime"/>
										</xsl:element>
									</xsl:if>
									<xsl:if test="trpCardInfo/trpcAcquirerBatchNr">
										<xsl:element name="acquirerBatch">
											<xsl:value-of select="trpCardInfo/trpcAcquirerBatchNr"/>
										</xsl:element>
									</xsl:if>
									<xsl:if test="trpCardInfo/Extension">
										<xsl:copy-of select="trpCardInfo/Extension"/>
									</xsl:if>
								</xsl:element>
							</xsl:if>
							<xsl:if test="trpHouseAcct">
								<xsl:element name="t:houseAcct">
									<xsl:element name="acct">
										<xsl:value-of select="trpHouseAcct"/>
									</xsl:element>
									<xsl:if test="trpHouseAcct/@name">
										<xsl:element name="name">
											<xsl:value-of select="trpHouseAcct/@name"/>
										</xsl:element>
									</xsl:if>
									<xsl:if test="trpHouseAcct/@subAccount">
										<xsl:element name="subAccount">
											<xsl:value-of select="trpHouseAcct/@subAccount"/>
										</xsl:element>
									</xsl:if>
								</xsl:element>
							</xsl:if>
							
							<xsl:if test="$cshBack">
								<xsl:choose>
									
									<xsl:when test="not(msxsl:node-set($cshBack)//trpPaycode) and trpPaycode/@cat = $ns:debitCat">
										<xsl:call-template name="ns:procCashback">
											<xsl:with-param name="cshBk" select="$cshBack"/>
											<xsl:with-param name="payline" select="."/>
										</xsl:call-template>
									</xsl:when>
									
									<xsl:when test="trpPaycode[@mop=msxsl:node-set($cshBack)//trpPaycode/@mop and @cat=msxsl:node-set($cshBack)//trpPaycode/@cat] and not(preceding-sibling::trPayline[trpPaycode/@mop=msxsl:node-set($cshBack)//trpPaycode/@mop and trpPaycode/@cat=msxsl:node-set($cshBack)//trpPaycode/@cat])">
										<xsl:call-template name="ns:procCashback">
											<xsl:with-param name="cshBk" select="$cshBack"/>
											<xsl:with-param name="payline" select="."/>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										
									</xsl:otherwise>
								</xsl:choose>
							</xsl:if>
							
							
							<xsl:if test="trpSigCap">
								<xsl:element name="sigCapture">
									<xsl:attribute name="mimeType"><xsl:value-of select="trpSigCap/@mime_type"/></xsl:attribute>
									<xsl:attribute name="reference"><xsl:value-of select="trpSigCap/@ref"/></xsl:attribute>
									<xsl:value-of select="trpSigCap"/>
								</xsl:element>
							</xsl:if>
							
						</xsl:element>
					</xsl:for-each>
				</xsl:element>
			</xsl:if>
			<xsl:element name="duration">
				<xsl:choose>
					<xsl:when test="trHeader/duration &lt; 0">
						<xsl:attribute name="error"><xsl:value-of select="trHeader/duration"/></xsl:attribute>
						<xsl:value-of select="0"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="trHeader/duration"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="sum">
				<xsl:element name="beforeTax">
					<xsl:call-template name="ns:currencyProc">
						<xsl:with-param name="location" select="trValue/trTotNoTax"/>
					</xsl:call-template>
				</xsl:element>
				
				<xsl:variable name="sumTaxTaxes">
					<xsl:choose>
						<xsl:when test="trValue/trTax/taxAmts/taxAmt">
							<xsl:for-each select="trValue/trTax/taxAmts/taxAmt">
								<xsl:variable name="cat" select="@cat"/>
								<xsl:element name="t:sumTax">
									<xsl:element name="vs:taxrateBase">
										<xsl:attribute name="sysid"><xsl:value-of select="@sysid"/></xsl:attribute>
										<xsl:element name="name">
											<xsl:value-of select="$cat"/>
										</xsl:element>
										<xsl:element name="taxRate">
											<xsl:value-of select="ancestor::taxAmts/taxRate[@cat = $cat]"/>
										</xsl:element>
									</xsl:element>
									<xsl:element name="amt">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="."/>
											<xsl:with-param name="value" select="ancestor::taxAmts/taxNet[@cat = $cat]"/>
										</xsl:call-template>
									</xsl:element>
									<xsl:element name="taxable">
										<xsl:call-template name="ns:currencyProc">
											<xsl:with-param name="location" select="."/>
										</xsl:call-template>
									</xsl:element>
									
									
									<xsl:if test="ancestor::taxAmts/taxForgiven[@cat = $cat] and ancestor::taxAmts/taxForgiven[@cat = $cat] != 0">
										
										<xsl:element name="forgivenTax">
											<xsl:call-template name="ns:currencyProc">
												<xsl:with-param name="location" select="."/>
												<xsl:with-param name="value" select="ancestor::taxAmts/taxForgiven[@cat = $cat]"/>
											</xsl:call-template>
										</xsl:element>
										<xsl:element name="forgivenAgainst">
											<xsl:call-template name="ns:currencyProc">
												<xsl:with-param name="location" select="."/>
												<xsl:with-param name="value" select="ancestor::taxAmts/taxForgivenAgainst[@cat = $cat]"/>
											</xsl:call-template>
										</xsl:element>
									</xsl:if>
									
									<xsl:if test="ancestor::taxAmts/taxExempt[@cat = $cat] and ancestor::taxAmts/taxExempt[@cat = $cat] != 0">
										
										<xsl:element name="exemptTax">
											<xsl:call-template name="ns:currencyProc">
												<xsl:with-param name="location" select="."/>
												<xsl:with-param name="value" select="ancestor::taxAmts/taxExempt[@cat = $cat]"/>
											</xsl:call-template>
										</xsl:element>
										<xsl:element name="exemptAgainst">
											<xsl:call-template name="ns:currencyProc">
												<xsl:with-param name="location" select="."/>
												<xsl:with-param name="value" select="ancestor::taxAmts/taxExemptAgainst[@cat = $cat]"/>
											</xsl:call-template>
										</xsl:element>
									</xsl:if>
									
									<xsl:if test="ancestor::taxAmts/taxableRebate[@cat = $cat] and ancestor::taxAmts/taxableRebate[@cat = $cat] != 0">
										<xsl:variable name="taxableRebates">
											<xsl:copy-of select="ancestor::taxAmts/taxableRebate[@cat=$cat]"/>
										</xsl:variable>
										<xsl:for-each select="msxsl:node-set($taxableRebates)/*">
											<xsl:element name="taxableRebate">
												<xsl:if test="@promoID">
													<xsl:attribute name="promoID"><xsl:value-of select="@promoID"/></xsl:attribute>
												</xsl:if>
												<xsl:call-template name="ns:currencyProc">
													<xsl:with-param name="location" select="."/>
													<xsl:with-param name="value" select="."/>
												</xsl:call-template>
											</xsl:element>
										</xsl:for-each>
									</xsl:if>
								</xsl:element>
								
							</xsl:for-each>
						</xsl:when>
						<xsl:when test="trValue/trTotTax != 0">
							<xsl:element name="t:sumTax">
								<xsl:element name="vs:taxrateBase">
									<xsl:element name="name">
										<xsl:value-of select="'UNKNOWN'"/>
									</xsl:element>
									<xsl:element name="taxRate">
										<xsl:value-of select="0"/>
									</xsl:element>
								</xsl:element>
								<xsl:element name="amt">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trValue/trTotTax"/>
									</xsl:call-template>
								</xsl:element>
							</xsl:element>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<xsl:copy-of select="msxsl:node-set($sumTaxTaxes)//t:sumTax"/>
				<xsl:copy-of select="msxsl:node-set($sumTaxTaxes)//t:sumTaxExempt"/>
				<xsl:for-each select="trLoyalty/trLoyaltyProgram">
					<xsl:element name="t:sumLoyalty">
						<xsl:element name="name">
							<xsl:if test="@programID">
								<xsl:value-of select="@programID"/>
							</xsl:if>
							<xsl:if test="@name">
								<xsl:value-of select="@name"/>
							</xsl:if>
						</xsl:element>
						<xsl:element name="loyaltyCardInfo">
							<xsl:element name="acct">
								<xsl:value-of select="trloAccount"/>
								
							</xsl:element>
							<xsl:element name="entryMeth">
								<xsl:attribute name="type"><xsl:value-of select="jsc:xlateCardEntry(string(trloEntryMeth))"/></xsl:attribute>
								<xsl:value-of select="trloEntryMeth"/>
							</xsl:element>
							<xsl:element name="auth">
								<xsl:value-of select="trloAuthReply"/>
								
							</xsl:element>
							<xsl:element name="type">
								<xsl:value-of select="trloTranType"/>
								
							</xsl:element>
						</xsl:element>
						<xsl:if test="trloCustDisc!=0 or trloAutoDisc!=0">
							<xsl:element name="loyaltyDiscounts">
								<xsl:if test="trloRefundFlg='1'">
									<xsl:attribute name="reversed"><xsl:value-of select="'true'"/></xsl:attribute>
								</xsl:if>
								<xsl:element name="custApproved">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trloCustDisc"/>
										<xsl:with-param name="value" select="trloCustDisc"/>
									</xsl:call-template>
								</xsl:element>
								<xsl:element name="autoApplied">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trloAutoDisc"/>
										<xsl:with-param name="value" select="trloAutoDisc"/>
									</xsl:call-template>
								</xsl:element>
								<xsl:element name="total">
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="trloAutoDisc | trloCustDisc"/>
										<xsl:with-param name="value" select="trloCustDisc + trloAutoDisc"/>
									</xsl:call-template>
								</xsl:element>
							</xsl:element>
						</xsl:if>
					</xsl:element>
				</xsl:for-each>
				
				<xsl:if test="trScannedCoupons">
					<xsl:element name="t:sumCoupons">
						<xsl:for-each select="trScannedCoupons/couponDisc | trScannedCoupons/trlCouponDisc">
							<xsl:element name="t:coupon">
								<xsl:element name="amt">
									<xsl:attribute name="affectsTax"><xsl:choose><xsl:when test="affectsTax = 'true'"><xsl:value-of select="'true'"/></xsl:when><xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise></xsl:choose></xsl:attribute>
									<xsl:call-template name="ns:currencyProc">
										<xsl:with-param name="location" select="."/>
										<xsl:with-param name="value" select="discountAmt"/>
									</xsl:call-template>
								</xsl:element>
								<xsl:element name="data">
									<xsl:attribute name="entryMeth"><xsl:choose><xsl:when test="entryMethod = 'SCAN_UPCA' or entryMethod = 'SCAN_EXTENDED' or entryMethod = 'SCAN_CHECKER' or entryMethod = 'SCAN_GS1'"><xsl:value-of select="'scanned'"/></xsl:when><xsl:otherwise><xsl:value-of select="'manual'"/></xsl:otherwise></xsl:choose></xsl:attribute>
									<xsl:value-of select="couponData"/>
								</xsl:element>
							</xsl:element>
						</xsl:for-each>
						<xsl:element name="amt">
							<xsl:call-template name="ns:currencyProc">
								<xsl:with-param name="location" select="."/>
								<xsl:with-param name="value" select="trScannedCoupons/couponDiscTotal"/>
							</xsl:call-template>
						</xsl:element>
					</xsl:element>
				</xsl:if>
				<xsl:element name="total">
					<xsl:choose>
						<xsl:when test="trValue/trCurrTot">
							<xsl:call-template name="ns:currencyProc">
								<xsl:with-param name="location" select="trValue/trCurrTot"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="0"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:element>
			<xsl:if test="not($lname = 'pumpTest')">
				<xsl:if test="trValue/custDOB">
					<xsl:element name="ageVerification">
							<xsl:attribute name="minAge"><xsl:value-of select="trValue/custDOB/@minAge"/></xsl:attribute>
							<xsl:attribute name="custAge"><xsl:value-of select="trValue/custDOB/@custAge"/></xsl:attribute>
							<xsl:attribute name="dobEntryMeth"><xsl:value-of select="trValue/custDOB/@dobEntryMeth"/></xsl:attribute>
							<xsl:attribute name="dob"><xsl:value-of select="trValue/custDOB/@dob"/></xsl:attribute>
						<xsl:choose>
							<xsl:when test="trValue/custDOB = 'SKIPID'">
								<xsl:value-of select="'SKIPPED'"/>
							</xsl:when>
							<xsl:when test="trValue/custDOB = 'PASSED'">
								<xsl:value-of select="'PASSED'"/>
							</xsl:when>
							<xsl:when test="trValue/custDOB = 'FAILED'">
								<xsl:value-of select="'FAILED'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="jsc:old2NewDate(string(trValue/custDOB))"/>								
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
				</xsl:if>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:eventProc">
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:variable name="lname">
			<xsl:choose>
				<xsl:when test="trJournal/trjText/@type = 'RECEIPT PRINTED'">
					<xsl:value-of select="'t:printEvent'"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'t:event'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:element name="{$lname}">
			<xsl:if test="$lname != 't:printEvent'">
				<xsl:attribute name="type"><xsl:choose><xsl:when test="trJournal/trjText/@type = 'SYSTEM STARTUP'"><xsl:value-of select="'startup'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'PERIOD CLOSE'"><xsl:value-of select="'periodClose'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'FILE CHANGE'"><xsl:value-of select="'fileChange'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'FILE DOWNLOAD'"><xsl:value-of select="'fileDownload'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'LOGIN/LOGOUT'"><xsl:value-of select="'loginLogout'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'ERROR CORRECT'"><xsl:value-of select="'errorCorrect'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'PRINTER MESSAGE'"><xsl:value-of select="'printer'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'SAFE DROP EVENT'"><xsl:choose><xsl:when test="starts-with(trJournal/trjText,'Exiting Safe Drop w/o Doing Drop')"><xsl:value-of select="'safeDropCancel'"/></xsl:when><xsl:otherwise><xsl:value-of select="'safeDrop'"/></xsl:otherwise></xsl:choose></xsl:when><xsl:when test="trJournal/trjText/@type = 'MONEY ORDER'"><xsl:value-of select="'moneyOrder'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'DCR EVENT'"><xsl:value-of select="'dcr'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'FUEL EVENT'"><xsl:choose><xsl:when test="starts-with(trJournal/trjText,'STOP RESERVED')"><xsl:value-of select="'fuelPrepaidCancel'"/></xsl:when><xsl:otherwise><xsl:value-of select="'fuel'"/></xsl:otherwise></xsl:choose></xsl:when><xsl:when test="trJournal/trjText/@type = 'DRAWER ALARM'"><xsl:value-of select="'drawerAlarm'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'OTHER'"><xsl:value-of select="'other'"/></xsl:when><xsl:when test="trJournal/@type = 'OTHER'"><xsl:value-of select="'other'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'TRANSACTION EVENT'"><xsl:value-of select="'fuel'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'NETWORK ERROR'"><xsl:value-of select="'network'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'FUEL APPROVAL'"><xsl:value-of select="'fuel'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'PREPAID EVENT'"><xsl:value-of select="'prepaidCard'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'EBT VOUCHER CLEAR'"><xsl:value-of select="'ebtVoucherClear'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'SECURE USER'"><xsl:value-of select="'secureUser'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'ESAFE CONTENT EVENT'"><xsl:value-of select="'eSafeContent'"/></xsl:when><xsl:when test="@type = 'fuelpriceChange'"><xsl:value-of select="'fuel'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'PRICE CHECK'"><xsl:value-of select="'priceCheckCancel'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'CAR WASH DEVICE STATUS EVENT'"><xsl:value-of select="'cwDeviceStatus'"/></xsl:when><xsl:when test="trJournal/trjText/@type = 'EPS MESSAGE'"><xsl:value-of select="'epsMsg'"/></xsl:when><xsl:otherwise><xsl:value-of select="trJournal/trjText/@type"/></xsl:otherwise></xsl:choose></xsl:attribute>
			</xsl:if>
			<xsl:element name="hdr">
				<xsl:call-template name="ns:tlogEntryHeaderType">
					<xsl:with-param name="site" select="$site"/>
					<xsl:with-param name="busDate" select="$busDate"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:if test="trHeader/cashier">
				<xsl:call-template name="ns:cashierElem"/>
			</xsl:if>
			<xsl:element name="text">
				
				<xsl:choose>
					<xsl:when test="trJournal/@type = 'OTHER'">
						<xsl:value-of select="trJournal"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="trJournal/trjText"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:if test="trJournal/trjText/@type = 'FUEL EVENT' and starts-with(trJournal/trjText,'STOP RESERVED')">
				<xsl:element name="t:fuelPrepay">
					<xsl:element name="pos">
						<xsl:value-of select="jsc:getPrepaidCancelFP(string(trJournal/trjText))"/>
					</xsl:element>
					<xsl:element name="amt">
						
						<xsl:value-of select="format-number(jsc:getDecimalValue(string(trJournal/trjText)),'#.00')"/>
					</xsl:element>
				</xsl:element>
			</xsl:if>
			
			<xsl:element name="marker"/>
			
			<xsl:if test="trPriceChange">
				<xsl:copy-of select="trPriceChange"/>
			</xsl:if>
			<xsl:if test="trJournal/priceCheckCancelItem">
				<xsl:copy-of select="trJournal/priceCheckCancelItem"/>
			</xsl:if>
			<xsl:if test="trJournal/trLine">
				<xsl:copy-of select="trJournal/trLine"/>
			</xsl:if>
			<xsl:if test="trJournal/ppdFunction">
				<xsl:copy-of select="trJournal/ppdFunction"/>
			</xsl:if>
			<xsl:if test="trJournal/trPayline">
				<xsl:copy-of select="trJournal/trPayline"/>
			</xsl:if>
			<xsl:if test="trJournal/contentData ">
				<xsl:copy-of select="trJournal[trjText/@type = 'ESAFE CONTENT EVENT']/contentData "/>
			</xsl:if>
			<xsl:if test="$lname = 't:printEvent'">
				<xsl:element name="printInfo">
					<xsl:element name="vs:transactionSeq">
						<xsl:value-of select="trJournal/trjTicketNum"/>
					</xsl:element>
					<xsl:element name="count">
						<xsl:choose>
							<xsl:when test="trJournal/trjPrintCount">
								<xsl:value-of select="trJournal/trjPrintCount"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'1'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:element>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:currencyProc">
		<xsl:param name="location"/>
		<xsl:param name="value"/>
		<xsl:param name="mask"/>
		<xsl:variable name="currency">
			<xsl:choose>
				<xsl:when test="$location/@locale">
					<xsl:value-of select="$location/@locale"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$location/ancestor::*/trValue/trCurrTot/@locale"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="not($currency = 'USD' or $currency = '')">
			<xsl:attribute name="currency"><xsl:value-of select="$currency"/></xsl:attribute>
		</xsl:if>
		<xsl:variable name="val">
			<xsl:choose>
				<xsl:when test="$value != '0' and not($value) ">
					<xsl:value-of select="$location"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="msk">
			<xsl:choose>
				<xsl:when test="not($mask)">
					<xsl:value-of select="$ns:currencyMask"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$mask"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="format-number($val,$msk)"/>
	</xsl:template>
	<xsl:template name="ns:uomProc">
		<xsl:param name="location"/>
		<xsl:param name="value"/>
		<xsl:param name="mask"/>
		<xsl:copy-of select="$location/@uom"/>
		<xsl:variable name="val">
			<xsl:choose>
				<xsl:when test="not($value)">
					<xsl:value-of select="$location"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="msk">
			<xsl:choose>
				<xsl:when test="not($mask)">
					<xsl:value-of select="$ns:uomMask"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$mask"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="format-number($val,$msk)"/>
	</xsl:template>
	
	<xsl:template name="ns:procCashback">
		<xsl:param name="cshBk"/>
		<xsl:param name="payline"/>
		<xsl:element name="cashback">
			<xsl:element name="amt">
				<xsl:choose>
					
					<xsl:when test="msxsl:node-set($cshBk)/trCshBkCancel">
						<xsl:call-template name="ns:currencyProc">
							<xsl:with-param name="location" select="$payline"/>
							<xsl:with-param name="value" select="msxsl:node-set($cshBk)/trCshBkCancel"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="ns:currencyProc">
							<xsl:with-param name="location" select="$payline"/>
							<xsl:with-param name="value" select="msxsl:node-set($cshBk)/trCshBkAmt"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:if test="msxsl:node-set($cshBk)/trCshBkFee">
				<xsl:element name="fee">
					<xsl:call-template name="ns:currencyProc">
						<xsl:with-param name="location" select="$payline"/>
						<xsl:with-param name="value" select="msxsl:node-set($cshBk)/trCshBkFee"/>
					</xsl:call-template>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	
	
	<xsl:template name="ns:mwsEventsProc">
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:param name="mwsEventName"/>
		<xsl:param name="eventType"/>
		<xsl:element name="t:managerWSEvent">
			<xsl:element name="hdr">
				<xsl:call-template name="ns:tlogEntryHeaderType">
					<xsl:with-param name="site" select="$site"/>
					<xsl:with-param name="busDate" select="$busDate"/>
					<xsl:with-param name="device" select="'mws'"/>
				</xsl:call-template>
			</xsl:element>
			<xsl:choose>
				<xsl:when test="$mwsEventName = 'mwsMgrCorrectionEvent'">
					<xsl:call-template name="ns:handleMWSCorrectionEvents">
						<xsl:with-param name="site" select="trHeader/storeNumber"/>
						<xsl:with-param name="busDate" select="trHeader/date"/>
						<xsl:with-param name="correctedBy" select="trHeader/user"/>
						<xsl:with-param name="correctedCashier" select="correctedCashier"/>
						<xsl:with-param name="correctionsList" select="corrections"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$mwsEventName = 'mwsMgrAcceptedEvent'">
					<xsl:call-template name="ns:handleMWSAcceptEvents">
						<xsl:with-param name="busDate" select="trHeader/date"/>
						<xsl:with-param name="acceptedBy" select="trHeader/user"/>
						<xsl:with-param name="autoApproved" select="autoApproved"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$mwsEventName = 'mwsMgrFinalizeEvent'">
					<xsl:call-template name="ns:handleMWSFinalizeEvents">
						<xsl:with-param name="busDate" select="trHeader/date"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$mwsEventName = 'mwsMgrReviewEvent'">
					<xsl:call-template name="ns:handleMWSReviewEvents">
						<xsl:with-param name="busDate" select="trHeader/date"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$mwsEventName = 'mwsMgrAdjustmentEvent'">
					<xsl:call-template name="ns:handleMWSAdjustmentEvents">
						<xsl:with-param name="site" select="trHeader/storeNumber"/>
						<xsl:with-param name="cashier" select="trHeader/cashier"/>
						<xsl:with-param name="eventType" select="$eventType"/>
						<xsl:with-param name="busDate" select="trHeader/date"/>
						<xsl:with-param name="adjustedBy" select="trHeader/user"/>
						<xsl:with-param name="adjustedCashier" select="adjustedCashier"/>
						<xsl:with-param name="trMiscRefNum" select="trHeader/trMiscRefNum"/>
						<xsl:with-param name="refNum" select="trHeader/trHouseAcct"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$mwsEventName = 'mwsMgrVerifiedCsrPds'">
					<xsl:call-template name="ns:handleMWSverifiedCSRPdEvents">
						<xsl:with-param name="busDate" select="trHeader/date"/>
						<xsl:with-param name="verifiedBy" select="trHeader/user"/>
						<xsl:with-param name="cashier" select="trHeader/cashier"/>
						<xsl:with-param name="verfiedCSRPeriod" select="mgrVerifiedCsrPd"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:handleMWSverifiedCSRPdEvents">
		<xsl:param name="busDate"/>
		<xsl:param name="verifiedBy"/>
		<xsl:param name="cashier"/>
		<xsl:param name="verfiedCSRPeriod"/>
		<xsl:call-template name="ns:mwsCashierProc">
			<xsl:with-param name="cashier" select="$verifiedBy"/>
		</xsl:call-template>
		<xsl:element name="verifiedCSRperiodInfo">
			<xsl:call-template name="ns:mwsCashierProc">
				<xsl:with-param name="cashier" select="$verfiedCSRPeriod"/>
			</xsl:call-template>
			<xsl:element name="eventdate">
				<xsl:value-of select="$busDate"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:handleMWSAdjustmentEvents">
		<xsl:param name="adjustedBy"/>
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:param name="adjustedCashier"/>
		<xsl:param name="eventType"/>
		<xsl:param name="trMiscRefNum"/>
		<xsl:param name="cashier"/>
		<xsl:param name="refNum"/>
		<xsl:call-template name="ns:mwsCashierProc">
			<xsl:with-param name="cashier" select="$adjustedBy"/>
		</xsl:call-template>
		<xsl:element name="adjustmentCSRPeriodInfo">
			<xsl:element name="adjustmentCSRInfo">
				<xsl:attribute name="type"><xsl:value-of select="$eventType"/></xsl:attribute>
				<xsl:call-template name="ns:mwsCashierProc">
					<xsl:with-param name="cashier" select="$adjustedCashier"/>
				</xsl:call-template>
				<xsl:element name="eventDate">
					<xsl:value-of select="$busDate"/>
				</xsl:element>
				<xsl:element name="adjustedAmount">
					<xsl:attribute name="currency"><xsl:value-of select="amount/@locale"/></xsl:attribute>
					<xsl:value-of select="amount"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="miscRefNo">
				<xsl:value-of select="$trMiscRefNum"/>
			</xsl:element>
			<xsl:element name="houseAccount">
				<xsl:element name="Acct">
					<xsl:value-of select="$refNum"/>
				</xsl:element>
				<xsl:if test="$refNum/@name">
					<xsl:element name="name">
						<xsl:value-of select="$refNum/@name"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="$refNum/@subAccount">
					<xsl:element name="subAccount">
						<xsl:value-of select="$refNum/@subAccount"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:handleMWSCorrectionEvents">
		<xsl:param name="correctedBy"/>
		<xsl:param name="site"/>
		<xsl:param name="busDate"/>
		<xsl:param name="correctedCashier"/>
		<xsl:param name="correctionsList"/>
		<xsl:call-template name="ns:mwsCashierProc">
			<xsl:with-param name="cashier" select="$correctedBy"/>
		</xsl:call-template>
		<xsl:element name="correctionCSRPeriodInfo">
			<xsl:element name="correctionCSRInfo">
				<xsl:call-template name="ns:mwsCashierProc">
					<xsl:with-param name="cashier" select="$correctedCashier"/>
				</xsl:call-template>
				<xsl:element name="eventDate">
					<xsl:value-of select="$busDate"/>
				</xsl:element>
				
				<xsl:element name="corrections">
					<xsl:call-template name="ns:paymentinfoproc">
						<xsl:with-param name="safeBeginAmount" select="$correctionsList"/>
					</xsl:call-template>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:handleMWSReviewEvents">
		<xsl:param name="busDate"/>
		<xsl:call-template name="ns:mwsCashierProc">
			<xsl:with-param name="cashier" select="trHeader/user"/>
		</xsl:call-template>
		<xsl:element name="mgrReviewAction">
			<xsl:call-template name="ns:gatherPeriodInfo">
				<xsl:with-param name="periodSeqNum" select="periodSeq"/>
				<xsl:with-param name="periodType" select="periodType"/>
				<xsl:with-param name="periodEndDate" select="periodCloseDate"/>
			</xsl:call-template>
			<xsl:element name="reviewCashierStatus">
				<xsl:choose>
					<xsl:when test="reviewCashierStatus = 1">
						<xsl:value-of select="true()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="finalizeStatus">
				<xsl:choose>
					<xsl:when test="finalizeStatus = 1">
						<xsl:value-of select="true()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="acceptDailyStatus">
				<xsl:choose>
					<xsl:when test="acceptDailyStatus = 1">
						<xsl:value-of select="true()"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="false()"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:handleMWSFinalizeEvents">
		<xsl:param name="busDate"/>
		<xsl:call-template name="ns:mwsCashierProc">
			<xsl:with-param name="cashier" select="trHeader/user"/>
		</xsl:call-template>
		<xsl:element name="mgrFinalizeAction">
			<xsl:call-template name="ns:gatherPeriodInfo">
				<xsl:with-param name="periodSeqNum" select="periodSeq"/>
				<xsl:with-param name="periodType" select="periodType"/>
				<xsl:with-param name="periodEndDate" select="periodCloseDate"/>
			</xsl:call-template>
			<xsl:element name="depositamount">
				<xsl:attribute name="currency"><xsl:value-of select="depositAmount/@locale"/></xsl:attribute>
				<xsl:value-of select="depositAmount"/>
			</xsl:element>
			<xsl:element name="depositbagrefinfo">
				<xsl:value-of select="depositBagRef"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:handleMWSAcceptEvents">
		<xsl:param name="busDate"/>
		<xsl:param name="acceptedBy"/>
		<xsl:param name="autoApproved"/>
		<xsl:call-template name="ns:mwsCashierProc">
			<xsl:with-param name="cashier" select="$acceptedBy"/>
		</xsl:call-template>
		<xsl:element name="mgrAcceptAction">
			<xsl:call-template name="ns:gatherPeriodInfo">
				<xsl:with-param name="periodSeqNum" select="periodSeq"/>
				<xsl:with-param name="periodType" select="periodType"/>
				<xsl:with-param name="periodEndDate" select="periodCloseDate"/>
			</xsl:call-template>
			<xsl:choose>
				<xsl:when test="$autoApproved">
					<xsl:element name="autoApproved">
						<xsl:choose>
							<xsl:when test="$autoApproved = 1">
								<xsl:value-of select="true()"/>
							</xsl:when>
							<xsl:otherwise/>
						</xsl:choose>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>					
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:mwsCashierProc">
		<xsl:param name="cashier"/>
		<xsl:element name="t:cashier">
			<xsl:variable name="sysid">
				<xsl:choose>
					<xsl:when test="$cashier/@sysid">
						<xsl:value-of select="$cashier/@sysid"/>
					</xsl:when>
					<xsl:otherwise>0</xsl:otherwise>
					
				</xsl:choose>
			</xsl:variable>
			<xsl:attribute name="sysid"><xsl:value-of select="$sysid"/></xsl:attribute>
			<xsl:choose>
				<xsl:when test="$cashier/@empNum">
					<xsl:attribute name="number"><xsl:value-of select="$cashier/@empNum"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			
			<xsl:variable name="cashierName">
				<xsl:choose>
					<xsl:when test="$cashier/name">
						<xsl:value-of select="$cashier/name"/>
						
					</xsl:when>
					<xsl:otherwise>unknown</xsl:otherwise>
					
				</xsl:choose>
			</xsl:variable>
			<xsl:element name="name">
				<xsl:value-of select="$cashier"/>
			</xsl:element>
			<xsl:choose>
				<xsl:when test="$cashier/@period">
					<xsl:element name="period">
						<xsl:value-of select="$cashier/@period"/>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$cashier/@closeDate">
					<xsl:element name="closeDate">
						<xsl:value-of select="$cashier/@closeDate"/>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$cashier/@openDate">
					<xsl:element name="openDate">
						<xsl:value-of select="$cashier/@openDate"/>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:gatherPeriodInfo">
		<xsl:param name="sysid"/>
		<xsl:param name="periodSeqNum"/>
		<xsl:param name="periodType"/>
		<xsl:param name="periodEndDate"/>
		<xsl:param name="periodBeginDate"/>
		<xsl:param name="name"/>
		<xsl:param name="isFirst"/>
		<xsl:param name="isLast"/>
		<xsl:element name="vs:period">
			<xsl:choose>
				<xsl:when test="$sysid">
					<xsl:attribute name="sysid"><xsl:value-of select="$sysid"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$periodEndDate">
					<xsl:attribute name="periodEndDate"><xsl:value-of select="$periodEndDate"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$periodSeqNum">
					<xsl:attribute name="periodSeqNum"><xsl:value-of select="$periodSeqNum"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$periodType = '1'">
					<xsl:attribute name="periodType"><xsl:text>SHIFT</xsl:text></xsl:attribute>
				</xsl:when>
				<xsl:when test="$periodType = '2'">
					<xsl:attribute name="periodType"><xsl:text>DAY</xsl:text></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$periodBeginDate">
					<xsl:attribute name="periodBeginDate"><xsl:value-of select="$periodBeginDate"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$name">
					<xsl:attribute name="name"><xsl:value-of select="$name"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$isFirst">
					<xsl:attribute name="isFirst"><xsl:value-of select="$isFirst"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$isLast">
					<xsl:attribute name="isLast"><xsl:value-of select="$isLast"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="ns:paymentinfoproc">
		<xsl:param name="safeBeginAmount"/>
		<xsl:for-each select="$safeBeginAmount">
			<xsl:element name="t:mop">
				<xsl:choose>
					<xsl:when test="paymentName/@mop">
						<xsl:attribute name="sysid"><xsl:value-of select="paymentName/@mop"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="paymentName/@cat">
						<xsl:attribute name="cat"><xsl:value-of select="paymentName/@cat"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="paymentName/@nacstendercode">
						<xsl:attribute name="nacstendercode"><xsl:value-of select="paymentName/@nacstendercode"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
				<xsl:choose>
					<xsl:when test="paymentName/@nacstendersubcode">
						<xsl:attribute name="nacstendersubcode"><xsl:value-of select="paymentName/@nacstendersubcode"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise/>
				</xsl:choose>
				<xsl:element name="name">
					<xsl:value-of select="paymentName"/>
				</xsl:element>
			</xsl:element>
			<xsl:element name="amount">
				<xsl:attribute name="currency"><xsl:value-of select="amount/@locale"/></xsl:attribute>
				<xsl:value-of select="amount"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>