<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:msxsl="urn:schemas-microsoft-com:xslt"
xmlns:js="javascript:code-transactionSet-scripts"  
xmlns:dts="javascript:code-transactionSet-dateTimeScripts"  
>
	<xsl:import href="../transactionSet/scripts.xslt"/>
	<!--
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	-->
	
	<msxsl:script language="javascript" implements-prefix="dts"><![CDATA[
		function parseDate(timeDateStr) {
			var ix = timeDateStr.indexOf('T');
			if (ix != -1)
				timeDateStr = timeDateStr.substring(0,ix);
			return timeDateStr;
		}
		
		function parseTime(timeDateStr) {
			var ix = timeDateStr.indexOf('T');
			if (ix ==  -1) ix = 0;
			var ix1 = timeDateStr.indexOf('-',ix+1);
			if (ix1 == -1) ix1 = timeDateStr.length;
			timeDateStr = timeDateStr.substring(ix+1,ix1);
			return timeDateStr;
		}

		/*
		 * function to increment a date/time string by a given number of 
		 * seconds.
		 * callable from a stylesheet
		 */
		function incrementDateTime(timeDateStr,secs) {
			if(secs < 0){
				secs = 0;
			}

			if (timeDateStr.length < 19){
				return "1979-12-31T00:00:00";
			}
				
			var date = parseDate(timeDateStr);
			var time = parseTime(timeDateStr);

			var ix0 = 0;			
			var ix1 = date.indexOf('-',ix0);
			if (ix1 < 0) ix1 = 0;
			var yr = date.substring(ix0,ix1);
			
			ix0 = ix1+1;
			ix1 = date.indexOf('-',ix0);
			if (ix1 < 0) ix1 = 0;
			var mo = date.substring(ix0,ix1);
			
			ix0 = ix1+1;
			ix1 = date.length;
			if (ix1 < 0) ix1 = 0;
			var da = date.substring(ix0,ix1);
			
			ix0 = 0;
			ix1 = time.indexOf(':',ix0);
			if (ix1 < 0) ix1 = 0;
			var hr = time.substring(ix0,ix1);

			ix0 = ix1+1;
			ix1 = time.indexOf(':',ix0);
			if (ix1 < 0) ix1 = 0;
			var mi = time.substring(ix0,ix1);

			ix0 = ix1+1;
			ix1 = time.length;
			if (ix1 < 0) ix1 = 0;
			var se = time.substring(ix0,ix1);
			se = (se*1) + (secs*1);
			return IsiNormalizeSecond(yr,mo,da,hr,mi,se);
		}
				
		/*
		 * the following functions are defined in XML Schema 1.1
		 * generally, these are not called from a stylesheet
		 */
		function IsiNormalizeSecond(yr,mo,da,hr,mi,se) {
			mi = (mi * 1) + Math.floor(se / 60);
			se %= 60;	
			var str = normalizeMinute(yr,mo,da,hr,mi);
			return str+':'+twoDigit(se);
		}
		
		function normalizeMinute(yr,mo,da,hr,mi) {
			hr = (hr * 1) + Math.floor(mi / 60);
			mi %= 60;
			da = (da * 1) + Math.floor(hr / 24);
			hr %= 24; 
			var str = normalizeDay(yr,mo,da);
			hr = twoDigit(hr);
			mi = twoDigit(mi);
			return str+'T'+hr+':'+mi;
		}
		
		function normalizeDay(yr,mo,da) {			
			if (da <= 0){
				da = 1;
			}
			for (;;) {
				var str = normalizeMonth(yr,mo);
				var ix0 = 0;
				var ix1 = str.indexOf('-');
				if (ix1 == -1) ix1 = str.length;
				yr = str.substring(ix0,ix1);
				ix0 = ix1+1;
				ix1 = str.length;
				mo = str.substring(ix0,ix1);
				
				var dimo = daysInMonth(yr,mo);
				if (da > 0 && da <= dimo)
					break;
				mo++;
				da -= dimo;
			}
			mo = twoDigit(mo);
			da = twoDigit(da);
			return yr+'-'+mo+'-'+da;
		}
		
		function normalizeMonth(yr,mo) {
			yr = (yr*1) + Math.floor((mo - 1) / 12);
			mo = (mo-1) % 12;
			mo++;
			return yr+'-'+twoDigit(mo);
		}
		
		function daysInMonth(yr,mo) {
			var val = 0;
			if (mo == 1 || mo == 3 || mo == 5 || mo == 7 || mo == 8 || mo == 10 || mo == 12) {
				val = 31;
			} else {
				if (mo != 2) {
					val = 30;
				} else {
					if ( ((yr % 4) == 0) && ( ((yr % 100) != 0) || ((yr % 400) == 0) ) ) {
						val = 29;
					} else {
						val = 28;
					}
				}
			}
			return val;
		}
		
		/* end XML Schema 1.1 functions */
		
		function twoDigit(n) {
			if (n < 10)
				n = '0' + (n*1);
			return n;
		}	

]]></msxsl:script>

</xsl:stylesheet>
